package fr.unedic.cali.asu.asr.antecedent;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.asr.liquidation.outilsfonctionnels.DeterminationDateLimiteIndemnisation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDonneesDeterminationSjr;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSjrSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Antecedent;
import fr.unedic.cali.asu.produits.liquidation.dom.Competence;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionAge;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientSaisonnier;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientTempsPartiel;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDateAttribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.PrcSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.ResultatDeterminationDateLimiteIndemnisation;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.Metier;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.Retraite;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public abstract class GrapheAntecedent
  extends fr.unedic.cali.asu.antecedent.GrapheAntecedent
{
  private static final BigDecimal COEFFICIENT_ARE2011 = new BigDecimal("1");
  
  protected void initialiserDossierExamen(Demande p_demande)
    throws CoucheLogiqueException
  {
    p_demande.getDossierAffectation().setDossierExamen(new Antecedent());
  }
  
  protected void alimenterConditionsAdmission(Demande p_demande)
    throws CoucheLogiqueException
  {
    SaisieAntecedent saisieAntecedent = p_demande.getSaisieAntecedent();
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierExamen();
    
    alimenterConditionFaitGenerateur(dossierExamen, saisieAntecedent);
    
    alimenterConditionAge(dossierExamen);
  }
  
  protected void alimenterConditionFaitGenerateur(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    IndividuSpec demandeur = p_dossierExamen.getDemande().getDemandeur();
    ConditionFaitGenerateur conditionFaitGenerateur = p_dossierExamen.createConditionFaitGenerateur();
    
    String identifiantFaitGenerateur = p_saisieAntecedent.getIdentifiantFaitGenerateur();
    ActiviteSalarie periodeFaitGenerateur = (ActiviteSalarie)demandeur.rechercherPeriodePasseProfessionnel(identifiantFaitGenerateur);
    
    conditionFaitGenerateur.setPeriodeFaitGenerateur(periodeFaitGenerateur);
    conditionFaitGenerateur.setAgeIndividuDateFG(demandeur.getAgeALaDate(periodeFaitGenerateur.getDateFin()));
    conditionFaitGenerateur.setEtatSatisfait(true);
  }
  
  protected void alimenterConditionAge(DossierExamen p_dossierExamen)
    throws CoucheLogiqueException
  {
    IndividuSpec demandeur = p_dossierExamen.getDemande().getDemandeur();
    ConditionAge conditionAge = p_dossierExamen.getConditionsAttributionAdmission().createConditionAge();
    
    Damj dateEffetTheoriquePensionRetraite = OutilRetraite.getInstance().determinerRetraite(demandeur).getDate();
    conditionAge.setDateEffetPension(dateEffetTheoriquePensionRetraite);
  }
  
  protected void alimenterConstituantsAdmission(Demande p_demande)
    throws CoucheLogiqueException
  {
    SaisieAntecedent saisieAntecedent = p_demande.getSaisieAntecedent();
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierExamen();
    
    alimenterConstitutionDateAttribution(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionReglementApplicable(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionSjr(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionSjc(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionCoefficientTempsPartiel(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionCoefficientSaisonnier(dossierExamen, saisieAntecedent);
    
    alimenterDateLimiteIndemnisation(dossierExamen, p_demande);
    
    alimenterConstitutionDurees(dossierExamen, saisieAntecedent);
    
    Competence competence = new Competence();
    dossierExamen.setCompetence(competence);
    alimenterCompetence((Demande)dossierExamen.getDemande(), competence, saisieAntecedent);
    
    alimenterConstitutionMontantBrut(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionProduitResultant(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionDelais(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionPointDeDepart(dossierExamen, saisieAntecedent);
  }
  
  protected void alimenterConstitutionCoefficientSaisonnier(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    ConstitutionCoefficientSaisonnier constitutionCoefficientSaisonnier = p_dossierExamen.createConstitutionCoefficientSaisonnier();
    
    constitutionCoefficientSaisonnier.setCoefficientSaisonnierRetenu(COEFFICIENT_ARE2011);
    
    constitutionCoefficientSaisonnier.setJourActiviteDouzeDerniersMois(null);
  }
  
  protected void alimenterConstitutionDateAttribution(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    ConstitutionDateAttribution constitutionDateAttribution = p_dossierExamen.createConstitutionDateAttribution();
    
    Damj dateAttribution = p_saisieAntecedent.getDateAttribution();
    
    constitutionDateAttribution.setDateAttribution(dateAttribution);
  }
  
  protected void alimenterConstitutionReglementApplicable(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    ReglementApplicableSpec constitutionReglementApplicable = p_dossierExamen.createConstitutionReglementApplicable();
    
    Reglement reglement = ((ActiviteSalarie)((DossierAffectation)p_dossierExamen.getDemande().getDossierAffectation()).getSinistre()).getReglement();
    
    constitutionReglementApplicable.setReglement(reglement);
  }
  
  protected void alimenterConstitutionSjr(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    ConstitutionSjr constitutionSjr = p_dossierExamen.createConstitutionSjr();
    Sjrip sjrip = constitutionSjr.createSjrip();
    DonneesEntreeDeterminationSjrSpec donneesEntree = OutilDonneesDeterminationSjr.getInstance().initialiserDonneesEntreeAvecProduit();
    
    ProduitAsuSpec produitCourant = (ProduitAsuSpec)p_dossierExamen.getDossierAffecte().getProduit();
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOfSjr = (FabriqueOutilFonctionnelDeterminationSjrSpec)produitCourant.determinerFabriqueOutilFonctionnelDeterminationSjr(((Demande)p_dossierExamen.getDemande()).getDateFaitGenerateurOuDernierSinistre());
    
    Integer codeEmploiA2b = p_saisieAntecedent.getCodeEmploiA2B();
    Damj termePRC = p_saisieAntecedent.getTermePRC();
    Damj debutPrc = p_saisieAntecedent.getDateDebutPRC();
    Quantite sjrPlafonne = p_saisieAntecedent.getSalaireJournalierReferencePlafonne();
    if ((codeEmploiA2b != null) && (codeEmploiA2b.intValue() != 0))
    {
      termePRC = p_saisieAntecedent.getPeriodeFctRetenue().getDateFin();
      debutPrc = termePRC;
      DonneesEntreeDeterminationSjrSpec donneesEntreeA2b = OutilDonneesDeterminationSjr.getInstance().initialiserDonneesEntreeAvecDemandeEtProduit((Demande)p_dossierExamen.getDemande());
      
      DonneesResultatDeterminationSjr resultat = fabriqueOfSjr.getOutilDeterminationSjr().determinerSjripPourA2B(donneesEntreeA2b);
      sjrPlafonne = new QuantiteEuro(resultat.getSjri());
    }
    boolean topRemunerationBaseSMIC = p_saisieAntecedent.isSalaireReferenceSurBaseSMIC();
    if (p_saisieAntecedent.getCodeEmploiA2B() != null) {
      constitutionSjr.setCodeEmploiA2b(codeEmploiA2b.intValue());
    }
    PrcSjr prcSjr = new PrcSjr(new Periode(debutPrc, termePRC));
    sjrip.setPrc(prcSjr);
    sjrip.setDateEvenement(termePRC);
    
    BigDecimal plafondSjr = fabriqueOfSjr.getOutilDeterminationSjr().determinerPlafondSjr(termePRC, donneesEntree);
    sjrip.setPlafondSjr(new QuantiteEuro(plafondSjr));
    sjrip.setSjrInitial(new QuantiteEuro(sjrPlafonne.getValeur()));
    constitutionSjr.getSjrip().getPrc().setTopContratsDeTypeParticulier(topRemunerationBaseSMIC);
    constitutionSjr.setSjrrp(new Sjr(sjrPlafonne.getValeur()));
    
    constitutionSjr.setSjnpr(null);
    prcSjr.setDiviseur(null);
  }
  
  protected void alimenterConstitutionSjc(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    ConstitutionSjc constitutionSjc = p_dossierExamen.createConstitutionSjc();
    constitutionSjc.createSjcip();
    constitutionSjc.getSjcip().setSjcInitial(new QuantiteEuro("0"));
    constitutionSjc.getSjcip().setDateEvenement(Damj.NUIT_DES_TEMPS);
    
    determinerListeActiviteConservees(p_dossierExamen, p_saisieAntecedent);
  }
  
  private void determinerListeActiviteConservees(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)p_dossierExamen.getDossierAffecte().getProduit();
    
    Damj dateExamen = p_dossierExamen.getDemande().getDateExamen();
    
    Damj dateExamenRechercheActiviteConservees = p_saisieAntecedent.getDateAttribution();
    p_dossierExamen.getDemande().getEvenementReferenceExamen().setDateEvenement(dateExamenRechercheActiviteConservees);
    
    produit.recalculerActivitesConserveesPourDemandeMigree(p_dossierExamen.getDemande());
    
    p_dossierExamen.getDemande().getEvenementReferenceExamen().setDateEvenement(dateExamen);
  }
  
  protected void alimenterConstitutionCoefficientTempsPartiel(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    ConstitutionCoefficientTempsPartiel constitutionCoefficientTempsPartiel = p_dossierExamen.getConstitutionElementsActifs().createConstitutionCoefficientTempsPartiel();
    
    BigDecimal coefficientTempsPartiel = p_saisieAntecedent.getCoefficientTempsPartiel();
    if (coefficientTempsPartiel == null) {
      coefficientTempsPartiel = new BigDecimal("1");
    }
    constitutionCoefficientTempsPartiel.setCoefficientTempsPartielRetenu(coefficientTempsPartiel);
  }
  
  protected void alimenterDateLimiteIndemnisation(DossierExamen p_dossierExamen, Demande p_demande)
    throws CoucheLogiqueException
  {
    ConstitutionDateLimiteIndemnisation dateLimiteIndemnisation = p_dossierExamen.getConstitutionElementsActifs().createConstitutionDateLimiteIndemnisation();
    
    ResultatDeterminationDateLimiteIndemnisation resultat = DeterminationDateLimiteIndemnisation.determinerDateLimiteIndemnisation(p_demande);
    
    dateLimiteIndemnisation.setDateLimiteIndem(resultat.getDateLimiteIndemnisation());
    dateLimiteIndemnisation.setDateDebutIndem(resultat.getDateDebutIndemnisation());
    dateLimiteIndemnisation.setContexteDateLimiteIndemnisation(resultat.getContexteDateLimiteIndemnisation());
  }
  
  protected void alimenterConstitutionDurees(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    ConstitutionDurees constitutionDurees = p_dossierExamen.getConstitutionElementsActifs().createConstitutionDurees();
    DureeIndemnisation dureeIndemnisation = constitutionDurees.createDureeIndemnisation();
    
    Quantite dureeInitialeDroit = p_saisieAntecedent.getDureeInitialeDroit();
    if (dureeInitialeDroit == null) {
      dureeInitialeDroit = new QuantiteJour("0");
    }
    dureeIndemnisation.setDureeTheorique(dureeInitialeDroit);
    dureeIndemnisation.setDureeEffective(dureeInitialeDroit);
    
    dureeIndemnisation.setDureeImputation(null);
    dureeIndemnisation.setQuantiteTotalJourImputation(null);
    dureeIndemnisation.setQuantiteJourImputationForce(null);
  }
  
  protected void alimenterConstitutionDelais(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    p_dossierExamen.createConstitutionDelais();
  }
  
  protected void alimenterConstitutionPointDeDepart(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    ConstitutionPointDepartIndemnisation constitutionPointDepartIndemnisation = p_dossierExamen.createConstitutionPointDepartIndemnisation();
    
    Damj pji = p_saisieAntecedent.getDateAttribution();
    
    constitutionPointDepartIndemnisation.setPji(pji);
  }
  
  protected void alimenterConstitutionProduitResultant(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    ConstitutionProduitResultant constitutionProduitResultant = p_dossierExamen.createConstitutionProduitResultant();
    if (!"0".equals(p_saisieAntecedent.getMontantReadmissionRetenu())) {
      constitutionProduitResultant.setTypeMontantRetenu(2);
    } else {
      constitutionProduitResultant.setTypeMontantRetenu(1);
    }
  }
  
  protected void alimenterCompetence(Demande p_demande, CompetenceSpec p_competence, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    int competenceFinanciere = 1;
    int competenceAdministrative = 1;
    String numeroConventionGestion = "";
    
    String identifiantCompetence = p_saisieAntecedent.getIdentifiantFaitGenerateur();
    ActiviteSalarie periodeCompetence = (ActiviteSalarie)p_demande.getDemandeur().rechercherPeriodePasseProfessionnel(identifiantCompetence);
    if (periodeCompetence != null)
    {
      numeroConventionGestion = periodeCompetence.getEntreprise().getNumeroConventionGestion();
      int champApplication = periodeCompetence.getMetier().getChampApplication();
      if (champApplication == 3)
      {
        competenceFinanciere = 2;
        competenceAdministrative = 2;
      }
      else if (champApplication == 4)
      {
        competenceFinanciere = 2;
      }
    }
    p_competence.setCompetenceAdministrative(competenceAdministrative);
    p_competence.setCompetenceFinanciere(competenceFinanciere);
    p_competence.setNumeroConventionGestion(numeroConventionGestion);
  }
  
  protected void alimenterConstitutionMontantBrut(DossierExamenAssuranceSpec p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    DomLiquidationAssurance dom = new DomLiquidationAssurance();
    Contexte contexte = new Contexte();
    contexte.setDonnees(dom);
    
    DemandeAssuranceSpec demande = p_dossierExamen.getDemandeAssurance();
    
    ProduitAsuSpec produit = (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
    dom.setDemande(demande);
    try
    {
      produit.constituerMontantsBruts(contexte);
    }
    catch (ApplicativeException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), ex);
    }
  }
}

/* Location:
 * Qualified Name:     GrapheAntecedent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */