package fr.unedic.cali.asu.caa14.calcul.dom;

import fr.unedic.cali.asu.caa14.calcul.dom.gen.MontantGen;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.outilsfonctionnels.OutilCalculEstimationCotisationsSociales;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import java.math.BigDecimal;

public class Montant
  extends MontantGen
  implements MontantAsuSpec
{
  private static final long serialVersionUID = 1L;
  public static final String PLAFOND = "03";
  public static final String PLANCHER = "01";
  public static final String MINI = "02";
  public static final String MINI_FORMATION = "04";
  private transient Quantite m_mini = null;
  private transient Quantite m_miniFormation = null;
  private transient Quantite m_plafond = null;
  private transient Quantite m_plancher = null;
  private transient Quantite m_base = null;
  private transient BigDecimal m_tauxCrc = null;
  private transient BigDecimal m_baseCalculCrc = null;
  private transient String m_positionExonerationCrc = null;
  private transient Quantite m_csg = null;
  private transient Quantite m_crds = null;
  private transient Quantite m_totalCotisationContribution = null;
  private transient Quantite m_montantBrutSansPensionInvaliditeADeduire = null;
  private transient Quantite m_pensionInvaliditeADeduirePriseEnCompte = null;
  private transient Quantite montantJournalierAvantageVieillesse = null;
  private transient Quantite montantJournalierAvantageVieillesseDeduit = null;
  
  public Quantite getMontantJournalierAvantageVieillesse()
  {
    return montantJournalierAvantageVieillesse;
  }
  
  public void setMontantJournalierAvantageVieillesse(Quantite montantJournalierAvantageVieillesse)
  {
    this.montantJournalierAvantageVieillesse = montantJournalierAvantageVieillesse;
  }
  
  public Quantite getMontantJournalierAvantageVieillesseDeduit()
  {
    return montantJournalierAvantageVieillesseDeduit;
  }
  
  public void setMontantJournalierAvantageVieillesseDeduit(Quantite montantJournalierAvantageVieillesseDeduit)
  {
    this.montantJournalierAvantageVieillesseDeduit = montantJournalierAvantageVieillesseDeduit;
  }
  
  private transient String m_justificationCalculMontant = null;
  private transient String m_type = null;
  private transient BigDecimal m_sjrNonReduit = null;
  protected transient Quantite m_csgEstimee = null;
  protected transient Quantite m_crdsEstimee = null;
  protected transient Quantite m_ccamEstimee = null;
  protected transient Quantite m_montantNetEstimee = null;
  
  public Montant()
  {
    setAvecPrecompteCRC(true);
    setType("NORMAL");
  }
  
  public Montant(DomPCSpec p_montantPC)
  {
    super(p_montantPC);
    setAvecPrecompteCRC(true);
  }
  
  public Montant(MontantBaseSpec p_montant)
  {
    setAvecPrecompteCRC(true);
    setType("NORMAL");
    setMontantBrut(p_montant.getMontantBrut());
    setCrc(p_montant.getCrc());
    setBase(p_montant.getBase());
    setBaseCalculCrc(p_montant.getBaseCalculCrc());
    setCrds(p_montant.getCrds());
    setCsg(p_montant.getCsg());
    setJustificationCalculMontant(p_montant.getJustificationCalculMontant());
    setMini(p_montant.getMini());
    setMontantBrutSansPensionInvaliditeADeduire(p_montant.getMontantBrutSansPensionInvaliditeADeduire());
    setPensionInvaliditeADeduirePriseEnCompte(p_montant.getPensionInvaliditeADeduirePriseEnCompte());
    setPlafond(p_montant.getPlafond());
    setPositionExonerationCrc(p_montant.getPositionExonerationCrc());
    setTauxCrc(p_montant.getTauxCrc());
    setTotalCotisationContribution(p_montant.getCotisationContribution());
    setSjrNonReduit(p_montant.getSjrNonReduit());
    setMiniFormation(p_montant.getMiniFormation());
    setPlancher(p_montant.getPlancher());
    setEstAvecPrecompte(p_montant.getAvecPrecompteCRC());
    setMontantJournalierAvantageVieillesse(p_montant.getMontantJournalierAvantageVieillesse());
    setMontantJournalierAvantageVieillesseDeduit(p_montant.getMontantJournalierAvantageVieillesseDeduit());
  }
  
  public Quantite getBase()
  {
    return m_base;
  }
  
  public void setBase(Quantite p_base)
  {
    m_base = p_base;
  }
  
  public BigDecimal getBaseCalculCrc()
  {
    return m_baseCalculCrc;
  }
  
  public void setBaseCalculCrc(BigDecimal p_baseCalculCrc)
  {
    m_baseCalculCrc = p_baseCalculCrc;
  }
  
  public Quantite getCrds()
  {
    return m_crds;
  }
  
  public void setCrds(Quantite p_crds)
  {
    m_crds = p_crds;
  }
  
  public Quantite getCsg()
  {
    return m_csg;
  }
  
  public void setCsg(Quantite p_csg)
  {
    m_csg = p_csg;
  }
  
  public Quantite getMini()
  {
    return m_mini;
  }
  
  public void setMini(Quantite p_mini)
  {
    m_mini = p_mini;
  }
  
  public Quantite getMontantBrutSansPensionInvaliditeADeduire()
  {
    return m_montantBrutSansPensionInvaliditeADeduire;
  }
  
  public void setMontantBrutSansPensionInvaliditeADeduire(Quantite p_montantBrutSansPensionInvaliditeADeduire)
  {
    m_montantBrutSansPensionInvaliditeADeduire = p_montantBrutSansPensionInvaliditeADeduire;
  }
  
  public Quantite getPensionInvaliditeADeduirePriseEnCompte()
  {
    return m_pensionInvaliditeADeduirePriseEnCompte;
  }
  
  public void setPensionInvaliditeADeduirePriseEnCompte(Quantite p_pensionInvaliditeADeduirePriseEnCompte)
  {
    m_pensionInvaliditeADeduirePriseEnCompte = p_pensionInvaliditeADeduirePriseEnCompte;
  }
  
  public Quantite getPlafond()
  {
    return m_plafond;
  }
  
  public void setPlafond(Quantite p_plafond)
  {
    m_plafond = p_plafond;
  }
  
  public String getPositionExonerationCrc()
  {
    return m_positionExonerationCrc;
  }
  
  public void setPositionExonerationCrc(String p_positionExonerationCrc)
  {
    m_positionExonerationCrc = p_positionExonerationCrc;
  }
  
  public BigDecimal getTauxCrc()
  {
    return m_tauxCrc;
  }
  
  public void setTauxCrc(BigDecimal p_tauxCrc)
  {
    m_tauxCrc = p_tauxCrc;
  }
  
  public Quantite getTotalCotisationContribution()
  {
    return m_totalCotisationContribution;
  }
  
  public void setTotalCotisationContribution(Quantite p_totalCotisationContribution)
  {
    m_totalCotisationContribution = p_totalCotisationContribution;
  }
  
  public void setJustificationCalculMontant(String p_justificationCalculMontant)
  {
    m_justificationCalculMontant = p_justificationCalculMontant;
  }
  
  public void setType(String p_type)
  {
    m_type = p_type;
  }
  
  public String getJustificationCalculMontant()
  {
    return m_justificationCalculMontant;
  }
  
  public String getType()
  {
    return m_type;
  }
  
  public Quantite getPlancher()
  {
    return m_plancher;
  }
  
  public void setPlancher(Quantite p_plancher)
  {
    m_plancher = p_plancher;
  }
  
  public ObjetMetierSpec copie()
  {
    Montant copie = new Montant();
    copieElements(copie);
    return copie;
  }
  
  public Quantite getMontantPrecompteEffectif()
  {
    if (getAvecPrecompteCRC()) {
      return new Quantite(getMontantBrut().getValeur().subtract(getCrc().getValeur()), getMontantBrut().getUnite());
    }
    return getMontantBrut();
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    Montant copie = (Montant)p_copie;
    super.copieElements(copie);
    
    copie.setBase(getBase());
    copie.setBaseCalculCrc(getBaseCalculCrc());
    copie.setCrds(getCrds());
    copie.setCsg(getCsg());
    copie.setJustificationCalculMontant(getJustificationCalculMontant());
    copie.setMini(getMini());
    copie.setMontantBrutSansPensionInvaliditeADeduire(getMontantBrutSansPensionInvaliditeADeduire());
    copie.setPensionInvaliditeADeduirePriseEnCompte(getPensionInvaliditeADeduirePriseEnCompte());
    copie.setPlafond(getPlafond());
    copie.setPositionExonerationCrc(getPositionExonerationCrc());
    copie.setTauxCrc(getTauxCrc());
    copie.setTotalCotisationContribution(getCotisationContribution());
    copie.setType(getType());
    copie.setSjrNonReduit(getSjrNonReduit());
    copie.setMiniFormation(getMiniFormation());
    copie.setMontantJournalierAvantageVieillesse(getMontantJournalierAvantageVieillesse());
    copie.setMontantJournalierAvantageVieillesseDeduit(getMontantJournalierAvantageVieillesseDeduit());
  }
  
  public String toString()
  {
    StringBuffer string = new StringBuffer();
    string.append("\nMontant : " + getMontantBrut() + "\n");
    return string.toString();
  }
  
  public BigDecimal getMontantPrecompte()
  {
    return getMontantBrut().getValeur().subtract(getCrc().getValeur());
  }
  
  public BigDecimal getSjrNonReduit()
  {
    return m_sjrNonReduit;
  }
  
  public void setSjrNonReduit(BigDecimal p_sjrNonReduit)
  {
    m_sjrNonReduit = p_sjrNonReduit;
  }
  
  public Quantite getMiniFormation()
  {
    return m_miniFormation;
  }
  
  public void setMiniFormation(Quantite p_miniFormation)
  {
    m_miniFormation = p_miniFormation;
  }
  
  public Quantite getCsgEstimee()
  {
    return new QuantiteEuro(BigDecimal.ZERO);
  }
  
  public Quantite getCrdsEstimee()
  {
    return new QuantiteEuro(BigDecimal.ZERO);
  }
  
  public Quantite getCcamEstimee(boolean p_topAlsaceMoselle)
  {
    return new QuantiteEuro(BigDecimal.ZERO);
  }
  
  public Quantite getMontantNetEstime(boolean p_topAlsaceMoselle)
  {
    if ((m_montantNetEstimee == null) && (getMontantBrut() != null) && (getCrc() != null)) {
      m_montantNetEstimee = new QuantiteEuro(OutilCalculEstimationCotisationsSociales.calculerMontantNet(getMontantBrut().getValeur(), getCrc().getValeur(), getCsgEstimee().getValeur(), getCrdsEstimee().getValeur(), getCcamEstimee(p_topAlsaceMoselle).getValeur()));
    }
    return m_montantNetEstimee;
  }
  
  public MontantAsuSpec getMontantAreExecute()
  {
    return null;
  }
  
  public MontantAsuSpec getMontantAreNonExecute()
  {
    return null;
  }
  
  public BigDecimal getSjrMontantMax()
  {
    return null;
  }
  
  public BigDecimal getPlafondASP()
  {
    return null;
  }
  
  public Montant getMontantSJR()
  {
    return null;
  }
}

/* Location:
 * Qualified Name:     Montant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */