package fr.unedic.cali.asu.caa14.calcul.outilsfonctionnels;

import fr.unedic.cali.calcul.dom.ConstituantsCalculActiviteReduiteSpec;
import fr.unedic.cali.calcul.dom.SyntheseARsurUT;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.periode.DsmTravail;
import fr.unedic.cali.calcul.dom.periode.PeriodePrime;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravailJustifiee;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ResultatActiviteReduite;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalcul;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteMonaitaire;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.UniteDuree;
import java.math.BigDecimal;

public class TraitementActiviteReduite
  extends fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.TraitementActiviteReduite
{
  public static void traitementPeriodesGelantes(AttributionSpec p_attribution, ChronologiePeriodes p_periodesGelantes, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduite, UniteTraitement p_ut)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesGelantesDeclareees = new ChronologiePeriodes();
    ChronologiePeriodes periodesGelantesJustifiees = new ChronologiePeriodes();
    
    preTraitementPeriodesGelantes(p_attribution, p_ut, p_periodesGelantes, periodesGelantesDeclareees, periodesGelantesJustifiees);
  }
  
  public static void traitementPeriodesDecalantes(ChronologiePeriodes p_periodesDecalantes, UniteTraitement p_ut)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesTravailJustifieesOuDeclarees = new ChronologiePeriodes();
    ObjetChronoPeriodeCalcul periodeTravailCalcul = null;
    
    p_periodesDecalantes.iterer();
    while (p_periodesDecalantes.encoreSuivant())
    {
      periodeTravailCalcul = (ObjetChronoPeriodeCalcul)p_periodesDecalantes.elementSuivant();
      if (((periodeTravailCalcul instanceof PeriodeTravailJustifiee)) || ((periodeTravailCalcul instanceof PeriodePrime)) || ((periodeTravailCalcul instanceof DsmTravail))) {
        periodesTravailJustifieesOuDeclarees.ajouter(periodeTravailCalcul);
      }
    }
    if (periodesTravailJustifieesOuDeclarees.getTaille() != 0)
    {
      ResultatActiviteReduite resultatActiviteReduite = appelleActiviteReduite(p_periodesDecalantes);
      postTraitementPeriodesDecalantes(p_ut, resultatActiviteReduite);
    }
  }
  
  protected static ResultatActiviteReduite appelleActiviteReduite(ChronologiePeriodes p_periodes)
    throws CoucheLogiqueException
  {
    ResultatActiviteReduite resultatActiviteReduite = new ResultatActiviteReduite();
    
    ObjetChronoPeriodeCalcul periodeCourante = null;
    
    BigDecimal cumulGainJustifie = BigDecimal.ZERO;
    BigDecimal cumulNbHeuresJustifiees = BigDecimal.ZERO;
    BigDecimal cumulJourDeTravail = BigDecimal.ZERO;
    
    Chronologie periodesEmploiCourantes = p_periodes.copier(new FiltrePeriodeTravailCalcul());
    
    periodesEmploiCourantes.iterer();
    while (periodesEmploiCourantes.encoreSuivant())
    {
      periodeCourante = (ObjetChronoPeriodeCalcul)periodesEmploiCourantes.elementSuivant();
      if ((periodeCourante instanceof PeriodeTravailJustifiee))
      {
        PeriodeTravailJustifiee periodeTravail = (PeriodeTravailJustifiee)periodeCourante;
        cumulGainJustifie = cumulGainJustifie.add(periodeTravail.getGain());
        cumulNbHeuresJustifiees = cumulNbHeuresJustifiees.add(periodeTravail.getNombreHeures());
        cumulJourDeTravail = cumulJourDeTravail.add(new BigDecimal(periodeTravail.getDuree()));
      }
    }
    resultatActiviteReduite.setNbHeuresPrisesEnCompte(cumulNbHeuresJustifiees);
    resultatActiviteReduite.setGainPrisEnCompte(cumulGainJustifie);
    resultatActiviteReduite.setCumulGainJustifie(cumulGainJustifie);
    resultatActiviteReduite.setCumulNbHeuresJustifiees(cumulNbHeuresJustifiees);
    resultatActiviteReduite.setCumulJourDeTravail(cumulJourDeTravail);
    resultatActiviteReduite.setCumulGainICCPConserves(BigDecimal.ZERO);
    resultatActiviteReduite.setCumulGainICCPRepris(BigDecimal.ZERO);
    
    return resultatActiviteReduite;
  }
  
  protected static void postTraitementPeriodesDecalantes(UniteTraitement p_ut, ResultatActiviteReduite p_resultatActiviteReduite)
    throws CoucheLogiqueException
  {
    p_ut.getSyntheseARsurUT().setTotalGainUtilisePourDecalage(new Quantite(p_resultatActiviteReduite.getGainPrisEnCompte(), UniteMonaitaire.EUROS));
    p_ut.getSyntheseARsurUT().setTotalHeureUtilisePourDecalage(new Quantite(p_resultatActiviteReduite.getNbHeuresPrisesEnCompte(), UniteDuree.HEURE));
    
    p_ut.getSyntheseARsurUT().setTotalGainICCPConserves(new Quantite(p_resultatActiviteReduite.getCumulGainICCPConserves(), UniteMonaitaire.EUROS));
    
    p_ut.getSyntheseARsurUT().setTotalGainICCPRepris(new Quantite(p_resultatActiviteReduite.getCumulGainICCPRepris(), UniteMonaitaire.EUROS));
    
    p_ut.getSyntheseARsurUT().setCumulJourDeTravailAR(new Quantite(p_resultatActiviteReduite.getCumulJourDeTravail(), UniteDuree.JOUR));
    
    p_ut.getSyntheseARsurUT().setTotalGainActiviteReduiteJustifie(new Quantite(p_resultatActiviteReduite.getCumulGainJustifie(), UniteMonaitaire.EUROS));
    
    p_ut.getSyntheseARsurUT().setTotalNbHeureActiviteReduiteJustifie(new Quantite(p_resultatActiviteReduite.getCumulNbHeuresJustifiees(), UniteDuree.HEURE));
    if (!p_resultatActiviteReduite.isNeutralise()) {
      p_ut.setCreditDecalage(null);
    } else {
      p_ut.setTypeNeutralisation(p_resultatActiviteReduite.getTypeNeutralisation());
    }
    BigDecimal decalageDuree = p_resultatActiviteReduite.getDecalageDuree();
    if (decalageDuree != null)
    {
      Quantite qteDecalageDuree = new Quantite(decalageDuree, p_ut.getUniteParDefautQuantites());
      p_ut.getSyntheseARsurUT().setDecalageDureeUT(qteDecalageDuree);
      Quantite qteDecalageDureeDureeCourant = p_ut.getCreditDecalageDuree();
      if (qteDecalageDureeDureeCourant != null) {
        qteDecalageDuree = qteDecalageDuree.ajouter(qteDecalageDureeDureeCourant);
      }
      p_ut.setCreditDecalageDuree(qteDecalageDuree);
    }
  }
}

/* Location:
 * Qualified Name:     TraitementActiviteReduite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */