package fr.unedic.cali.asu.caa14.p01.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.caa14.p01.calcul.dom.FormuleMontantASRAREF;
import fr.unedic.cali.asu.caa14.p01.calcul.dom.FormuleMontantRegimeGeneralASRARE;
import fr.unedic.cali.asu.calcul.FacadeCalculProduitPourLiquidationAsuAbstraite;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.RecuperationPensionInvaliditeAvantDate;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.ActiviteReduite;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.DeterminationReliquat;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisationAREF;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMappingSjmSjr;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationAvantageVieillesseAvantPJI;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodePANSConservee;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P04;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class FacadeCalculProduitPourLiquidationImpl
  extends FacadeCalculProduitPourLiquidationAsuAbstraite
{
  private static final int CINQUANTE_ANS = 50;
  private static final int DIX = 10;
  
  public Periode determinerPeriodeAvantSansCalendrier(AttributionSpec attribution)
    throws ApplicativeException
  {
    return null;
  }
  
  public Quantite calculerCapital(AttributionSpec attribution, Damj dateAttribution, Damj pointDeDepart, Quantite nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public Quantite calculerCapital(AttributionSpec attribution, MontantAsuSpec pmontant, Damj pointDeDepart, Quantite nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    IndividuSpec individu = attribution.getDemandeur();
    
    BigDecimal capital = new BigDecimal("0.00");
    
    Damj pji = pointDeDepart;
    
    int dureeDroit = OutilRetraite.getInstance().bornerDureeALaRetraite(individu, pointDeDepart, nbJoursIndemnisables, false);
    Damj dji = pji.deplacerVersAvant(new DureeCalendaire(0, 0, dureeDroit));
    if (pji.estAvant(dji))
    {
      BigDecimal montant = pmontant.getMontantPrecompteEffectif().getValeur();
      
      capital = montant.multiply(new BigDecimal(dureeDroit));
    }
    return new QuantiteEuro(capital);
  }
  
  public Damj determinerDateConditionNombreJoursIndemnisesNecessaireMaintien(AttributionSpec attribution)
    throws ApplicativeException
  {
    return null;
  }
  
  public Quantite determinerDureeEffectiveReliquat(Quantite quantiteInitiale, Quantite nbHeuresFormation)
    throws IllegalArgumentException
  {
    return DeterminationReliquat.determinerDureeEffectiveReliquat(quantiteInitiale, nbHeuresFormation);
  }
  
  public boolean determinerPrecompteCRC(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    return true;
  }
  
  public FormuleMontantSpec getFormuleMontant()
  {
    return new FormuleMontantRegimeGeneralASRARE();
  }
  
  private ConstituantsIndemnisation initialiserConstituantsIndemnisation(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    Damj dateCalcul = donneesEntreesRecuperationMontant.getDateCalculMontant();
    IndividuSpec individu = donneesEntreesRecuperationMontant.getIndividu();
    
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    
    ElementBaseIndemnisation elementBaseIndemnisationCourant = new ElementBaseIndemnisation();
    if (donneesCalculMontant.getCoefficientSaisonnier() != null)
    {
      elementBaseIndemnisationCourant.setCoefficientSaisonnier(donneesCalculMontant.getCoefficientSaisonnier());
      if ((donneesCalculMontant.getCoefficientSaisonnier().intValue() != 1) && (individu.getAgeALaDate(dateCalcul).getAnnees() >= 50)) {
        if ((donneesCalculMontant.getTypeCaractereSaisonnierRetenu() == 1) && (donneesCalculMontant.isConditionCaractereSaisonnierParRythme())) {
          elementBaseIndemnisationCourant.setCoefficientSaisonnier(new BigDecimal("1.00"));
        }
      }
    }
    if (donneesCalculMontant.getCoefficientTempsPartiel() != null) {
      elementBaseIndemnisationCourant.setCoefficientTempsPartiel(donneesCalculMontant.getCoefficientTempsPartiel());
    }
    Sjr sjr = OutilMappingSjmSjr.convertirSjr(donneesCalculMontant.getSalaireJournalier());
    
    elementBaseIndemnisationCourant.setSjr(sjr);
    
    Sjr sjrRevalorise = RevalorisationSalaire.revaloriserSjr(elementBaseIndemnisationCourant, ProduitAsuCge01P04.getInstance(), dateCalcul);
    elementBaseIndemnisationCourant.setSjr(sjrRevalorise);
    if (donneesCalculMontant.isPriseEnComptePensionInvalidite()) {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPI(individu, dateCalcul));
    } else {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(new BigDecimal("0.00"));
    }
    elementBaseIndemnisationCourant.setTypeCaractereSaisonnierRetenu(donneesCalculMontant.getTypeCaractereSaisonnierRetenu());
    
    elementBaseIndemnisationCourant.setIsConditionCaractereSaisonnierParRythme(donneesCalculMontant.isConditionCaractereSaisonnierParRythme());
    if (donneesCalculMontant.getAvecPrecompteCRC() != null) {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(donneesCalculMontant.getAvecPrecompteCRC());
    } else {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(Boolean.TRUE);
    }
    if (donneesCalculMontant.isPriseEnCompteAvantageVieillesse())
    {
      PeriodeAvantageVieillesse periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(individu, dateCalcul);
      
      BigDecimal montantAV = BigDecimal.ZERO;
      if (periodeAvCourante != null)
      {
        montantAV = periodeAvCourante.getQuantiteEuro().getValeur();
        
        elementBaseIndemnisationCourant.setDateEffetAV(dateCalcul);
      }
      BigDecimal coeffAV = new BigDecimal("0.00");
      if ((sjrRevalorise != null) && (sjrRevalorise.getSalaire() != null) && (!sjrRevalorise.getSalaire().equals(new BigDecimal("0.00")))) {
        coeffAV = montantAV.divide(sjrRevalorise.getSalaire(), 10, 4);
      }
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(montantAV);
      elementBaseIndemnisationCourant.setCoefficientSanctionReduction(new BigDecimal("1.00"));
      
      BigDecimal tauxavantageVieillesse = parametresIndemnisation.getTauxAvantageViellesse(individu.getAgeALaDate(dateCalcul));
      if (tauxavantageVieillesse != null) {
        elementBaseIndemnisationCourant.setTauxAvantageVieillesse(tauxavantageVieillesse);
      }
    }
    else
    {
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(new BigDecimal("0.00"));
      elementBaseIndemnisationCourant.setTauxAvantageVieillesse(new BigDecimal("0.00"));
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(new BigDecimal("0.00"));
    }
    elementBaseIndemnisationCourant.setProduitMontantRetenu((ProduitAsuSpec)donneesCalculMontant.getProduit());
    constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationCourant);
    if (donneesCalculMontant.isContexteFormation())
    {
      ElementBaseIndemnisationAREF ebiAREF = new ElementBaseIndemnisationAREF(elementBaseIndemnisationCourant);
      constituantsIndemnisation.setElementBaseIndemnisationCourant(ebiAREF);
    }
    return constituantsIndemnisation;
  }
  
  public BigDecimal getSeuilRenumeration(AttributionSpec pattribution, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)pattribution;
    ElementBaseIndemnisation ebi = attribution.getElementBaseIndemnisation();
    BigDecimal sjr = null;
    if (ebi.getSjr() != null) {
      sjr = RevalorisationSalaire.revaloriserSjr(ebi.getSjr(), dateCalcul).getSalaire();
    }
    boolean apprenti = ((Attribution)pattribution).isTopContratsRemuneresBaseSmic();
    Chronologie chronoPeriodesConserveesLiq = attribution.getListeActiviteConservee();
    boolean estAvecSjc = false;
    BigDecimal sjc = null;
    if (ebi.getSjc() == null)
    {
      sjc = BigDecimal.ZERO;
    }
    else if (!chronoPeriodesConserveesLiq.estVide())
    {
      estAvecSjc = true;
      sjc = RevalorisationSalaire.revaloriserSjc(ebi.getSjc(), dateCalcul).getSalaire();
    }
    boolean presencePansConservee = !chronoPeriodesConserveesLiq.copier(new FiltrePeriodePANSConservee()).estVide();
    return ActiviteReduite.calculerSeuilMensuel(dateCalcul, sjr, sjc, apprenti, estAvecSjc, BigDecimal.ZERO, presencePansConservee);
  }
  
  public MontantBaseSpec determinerMontant(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    FormuleMontantSpec formuleMontant = null;
    ConstituantsIndemnisation constituantsIndemnisation = initialiserConstituantsIndemnisation(donneesEntreesRecuperationMontant);
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    if (donneesCalculMontant.getFormuleMontant() != null) {
      formuleMontant = donneesCalculMontant.getFormuleMontant();
    } else if (donneesCalculMontant.isContexteFormation()) {
      formuleMontant = getFormuleMontantEnFormation();
    } else {
      formuleMontant = getFormuleMontant();
    }
    return formuleMontant.calculer(constituantsIndemnisation, donneesEntreesRecuperationMontant.getDateCalculMontant());
  }
  
  public FormuleMontantSpec getFormuleMontantEnFormation()
  {
    return new FormuleMontantASRAREF();
  }
  
  public MontantBaseSpec determinerMontant(AttributionSpec attribution, Damj dateCalcul)
    throws ApplicativeException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitPourLiquidationImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */