package fr.unedic.cali.asu.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.calcul.dom.ConstituantsCalculActiviteReduiteGamme;
import fr.unedic.cali.asu.calcul.dom.EtatAuDjiGamme;
import fr.unedic.cali.asu.calcul.parcours.ResultatDeterminationEtatDroit;
import fr.unedic.cali.asu.calcul.parcours.ResultatMigrationCalcul;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.calcul.PostTraitementsHorsGamme;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreContientDate;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class PostTraitementsAsu
  extends PostTraitementsHorsGamme
{
  protected static void remplirResultatPostTraitement(AttributionSpec p_attribution, CalendrierExecutionCalculSpec p_calendrierExecutionCalcul, Damj p_dateEtatDroit, ResultatDeterminationEtatDroit p_resultat)
    throws CoucheLogiqueException
  {
    PostTraitementsHorsGamme.remplirResultatPostTraitement(p_attribution, p_calendrierExecutionCalcul, p_dateEtatDroit, p_resultat);
    
    EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)p_calendrierExecutionCalcul.getEtatAuDJI();
    if (etatAuDji != null)
    {
      p_resultat.setReliquatAREAvecMaintien(etatAuDji.getReliquatDureeIndemnisationAvecMaintien());
      
      p_resultat.setReliquatProlongation(etatAuDji.getReliquatDureeProlongation());
      if ((etatAuDji.getReliquatDureeIndemnisation() != null) && (etatAuDji.getReliquatDureeIndemnisation().getValeur().intValue() > 0) && ((etatAuDji.getReliquatDureeIndemnisationAvecMaintien() == null) || (etatAuDji.getReliquatDureeIndemnisationAvecMaintien().getValeur().intValue() == 0)))
      {
        etatAuDji.setReliquatDureeIndemnisationAvecMaintien(etatAuDji.getReliquatDureeIndemnisation());
        p_resultat.setReliquatAREAvecMaintien(etatAuDji.getReliquatDureeIndemnisation());
      }
    }
    if ((etatAuDji != null) && (p_dateEtatDroit == p_calendrierExecutionCalcul.getDernierJourIndemnisable()))
    {
      p_resultat.setReliquatDureeIndemnisation(etatAuDji.getReliquatDureeIndemnisation());
      p_resultat.setCumulMoisActiviteReduite(etatAuDji.getCumulMoisActiviteReduite());
      if (p_calendrierExecutionCalcul.getEtatAttribution() == 6) {
        p_resultat.setEtatAttribution(1);
      } else if ((etatAuDji.getReliquatDureeIndemnisationAvecMaintien() != null) && (etatAuDji.getReliquatDureeIndemnisationAvecMaintien().getValeur().intValue() > 0)) {
        p_resultat.setEtatAttribution(3);
      } else {
        p_resultat.setEtatAttribution(2);
      }
      p_resultat.setNbJourFormation(etatAuDji.getNbJourAREF());
      p_resultat.setNombreMoisIndemnisationAssurance(etatAuDji.getNbMoisIndemniseAsu());
      p_resultat.setEstNombreMoisIndemnisationAssuranceAlimente(etatAuDji.isEstNbMoisIndemniseAsu());
    }
    else
    {
      Quantite reliquatDureeIndemnisation = recupererReliquatDureeIndemnisation(p_calendrierExecutionCalcul);
      if (reliquatDureeIndemnisation != null) {
        p_resultat.setReliquatDureeIndemnisation(new Quantite(reliquatDureeIndemnisation.getValeur().setScale(0), reliquatDureeIndemnisation.getUnite()));
      }
      p_resultat.setCumulMoisActiviteReduite(recupererReliquatCumulAR(p_calendrierExecutionCalcul));
      p_resultat.setEtatAttribution(recupererEtatAttribution(p_calendrierExecutionCalcul));
      UniteTraitement dernierUT = (UniteTraitement)((CalendrierExecutionCalculPeriodique)p_calendrierExecutionCalcul).getChronologieUnitesTraitements().dernierElement();
      p_resultat.setNbJourFormation(dernierUT.getNbJoursFormationEnFinDUT());
      p_resultat.setNombreMoisIndemnisationAssurance(dernierUT.getNbMoisIndemniseAsu());
      p_resultat.setEstNombreMoisIndemnisationAssuranceAlimente(dernierUT.isEstNbMoisIndemniseAsu());
    }
    if (((p_attribution instanceof AttributionAssuranceSpec)) && (((AttributionAssuranceSpec)p_attribution).getAttributionFinancement() != null)) {
      if ((etatAuDji != null) && (etatAuDji.getReliquatDureeFinancement() != null))
      {
        p_resultat.setReliquatDureeFinancement(etatAuDji.getReliquatDureeFinancement());
      }
      else
      {
        Quantite quantiteInitiale = ((AttributionAssuranceSpec)p_attribution).getAttributionFinancement().getDureeInitiale();
        p_resultat.setReliquatDureeFinancement(quantiteInitiale);
      }
    }
  }
  
  public static int recupererReliquatCumulAR(CalendrierExecutionCalculSpec p_calendrierExecutionCalcul)
    throws CoucheLogiqueException
  {
    int reliquatCumulAR = 0;
    UniteTraitement ut = null;
    if ((p_calendrierExecutionCalcul instanceof CalendrierExecutionCalculPeriodique))
    {
      Chronologie chronoUT = ((CalendrierExecutionCalculPeriodique)p_calendrierExecutionCalcul).getChronologieUnitesTraitements().copier(new FiltreContientDate(p_calendrierExecutionCalcul.getDernierJourIndemnisable()));
      if (!chronoUT.estVide()) {
        ut = (UniteTraitement)chronoUT.premierElement();
      } else {
        ut = (UniteTraitement)((CalendrierExecutionCalculPeriodique)p_calendrierExecutionCalcul).getChronologieUnitesTraitements().dernierElement();
      }
      reliquatCumulAR = ((ConstituantsCalculActiviteReduiteGamme)ut.getConstituantsCalculActiviteReduiteEnFinUT()).getCumul();
    }
    return reliquatCumulAR;
  }
  
  protected static void remplirResultatPostTraitement(AttributionSpec p_attribution, CalendrierExecutionCalculSpec p_calendrierExecutionCalcul, ResultatMigrationCalcul p_resultat)
    throws CoucheLogiqueException
  {
    PostTraitementsHorsGamme.remplirResultatPostTraitement(p_attribution, p_calendrierExecutionCalcul, p_resultat);
    
    Quantite reliquatDureeIndemnisation = recupererReliquatDureeIndemnisation(p_calendrierExecutionCalcul);
    if (reliquatDureeIndemnisation != null) {
      p_resultat.setReliquatDureeIndemnisation(new Quantite(reliquatDureeIndemnisation.getValeur().setScale(0), reliquatDureeIndemnisation.getUnite()));
    }
    p_resultat.setCumulMoisActiviteReduite(recupererReliquatCumulAR(p_calendrierExecutionCalcul));
  }
}

/* Location:
 * Qualified Name:     PostTraitementsAsu
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */