package fr.unedic.cali.asu.cge01.calcul.pbjc;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.calcul.dom.ConstituantsCalculActiviteReduiteAsu;
import fr.unedic.cali.asu.calcul.dom.ConstituantsCalculActiviteReduiteGamme;
import fr.unedic.cali.asu.calcul.dom.EtatAuDjiGamme;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeAEDV;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeCarences;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeDebutPec;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeFinDureeMaintienDroit;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodePreavis;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeRejetDRV;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeRejetDVDemandeExpresse;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeRejetDVFilEau;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeRejetRevision;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.OutilsMaintienEuropeenEessiASU;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.Qualification;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.mnt.dom.Accord;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.DossierExamen;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.asu.outilsfonctionnels.RechercheDecisionsInterruptives;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.Poursuite;
import fr.unedic.cali.asu.produits.liquidation.dom.Readmission;
import fr.unedic.cali.asu.produits.liquidation.dom.Reprise;
import fr.unedic.cali.asu.produits.liquidation.dom.Revision;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.calcul.OutillageCalculADate;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.OutillageQuantites;
import fr.unedic.cali.calcul.dom.ArretProduitAvecRaison;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvant;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.ConsommationPeriodes;
import fr.unedic.cali.calcul.dom.ConstituantsCalculActiviteReduiteSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.DureeConsommableAvant;
import fr.unedic.cali.calcul.dom.EvenementCalculSpec;
import fr.unedic.cali.calcul.dom.EvenementChangementParametre;
import fr.unedic.cali.calcul.dom.EvenementFinCumul;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.Somme;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.UniteTraitementAvant;
import fr.unedic.cali.calcul.dom.periode.ActionFormation;
import fr.unedic.cali.calcul.dom.periode.DsmMaladie;
import fr.unedic.cali.calcul.dom.periode.FinActionFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodeAbsenceAuPointage;
import fr.unedic.cali.calcul.dom.periode.PeriodeActiviteEmploiCalcul;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.dom.periode.PeriodeBlocageIndemnisation;
import fr.unedic.cali.calcul.dom.periode.PeriodeDisponibilite;
import fr.unedic.cali.calcul.dom.periode.PeriodeEvenementActualisation;
import fr.unedic.cali.calcul.dom.periode.PeriodeEvenementPersonnel;
import fr.unedic.cali.calcul.dom.periode.PeriodeExclusionDefinitiveDDTE;
import fr.unedic.cali.calcul.dom.periode.PeriodeFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodeInterStageFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodePensionInvalidite;
import fr.unedic.cali.calcul.dom.periode.PeriodeSanctionReductionMontant;
import fr.unedic.cali.calcul.dom.periode.PeriodeServiceCivique;
import fr.unedic.cali.calcul.dom.periode.PeriodeSuspensionDDTEAvecImputation;
import fr.unedic.cali.calcul.dom.periode.PeriodeSuspensionDDTESansImputation;
import fr.unedic.cali.calcul.dom.periode.PeriodeSuspensionTitreConservatoire;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravailJustifiee;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoAnniversaire50Ans;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoAnniversaire55Ans;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoAnniversaire60Ans;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeFinPec;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeInterProduits;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeLimiteIndemnisationPMVS;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeRadiation;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeRetraite;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeSuspensionIslr;
import fr.unedic.cali.calcul.outilsfonctionnels.GestionSanctions;
import fr.unedic.cali.calcul.outilsfonctionnels.OutilGestionPoursuite;
import fr.unedic.cali.calcul.parametres.AccesTauxCotisationAccidentTravail;
import fr.unedic.cali.calcul.pbjc.FacadePBJCProduitSpec;
import fr.unedic.cali.calcul.pbjc.dom.IndividuPbjcNcp;
import fr.unedic.cali.calcul.pbjc.dom.PbjcNcp;
import fr.unedic.cali.calcul.pbjc.outilsfonctionnels.GenerateurPBJCs;
import fr.unedic.cali.dom.AntecedentSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DureeIndemnisationAbstraite;
import fr.unedic.cali.dom.DureeProlongationAbstraite;
import fr.unedic.cali.dom.ElementBaseIndemnisationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.PoursuiteSpec;
import fr.unedic.cali.dom.Prescription;
import fr.unedic.cali.dom.QuantiteDroitSpec;
import fr.unedic.cali.dom.ReadmissionSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.Retraite;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.fabriques.FabriqueStrategieCotisationsGeneralesForfaitaires;
import fr.unedic.cali.outilsfonctionnels.OutilConventionGestion;
import fr.unedic.cali.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.outilsfonctionnels.strategies.StrategieCotisationsGeneralesForfaitairesSpec;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.parcours.DomAvantPilotage;
import fr.unedic.cali.parcours.ParcoursAvantPilotageElementsIndemnisation;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreAttributionSurDecisions;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourProduit;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ChronologieStandard;
import fr.unedic.util.temps.ComparateurTemporelsSurDateDebut;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

public class FacadePBJCLigneImpl
  implements FacadePBJCProduitSpec
{
  public static final int REDUCTION_50_POURCENT = 50;
  public static final int REDUCTION_20_POURCENT = 20;
  public static final int REF_BASE_CALCUL_OUVERTURE_DROIT = 1;
  public static final int REF_BASE_CALCUL_READ_SUR_DROIT_ANTECEDENT = 2;
  private static final int AGE_50_ANS = 50;
  private static final int AGE_55_ANS = 55;
  private static final int AGE_60_ANS = 60;
  public static final BigDecimal ZERO = new BigDecimal("0");
  protected static final int SEUIL_MOIS_NI = 3;
  
  public boolean controlerExecutionPBJCs(AttributionSpec attribution)
  {
    return true;
  }
  
  public ChronologiePeriodes creerChronologiePBJCsAvant(AttributionSpec attributionSpec, Damj dateGeneration, Damj dateBlocageActualisation, String libelleBlocageActualisation)
    throws ApplicativeException
  {
    ChronologiePeriodes pbjcsAvant = new ChronologiePeriodes();
    IndividuSpec individu = attributionSpec.getDemandeur();
    Periode periodeAvant = null;
    ObjetChronoPeriodePriseEnCharge periodePEC = null;
    ResultatAvant resultatAvant = null;
    PbjcNcp pbjcNcpAvant = null;
    ChronologiePeriodes periodesFormation = new ChronologiePeriodes();
    ChronologiePeriodes actionsFormation = new ChronologiePeriodes();
    ObjetChronoPeriode periode = null;
    List datesDeDecoupageDesPBJCs = null;
    AccesTauxCotisationAccidentTravail acces = new AccesTauxCotisationAccidentTravail();
    ChronologieStandard valeursParametre = null;
    List datesChgtTauxCADT = new ArrayList();
    Damj dateChtTaux = null;
    ObjetChronoPeriode laPeriodeInterruptive = null;
    Damj dateAttribution = OutilGestionPoursuite.getInstance().recupererDateAttributionOuPjpSiPoursuite(attributionSpec);
    
    periodePEC = OutillagePeriodes.recupererPeriodePECContenant(individu, dateAttribution);
    resultatAvant = retournerResultatCalculAvant(attributionSpec, periodePEC);
    
    CalendrierExecutionAvant calendrierAvant = (CalendrierExecutionAvant)attributionSpec.getCalendrierExecutionAvant();
    if (calendrierAvant == null) {
      return pbjcsAvant;
    }
    periodeAvant = calendrierAvant.getPeriode();
    periodeAvant.setDebut(dateAttribution);
    
    ChronologiePeriodes periodesQualifiees = recuperationDeToutesLesDesPeriodes(attributionSpec.getDemandeur(), attributionSpec);
    ChronologiePeriodes periodesInterruptivesDefinitives = new Qualification().qualificationPeriodesPourAvant(periodesQualifiees, attributionSpec).getPeriodesInterruptivesDefinitives();
    if (!periodesInterruptivesDefinitives.estVide())
    {
      periodesInterruptivesDefinitives.iterer();
      while (periodesInterruptivesDefinitives.encoreSuivant())
      {
        ObjetChronoPeriode periodeInterruptiveDefinitive = (ObjetChronoPeriode)periodesInterruptivesDefinitives.elementSuivant();
        if (periodeInterruptiveDefinitive.getDateDebut().veille().estContenueDans(periodeAvant))
        {
          periodeAvant.setFin(periodeInterruptiveDefinitive.getDateDebut().veille());
          laPeriodeInterruptive = periodeInterruptiveDefinitive;
        }
      }
    }
    valeursParametre = acces.getChronoValeursParametre();
    valeursParametre.iterer();
    while (valeursParametre.encoreSuivant())
    {
      dateChtTaux = ((fr.unedic.cali.calcul.dom.EvenementParametre)valeursParametre.elementSuivant()).getDateEvenement();
      if (dateChtTaux.estStrictementContenueDans(periodeAvant)) {
        datesChgtTauxCADT.add(dateChtTaux);
      }
    }
    Collection periodesAER = new ArrayList();
    Damj datePivot = periodeAvant.getFin();
    while (datePivot.estApres(dateAttribution))
    {
      FiltreET filtreCali = new FiltreET();
      filtreCali.ajouterFiltre(new FiltreAttributionSurDecisions());
      FiltreOU filtreProduit = new FiltreOU();
      filtreProduit.ajouterFiltre(new FiltreDecisionPourProduit(12));
      filtreProduit.ajouterFiltre(new FiltreDecisionPourProduit(52));
      filtreProduit.ajouterFiltre(new FiltreDecisionPourProduit(55));
      filtreCali.ajouterFiltre(filtreProduit);
      AttributionSpec attribution = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(attributionSpec.getDemandeur().getChronoDemandesNonTriees(), datePivot, filtreCali);
      if (attribution != null)
      {
        Periode periodeAER = new Periode(attribution.getPji(), attribution.getPji().deplacerVersAvant(new DureeCalendaire(1, 0, 0)));
        if (periodeAER.chevauche(periodeAvant))
        {
          periodesAER.add(periodeAER);
          datePivot = dateAttribution.veille();
          if (periodeAER.getDebut().estStrictementContenueDans(periodeAvant)) {
            datesChgtTauxCADT.add(periodeAER.getDebut());
          }
          if (periodeAER.getFin().lendemain().estStrictementContenueDans(periodeAvant)) {
            datesChgtTauxCADT.add(periodeAER.getFin().lendemain());
          }
        }
        else
        {
          datePivot = Damj.NUIT_DES_TEMPS;
        }
      }
      else
      {
        datePivot = Damj.NUIT_DES_TEMPS;
      }
    }
    ChronologiePeriodes periodesGAEC = OutillagePeriodes.recupererPeriodesGAEC(individu, dateAttribution, attributionSpec.getPji());
    
    periodesGAEC.iterer();
    while (periodesGAEC.encoreSuivant())
    {
      periode = (ObjetChronoPeriode)periodesGAEC.elementSuivant();
      if ((periode instanceof PeriodeFormation))
      {
        PeriodeFormation periodeFormationCalcul = (PeriodeFormation)periode;
        if ((periodeFormationCalcul.getPeriodeEffectiveInitiale() != null) && (periodeFormationCalcul.getPeriodeEffectiveInitiale().chevauche(periodeAvant)))
        {
          periodesFormation.ajouter(periode);
          if (periodeFormationCalcul.getPeriodeEffectiveInitiale().getDebut().estStrictementContenueDans(periodeAvant)) {
            datesChgtTauxCADT.add(periode.getDateDebut());
          }
          if (periodeFormationCalcul.getPeriodeEffectiveInitiale().getFin().estStrictementContenueDans(periodeAvant)) {
            datesChgtTauxCADT.add(periode.getDateFin().lendemain());
          }
        }
      }
      else if ((periode instanceof ActionFormation))
      {
        ActionFormation actionFormationCalcul = (ActionFormation)periode;
        if ((actionFormationCalcul.getPeriode() != null) && (actionFormationCalcul.getPeriode().chevauche(periodeAvant))) {
          actionsFormation.ajouter(periode);
        }
      }
    }
    if (resultatAvant.getListeCarencesEffectives().size() > 0) {
      traiterLesPBJCsSurLAvant(attributionSpec, periodeAvant, datesDeDecoupageDesPBJCs, dateBlocageActualisation, datesChgtTauxCADT, periodesAER, periodesFormation, actionsFormation, dateGeneration, libelleBlocageActualisation, pbjcsAvant);
    }
    pbjcsAvant = GenerateurPBJCs.decouperEnPBJCsDisjointes(pbjcsAvant, true, false);
    if (!pbjcsAvant.estVide())
    {
      pbjcNcpAvant = (PbjcNcp)pbjcsAvant.dernierElement();
      if ((resultatAvant.getPji() == null) && (pbjcNcpAvant.getDateFin().coincideAvec(periodePEC.getDateFin())))
      {
        String motifRadiation = periodePEC.getMotifAnnulation();
        pbjcNcpAvant.setCodeRadiationLendemainPeriode(motifRadiation);
        pbjcNcpAvant.ajouterComplementDeJustification("TD");
        if ((motifRadiation != null) && (motifRadiation.equals("73"))) {
          pbjcNcpAvant.ajouterComplementDeJustification("OH");
        }
      }
      if ((laPeriodeInterruptive != null) && (laPeriodeInterruptive.getDateDebut().coincideAvec(pbjcNcpAvant.getDateFin().lendemain()))) {
        if ((laPeriodeInterruptive instanceof ObjetChronoPeriodeRetraite))
        {
          if (((ObjetChronoPeriodeRetraite)laPeriodeInterruptive).getRetraite().estTypeBase()) {
            pbjcNcpAvant.ajouterComplementDeJustification("OD");
          } else {
            pbjcNcpAvant.ajouterComplementDeJustification(((ObjetChronoPeriodeRetraite)laPeriodeInterruptive).getRetraite().getMotif());
          }
        }
        else if ((laPeriodeInterruptive instanceof PeriodeExclusionDefinitiveDDTE))
        {
          String codeSanction = ((PeriodeExclusionDefinitiveDDTE)laPeriodeInterruptive).getCodeSanction();
          if (codeSanction.equals("ED")) {
            pbjcNcpAvant.ajouterComplementDeJustification("SJ");
          } else if (codeSanction.equals("EX")) {
            pbjcNcpAvant.ajouterComplementDeJustification("SI");
          }
        }
        else if (((laPeriodeInterruptive instanceof ObjetChronoPeriodeRejetDRV)) || ((laPeriodeInterruptive instanceof ObjetChronoPeriodeRejetDVFilEau)))
        {
          pbjcNcpAvant.ajouterComplementDeJustification("NX");
        }
        else if ((laPeriodeInterruptive instanceof ObjetChronoPeriodeAEDV))
        {
          pbjcNcpAvant.ajouterComplementDeJustification("HX");
        }
        else if ((laPeriodeInterruptive instanceof ObjetChronoPeriodeRejetDVDemandeExpresse))
        {
          pbjcNcpAvant.ajouterComplementDeJustification("ST");
        }
        else if ((laPeriodeInterruptive instanceof PeriodeBlocageIndemnisation))
        {
          pbjcNcpAvant.ajouterComplementDeJustification("OM");
        }
      }
    }
    Chronologie chronologiePeriodesEvtActualisation = OutillagePeriodes.recupererPeriodesEvtActualisation(attributionSpec.getDemandeur());
    if (chronologiePeriodesEvtActualisation != null)
    {
      chronologiePeriodesEvtActualisation.iterer();
      while (chronologiePeriodesEvtActualisation.encoreSuivant())
      {
        PeriodeEvenementActualisation periodeAbsenceAuPointage = (PeriodeEvenementActualisation)chronologiePeriodesEvtActualisation.elementSuivant();
        if ((periodeAbsenceAuPointage instanceof PeriodeAbsenceAuPointage))
        {
          pbjcsAvant.iterer();
          while (pbjcsAvant.encoreSuivant())
          {
            PbjcNcp pbjcNcpAvantAb = (PbjcNcp)pbjcsAvant.elementSuivant();
            if (pbjcNcpAvantAb.chevauche(periodeAbsenceAuPointage.getPeriode())) {
              pbjcNcpAvantAb.setNaturePBJC("AB");
            }
          }
        }
      }
    }
    return pbjcsAvant;
  }
  
  private ChronologiePeriodes recuperationDeToutesLesDesPeriodes(IndividuSpec individu, AttributionSpec attributionSpec)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronologiePeriodesGAEC = new ChronologiePeriodes();
    ChronologiePeriodes chronologiePeriodesPEC = new ChronologiePeriodes();
    ChronologiePeriodes chronologiePeriodesSanctions = new ChronologiePeriodes();
    ChronologiePeriodes chronologiePeriodesPourAttribution = new ChronologiePeriodes();
    ChronologiePeriodes chronologieRetraite = new ChronologiePeriodes();
    ChronologiePeriodes chronologieDemandeExpresse = new ChronologiePeriodes();
    ChronologiePeriodes chronologiePeriodeInterProduit = new ChronologiePeriodes();
    Collection collectionPeriodesPourAttribution = new LinkedList();
    Collection decisionsSuivi = null;
    Damj dateAttribOuPjp = OutilGestionPoursuite.getInstance().recupererDateAttributionOuPjpSiPoursuite(attributionSpec);
    chronologiePeriodesGAEC = OutillagePeriodes.recupererPeriodesGAEC(individu, dateAttribOuPjp, null);
    decisionsSuivi = OutillagePeriodes.recupererDecisionsSuivi(individu);
    chronologiePeriodesSanctions = GestionSanctions.recupererSanctions(decisionsSuivi);
    chronologiePeriodesPEC = OutillagePeriodes.recupererRadiations(individu);
    ObjetChronoPeriodeRetraite chronoRetraite = OutillagePeriodes.genererPeriodeRetraite(individu);
    chronologieRetraite.ajouter(chronoRetraite);
    chronologieDemandeExpresse = (ChronologiePeriodes)RechercheDecisionsInterruptives.rechercher(individu, attributionSpec.getDateAttribution(), attributionSpec);
    chronologiePeriodeInterProduit = recuperationObjetPeriodeInterProduitPourGamme(individu, "ASU", attributionSpec, 1);
    
    chronologiePeriodeInterProduit.ajouter(recuperationObjetPeriodeInterProduitPourProduit(individu, "INR_RCE04_01", attributionSpec, 1));
    
    collectionPeriodesPourAttribution.addAll(chronologiePeriodesGAEC.mapperVersCollection());
    collectionPeriodesPourAttribution.addAll(chronologiePeriodesPEC.mapperVersCollection());
    collectionPeriodesPourAttribution.addAll(chronologiePeriodesSanctions.mapperVersCollection());
    collectionPeriodesPourAttribution.addAll(chronologieRetraite.mapperVersCollection());
    collectionPeriodesPourAttribution.addAll(chronologieDemandeExpresse.mapperVersCollection());
    collectionPeriodesPourAttribution.addAll(chronologiePeriodeInterProduit.mapperVersCollection());
    if (individu.getDateBlocageIndemnisation() != null)
    {
      PeriodeBlocageIndemnisation periodeBlocageIndemnisation = new PeriodeBlocageIndemnisation(individu.getDateBlocageIndemnisation().lendemain());
      collectionPeriodesPourAttribution.add(periodeBlocageIndemnisation);
    }
    collectionPeriodesPourAttribution.addAll(OutilsMaintienEuropeenEessiASU.getListesPeriodesMaintienEuropeen(attributionSpec).mapperVersCollection());
    chronologiePeriodesPourAttribution.ajouter(collectionPeriodesPourAttribution);
    return chronologiePeriodesPourAttribution;
  }
  
  private ChronologiePeriodes recuperationObjetPeriodeInterProduitPourProduit(IndividuSpec individu, String produit, AttributionSpec attributionSpec, int typeDateDebutPeriodeInterProduits)
    throws CoucheLogiqueException
  {
    Iterator iterateur = null;
    AttributionSpec attribution = null;
    ObjetChronoPeriodeInterProduits objetChronoPeriodeInterProduits = null;
    ChronologiePeriodes listePeriodesInterProduit = new ChronologiePeriodes();
    iterateur = individu.getListeAttributionsExecutables().iterator();
    while (iterateur.hasNext())
    {
      attribution = (AttributionSpec)iterateur.next();
      if ((attribution.estValidee()) && (!attribution.estEnReexamen()) && (attribution.getProduit().getNomUnique().equals(produit)) && (attribution != attributionSpec))
      {
        objetChronoPeriodeInterProduits = getPeriodeInterProduit(typeDateDebutPeriodeInterProduits, attribution);
        if (objetChronoPeriodeInterProduits != null) {
          listePeriodesInterProduit.ajouter(objetChronoPeriodeInterProduits);
        }
      }
    }
    return listePeriodesInterProduit;
  }
  
  private ObjetChronoPeriodeInterProduits getPeriodeInterProduit(int typeDateDebutPeriodeInterProduits, AttributionSpec attributionSpec)
    throws CoucheLogiqueException
  {
    ObjetChronoPeriodeInterProduits objetChronoPeriodeInterProduits = null;
    Damj dateDepart = null;
    switch (typeDateDebutPeriodeInterProduits)
    {
    case 1: 
      dateDepart = attributionSpec.getDateEffet();
      break;
    case 2: 
      dateDepart = attributionSpec.getPji();
      break;
    default: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_UT_TYPE_PER_INTER_PROD_INCONNU", "Type de période inter-produit inconnu", null);
    }
    objetChronoPeriodeInterProduits = new ObjetChronoPeriodeInterProduits(dateDepart, Damj.FIN_DES_TEMPS, typeDateDebutPeriodeInterProduits, attributionSpec);
    return objetChronoPeriodeInterProduits;
  }
  
  private ChronologiePeriodes recuperationObjetPeriodeInterProduitPourGamme(IndividuSpec individu, String gamme, AttributionSpec attributionSpec, int typeDateDebutPeriodeInterProduits)
    throws CoucheLogiqueException
  {
    Iterator iterateur = null;
    AttributionSpec attribution = null;
    ObjetChronoPeriodeInterProduits objetChronoPeriodeInterProduits = null;
    ChronologiePeriodes listePeriodesInterProduit = new ChronologiePeriodes();
    iterateur = individu.getListeAttributionsExecutables().iterator();
    while (iterateur.hasNext())
    {
      attribution = (AttributionSpec)iterateur.next();
      if ((attribution.estValidee()) && (!attribution.estEnReexamen()) && (attribution.getGamme().getNomUnique().equals(gamme)) && (attribution != attributionSpec))
      {
        objetChronoPeriodeInterProduits = getPeriodeInterProduit(typeDateDebutPeriodeInterProduits, attribution);
        if (objetChronoPeriodeInterProduits != null) {
          listePeriodesInterProduit.ajouter(objetChronoPeriodeInterProduits);
        }
      }
    }
    return listePeriodesInterProduit;
  }
  
  private void traiterLesPBJCsSurLAvant(AttributionSpec p_attribution, Periode p_periodeAvant, List p_datesDeDecoupageDesPBJCs, Damj p_dateBlocageActualisation, List p_datesChgtTauxCADT, Collection p_periodesAER, ChronologiePeriodes p_periodesFormation, ChronologiePeriodes p_actionsFormation, Damj p_dateGeneration, String p_libelleBlocageActualisation, ChronologiePeriodes p_pbjcsAvant)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodes = null;
    ChronologiePeriodes periodesInterruptives = null;
    ObjetChronoPeriode laPeriodeInterruptive = null;
    PbjcNcp pbjcsAvantSusp = null;
    PbjcNcp pbjcsAvantDec = null;
    
    Damj dateAttribution = OutilGestionPoursuite.getInstance().recupererDateAttributionOuPjpSiPoursuite(p_attribution);
    List listePeriode = new ArrayList();
    List listeConstantesPBJC = new ArrayList();
    
    CalendrierExecutionAvant calendrierAvant = (CalendrierExecutionAvant)p_attribution.getCalendrierExecutionAvant();
    Chronologie listUtAvant = calendrierAvant.getChronologieUnitesTraitements();
    listUtAvant.iterer();
    while (listUtAvant.encoreSuivant())
    {
      UniteTraitementAvant utAvant = (UniteTraitementAvant)listUtAvant.elementSuivant();
      if ((dateAttribution.estContenueDans(new Periode(utAvant.getDateDebut(), utAvant.getDateFin()))) || (dateAttribution.estAvant(utAvant.getDateDebut())))
      {
        periodes = utAvant.getQualificationPeriodes().getPeriodesSuspensives();
        periodesInterruptives = utAvant.getQualificationPeriodes().getPeriodesInterruptives();
        periodesInterruptives.setComparateur(new ComparateurTemporelsSurDateDebut());
        periodes.iterer();
        while (periodes.encoreSuivant())
        {
          ObjetChronoPeriode periode = (ObjetChronoPeriode)periodes.elementSuivant().copie();
          if ((periode.getDateDebut().estApresOuCoincideAvec(dateAttribution)) || (periode.getDateFin().estApresOuCoincideAvec(dateAttribution)))
          {
            if (periode.getDateDebut().estAvant(dateAttribution)) {
              periode.setDateDebut(dateAttribution);
            }
            boolean peutAjouter = true;
            for (int i = 0; i < listePeriode.size(); i++)
            {
              ObjetChronoPeriode periodeTmp = (ObjetChronoPeriode)listePeriode.get(i);
              if ((periode.getDateDebut().coincideAvec(periodeTmp.getDateDebut())) && (periode.getDateFin().coincideAvec(periodeTmp.getDateFin()))) {
                peutAjouter = false;
              }
            }
            if (peutAjouter)
            {
              listePeriode.add(periode);
              if (((periode instanceof PeriodeEvenementPersonnel)) && (((PeriodeEvenementPersonnel)periode).getNature() == 38)) {
                listeConstantesPBJC.add("CA");
              } else if (((periode instanceof DsmMaladie)) || (((periode instanceof PeriodeEvenementPersonnel)) && (((PeriodeEvenementPersonnel)periode).getNature() != 38))) {
                listeConstantesPBJC.add("MA");
              } else if (((periode instanceof PeriodeTravailJustifiee)) || ((periode instanceof PeriodeActiviteEmploiCalcul))) {
                listeConstantesPBJC.add("CT");
              } else if ((periode instanceof PeriodeSuspensionDDTEAvecImputation)) {
                listeConstantesPBJC.add("CA");
              } else {
                listeConstantesPBJC.add("CT");
              }
            }
          }
        }
        listePeriode = filtrerPeriodesSuspensivesPeriodesInterruptives(listePeriode, periodesInterruptives);
        for (int i = 0; i < listePeriode.size(); i++)
        {
          ObjetChronoPeriode periode = (ObjetChronoPeriode)listePeriode.get(i);
          if (periode.chevauche(new Periode(utAvant.getDateDebut(), Damj.min(utAvant.getDateFin(), calendrierAvant.getDernierJourAvant()))))
          {
            Damj dateFinPeriodeSusp = Damj.min(Damj.min(periode.getDateFin(), utAvant.getDateFin()), calendrierAvant.getDernierJourAvant());
            pbjcsAvantSusp = creerPBJCSuspensivePourLAvant(Damj.max(periode.getDateDebut(), utAvant.getDateDebut()), dateFinPeriodeSusp, periode, p_attribution, (String)listeConstantesPBJC.get(i));
            if ((periode instanceof ObjetChronoPeriodeSuspensionIslr))
            {
              if ((((ObjetChronoPeriodeSuspensionIslr)periode).getDuree() > 0) && 
                (((ObjetChronoPeriodeSuspensionIslr)periode).getPeriodeGlobaleSuspensionISLR() != null))
              {
                ObjetChronoPeriodeSuspensionIslr periodeGlobaleISLR = ((ObjetChronoPeriodeSuspensionIslr)periode).getPeriodeGlobaleSuspensionISLR();
                if (pbjcsAvantSusp.getDateDebut().coincideAvec(periodeGlobaleISLR.getDateDebut())) {
                  pbjcsAvantSusp.ajouterComplementDeJustification("EV");
                }
                if (pbjcsAvantSusp.getDateFin().coincideAvec(periodeGlobaleISLR.getDateFin())) {
                  pbjcsAvantSusp.ajouterComplementDeJustification("SV");
                }
              }
            }
            else if ((periode instanceof PeriodeSuspensionDDTEAvecImputation))
            {
              pbjcsAvantSusp.supprimeComplementDeJustification("EU");
              positionnerInformationDecisionSanction(pbjcsAvantSusp, periode);
              pbjcsAvantSusp.setQualificationPeriode(4);
              if (((PeriodeSuspensionDDTEAvecImputation)periode).getCodeSanction().equals("SD")) {
                pbjcsAvantSusp.setCodeMotifNonPaiement("13");
              } else if (((PeriodeSuspensionDDTEAvecImputation)periode).getCodeSanction().equals("SE")) {
                pbjcsAvantSusp.setCodeMotifNonPaiement("11");
              }
              pbjcsAvantSusp.setEtatAdministratifOd("5");
            }
            ajouterPBJCSurLAvant(p_pbjcsAvant, pbjcsAvantSusp, p_dateGeneration);
          }
        }
        DureeConsommableAvant dureePmc = (DureeConsommableAvant)utAvant.getDureePmcEnDebutUT().copie();
        DureeConsommableAvant dureeDiffereStandard = (DureeConsommableAvant)utAvant.getDureeDiffereStandardEnDebutUT().copie();
        DureeConsommableAvant dureeDiffereSpecifique = (DureeConsommableAvant)utAvant.getDureeDiffereSpecifiqueEnDebutUT().copie();
        DureeConsommableAvant dureeDelaiAttente = (DureeConsommableAvant)utAvant.getDureeDelaiAttenteEnDebutUT().copie();
        DureeConsommableAvant dureePmcFin = (DureeConsommableAvant)utAvant.getDureePmcEnFinUT().copie();
        DureeConsommableAvant dureeDiffereStandardFin = (DureeConsommableAvant)utAvant.getDureeDiffereStandardEnFinUT().copie();
        DureeConsommableAvant dureeDiffereSpecifiqueFin = (DureeConsommableAvant)utAvant.getDureeDiffereSpecifiqueEnFinUT().copie();
        DureeConsommableAvant dureeDelaiAttenteFin = (DureeConsommableAvant)utAvant.getDureeDelaiAttenteEnFinUT().copie();
        ConsommationPeriodes consoPeriode = utAvant.getConsommationPeriodes();
        
        periodesInterruptives.iterer();
        if (periodesInterruptives.encoreSuivant()) {
          laPeriodeInterruptive = (ObjetChronoPeriode)periodesInterruptives.elementSuivant();
        }
        Periode periodeUtAvant = new Periode(Damj.max(utAvant.getDateDebut(), p_periodeAvant.getDebut()), utAvant.getDateFin());
        if ((consoPeriode.getPeriodePmc() != null) && (consoPeriode.getPeriodePmc().chevauche(periodeUtAvant)))
        {
          boolean positionJustifFermeture;
          boolean positionJustifFermeture;
          if ((dureePmcFin.getQuantiteCourante() != null) && (!dureePmcFin.getQuantiteCourante().getValeur().equals(ZERO))) {
            positionJustifFermeture = false;
          } else {
            positionJustifFermeture = true;
          }
          boolean positionJustifOuverture;
          boolean positionJustifOuverture;
          if ((dureePmc.getQuantiteCourante() != null) && (!dureePmc.getQuantiteCourante().getValeur().equals(dureePmc.getQuantiteInitial().getValeur()))) {
            positionJustifOuverture = false;
          } else {
            positionJustifOuverture = true;
          }
          traiterLesPBJCsAvant(dureePmc, p_periodeAvant, p_datesDeDecoupageDesPBJCs, p_dateBlocageActualisation, p_datesChgtTauxCADT, p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateGeneration, p_libelleBlocageActualisation, p_pbjcsAvant, consoPeriode.getPeriodePmc(), false, positionJustifOuverture, positionJustifFermeture, periodesInterruptives, laPeriodeInterruptive);
        }
        if ((consoPeriode.getPeriodeDiffereSpecifique() != null) && (consoPeriode.getPeriodeDiffereSpecifique().chevauche(periodeUtAvant)))
        {
          boolean positionJustifFermeture;
          boolean positionJustifFermeture;
          if ((dureeDiffereSpecifiqueFin.getQuantiteCourante() != null) && (!dureeDiffereSpecifiqueFin.getQuantiteCourante().getValeur().equals(ZERO))) {
            positionJustifFermeture = false;
          } else {
            positionJustifFermeture = true;
          }
          boolean positionJustifOuverture;
          boolean positionJustifOuverture;
          if ((dureeDiffereSpecifique.getQuantiteCourante() != null) && (!dureeDiffereSpecifique.getQuantiteCourante().getValeur().equals(dureeDiffereSpecifique.getQuantiteInitial().getValeur()))) {
            positionJustifOuverture = false;
          } else {
            positionJustifOuverture = true;
          }
          traiterLesPBJCsAvant(dureeDiffereSpecifique, p_periodeAvant, p_datesDeDecoupageDesPBJCs, p_dateBlocageActualisation, p_datesChgtTauxCADT, p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateGeneration, p_libelleBlocageActualisation, p_pbjcsAvant, consoPeriode.getPeriodeDiffereSpecifique(), false, positionJustifOuverture, positionJustifFermeture, periodesInterruptives, laPeriodeInterruptive);
        }
        if ((consoPeriode.getPeriodeDiffereStandard() != null) && (consoPeriode.getPeriodeDiffereStandard().chevauche(periodeUtAvant)))
        {
          boolean positionJustifFermeture;
          boolean positionJustifFermeture;
          if ((dureeDiffereStandardFin.getQuantiteCourante() != null) && (!dureeDiffereStandardFin.getQuantiteCourante().getValeur().equals(ZERO))) {
            positionJustifFermeture = false;
          } else {
            positionJustifFermeture = true;
          }
          boolean positionJustifOuverture;
          boolean positionJustifOuverture;
          if ((dureeDiffereStandard.getQuantiteCourante() != null) && (!dureeDiffereStandard.getQuantiteCourante().getValeur().equals(dureeDiffereStandard.getQuantiteInitial().getValeur()))) {
            positionJustifOuverture = false;
          } else {
            positionJustifOuverture = true;
          }
          traiterLesPBJCsAvant(dureeDiffereStandard, p_periodeAvant, p_datesDeDecoupageDesPBJCs, p_dateBlocageActualisation, p_datesChgtTauxCADT, p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateGeneration, p_libelleBlocageActualisation, p_pbjcsAvant, consoPeriode.getPeriodeDiffereStandard(), false, positionJustifOuverture, positionJustifFermeture, periodesInterruptives, laPeriodeInterruptive);
        }
        if ((consoPeriode.getPeriodeDelaiAttente() != null) && (consoPeriode.getPeriodeDelaiAttente().chevauche(periodeUtAvant)))
        {
          boolean positionJustifFermeture;
          boolean positionJustifFermeture;
          if ((!consoPeriode.getPeriodeDelaiAttente().getFin().coincideAvec(p_periodeAvant.getFin())) && (dureeDelaiAttenteFin.getQuantiteCourante() != null) && (!dureeDelaiAttenteFin.getQuantiteCourante().getValeur().equals(ZERO))) {
            positionJustifFermeture = false;
          } else {
            positionJustifFermeture = true;
          }
          boolean positionJustifOuverture;
          boolean positionJustifOuverture;
          if ((dureeDelaiAttente.getQuantiteCourante() != null) && (!dureeDelaiAttente.getQuantiteCourante().getValeur().equals(dureeDelaiAttente.getQuantiteInitial().getValeur()))) {
            positionJustifOuverture = false;
          } else {
            positionJustifOuverture = true;
          }
          traiterLesPBJCsAvant(dureeDelaiAttente, p_periodeAvant, p_datesDeDecoupageDesPBJCs, p_dateBlocageActualisation, p_datesChgtTauxCADT, p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateGeneration, p_libelleBlocageActualisation, p_pbjcsAvant, consoPeriode.getPeriodeDelaiAttente(), true, positionJustifOuverture, positionJustifFermeture, periodesInterruptives, laPeriodeInterruptive);
        }
        if ((utAvant.getQuantiteDecale() != null) && (utAvant.getQuantiteDecale().getValeurEntiere() > 0))
        {
          ChronologiePeriodes chronoPeriode = new ChronologiePeriodes();
          Iterator iterPbjc = p_pbjcsAvant.iterer();
          while (iterPbjc.hasNext())
          {
            PbjcNcp pbjcAvant = (PbjcNcp)iterPbjc.next();
            if (pbjcAvant.getDateDebut().estContenueDans(utAvant.getPeriode())) {
              chronoPeriode.ajouter(new ObjetChronoPeriodeConcrete(pbjcAvant.getDateDebut(), pbjcAvant.getDateFin()));
            }
          }
          ChronologiePeriodes chronoTrouPbjc = OutillageCalculADate.retourneLesTrous(chronoPeriode, ObjetChronoPeriodeConcrete.class, utAvant.getDateDebutConsoDATheorique(), Damj.min(utAvant.getDateFin(), calendrierAvant.getDernierJourAvant()));
          
          chronoTrouPbjc.iterer();
          while (chronoTrouPbjc.encoreSuivant())
          {
            ObjetChronoPeriodeConcrete objetChronoPeriodeConcrete = (ObjetChronoPeriodeConcrete)chronoTrouPbjc.elementSuivant();
            pbjcsAvantDec = creerPBJCDecalantePourLAvant(objetChronoPeriodeConcrete.getDateDebut(), objetChronoPeriodeConcrete.getDateFin(), p_attribution, "CT", new QuantiteJour(new BigDecimal(objetChronoPeriodeConcrete.getDuree())));
            
            ajouterPBJCSurLAvant(p_pbjcsAvant, pbjcsAvantDec, p_dateGeneration);
          }
        }
        filtrerPbjcAvantPeriodesInterruptives(periodesInterruptives, p_pbjcsAvant);
      }
    }
  }
  
  private void traiterLesPBJCsAvant(DureeConsommableAvant p_duree, Periode p_periodeAvant, List p_dateDecoupagePBJC, Damj p_dateBlocageActualisation, List p_dateChgtTauxCADT, AttributionSpec p_attribution, Collection p_periodesAER, ChronologiePeriodes p_periodesFormation, ChronologiePeriodes p_actionsFormation, Damj p_dateGeneration, String p_libelleBlocageActualisation, ChronologiePeriodes p_pbjcsAvant, Periode p_periodeConso, boolean p_estDelaiAttente, boolean p_positionJustifOuverture, boolean p_positionJustifFermeture, ChronologiePeriodes p_periodesInterruptives, ObjetChronoPeriode p_periodeInterruptive)
  {
    if (p_estDelaiAttente) {
      traiterLesPBJCsAvantDelaiAttente(p_periodeAvant, p_dateDecoupagePBJC, p_dateBlocageActualisation, p_dateChgtTauxCADT, p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateGeneration, p_libelleBlocageActualisation, p_pbjcsAvant, p_periodeConso, p_positionJustifOuverture, p_positionJustifFermeture, p_periodesInterruptives, p_periodeInterruptive);
    } else {
      traiterLesPBJCsAvantHorsDelaiAttente(p_duree, p_periodeAvant, p_dateDecoupagePBJC, p_dateBlocageActualisation, p_dateChgtTauxCADT, p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateGeneration, p_libelleBlocageActualisation, p_pbjcsAvant, p_periodeConso, p_positionJustifOuverture, p_positionJustifFermeture, p_periodesInterruptives, p_periodeInterruptive);
    }
  }
  
  private void traiterLesPBJCsAvantDelaiAttente(Periode p_periodeAvant, List p_dateDecoupagePBJC, Damj p_dateBlocageActualisation, List p_dateChgtTauxCADT, AttributionSpec p_attribution, Collection p_periodesAER, ChronologiePeriodes p_periodesFormation, ChronologiePeriodes p_actionsFormation, Damj p_dateGeneration, String p_libelleBlocageActualisation, ChronologiePeriodes p_pbjcsAvant, Periode p_periodeConso, boolean p_positionJustifOuverture, boolean p_positionJustifFermeture, ChronologiePeriodes p_periodesInterruptives, ObjetChronoPeriode p_periodeInterruptive)
  {
    Damj dateDebut = null;
    Damj date = null;
    Iterator iteratorDatesDecoupage = null;
    
    Periode periodeDiffere = new Periode(p_periodeConso.getDebut(), Damj.min(p_periodeConso.getFin(), p_periodeAvant.getFin()));
    
    p_dateDecoupagePBJC = retournerDatesDeRupturePBJCsAvant(p_dateChgtTauxCADT, periodeDiffere, p_dateBlocageActualisation);
    
    dateDebut = periodeDiffere.getDebut();
    iteratorDatesDecoupage = p_dateDecoupagePBJC.iterator();
    while (iteratorDatesDecoupage.hasNext())
    {
      date = (Damj)iteratorDatesDecoupage.next();
      dateDebut = creationPbjcAvantCarenceGestionMaintienEuropeen(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, dateDebut, date.veille(), null, p_periodesInterruptives, p_periodeInterruptive, p_dateBlocageActualisation, p_libelleBlocageActualisation, p_pbjcsAvant, p_dateGeneration, true, periodeDiffere, p_positionJustifOuverture, p_positionJustifFermeture);
    }
    creationPbjcAvantCarenceGestionMaintienEuropeen(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, dateDebut, periodeDiffere.getFin(), null, p_periodesInterruptives, p_periodeInterruptive, p_dateBlocageActualisation, p_libelleBlocageActualisation, p_pbjcsAvant, p_dateGeneration, true, periodeDiffere, p_positionJustifOuverture, p_positionJustifFermeture);
  }
  
  private void traiterLesPBJCsAvantHorsDelaiAttente(DureeConsommableAvant p_duree, Periode p_periodeAvant, List p_dateDecoupagePBJC, Damj p_dateBlocageActualisation, List p_dateChgtTauxCADT, AttributionSpec p_attribution, Collection p_periodesAER, ChronologiePeriodes p_periodesFormation, ChronologiePeriodes p_actionsFormation, Damj p_dateGeneration, String p_libelleBlocageActualisation, ChronologiePeriodes p_pbjcsAvant, Periode p_periodeConso, boolean p_positionJustifOuverture, boolean p_positionJustifFermeture, ChronologiePeriodes p_periodesInterruptives, ObjetChronoPeriode p_periodeInterruptive)
  {
    Damj dateDebut = null;
    Damj date = null;
    Iterator iteratorDatesDecoupage = null;
    Periode periodeDiff = new Periode(Damj.max(p_periodeConso.getDebut(), p_periodeAvant.getDebut()), Damj.min(p_periodeConso.getFin(), p_periodeAvant.getFin()));
    
    p_dateDecoupagePBJC = retournerDatesDeRupturePBJCsAvant(p_dateChgtTauxCADT, periodeDiff, p_dateBlocageActualisation);
    
    dateDebut = periodeDiff.getDebut();
    iteratorDatesDecoupage = p_dateDecoupagePBJC.iterator();
    while (iteratorDatesDecoupage.hasNext())
    {
      date = (Damj)iteratorDatesDecoupage.next();
      dateDebut = creationPbjcAvantCarenceGestionMaintienEuropeen(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, dateDebut, date.veille(), p_duree, p_periodesInterruptives, p_periodeInterruptive, p_dateBlocageActualisation, p_libelleBlocageActualisation, p_pbjcsAvant, p_dateGeneration, false, periodeDiff, p_positionJustifOuverture, p_positionJustifFermeture);
    }
    creationPbjcAvantCarenceGestionMaintienEuropeen(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, dateDebut, periodeDiff.getFin(), p_duree, p_periodesInterruptives, p_periodeInterruptive, p_dateBlocageActualisation, p_libelleBlocageActualisation, p_pbjcsAvant, p_dateGeneration, false, periodeDiff, p_positionJustifOuverture, p_positionJustifFermeture);
  }
  
  protected ResultatAvant retournerResultatCalculAvant(AttributionSpec p_attribution, ObjetChronoPeriodePriseEnCharge p_periodePEC)
    throws ApplicativeException
  {
    IndividuSpec individu = p_attribution.getDemandeur();
    if ((p_attribution instanceof Poursuite)) {
      p_periodePEC = OutillagePeriodes.recupererPeriodePECContenant(individu, ((Poursuite)p_attribution).getPjp());
    } else {
      p_periodePEC = OutillagePeriodes.recupererPeriodePECContenant(individu, p_attribution.getDateEffet());
    }
    if (p_periodePEC == null) {
      throw new CoucheLogiqueException("HG_PR_CALI_L_PAS_DE_PEC_POUR_EXECUTION_AVANT", "Attention lors de l'execution de l'avant, impossible de retrouver une periode de prise en charge.", null);
    }
    DomAvantPilotage domAvantPilotage = new DomAvantPilotage(p_attribution);
    domAvantPilotage.setAvecPriseEnCompteEvenement(true);
    domAvantPilotage.setExecutionPersistante(true);
    Contexte contexteCalcul = new Contexte();
    contexteCalcul.setDonnees(domAvantPilotage);
    
    Parcours parcoursAvant = new ParcoursAvantPilotageElementsIndemnisation();
    ResultatAvant resultatAvant = (ResultatAvant)parcoursAvant.effectuerParcours(contexteCalcul);
    
    return resultatAvant;
  }
  
  private PbjcNcp creerPBJCAvantTypeCarence(AttributionSpec p_attribution, Collection p_periodesAER, ChronologiePeriodes p_periodesFormation, ChronologiePeriodes p_actionsFormation, Damj p_debutPBJC, Damj p_finPBJC, DureeConsommableAvant p_duree, Periode p_periodeDuree, boolean p_positionJustifOuverture, boolean p_positionJustifFermeture)
  {
    Damj dateEffet = p_attribution.getDateEffet();
    if ((p_attribution instanceof Poursuite)) {
      dateEffet = ((Poursuite)p_attribution).getPjp();
    }
    PbjcNcp pbjcNcpAvant = creerPBJCAvant(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_debutPBJC, p_finPBJC);
    
    pbjcNcpAvant.setEtatReglementaireOd("3");
    if ((p_duree != null) && (p_duree.getTypeDureeConsommable() == 0))
    {
      pbjcNcpAvant.setEtatReglementaireOd("7");
    }
    else if ((p_duree != null) && (p_duree.getTypeDureeConsommable() == 2))
    {
      pbjcNcpAvant.setTypeCarence("IR");
      if (((p_debutPBJC.coincideAvec(p_periodeDuree.getDebut())) || (p_debutPBJC.coincideAvec(dateEffet))) && (p_positionJustifOuverture)) {
        pbjcNcpAvant.ajouterComplementDeJustification("AE");
      }
      if ((p_finPBJC.coincideAvec(p_periodeDuree.getFin())) && (p_positionJustifFermeture)) {
        pbjcNcpAvant.ajouterComplementDeJustification("ME");
      }
    }
    else if ((p_duree != null) && (p_duree.getTypeDureeConsommable() == 1))
    {
      pbjcNcpAvant.setTypeCarence("CP");
      if (((p_debutPBJC.coincideAvec(p_periodeDuree.getDebut())) || (p_debutPBJC.coincideAvec(dateEffet))) && (p_positionJustifOuverture)) {
        pbjcNcpAvant.ajouterComplementDeJustification("AD");
      }
      if ((p_finPBJC.coincideAvec(p_periodeDuree.getFin())) && (p_positionJustifFermeture)) {
        pbjcNcpAvant.ajouterComplementDeJustification("MP");
      }
    }
    return pbjcNcpAvant;
  }
  
  protected void ajouterPBJCSurLAvant(ChronologiePeriodes p_chronoAvant, PbjcNcp p_pbjcNcp, Damj p_dateGeneration)
  {
    if (p_pbjcNcp.getDateDebut().estApresOuCoincideAvec(p_dateGeneration))
    {
      p_chronoAvant.ajouter(p_pbjcNcp);
    }
    else if (p_pbjcNcp.getDateFin().estApres(p_dateGeneration))
    {
      p_pbjcNcp.setDateDebutPbjcsTrans(p_dateGeneration.lendemain());
      p_chronoAvant.ajouter(p_pbjcNcp);
    }
  }
  
  protected List retournerDatesDeRupturePBJCsAvant(List p_datesChgtTauxCADT, Periode p_periodeDeReference, Damj p_dateBlocageActualisation)
  {
    List listeARetourner = null;
    Damj dateChtTaux = null;
    Iterator iterateurDatesChtTaux = null;
    Damj date = null;
    
    listeARetourner = new ArrayList();
    
    iterateurDatesChtTaux = p_datesChgtTauxCADT.iterator();
    while (iterateurDatesChtTaux.hasNext())
    {
      dateChtTaux = (Damj)iterateurDatesChtTaux.next();
      if ((dateChtTaux.estApres(p_periodeDeReference.getDebut())) && (dateChtTaux.estAvantOuCoincideAvec(p_periodeDeReference.getFin())) && (!listeARetourner.contains(dateChtTaux))) {
        listeARetourner.add(dateChtTaux);
      }
    }
    date = p_periodeDeReference.getDebut();
    while (date.estAvant(p_periodeDeReference.getFin()))
    {
      date = date.getFinMois().lendemain();
      if ((date.estContenueDans(p_periodeDeReference)) && (!listeARetourner.contains(date))) {
        listeARetourner.add(date);
      }
    }
    if ((p_dateBlocageActualisation != null) && (p_dateBlocageActualisation.estContenueDans(p_periodeDeReference)) && (!listeARetourner.contains(p_dateBlocageActualisation))) {
      listeARetourner.add(p_dateBlocageActualisation);
    }
    Collections.sort(listeARetourner);
    
    return listeARetourner;
  }
  
  private PbjcNcp creerPBJCAvantTypeDiffere(AttributionSpec p_attribution, Collection p_periodesAER, ChronologiePeriodes p_periodesFormation, ChronologiePeriodes p_actionsFormation, Damj p_debut, Damj p_fin, Periode p_periode, boolean p_positionJustifOuverture, boolean p_positionJustifFermeture)
  {
    PbjcNcp pbjcNcpAvant = creerPBJCAvant(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_debut, p_fin);
    
    pbjcNcpAvant.setEtatReglementaireOd("9");
    if ((p_debut.coincideAvec(p_periode.getDebut())) && (p_positionJustifOuverture)) {
      pbjcNcpAvant.ajouterComplementDeJustification("AF");
    }
    if ((p_fin.coincideAvec(p_periode.getFin())) && (p_positionJustifFermeture)) {
      pbjcNcpAvant.ajouterComplementDeJustification("MF");
    }
    return pbjcNcpAvant;
  }
  
  protected void ajouterGroupeMontantPCRC(PbjcNcp p_pbjcNcp, MontantBaseSpec p_montantBaseSpec)
  {
    MontantAsuSpec montant = (MontantAsuSpec)p_montantBaseSpec;
    
    p_pbjcNcp.ajouterGroupeMontants("PCRC", 0, montant.getSjrNonReduit(), montant.getBaseCalculCrc().setScale(2, 3), Mathematiques.arrondiASup(montant.getTauxCrc().multiply(new BigDecimal("100")), 2), Mathematiques.arrondiASup(montant.getCrc().getValeur(), 2), montant.getPositionExonerationCrc());
    if (montant.getPensionInvaliditeADeduirePriseEnCompte() != null) {
      p_pbjcNcp.setMontantPensionInvalidite(montant.getPensionInvaliditeADeduirePriseEnCompte().getValeur());
    }
  }
  
  public void positionnerMontantSalaireRevalorisePlafonne(PbjcNcp pbjcNcp, AttributionSpec attribution, ConstituantsIndemnisation constituantsIndemnisation, MontantBaseSpec montant)
    throws CoucheLogiqueException
  {
    BigDecimal sjr = ((ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant()).getSjr().getSalaire();
    if (((ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant()).getCoefficientSaisonnier() != null) {
      sjr = sjr.multiply(((ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant()).getCoefficientSaisonnier());
    }
    pbjcNcp.setMontantSalaireRevalorisePlafonne(sjr.setScale(2, 3));
  }
  
  public void positionnerCoefficientTempsPartiel(PbjcNcp p_pbjcNcp, UniteTraitement p_ut, AttributionSpec p_attribution)
  {
    BigDecimal coeffTP = p_ut.getConstituantsIndemnisationEnDebutUT().getElementBaseIndemnisationCourant().getCoefficientTempsPartiel();
    p_pbjcNcp.setCoefficientTempsPartiel(coeffTP);
  }
  
  public void positionnerMontantSjc(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution, ConstituantsIndemnisation p_constituantsIndemnisation)
    throws CoucheLogiqueException
  {
    BigDecimal sjc = ((ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant()).getSjc().getSalaire();
    p_pbjcNcp.setMontantSjc(sjc);
  }
  
  public String retournerReglementApplicable(AttributionSpec p_attribution)
  {
    return ((AttributionAssuranceSpec)p_attribution).getReglementApplicable().getReglement().getNomReglement();
  }
  
  public void positionnerJustificationOuverturePJI(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    if ((p_attribution instanceof RepriseSpec))
    {
      AttributionAssuranceSpec reprise = (AttributionAssuranceSpec)p_attribution;
      if ("ASU_27".equals(reprise.getTypeExamen())) {
        p_pbjcNcp.ajouterComplementDeJustification("FE");
      }
      p_pbjcNcp.ajouterComplementDeJustification("BP");
      if (reprise.getDateAttribution().coincideAvec(reprise.getPji()))
      {
        AttributionAssuranceSpec assurancePrecedente = ((AttributionAssuranceSpec)p_attribution).getAttributionPrecedente();
        if ((assurancePrecedente != null) && (OutilDemande.estUneDemandeFinDroitAsr(assurancePrecedente.getDemande()))) {
          p_pbjcNcp.ajouterComplementDeJustification("BV");
        }
      }
      Collection collectionEvtsChangementParametre = null;
      Iterator iterateur = null;
      EvenementChangementParametre evenementChangementParametre = null;
      
      Damj dateDerniereRevalorisationAvantCessation = Damj.NUIT_DES_TEMPS;
      Damj dateDerniereRevalorisationAvantReprise = Damj.NUIT_DES_TEMPS;
      
      CalendrierExecutionCalculSpec calendrier = reprise.getAttributionPrecedente().getCalendrierExecutionCalcul();
      Damj dateFinAttributionPrecedente;
      Damj dateFinAttributionPrecedente;
      if ((calendrier != null) && (calendrier.getEtatAttribution() != 4)) {
        dateFinAttributionPrecedente = calendrier.getDernierJourIndemnisable();
      } else {
        dateFinAttributionPrecedente = OutilGestionPoursuite.getInstance().recupererDateAttributionOuPjpSiPoursuite(reprise.getAttributionPrecedente());
      }
      collectionEvtsChangementParametre = getEvtsChangementParametre(dateFinAttributionPrecedente);
      if (collectionEvtsChangementParametre != null)
      {
        iterateur = collectionEvtsChangementParametre.iterator();
        while (iterateur.hasNext())
        {
          evenementChangementParametre = (EvenementChangementParametre)iterateur.next();
          if (evenementChangementParametre.getNomParametre().equals("REVALORISATION")) {
            dateDerniereRevalorisationAvantCessation = evenementChangementParametre.getDateEffet();
          }
        }
      }
      collectionEvtsChangementParametre = getEvtsChangementParametre(dateFinAttributionPrecedente, p_attribution.getCalendrierExecutionCalcul().getPremierJourIndemnisable(), p_attribution);
      if (collectionEvtsChangementParametre != null)
      {
        iterateur = collectionEvtsChangementParametre.iterator();
        while (iterateur.hasNext())
        {
          evenementChangementParametre = (EvenementChangementParametre)iterateur.next();
          if (evenementChangementParametre.getNomParametre().equals("REVALORISATION")) {
            dateDerniereRevalorisationAvantReprise = evenementChangementParametre.getDateEffet();
          }
        }
      }
      Damj dateSjrAttributionPrecedente = null;
      if (OutilsTrancheCalcul.estTrancheActive(reprise.getAttributionPrecedente()))
      {
        TrancheExecutable tranche = OutilsTrancheCalcul.recupererTrancheInitiale(reprise);
        dateSjrAttributionPrecedente = tranche.getSjr().getDateDepart();
      }
      else
      {
        dateSjrAttributionPrecedente = reprise.getAttributionPrecedente().getElementBaseIndemnisation().getSjr().getDateDepart();
      }
      if ((dateDerniereRevalorisationAvantCessation.estAvant(dateDerniereRevalorisationAvantReprise)) && (RevalorisationSalaire.verifierDureePourReval(dateSjrAttributionPrecedente, dateDerniereRevalorisationAvantReprise))) {
        p_pbjcNcp.ajouterComplementDeJustification("CD");
      }
    }
    else if ((p_attribution instanceof ReadmissionSpec))
    {
      p_pbjcNcp.ajouterComplementDeJustification("BH");
    }
    else if ((p_attribution instanceof RevisionSpec))
    {
      p_pbjcNcp.ajouterComplementDeJustification("CX");
    }
    else
    {
      p_pbjcNcp.ajouterComplementDeJustification("BD");
    }
    if ((OutilsMaintienEuropeenEessiASU.getPjiMaintienEuropeenDuDroit(p_attribution) != null) && (p_pbjcNcp.getDateDebut().equals(OutilsMaintienEuropeenEessiASU.getPjiMaintienEuropeenDuDroit(p_attribution)))) {
      p_pbjcNcp.ajouterComplementDeJustification("CY");
    }
    if ((p_attribution instanceof Poursuite)) {
      p_pbjcNcp.ajouterComplementDeJustification("I2");
    }
  }
  
  public void positionnerJustificationFermetureDJI(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution, UniteTraitement p_ut)
  {
    if (p_ut.getArretProduitAvecRaison().isRaisonsContientRaison(1))
    {
      p_pbjcNcp.ajouterComplementDeJustification("ND");
      if (p_pbjcNcp.estEnAref()) {
        p_pbjcNcp.ajouterComplementDeJustification("NI");
      }
    }
    if (p_ut.getArretProduitAvecRaison().isRaisonsContientRaison(4))
    {
      Iterator iterateurPeriodesInterruptives = p_ut.getArretProduitAvecRaison().getPeriodesInterruptivesDefinitives().iterator();
      while (iterateurPeriodesInterruptives.hasNext())
      {
        ObjetChronoPeriode objetChronoPeriode = (ObjetChronoPeriode)iterateurPeriodesInterruptives.next();
        if ((objetChronoPeriode instanceof ObjetChronoPeriodeFinPec))
        {
          if (OutillagePeriodes.estRadiationFaisantSuitePecCA(p_attribution, objetChronoPeriode.getDateDebut())) {
            p_pbjcNcp.ajouterComplementDeJustification("RF");
          }
          String motifRadiation = ((ObjetChronoPeriodeFinPec)objetChronoPeriode).getMotifAnnulationPEC();
          
          p_pbjcNcp.setCodeRadiationLendemainPeriode(motifRadiation);
          
          p_pbjcNcp.ajouterComplementDeJustification("TD");
          if ((motifRadiation != null) && (motifRadiation.equals("73"))) {
            p_pbjcNcp.ajouterComplementDeJustification("OH");
          }
        }
        else if ((objetChronoPeriode instanceof ObjetChronoPeriodeRetraite))
        {
          if (((ObjetChronoPeriodeRetraite)objetChronoPeriode).getRetraite().estTypeBase()) {
            p_pbjcNcp.ajouterComplementDeJustification("OD");
          } else {
            p_pbjcNcp.ajouterComplementDeJustification(((ObjetChronoPeriodeRetraite)objetChronoPeriode).getRetraite().getMotif());
          }
        }
        else if ((objetChronoPeriode instanceof PeriodeExclusionDefinitiveDDTE))
        {
          String codeSanction = ((PeriodeExclusionDefinitiveDDTE)objetChronoPeriode).getCodeSanction();
          if (codeSanction.equals("ED")) {
            p_pbjcNcp.ajouterComplementDeJustification("SJ");
          } else if (codeSanction.equals("EX")) {
            p_pbjcNcp.ajouterComplementDeJustification("SI");
          }
        }
        else if ((objetChronoPeriode instanceof ObjetChronoPeriodeRejetDVDemandeExpresse))
        {
          p_pbjcNcp.ajouterComplementDeJustification("ST");
        }
        else if (((objetChronoPeriode instanceof ObjetChronoPeriodeRejetDRV)) || ((objetChronoPeriode instanceof ObjetChronoPeriodeRejetDVFilEau)))
        {
          p_pbjcNcp.ajouterComplementDeJustification("NX");
        }
        else if ((objetChronoPeriode instanceof ObjetChronoPeriodeAEDV))
        {
          p_pbjcNcp.ajouterComplementDeJustification("HX");
        }
        else if ((objetChronoPeriode instanceof ObjetChronoPeriodeRejetRevision))
        {
          p_pbjcNcp.ajouterComplementDeJustification("NY");
        }
        else if ((objetChronoPeriode instanceof PeriodeBlocageIndemnisation))
        {
          p_pbjcNcp.ajouterComplementDeJustification("OM");
        }
        else if ((objetChronoPeriode instanceof ObjetChronoPeriodeFinDureeMaintienDroit))
        {
          p_pbjcNcp.ajouterComplementDeJustification("R9");
        }
        else if ((objetChronoPeriode instanceof ObjetChronoPeriodeLimiteIndemnisationPMVS))
        {
          p_pbjcNcp.ajouterComplementDeJustification("NF");
        }
        else if ((objetChronoPeriode instanceof PeriodeDisponibilite))
        {
          p_pbjcNcp.ajouterComplementDeJustification(((PeriodeDisponibilite)objetChronoPeriode).getType());
          if (((PeriodeDisponibilite)objetChronoPeriode).estReintegration()) {
            p_pbjcNcp.ajouterComplementDeJustification("OA");
          }
        }
      }
    }
  }
  
  public void positionnerComplementJustification(PbjcNcp p_pbjcNcp, UniteTraitement p_ut, AttributionSpec p_attribution)
  {
    Collection collectionEvtsChangementParametre = null;
    Collection collectionEvenements = null;
    Iterator iterateur = null;
    EvenementChangementParametre evenementChangementParametre = null;
    
    EvenementCalculSpec evtCalcul = null;
    ChronologiePeriodes periodes = null;
    ObjetChronoPeriode objetChronoPeriode = null;
    if ((p_ut.getConstituantsCalculActiviteReduiteEnFinUT() != null) && (p_ut.getConstituantsCalculActiviteReduiteEnFinUT().getCumulMoisNonIndemnise() == 3) && (p_attribution.getDemandeur() != null) && (p_attribution.getDemandeur().getIndividuPbjcNcp() != null) && (p_attribution.getDemandeur().getIndividuPbjcNcp().getDateAtteinteMoisNonPaye() != null) && (p_ut.getDateFin().coincideAvec(p_attribution.getDemandeur().getIndividuPbjcNcp().getDateAtteinteMoisNonPaye())))
    {
      p_pbjcNcp.ajouterComplementDeJustification("SW");
    }
    else if ((p_attribution.getCalendrierExecutionCalcul() != null) && (((CalendrierExecutionCalculPeriodique)p_attribution.getCalendrierExecutionCalcul()).getDateDrv() != null) && (p_ut.getDateDebut().estApresOuCoincideAvec(((CalendrierExecutionCalculPeriodique)p_attribution.getCalendrierExecutionCalcul()).getDateDrv())))
    {
      p_pbjcNcp.ajouterComplementDeJustification("GY");
      p_pbjcNcp.setEtatAdministratifOd("2");
    }
    collectionEvtsChangementParametre = getEvtsChangementParametre(p_pbjcNcp.getDateDebut());
    if (collectionEvtsChangementParametre != null)
    {
      iterateur = collectionEvtsChangementParametre.iterator();
      while (iterateur.hasNext())
      {
        evenementChangementParametre = (EvenementChangementParametre)iterateur.next();
        if (evenementChangementParametre.getNomParametre().equals("REVALORISATION")) {
          if ((evenementChangementParametre.getDateEffet().coincideAvec(p_pbjcNcp.getDateDebut())) && (RevalorisationSalaire.verifierDureePourReval(p_attribution, evenementChangementParametre.getDateEffet()))) {
            p_pbjcNcp.ajouterComplementDeJustification("CD");
          }
        }
        if ((evenementChangementParametre.getNomParametre().equals("NV PARAMETRE")) && 
        
          (evenementChangementParametre.getDateEffet().coincideAvec(p_pbjcNcp.getDateDebut()))) {
          p_pbjcNcp.ajouterComplementDeJustification("DH");
        }
      }
    }
    if (p_ut.isNeutralisee())
    {
      int typeNeutralisation = p_ut.getTypeNeutralisation();
      if ((typeNeutralisation == 0) || (typeNeutralisation == 7)) {
        p_pbjcNcp.ajouterComplementDeJustification("GC");
      } else if ((typeNeutralisation == 1) || (typeNeutralisation == 2)) {
        p_pbjcNcp.ajouterComplementDeJustification("GD");
      } else if (typeNeutralisation == 6) {
        p_pbjcNcp.ajouterComplementDeJustification("GE");
      }
    }
    collectionEvenements = p_ut.getCollectionEvenements();
    if (collectionEvenements != null)
    {
      iterateur = collectionEvenements.iterator();
      while (iterateur.hasNext())
      {
        evtCalcul = (EvenementCalculSpec)iterateur.next();
        if (((evtCalcul instanceof EvenementFinCumul)) && 
          (((EvenementFinCumul)evtCalcul).getDateEvenement().coincideAvec(p_pbjcNcp.getDateDebut()))) {
          p_pbjcNcp.ajouterComplementDeJustification("G7");
        }
      }
    }
    periodes = p_ut.getQualificationPeriodes().getPeriodesSegmentantes();
    periodes.iterer();
    while (periodes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)periodes.elementSuivant();
      if (objetChronoPeriode.getDateDebut().coincideAvec(p_pbjcNcp.getDateDebut())) {
        if (((objetChronoPeriode instanceof ObjetChronoAnniversaire50Ans)) || ((objetChronoPeriode instanceof ObjetChronoAnniversaire55Ans)) || ((objetChronoPeriode instanceof ObjetChronoAnniversaire60Ans)))
        {
          if ((objetChronoPeriode instanceof ObjetChronoAnniversaire50Ans)) {
            p_pbjcNcp.setCoefAvantageVieillesse(fr.unedic.cali.asu.parametres.ParametresIndemnisation.getParametresIndemnisation().getTauxAvantageViellesse(new DureeCalendaire(50)));
          } else if ((objetChronoPeriode instanceof ObjetChronoAnniversaire55Ans)) {
            p_pbjcNcp.setCoefAvantageVieillesse(fr.unedic.cali.asu.parametres.ParametresIndemnisation.getParametresIndemnisation().getTauxAvantageViellesse(new DureeCalendaire(55)));
          } else if ((objetChronoPeriode instanceof ObjetChronoAnniversaire60Ans)) {
            p_pbjcNcp.setCoefAvantageVieillesse(fr.unedic.cali.asu.parametres.ParametresIndemnisation.getParametresIndemnisation().getTauxAvantageViellesse(new DureeCalendaire(60)));
          }
          if (p_pbjcNcp.getCoefAvantageVieillesse().compareTo(new BigDecimal("0")) == 1) {
            p_pbjcNcp.ajouterComplementDeJustification("DF");
          }
        }
        else if ((objetChronoPeriode instanceof PeriodePensionInvalidite))
        {
          p_pbjcNcp.ajouterComplementDeJustification("FR");
        }
        else if ((objetChronoPeriode instanceof PeriodeAvantageVieillesse))
        {
          p_pbjcNcp.ajouterComplementDeJustification("DG");
          if (objetChronoPeriode.getDateDebut().estApres(PeriodeAvantageVieillesse.DATE_BASCULE_AV)) {
            p_pbjcNcp.ajouterComplementDeJustification("DJ");
          } else {
            p_pbjcNcp.ajouterComplementDeJustification("DI");
          }
        }
        else if (((objetChronoPeriode instanceof PeriodeInterStageFormation)) || ((objetChronoPeriode instanceof FinActionFormation)))
        {
          p_pbjcNcp.ajouterComplementDeJustification("E2");
        }
        else if ((objetChronoPeriode instanceof ObjetChronoPeriodeDebutPec))
        {
          if (p_pbjcNcp.getDateDebut().coincideAvec(OutilsMaintienEuropeenEessiASU.getDateMaintienEuropeen(p_ut.getConstituantsIndemnisationEnFinUT()))) {
            p_pbjcNcp.ajouterComplementDeJustification("CY");
          }
          p_pbjcNcp.ajouterComplementDeJustification("E9");
        }
      }
    }
    Chronologie radiations = OutillagePeriodes.recupererRadiations(p_attribution.getDemandeur());
    radiations.iterer();
    while (radiations.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriodeRadiation)radiations.elementSuivant();
      if (((objetChronoPeriode instanceof ObjetChronoPeriodeRadiation)) && (objetChronoPeriode.getDateDebut().coincideAvec(p_pbjcNcp.getDateFin().lendemain())))
      {
        String motifRadiation = ((ObjetChronoPeriodeRadiation)objetChronoPeriode).getMotifAnnulationPEC();
        
        p_pbjcNcp.setCodeRadiationLendemainPeriode(motifRadiation);
        
        p_pbjcNcp.ajouterComplementDeJustification("TD");
      }
    }
  }
  
  public void positionnerInformationDecisionSanction(PbjcNcp p_pbjcNcp, UniteTraitement p_ut)
  {
    ChronologiePeriodes periodes = null;
    ObjetChronoPeriode objetChronoPeriode = null;
    
    periodes = p_ut.getQualificationPeriodes().getPeriodesSuspensives();
    periodes.iterer();
    while (periodes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)periodes.elementSuivant();
      if ((objetChronoPeriode.chevauche(new Periode(p_pbjcNcp.getDateDebut(), p_pbjcNcp.getDateFin()))) && (((objetChronoPeriode instanceof PeriodeSuspensionDDTEAvecImputation)) || ((objetChronoPeriode instanceof PeriodeSuspensionDDTESansImputation)))) {
        positionnerInformationDecisionSanction(p_pbjcNcp, objetChronoPeriode);
      }
    }
    periodes = p_ut.getQualificationPeriodes().getPeriodesSegmentantes();
    periodes.iterer();
    while (periodes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)periodes.elementSuivant();
      if (((objetChronoPeriode instanceof PeriodeSanctionReductionMontant)) && (objetChronoPeriode.chevauche(new Periode(p_pbjcNcp.getDateDebut(), p_pbjcNcp.getDateFin())))) {
        positionnerInformationDecisionSanction(p_pbjcNcp, objetChronoPeriode);
      }
    }
  }
  
  public void positionnerInformationDecisionSanction(PbjcNcp p_pbjcNcp, ObjetChronoPeriode p_periode)
  {
    String codeSanction = null;
    Periode periodeInitiale = null;
    if ((p_periode instanceof PeriodeSuspensionDDTEAvecImputation))
    {
      periodeInitiale = ((PeriodeSuspensionDDTEAvecImputation)p_periode).getPeriodeInitiale();
      codeSanction = ((PeriodeSuspensionDDTEAvecImputation)p_periode).getCodeSanction();
      if (periodeInitiale.getDebut().coincideAvec(p_pbjcNcp.getDateDebut())) {
        if (codeSanction.equals("SD")) {
          p_pbjcNcp.ajouterComplementDeJustification("EG");
        } else if (codeSanction.equals("SE")) {
          p_pbjcNcp.ajouterComplementDeJustification("EI");
        } else if (codeSanction.equals("SF")) {
          p_pbjcNcp.ajouterComplementDeJustification("EN");
        }
      }
      if (periodeInitiale.getFin().coincideAvec(p_pbjcNcp.getDateFin())) {
        if (codeSanction.equals("SD")) {
          p_pbjcNcp.ajouterComplementDeJustification("SG");
        } else if (codeSanction.equals("SE")) {
          p_pbjcNcp.ajouterComplementDeJustification("SH");
        } else if (codeSanction.equals("SF")) {
          p_pbjcNcp.ajouterComplementDeJustification("SN");
        }
      }
    }
    else if ((p_periode instanceof PeriodeSuspensionDDTESansImputation))
    {
      periodeInitiale = ((PeriodeSuspensionDDTESansImputation)p_periode).getPeriodeInitiale();
      codeSanction = ((PeriodeSuspensionDDTESansImputation)p_periode).getCodeSanction();
      if (periodeInitiale.getDebut().coincideAvec(p_pbjcNcp.getDateDebut())) {
        if (codeSanction.equals("SD")) {
          p_pbjcNcp.ajouterComplementDeJustification("EH");
        } else if (codeSanction.equals("SE")) {
          p_pbjcNcp.ajouterComplementDeJustification("EJ");
        } else if (codeSanction.equals("SF")) {
          p_pbjcNcp.ajouterComplementDeJustification("EO");
        }
      }
      if (periodeInitiale.getFin().coincideAvec(p_pbjcNcp.getDateFin())) {
        if (codeSanction.equals("SD")) {
          p_pbjcNcp.ajouterComplementDeJustification("SG");
        } else if (codeSanction.equals("SE")) {
          p_pbjcNcp.ajouterComplementDeJustification("SH");
        } else if (codeSanction.equals("SF")) {
          p_pbjcNcp.ajouterComplementDeJustification("SO");
        }
      }
    }
    else if ((p_periode instanceof PeriodeSanctionReductionMontant))
    {
      periodeInitiale = ((PeriodeSanctionReductionMontant)p_periode).getPeriodeInitiale();
      codeSanction = ((PeriodeSanctionReductionMontant)p_periode).getCodeSanction();
      if (codeSanction.equals("R1")) {
        p_pbjcNcp.setTxSanction(20);
      } else if (codeSanction.equals("R2")) {
        p_pbjcNcp.setTxSanction(50);
      }
      if (periodeInitiale.getDebut().coincideAvec(p_pbjcNcp.getDateDebut())) {
        if (codeSanction.equals("R1")) {
          p_pbjcNcp.ajouterComplementDeJustification("ES");
        } else if (codeSanction.equals("R2")) {
          p_pbjcNcp.ajouterComplementDeJustification("ET");
        }
      }
      if (periodeInitiale.getFin().coincideAvec(p_pbjcNcp.getDateFin())) {
        p_pbjcNcp.ajouterComplementDeJustification("SS");
      }
    }
    else if ((p_periode instanceof PeriodeSuspensionTitreConservatoire))
    {
      periodeInitiale = ((PeriodeSuspensionTitreConservatoire)p_periode).getPeriodeInitiale();
      if (periodeInitiale.getDebut().coincideAvec(p_pbjcNcp.getDateDebut())) {
        p_pbjcNcp.ajouterComplementDeJustification("EC");
      }
      if (periodeInitiale.getFin().coincideAvec(p_pbjcNcp.getDateFin())) {
        p_pbjcNcp.ajouterComplementDeJustification("SG");
      }
    }
  }
  
  public void positionnerInformationSuspension(PbjcNcp p_pbjcNcp, UniteTraitement p_ut)
  {
    ChronologiePeriodes periodes = null;
    ObjetChronoPeriode objetChronoPeriode = null;
    
    periodes = p_ut.getQualificationPeriodes().getPeriodesSuspensives();
    periodes.iterer();
    while (periodes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)periodes.elementSuivant();
      if ((objetChronoPeriode instanceof PeriodeServiceCivique))
      {
        PeriodeServiceCivique periodeServiceCivique = (PeriodeServiceCivique)objetChronoPeriode;
        if (periodeServiceCivique.getPeriodeInitiale().commenceAvec(p_pbjcNcp.getDateDebut())) {
          p_pbjcNcp.ajouterComplementDeJustification("I1");
        }
        if (periodeServiceCivique.getPeriodeInitiale().finitAvec(p_pbjcNcp.getDateFin())) {
          p_pbjcNcp.ajouterComplementDeJustification("U1");
        }
      }
    }
  }
  
  protected Collection getEvtsChangementParametre(Damj p_date)
  {
    List evtsRetour = new ArrayList();
    fr.unedic.cali.asu.parametres.EvenementParametre evtParam = fr.unedic.cali.asu.parametres.ParametresIndemnisation.getParametresIndemnisation().getElementActif(p_date);
    EvenementChangementParametre evt = null;
    if (evtParam.isNouveauRevalorisationSjr())
    {
      evt = new EvenementChangementParametre("REVALORISATION", evtParam.getDateEvenement());
      evtsRetour.add(evt);
    }
    if ((evtParam.isNouveauAllocationMinimale()) || (evtParam.isNouveauCotisationRetraiteComplementaire()) || (evtParam.isNouveauPartieFixe()) || (evtParam.isNouveauPlafond()) || (evtParam.isNouveauSeuilMinimalAREF()) || (evtParam.isNouveauSmicHoraire()))
    {
      evt = new EvenementChangementParametre("NV PARAMETRE", evtParam.getDateEvenement());
      evtsRetour.add(evt);
    }
    return evtsRetour;
  }
  
  public Collection getEvtsChangementParametre(Damj p_dateDebut, Damj p_dateFin, AttributionSpec p_attribution)
  {
    List evtsRetour = new ArrayList();
    Chronologie chronoEvtParam = fr.unedic.cali.asu.parametres.ParametresIndemnisation.getParametresIndemnisation().getParametresActifs(new Periode(p_dateDebut, p_dateFin));
    EvenementChangementParametre evt = null;
    
    Iterator iterateur = chronoEvtParam.iterer();
    while (iterateur.hasNext())
    {
      fr.unedic.cali.asu.parametres.EvenementParametre evtParam = (fr.unedic.cali.asu.parametres.EvenementParametre)iterateur.next();
      if (evtParam.isNouveauRevalorisationSjr())
      {
        evt = new EvenementChangementParametre("REVALORISATION", evtParam.getDateEvenement());
        evtsRetour.add(evt);
      }
      else if ((evtParam.isNouveauAllocationMinimale()) || (evtParam.isNouveauCotisationRetraiteComplementaire()) || (evtParam.isNouveauPartieFixe()) || (evtParam.isNouveauPlafond()) || (evtParam.isNouveauSeuilMinimalAREF()) || (evtParam.isNouveauSmicHoraire()))
      {
        evt = new EvenementChangementParametre("NV PARAMETRE", evtParam.getDateEvenement());
        evtsRetour.add(evt);
      }
    }
    return evtsRetour;
  }
  
  public void positionnerNombreMoisEnPaiementProvisoire(PbjcNcp p_pbjcNcp, UniteTraitement p_ut)
  {
    p_pbjcNcp.setNbMoisPaiementProvis(((ConstituantsCalculActiviteReduiteGamme)p_ut.getConstituantsCalculActiviteReduiteEnFinUT()).getNbMoisEnPPA());
  }
  
  public void ajouterGroupeMontantProduit(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution, Somme p_somme, UniteTraitement p_ut)
    throws CoucheLogiqueException
  {
    if ((p_somme.getMontant().getType().equals("FORMATION EFFECTIVE")) || ((p_somme.getMontant().getType().equals("FORMATION PREVISIONNELLE")) && (OutilsMaintienEuropeenEessiASU.ajouterGroupeMontantFormation(p_ut.getConstituantsIndemnisationEnFinUT(), p_pbjcNcp.getDateFin())))) {
      ajouterGroupeMontantAREF(p_pbjcNcp, p_attribution.getProduitExecution().getNom(), p_somme, p_ut);
    } else if (!estMontantAZeroApresDateApplication(p_somme, p_ut)) {
      p_pbjcNcp.ajouterGroupeMontants(p_attribution.getProduitExecution().getNom(), 0, BigDecimal.ZERO, p_somme.getMontant().getMontantBrut().getValeur(), BigDecimal.ONE, p_somme.getMontant().getMontantBrut().getValeur(), "");
    }
    if (p_pbjcNcp.isTopApplicationCRC()) {
      ajouterGroupeMontantPCRC(p_pbjcNcp, p_somme.getMontant());
    }
    verificationMontantNull(p_pbjcNcp, p_somme, p_ut);
  }
  
  private void verificationMontantNull(PbjcNcp pbjcNcp, Somme somme, UniteTraitement ut)
    throws CoucheLogiqueException
  {
    if ((pbjcNcp.getMontantPensionInvalidite() != null) && (pbjcNcp.getMontantPensionInvalidite().compareTo(BigDecimal.ZERO) > 0)) {
      pbjcNcp.setInterrupIndemParPensionInvalidite("N");
    }
    if (estMontantAZeroApresDateApplication(somme, ut))
    {
      pbjcNcp.setQualificationPeriode(2);
      if ((pbjcNcp.getMontantPensionInvalidite() != null) && (pbjcNcp.getMontantPensionInvalidite().compareTo(BigDecimal.ZERO) > 0) && (pbjcNcp.getEtatAdministratifOd().equals("1"))) {
        pbjcNcp.setInterrupIndemParPensionInvalidite("O");
      }
    }
  }
  
  private boolean estMontantAZeroApresDateApplication(Somme somme, UniteTraitement ut)
    throws CoucheLogiqueException
  {
    return (somme.getMontant().getMontantBrut().getValeur().compareTo(BigDecimal.ZERO) == 0) && (ut.getDateDebut().estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("PI à 0 suite INC0399669")));
  }
  
  private void ajouterGroupeMontantAREF(PbjcNcp p_pbjcNcp, String p_nomProduit, Somme p_somme, UniteTraitement p_ut)
  {
    ChronologiePeriodes periodes = null;
    ObjetChronoPeriode objetChronoPeriode = null;
    PeriodeFormation periodeFormationCalcul = null;
    
    p_pbjcNcp.ajouterGroupeMontants(p_nomProduit, 1, new BigDecimal("0"), p_somme.getMontant().getMontantBrut().getValeur(), new BigDecimal("1"), p_somme.getMontant().getMontantBrut().getValeur(), "");
    
    periodes = p_ut.getQualificationPeriodes().getPeriodesSegmentantes();
    periodes.iterer();
    while (periodes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)periodes.elementSuivant();
      if ((objetChronoPeriode instanceof PeriodeFormation))
      {
        if (objetChronoPeriode.getDateDebut().equals(p_pbjcNcp.getDateDebut())) {
          if (((PeriodeFormation)objetChronoPeriode).getIdentifiantPeriodeFormation() == 1) {
            p_pbjcNcp.ajouterComplementDeJustification("BF");
          } else {
            p_pbjcNcp.ajouterComplementDeJustification("BA");
          }
        }
        if (objetChronoPeriode.getDateFin().equals(p_pbjcNcp.getDateFin()))
        {
          p_pbjcNcp.ajouterComplementDeJustification("TH");
          p_pbjcNcp.ajouterComplementDeJustification("TD");
          
          p_pbjcNcp.setCodeRadiationLendemainPeriode("41");
        }
        if (p_pbjcNcp.chevauche(new Periode(objetChronoPeriode.getDateDebut(), objetChronoPeriode.getDateFin())))
        {
          periodeFormationCalcul = (PeriodeFormation)objetChronoPeriode;
          p_pbjcNcp.setIdStageFormation(periodeFormationCalcul.getIdentifiantPeriodeFormation());
          p_pbjcNcp.setTypeMesurePourLEmploi(periodeFormationCalcul.getTypeMesureEmploi());
        }
      }
      else if (((objetChronoPeriode instanceof PeriodeInterStageFormation)) && 
        (objetChronoPeriode.getDateDebut().veille().equals(p_pbjcNcp.getDateFin())))
      {
        p_pbjcNcp.ajouterComplementDeJustification("TH");
        p_pbjcNcp.ajouterComplementDeJustification("TD");
      }
    }
    periodes = p_ut.getQualificationPeriodes().getPeriodesNonQualifiees();
    periodes.iterer();
    while (periodes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)periodes.elementSuivant();
      if (((objetChronoPeriode instanceof ActionFormation)) && 
        (p_pbjcNcp.chevauche(new Periode(objetChronoPeriode.getDateDebut(), objetChronoPeriode.getDateFin()))))
      {
        p_pbjcNcp.setIdPlanFormation(((ActionFormation)objetChronoPeriode).getIdentifiantActionFormation());
        
        p_pbjcNcp.setTypeDePlan(((ActionFormation)objetChronoPeriode).getTypePlan());
      }
    }
    if ((periodeFormationCalcul != null) && (periodeFormationCalcul.getPeriodeEffectiveInitiale() != null)) {
      ajouterGroupeMontantCGF(p_pbjcNcp, periodeFormationCalcul);
    }
  }
  
  private PbjcNcp creerPBJCAvant(AttributionSpec p_attribution, Collection p_periodesAER, ChronologiePeriodes p_periodesFormation, ChronologiePeriodes p_actionsFormation, Damj p_dateDebut, Damj p_dateFin)
  {
    PbjcNcp pbjcNcp = null;
    ObjetChronoPeriodePriseEnCharge pec = null;
    PeriodeFormation periodeFormationCalcul = null;
    
    pbjcNcp = new PbjcNcp(p_dateDebut, p_dateFin);
    
    positionnerReferencesOuvertureDroit(pbjcNcp, p_attribution);
    
    pbjcNcp.setRefBaseCalculMontantBrut(retournerReferenceBaseCalcul(p_attribution));
    
    pbjcNcp.setProduit(p_attribution.getProduitExecution().getNom());
    
    pbjcNcp.setNaturePBJC("CA");
    
    pbjcNcp.setEtatIndemnisation("AVANT");
    
    pbjcNcp.setEtatAdministratifOd("1");
    
    pbjcNcp.setRegimeApplicable(retournerReglementApplicable(p_attribution));
    
    pbjcNcp.setCodeMotifNonPaiement("00");
    
    pbjcNcp.setRangProlongation(0);
    if ((p_attribution instanceof Poursuite)) {
      pbjcNcp.setReliquatDureeMax(((Poursuite)p_attribution).getUniteTraitement().getConstituantsIndemnisationEnFinUT().getDureeIndemnisation().getQuantiteCourante().getValeurEntiere());
    } else {
      pbjcNcp.setReliquatDureeMax(((AttributionAssuranceSpec)p_attribution).getDureeIndemnisationTheorique().getValeurEntiere());
    }
    pbjcNcp.setCumulCourant(retournerQuantiteIndemnisationInitialeDroit(p_attribution, null).getValeurEntiere() - pbjcNcp.getReliquatDureeMax());
    
    positionnerPriseEnChargeAER(pbjcNcp, p_periodesAER);
    
    pec = OutillagePeriodes.recupererPeriodePECContenant(p_attribution.getDemandeur(), p_dateDebut);
    if (pec != null) {
      pbjcNcp.setAleIndividu(pec.getAleIndividu());
    }
    positionnerInfoConventionGestion(pbjcNcp, p_attribution);
    
    p_periodesFormation.iterer();
    while (p_periodesFormation.encoreSuivant())
    {
      periodeFormationCalcul = (PeriodeFormation)p_periodesFormation.elementSuivant();
      if ((periodeFormationCalcul.getPeriodeEffectiveInitiale() != null) && 
        (periodeFormationCalcul.getPeriodeEffectiveInitiale().chevauche(new Periode(p_dateDebut, p_dateFin))))
      {
        if ((!pbjcNcp.getProduit().equals("ASU_CAA14_02")) && (!pbjcNcp.getProduit().equals("ASU_CAA14_03"))) {
          ajouterGroupeMontantCGF(pbjcNcp, periodeFormationCalcul);
        }
        pbjcNcp.setIdStageFormation(periodeFormationCalcul.getIdentifiantPeriodeFormation());
        pbjcNcp.setTypeMesurePourLEmploi(periodeFormationCalcul.getTypeMesureEmploi());
      }
    }
    p_actionsFormation.iterer();
    while (p_actionsFormation.encoreSuivant())
    {
      ActionFormation actionFormationCalcul = (ActionFormation)p_actionsFormation.elementSuivant();
      if (pbjcNcp.chevauche(new Periode(actionFormationCalcul.getDateDebut(), actionFormationCalcul.getDateFin())))
      {
        pbjcNcp.setIdPlanFormation(actionFormationCalcul.getIdentifiantActionFormation());
        
        pbjcNcp.setTypeDePlan(actionFormationCalcul.getTypePlan());
      }
    }
    pbjcNcp.setNbJoursAREF(initialiserCompteurFormation(p_attribution));
    if (OutilsTrancheCalcul.estTrancheActive(p_attribution))
    {
      TrancheExecutable tranche = OutilsTrancheCalcul.recupererTrancheInitiale(p_attribution);
      if (tranche.isEligibleAllongementAREF())
      {
        List<?> listeDuree = OutilsTrancheCalcul.getListeDurees((Attribution)p_attribution);
        Iterator<?> ite = listeDuree.iterator();
        while (ite.hasNext())
        {
          QuantiteDroitSpec duree = (QuantiteDroitSpec)ite.next();
          if ((duree instanceof DureeProlongationAbstraite)) {
            pbjcNcp.setReliquatAllongementAREF(duree.getQuantiteInitial().getValeurEntiere());
          }
        }
      }
    }
    return pbjcNcp;
  }
  
  protected void ajouterGroupeMontantCGF(PbjcNcp p_pbjcNcp, PeriodeFormation p_periodeFormationCalcul)
  {
    BigDecimal nbHeuresTotal = null;
    BigDecimal nbDuree = null;
    BigDecimal nbHeuresStageParJour = null;
    BigDecimal tauxCotisationAccidentTravail = null;
    fr.unedic.cali.calcul.dom.EvenementParametre evenementParametre = null;
    
    nbHeuresTotal = p_periodeFormationCalcul.getActionFormation().getQuantiteHoraireTotal().getValeur();
    
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(p_pbjcNcp.getDateDebut());
    StrategieCotisationsGeneralesForfaitairesSpec strategieCotisationsGeneralesForfaitaires = (StrategieCotisationsGeneralesForfaitairesSpec)FabriqueStrategieCotisationsGeneralesForfaitaires.getInstance().getStrategie(critereStrategie);
    
    nbDuree = strategieCotisationsGeneralesForfaitaires.determinerNombreJourFormation(p_periodeFormationCalcul.getActionFormation());
    
    nbHeuresStageParJour = Mathematiques.diviseASup(nbHeuresTotal, nbDuree, 2);
    
    evenementParametre = fr.unedic.cali.calcul.parametres.ParametresIndemnisation.getParametresIndemnisation().getElementActif(p_pbjcNcp.getDateDebut());
    
    tauxCotisationAccidentTravail = evenementParametre.getTauxAccidentTravail();
    if ((nbHeuresStageParJour != null) && (tauxCotisationAccidentTravail != null)) {
      p_pbjcNcp.ajouterGroupeMontants("CADT", 1, new BigDecimal("0"), nbHeuresStageParJour, tauxCotisationAccidentTravail, Mathematiques.arrondiASup(nbHeuresStageParJour.multiply(tauxCotisationAccidentTravail), 2), "");
    }
  }
  
  public int retournerMaxDureeReglementaireCourante(AttributionSpec p_attribution)
  {
    return 0;
  }
  
  public int retournerReliquatDureeReglementaireCourante(UniteTraitement p_ut)
  {
    return 0;
  }
  
  public void positionnerRangProlongation(PbjcNcp p_pbjcNcp, UniteTraitement p_ut, AttributionSpec p_attribution) {}
  
  public int retournerReferenceBaseCalcul(AttributionSpec p_attribution)
  {
    if ((p_attribution.getNatureDecision() == 11) || ((p_attribution.getNatureDecision() == 26) && (!((Attribution)p_attribution).isMontantRetenuCourant()))) {
      return 2;
    }
    if ((p_attribution instanceof RepriseSpec))
    {
      AttributionAssuranceSpec attributionOrigine = (AttributionAssuranceSpec)((AttributionAssuranceSpec)p_attribution).getOuvertureDroit();
      if ((attributionOrigine.getNatureDecision() == 11) || ((attributionOrigine.getNatureDecision() == 26) && (!((Attribution)attributionOrigine).isMontantRetenuCourant()))) {
        return 2;
      }
    }
    return 1;
  }
  
  public void positionnerDonneesAvantageVieillesse(PbjcNcp p_pbjcNcp, UniteTraitement p_ut, AttributionSpec p_attribution)
  {
    ElementBaseIndemnisation elementBaseIndemnisationFinUT = null;
    ElementBaseIndemnisation elementBaseIndemnisationDebutUT = null;
    ChronologiePeriodes chronoPeriodesSegmentantes = null;
    PeriodeAvantageVieillesse periodeAvantageVieillesse = null;
    fr.unedic.cali.asu.parametres.ParametresIndemnisation parametresIndemnisation = fr.unedic.cali.asu.parametres.ParametresIndemnisation.getParametresIndemnisation();
    BigDecimal montantAVAPositionner = null;
    
    elementBaseIndemnisationDebutUT = (ElementBaseIndemnisation)p_ut.getConstituantsIndemnisationEnDebutUT().getElementBaseIndemnisationCourant();
    elementBaseIndemnisationFinUT = (ElementBaseIndemnisation)p_ut.getConstituantsIndemnisationEnFinUT().getElementBaseIndemnisationCourant();
    
    chronoPeriodesSegmentantes = p_ut.getQualificationPeriodes().getPeriodesSegmentantes();
    if ((chronoPeriodesSegmentantes != null) && (!chronoPeriodesSegmentantes.estVide()))
    {
      chronoPeriodesSegmentantes.iterer();
      while (chronoPeriodesSegmentantes.encoreSuivant())
      {
        ObjetChronoPeriode periode = (ObjetChronoPeriode)chronoPeriodesSegmentantes.elementSuivant();
        if (((periode instanceof PeriodeAvantageVieillesse)) && (periode.chevauche(new Periode(p_pbjcNcp.getDateDebut(), p_pbjcNcp.getDateFin())))) {
          periodeAvantageVieillesse = (PeriodeAvantageVieillesse)periode;
        }
      }
    }
    p_pbjcNcp.setCoefAvantageVieillesse(parametresIndemnisation.getTauxAvantageViellesse(p_attribution.getDemandeur().getAgeALaDate(p_pbjcNcp.getDateDebut())));
    if (periodeAvantageVieillesse != null)
    {
      BigDecimal sjrDebutUt = elementBaseIndemnisationDebutUT.getSjr().getSalaire();
      BigDecimal sjrFinUt = elementBaseIndemnisationFinUT.getSjr().getSalaire();
      if ((periodeAvantageVieillesse.getDateDebut().estAvant(p_ut.getDateDebut().getDebutMois())) && (periodeAvantageVieillesse.getDateFin().estAvant(p_ut.getDateFin())))
      {
        if (sjrDebutUt.compareTo(sjrFinUt) != 0) {
          montantAVAPositionner = elementBaseIndemnisationDebutUT.getMontantAvantageVieillesse().multiply(sjrFinUt).divide(sjrDebutUt, 2);
        } else {
          montantAVAPositionner = elementBaseIndemnisationDebutUT.getMontantAvantageVieillesse();
        }
      }
      else if ((periodeAvantageVieillesse.getDateDebut().estApres(p_ut.getDateDebut())) && (periodeAvantageVieillesse.getDateFin().estAvant(p_ut.getDateFin()))) {
        montantAVAPositionner = periodeAvantageVieillesse.getQuantiteEuro().getValeurMontant();
      } else if ((elementBaseIndemnisationFinUT.getMontantAvantageVieillesse() != null) && (elementBaseIndemnisationFinUT.getMontantAvantageVieillesse().compareTo(new BigDecimal("0")) > 0)) {
        montantAVAPositionner = elementBaseIndemnisationFinUT.getMontantAvantageVieillesse();
      } else if ((elementBaseIndemnisationDebutUT.getMontantAvantageVieillesse() != null) && (elementBaseIndemnisationDebutUT.getMontantAvantageVieillesse().compareTo(new BigDecimal("0")) > 0)) {
        montantAVAPositionner = elementBaseIndemnisationDebutUT.getMontantAvantageVieillesse();
      } else {
        montantAVAPositionner = periodeAvantageVieillesse.getQuantiteEuro().getValeurMontant();
      }
      p_pbjcNcp.setMontantCumuleRevaloriseAV(Mathematiques.arrondiASup(montantAVAPositionner, 2));
    }
    else
    {
      p_pbjcNcp.setMontantCumuleRevaloriseAV(new BigDecimal("0"));
    }
  }
  
  public int retournerReliquatDureeMax(UniteTraitement p_ut, ChronologiePeriodes p_chronoPBJCs, AttributionSpec p_attributionSpec)
  {
    int reliquatARetourner = 0;
    
    QuantiteDroitSpec quantiteIndemnisation = null;
    PbjcNcp pbjcNcp = null;
    if (p_chronoPBJCs.estVide())
    {
      quantiteIndemnisation = OutillageQuantites.recupererPremiereQuantiteIndemnisationActive(p_ut.getConstituantsIndemnisationEnDebutUT().getCollectionQuantiteDroit());
      if (quantiteIndemnisation != null) {
        reliquatARetourner = quantiteIndemnisation.getQuantiteCourante().getValeurEntiere();
      }
    }
    else
    {
      pbjcNcp = (PbjcNcp)p_chronoPBJCs.dernierElement();
      if (!estUnContexteDallongementAREF(p_ut, pbjcNcp)) {
        reliquatARetourner = pbjcNcp.getReliquatDureeMax() - pbjcNcp.getNbJoursImputes();
      } else {
        reliquatARetourner = pbjcNcp.getReliquatDureeMax();
      }
    }
    return reliquatARetourner;
  }
  
  private static boolean estUnContexteDallongementAREF(UniteTraitement ut, PbjcNcp pbjc)
  {
    return (pbjc.getComplementTypeMontant1() == 1) && (ut.getConstituantsIndemnisationEnFinUT().getDureeProlongation() != null) && (ut.getConstituantsIndemnisationEnFinUT().getDureeProlongation().isContexteAllongementAref());
  }
  
  public void positionnerRessources(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution) {}
  
  public void positionnerActiviteReduite(PbjcNcp p_pbjcNcp, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduite)
  {
    p_pbjcNcp.setNbMoisActiviteReduite(((ConstituantsCalculActiviteReduiteAsu)p_constituantsCalculActiviteReduite).getCumul());
  }
  
  public Quantite retournerQuantiteIndemnisationInitialeDroit(AttributionSpec p_attribution, UniteTraitement ut)
  {
    if ((p_attribution instanceof Reprise))
    {
      Quantite dureeOdOrigine = ((Reprise)p_attribution).getAttributionOrigine().getDureeIndemnisationTheorique();
      return dureeOdOrigine;
    }
    if ((p_attribution instanceof Revision))
    {
      Quantite dureeOdOrigine = ((Revision)p_attribution).getAttributionOrigine().getDureeIndemnisationTheorique();
      return dureeOdOrigine;
    }
    if ((p_attribution instanceof Poursuite))
    {
      Quantite dureeOdOrigine = ((Poursuite)p_attribution).getSaisieAntecedent().getReliquatDuree();
      return dureeOdOrigine;
    }
    return ((AttributionAssuranceSpec)p_attribution).getDureeIndemnisationInitiale();
  }
  
  public void positionnerPriseEnChargeAER(PbjcNcp p_pbjcNcp, Collection p_periodesAER)
  {
    boolean chevauchementAER = false;
    Iterator iterator = p_periodesAER.iterator();
    while ((iterator.hasNext()) && (!chevauchementAER)) {
      chevauchementAER = p_pbjcNcp.chevauche((Periode)iterator.next());
    }
    p_pbjcNcp.setPriseEnChargeAERC(chevauchementAER);
  }
  
  public void positionnerPriseEnChargeAER(PbjcNcp p_pbjcNcp, UniteTraitement p_ut)
  {
    ChronologiePeriodes periodesSegmentantes = null;
    ObjetChronoPeriode periode = null;
    ObjetChronoPeriodeInterProduits periodeInterProduit = null;
    ObjetChronoPeriodeInterProduits periodeRetenue = null;
    
    periodesSegmentantes = p_ut.getQualificationPeriodes().getPeriodesSegmentantes();
    periodesSegmentantes.iterer();
    while (periodesSegmentantes.encoreSuivant())
    {
      periode = (ObjetChronoPeriode)periodesSegmentantes.elementSuivant();
      if (((periode instanceof ObjetChronoPeriodeInterProduits)) && ((((ObjetChronoPeriodeInterProduits)periode).getNomProduit().equals("SOL_AER05_01")) || (((ObjetChronoPeriodeInterProduits)periode).getNomProduit().equals("SOL_AER05_02")) || (((ObjetChronoPeriodeInterProduits)periode).getNomProduit().equals("SOL_AER05_03"))))
      {
        periodeInterProduit = (ObjetChronoPeriodeInterProduits)periode;
        if (p_pbjcNcp.chevauche(periodeInterProduit.getPeriode())) {
          if (periodeRetenue == null) {
            periodeRetenue = periodeInterProduit;
          } else if (periodeInterProduit.getDateDebut().estApresOuCoincideAvec(periodeRetenue.getDateDebut())) {
            periodeRetenue = periodeInterProduit;
          }
        }
      }
    }
    if (periodeRetenue != null) {
      p_pbjcNcp.setPriseEnChargeAERC((periodeRetenue.getTypePeriode() == 2) || (periodeRetenue.getTypePeriode() == 1));
    }
  }
  
  public void traiterPBJCsAPosteriori(ChronologiePeriodes p_chronoPBJCs, AttributionSpec p_attribution, Chronologie chronoUT)
    throws CoucheLogiqueException
  {
    PbjcNcp pbjcNcp = null;
    PbjcNcp pbjcNcpAvant = null;
    DossierExamen dossierExamen = null;
    Damj dateMaintien = null;
    boolean pbjcTrouvee = false;
    
    ChronologiePeriodes chronologiePeriodesRadiationPEC = OutillagePeriodes.recupererPecsRadiationSuiteEntreeFormation(p_attribution.getDemandeur());
    
    Chronologie demandes = p_attribution.getDemandeur().getChronoDemandeMaintien();
    demandes.iterer();
    while (demandes.encoreSuivant())
    {
      DemandeSpec demandeMaintien = (DemandeSpec)demandes.elementSuivant();
      if (((demandeMaintien instanceof DemandeMaintien)) && (!demandeMaintien.estEnReExamen()) && ((demandeMaintien.getClassementAdministratif() == null) || (((demandeMaintien.getClassementAdministratif() instanceof Prescription)) && (!((Prescription)demandeMaintien.getClassementAdministratif()).isValidite()))))
      {
        dossierExamen = ((DemandeMaintien)demandeMaintien).getDossierExamen();
        if ((dossierExamen != null) && ((dossierExamen instanceof Accord))) {
          dateMaintien = demandeMaintien.getDateEffet();
        }
      }
    }
    if ((dateMaintien == null) && (((AttributionAssuranceSpec)p_attribution).getOuvertureDroitCapitalRetenu() != null) && (!((AttributionAssuranceSpec)p_attribution).getOuvertureDroitCapitalRetenu().estEnReexamen()) && ((((AttributionAssuranceSpec)p_attribution).getOuvertureDroitCapitalRetenu() instanceof AntecedentSpec)))
    {
      AntecedentSpec attributionMaitre = (AntecedentSpec)((AttributionAssuranceSpec)p_attribution).getOuvertureDroitCapitalRetenu();
      if ((((AttributionAssuranceSpec)p_attribution).getAttributionMaitre() instanceof PoursuiteSpec)) {
        dateMaintien = ((PoursuiteSpec)attributionMaitre).getPjp().veille();
      } else {
        dateMaintien = attributionMaitre.getCalendrierExecutionCalcul().getDernierJourIndemnisable().veille();
      }
    }
    p_chronoPBJCs.iterer();
    while (p_chronoPBJCs.encoreSuivant())
    {
      pbjcNcp = (PbjcNcp)p_chronoPBJCs.elementSuivant();
      if ((dateMaintien != null) && (((AttributionAssuranceSpec)p_attribution).estMaintenue()))
      {
        if (pbjcNcp.getDateDebut().estApresOuCoincideAvec(dateMaintien))
        {
          if (pbjcNcp.getDateDebut().coincideAvec(dateMaintien)) {
            pbjcNcp.ajouterComplementDeJustification("B1");
          }
          pbjcTrouvee = true;
        }
        if (pbjcTrouvee) {
          pbjcNcp.setEtatReglementaireOd("5");
        }
      }
      chronologiePeriodesRadiationPEC.iterer();
      while (chronologiePeriodesRadiationPEC.encoreSuivant())
      {
        ObjetChronoPeriodeRadiation periodeRadiation = (ObjetChronoPeriodeRadiation)chronologiePeriodesRadiationPEC.elementSuivant();
        if (periodeRadiation.getDateDebut().veille().coincideAvec(pbjcNcp.getDateFin()))
        {
          pbjcNcp.ajouterComplementDeJustification("TD");
          
          pbjcNcp.setCodeRadiationLendemainPeriode("31");
        }
      }
      if (pbjcNcpAvant != null)
      {
        if (pbjcNcpAvant.getDateFin().coincideAvec(pbjcNcp.getDateDebut().veille()))
        {
          if (pbjcNcp.contientComplementDeJustification("FR")) {
            pbjcNcpAvant.ajouterComplementDeJustification("QF");
          }
          if ((pbjcNcp.getInterrupIndemParPensionInvalidite() != null) && (pbjcNcpAvant.getInterrupIndemParPensionInvalidite() != null))
          {
            if ((pbjcNcp.getInterrupIndemParPensionInvalidite().equals("O")) && 
              (pbjcNcpAvant.getInterrupIndemParPensionInvalidite().equals("N"))) {
              pbjcNcp.ajouterComplementDeJustification("FN");
            }
            if ((pbjcNcp.getInterrupIndemParPensionInvalidite().equals("N")) && 
              (pbjcNcpAvant.getInterrupIndemParPensionInvalidite().equals("O"))) {
              pbjcNcp.ajouterComplementDeJustification("FO");
            }
          }
        }
        if ((pbjcNcpAvant.getMontantCumuleRevaloriseAV() != null) && (pbjcNcpAvant.getMontantCumuleRevaloriseAV().compareTo(new BigDecimal("0")) > 0) && 
          (pbjcNcp.getMontantCumuleRevaloriseAV() != null) && (pbjcNcp.getMontantCumuleRevaloriseAV().compareTo(new BigDecimal("0")) > 0) && 
          (pbjcNcp.getMontantCumuleRevaloriseAV().compareTo(pbjcNcpAvant.getMontantCumuleRevaloriseAV()) != 0) && (!pbjcNcp.contientComplementDeJustification("DG"))) {
          pbjcNcp.ajouterComplementDeJustification("DH");
        }
      }
      if ((pbjcNcp.contientComplementDeJustification("FR")) && (pbjcNcp.getInterrupIndemParPensionInvalidite() != null) && (pbjcNcp.getInterrupIndemParPensionInvalidite().equals("O"))) {
        pbjcNcp.ajouterComplementDeJustification("FN");
      }
      if (((retournerQuantiteIndemnisationInitialeDroit(p_attribution, null).getValeurEntiere() == pbjcNcp.getReliquatDureeMax()) || (((AttributionAssuranceSpec)p_attribution).getDureeIndemnisationInitiale().getValeurEntiere() == pbjcNcp.getReliquatDureeMax())) && (pbjcNcp.getNbJoursImputes() != 0)) {
        positionnerJustificationOuverturePJI(pbjcNcp, p_attribution);
      }
      if (p_attribution.getDateAttribution().coincideAvec(pbjcNcp.getDateDebut()))
      {
        AttributionAssuranceSpec assurancePrecedente = ((AttributionAssuranceSpec)p_attribution).getAttributionPrecedente();
        if ((assurancePrecedente != null) && (OutilDemande.estUneDemandeFinDroitAsr(assurancePrecedente.getDemande()))) {
          pbjcNcp.ajouterComplementDeJustification("BV");
        }
        if ((p_attribution instanceof Reprise)) {
          pbjcNcp.ajouterComplementDeJustification("BO");
        } else if ((p_attribution instanceof Readmission)) {
          pbjcNcp.ajouterComplementDeJustification("BG");
        } else {
          pbjcNcp.ajouterComplementDeJustification("BB");
        }
      }
      if (pbjcNcpAvant != null) {
        pbjcNcp.setNbJoursAREF(pbjcNcpAvant.getNbJoursAREF());
      }
      if ((pbjcNcp.estEnAref()) && (pbjcNcp.getEtatIndemnisation().compareTo("AVANT") != 0)) {
        pbjcNcp.setNbJoursAREF(pbjcNcp.getNbJoursAREF() + pbjcNcp.getNbJoursImputes());
      }
      pbjcNcpAvant = pbjcNcp;
    }
  }
  
  public void positionnerReferencesOuvertureDroit(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution)
  {
    p_pbjcNcp.setIdentifiantReprise(new Integer(p_attribution.getRsrp()).intValue());
    
    p_pbjcNcp.setRefOdPjcFaitGenerateurOrigine(new Integer(p_attribution.getRsod()).intValue());
    
    p_pbjcNcp.setRefOdPjcPremierFaitGenerateur(p_pbjcNcp.getRefOdPjcFaitGenerateurOrigine());
  }
  
  public void positionnerEtatsReglementaireEtAdministratif(PbjcNcp p_pbjcNcp)
  {
    p_pbjcNcp.setEtatReglementaireOd("1");
    
    p_pbjcNcp.setEtatAdministratifOd("1");
  }
  
  public void positionnerPBJCASupprimer(PbjcNcp p_pbjcNcp, ObjetChronoPeriode p_periode)
  {
    if (((p_periode instanceof ObjetChronoPeriodeInterProduits)) && ("FOR_RFP04_01".equals(((ObjetChronoPeriodeInterProduits)p_periode).getNomProduit()))) {
      p_pbjcNcp.setQualificationPeriode(3);
    }
  }
  
  public void positionnerIndicateurInterruptionIndemnisationParPensionInvalidite(PbjcNcp p_pbjcNcp)
    throws CoucheLogiqueException
  {
    if ((p_pbjcNcp.getMontantPensionInvalidite().compareTo(BigDecimal.ZERO) > 0) && (p_pbjcNcp.getDateDebut().estAvant(GestionnaireDateApplication.getInstance().recupererDateApplication("PI à 0 suite INC0399669"))))
    {
      p_pbjcNcp.setInterrupIndemParPensionInvalidite("N");
      if (p_pbjcNcp.getEtatAdministratifOd().equals("1")) {
        if (p_pbjcNcp.getProduit().equals(p_pbjcNcp.getCodeTypeMontant1()))
        {
          if (p_pbjcNcp.getResultatCalcul1().compareTo(BigDecimal.ZERO) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
        else if (p_pbjcNcp.getProduit().equals(p_pbjcNcp.getCodeTypeMontant2()))
        {
          if (p_pbjcNcp.getResultatCalcul2().compareTo(BigDecimal.ZERO) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
        else if (p_pbjcNcp.getProduit().equals(p_pbjcNcp.getCodeTypeMontant3()))
        {
          if (p_pbjcNcp.getResultatCalcul3().compareTo(BigDecimal.ZERO) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
        else if (p_pbjcNcp.getProduit().equals(p_pbjcNcp.getCodeTypeMontant4()))
        {
          if (p_pbjcNcp.getResultatCalcul4().compareTo(BigDecimal.ZERO) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
        else if (p_pbjcNcp.getProduit().equals(p_pbjcNcp.getCodeTypeMontant5()))
        {
          if (p_pbjcNcp.getResultatCalcul5().compareTo(BigDecimal.ZERO) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
        else if (p_pbjcNcp.getProduit().equals(p_pbjcNcp.getCodeTypeMontant6()))
        {
          if (p_pbjcNcp.getResultatCalcul6().compareTo(BigDecimal.ZERO) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
        else if (p_pbjcNcp.getProduit().equals(p_pbjcNcp.getCodeTypeMontant7())) {
          if (p_pbjcNcp.getResultatCalcul7().compareTo(BigDecimal.ZERO) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
      }
    }
  }
  
  public ChronologiePeriodes supprimerPBJCsANePasPrendreEnCompte(ChronologiePeriodes p_chronoPBJCs)
  {
    ChronologiePeriodes chronoTemp = null;
    PbjcNcp pbjcNcp = null;
    
    chronoTemp = new ChronologiePeriodes();
    p_chronoPBJCs.iterer();
    while (p_chronoPBJCs.encoreSuivant())
    {
      pbjcNcp = (PbjcNcp)p_chronoPBJCs.elementSuivant();
      if (pbjcNcp.getQualificationPeriode() != 3) {
        chronoTemp.ajouter(pbjcNcp);
      }
    }
    return chronoTemp;
  }
  
  public void traiterBlocageActuPourLAvant(PbjcNcp pbjcNcpAvant, Damj dateBlocageActualisation, String libelleBlocageActualisation)
  {
    if ((dateBlocageActualisation != null) && (dateBlocageActualisation.veille().equals(pbjcNcpAvant.getDateFin())) && 
      (libelleBlocageActualisation != null) && (libelleBlocageActualisation.length() != 0)) {
      if (libelleBlocageActualisation.equals("blocage pour signal. pension d'inval. sur le DSM")) {
        pbjcNcpAvant.ajouterComplementDeJustification("HH");
      } else if (libelleBlocageActualisation.equals("blocage pour signal. pension de retraite sur le DSM")) {
        pbjcNcpAvant.ajouterComplementDeJustification("HI");
      } else if (libelleBlocageActualisation.equals("blocage pour arret recherche d'empl. sign. sur le DSM")) {
        pbjcNcpAvant.ajouterComplementDeJustification("HJ");
      } else if (libelleBlocageActualisation.equals("blocage pour signal maternité sans date sur le DSM")) {
        pbjcNcpAvant.ajouterComplementDeJustification("HK");
      } else if (libelleBlocageActualisation.equals("DSM en multi-déclaration recyclée")) {
        pbjcNcpAvant.ajouterComplementDeJustification("HL");
      } else if (libelleBlocageActualisation.equals("blocage pour motif divers")) {
        pbjcNcpAvant.ajouterComplementDeJustification("HN");
      } else if (libelleBlocageActualisation.equals("blocage ADE si actu sans déclaration TO")) {
        pbjcNcpAvant.ajouterComplementDeJustification("HO");
      } else if (libelleBlocageActualisation.equals("blocage pour signal formation")) {
        pbjcNcpAvant.ajouterComplementDeJustification("HM");
      } else if (libelleBlocageActualisation.equals("Blocage indemnisation pour DE en fin de formation")) {
        pbjcNcpAvant.ajouterComplementDeJustification("HR");
      }
    }
  }
  
  public boolean retournerTopPlafonnementDureeDroitParDate()
  {
    return false;
  }
  
  public boolean creerPBJCsurUT(AttributionSpec p_attribution, UniteTraitement p_ut)
  {
    return true;
  }
  
  public void qualifierPbjcSuspensive(PbjcNcp p_pbjcNcp, ObjetChronoPeriode p_periode)
  {
    if (((p_periode instanceof ObjetChronoPeriodeCarences)) || ((p_periode instanceof ObjetChronoPeriodePreavis))) {
      p_pbjcNcp.setQualificationPeriode(1);
    }
  }
  
  public void miseAJourNombreJoursImputes(UniteTraitement p_ut, PbjcNcp p_pbjcNcp) {}
  
  public void positionnerCategorieAttribution(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution, UniteTraitement p_ut) {}
  
  public boolean retournerTopPeriodeRessourcesSuperieuresPlafond(Somme p_somme)
  {
    return false;
  }
  
  protected PbjcNcp creerPBJCSuspensivePourLAvant(Damj debut, Damj fin, ObjetChronoPeriode periode, AttributionSpec attribution, String naturePbjc)
  {
    PbjcNcp pbjcNcp = null;
    ObjetChronoPeriodePriseEnCharge pec = null;
    
    pbjcNcp = new PbjcNcp(debut, fin);
    
    pbjcNcp.setProduit(attribution.getProduitExecution().getNom());
    
    pbjcNcp.setRegimeApplicable(retournerReglementApplicable(attribution));
    
    pbjcNcp.setStatutPaiement(1);
    
    pbjcNcp.setNaturePBJC(naturePbjc);
    
    positionnerReferencesOuvertureDroit(pbjcNcp, attribution);
    
    pbjcNcp.setRefBaseCalculMontantBrut(retournerReferenceBaseCalcul(attribution));
    
    positionnerRessources(pbjcNcp, attribution);
    
    positionnerEtatsReglementaireEtAdministratif(pbjcNcp);
    
    pbjcNcp.setEtatIndemnisation("AVANT");
    
    pec = OutillagePeriodes.recupererPeriodePECContenant(attribution.getDemandeur(), debut);
    if (pec != null) {
      pbjcNcp.setAleIndividu(pec.getAleIndividu());
    }
    if ((debut.coincideAvec(periode.getDateDebut())) && ((naturePbjc.equals("MA")) || (naturePbjc.equals("AB")))) {
      pbjcNcp.ajouterComplementDeJustification("HD");
    }
    pbjcNcp.setQualificationPeriode(1);
    
    positionnerInfoConventionGestion(pbjcNcp, attribution);
    if ((attribution instanceof Poursuite)) {
      pbjcNcp.setReliquatDureeMax(((Poursuite)attribution).getUniteTraitement().getConstituantsIndemnisationEnFinUT().getDureeIndemnisation().getQuantiteCourante().getValeurEntiere());
    } else {
      pbjcNcp.setReliquatDureeMax(((AttributionAssuranceSpec)attribution).getDureeIndemnisationTheorique().getValeurEntiere());
    }
    return pbjcNcp;
  }
  
  protected PbjcNcp creerPBJCDecalantePourLAvant(Damj p_debut, Damj p_fin, AttributionSpec p_attribution, String p_naturePbjc, Quantite p_quantiteDecalage)
  {
    PbjcNcp pbjcNcp = null;
    ObjetChronoPeriodePriseEnCharge pec = null;
    
    pbjcNcp = new PbjcNcp(p_debut, p_fin);
    
    pbjcNcp.setProduit(p_attribution.getProduit().getNom());
    
    pbjcNcp.setRegimeApplicable(retournerReglementApplicable(p_attribution));
    
    pbjcNcp.setStatutPaiement(1);
    
    pbjcNcp.setNaturePBJC(p_naturePbjc);
    
    positionnerReferencesOuvertureDroit(pbjcNcp, p_attribution);
    
    pbjcNcp.setRefBaseCalculMontantBrut(retournerReferenceBaseCalcul(p_attribution));
    
    positionnerRessources(pbjcNcp, p_attribution);
    
    pbjcNcp.setEtatReglementaireOd("9");
    
    pbjcNcp.setEtatAdministratifOd("1");
    
    pbjcNcp.setEtatIndemnisation("AVANT");
    
    pec = OutillagePeriodes.recupererPeriodePECContenant(p_attribution.getDemandeur(), p_debut);
    if (pec != null) {
      pbjcNcp.setAleIndividu(pec.getAleIndividu());
    }
    pbjcNcp.setNbJoursDecalage(p_quantiteDecalage.getValeurEntiere());
    
    positionnerInfoConventionGestion(pbjcNcp, p_attribution);
    if ((p_attribution instanceof Poursuite)) {
      pbjcNcp.setReliquatDureeMax(((Poursuite)p_attribution).getUniteTraitement().getConstituantsIndemnisationEnFinUT().getDureeIndemnisation().getQuantiteCourante().getValeurEntiere());
    } else {
      pbjcNcp.setReliquatDureeMax(((AttributionAssuranceSpec)p_attribution).getDureeIndemnisationTheorique().getValeurEntiere());
    }
    return pbjcNcp;
  }
  
  public void positionnerSituationParticuliere(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution, UniteTraitement p_ut)
  {
    p_pbjcNcp.setSituationParticuliere(p_attribution.getSituationParticuliere());
  }
  
  public ChronologiePeriodes traitementPeriodesSuspensives(ChronologiePeriodes p_periodesSuspensives, UniteTraitement p_ut)
  {
    return p_periodesSuspensives;
  }
  
  public void mapperPecSurPbjc(PbjcNcp p_pbjc, ObjetChronoPeriodePriseEnCharge p_pec)
  {
    OutilsMaintienEuropeenEessiASU.mapperPecSurPbjc(p_pbjc, p_pec);
  }
  
  private Damj creationPbjcAvantCarenceGestionMaintienEuropeen(AttributionSpec p_attribution, Collection p_periodesAER, ChronologiePeriodes p_periodesFormation, ChronologiePeriodes p_actionsFormation, Damj p_dateDebut, Damj p_dateFin, DureeConsommableAvant p_duree, ChronologiePeriodes p_periodesInterruptives, ObjetChronoPeriode p_periodeInterruptive, Damj p_dateBlocageActualisation, String p_libelleBlocageActualisation, ChronologiePeriodes p_chronologiePbjcs, Damj p_dateGeneration, boolean p_isDiffere, Periode p_periodeCarence, boolean p_positionJustifOuverture, boolean p_positionJustifFermeture)
  {
    PbjcNcp pbjcNcpAvant = null;
    Damj dateRetournee = p_dateFin.lendemain();
    if (p_periodeInterruptive != null)
    {
      if (p_dateFin.estAvant(p_periodeInterruptive.getDateDebut()))
      {
        if (!p_isDiffere) {
          pbjcNcpAvant = creerPBJCAvantTypeCarence(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateDebut, p_dateFin, p_duree, p_periodeCarence, p_positionJustifOuverture, p_positionJustifFermeture);
        } else {
          pbjcNcpAvant = creerPBJCAvantTypeDiffere(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateDebut, p_dateFin, p_periodeCarence, p_positionJustifOuverture, p_positionJustifFermeture);
        }
        traiterBlocageActuPourLAvant(pbjcNcpAvant, p_dateBlocageActualisation, p_libelleBlocageActualisation);
        ajouterPBJCSurLAvant(p_chronologiePbjcs, pbjcNcpAvant, p_dateGeneration);
        dateRetournee = p_dateFin.lendemain();
      }
      else if ((p_dateFin.estAvantOuCoincideAvec(p_periodeInterruptive.getDateFin())) && (p_dateDebut.estAvantOuCoincideAvec(p_periodeInterruptive.getDateDebut().veille())))
      {
        if (p_periodeCarence.getFin().estApres(p_periodeInterruptive.getDateFin())) {
          p_positionJustifFermeture = false;
        }
        if (!p_isDiffere) {
          pbjcNcpAvant = creerPBJCAvantTypeCarence(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateDebut, p_periodeInterruptive.getDateDebut().veille(), p_duree, p_periodeCarence, p_positionJustifOuverture, p_positionJustifFermeture);
        } else {
          pbjcNcpAvant = creerPBJCAvantTypeDiffere(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateDebut, p_periodeInterruptive.getDateDebut().veille(), p_periodeCarence, p_positionJustifOuverture, p_positionJustifFermeture);
        }
        traiterBlocageActuPourLAvant(pbjcNcpAvant, p_dateBlocageActualisation, p_libelleBlocageActualisation);
        ajouterPBJCSurLAvant(p_chronologiePbjcs, pbjcNcpAvant, p_dateGeneration);
        dateRetournee = p_dateFin.lendemain();
      }
      else if (p_dateFin.estApres(p_periodeInterruptive.getDateFin()))
      {
        if (p_dateDebut.estAvantOuCoincideAvec(p_periodeInterruptive.getDateDebut().veille()))
        {
          if (!p_isDiffere) {
            pbjcNcpAvant = creerPBJCAvantTypeCarence(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateDebut, p_periodeInterruptive.getDateDebut().veille(), p_duree, p_periodeCarence, p_positionJustifOuverture, false);
          } else {
            pbjcNcpAvant = creerPBJCAvantTypeDiffere(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateDebut, p_periodeInterruptive.getDateDebut().veille(), p_periodeCarence, p_positionJustifOuverture, false);
          }
          traiterBlocageActuPourLAvant(pbjcNcpAvant, p_dateBlocageActualisation, p_libelleBlocageActualisation);
          ajouterPBJCSurLAvant(p_chronologiePbjcs, pbjcNcpAvant, p_dateGeneration);
          
          p_positionJustifOuverture = false;
        }
        Damj dateDebutPbjcSup = p_periodeInterruptive.getDateFin().lendemain();
        
        ObjetChronoPeriode periodeInterruptive = null;
        if (p_periodesInterruptives.encoreSuivant()) {
          periodeInterruptive = (ObjetChronoPeriode)p_periodesInterruptives.elementSuivant();
        }
        while ((periodeInterruptive != null) && (p_dateFin.estApresOuCoincideAvec(periodeInterruptive.getDateDebut())))
        {
          if (p_dateFin.estAvant(periodeInterruptive.getDateFin())) {
            p_positionJustifFermeture = true;
          }
          if (!p_isDiffere) {
            pbjcNcpAvant = creerPBJCAvantTypeCarence(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, dateDebutPbjcSup, periodeInterruptive.getDateDebut().veille(), p_duree, p_periodeCarence, p_positionJustifOuverture, p_positionJustifFermeture);
          } else {
            pbjcNcpAvant = creerPBJCAvantTypeDiffere(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, dateDebutPbjcSup, periodeInterruptive.getDateDebut().veille(), p_periodeCarence, p_positionJustifOuverture, p_positionJustifFermeture);
          }
          pbjcNcpAvant.ajouterComplementDeJustification("E9");
          
          dateDebutPbjcSup = periodeInterruptive.getDateFin().lendemain();
          if (p_periodesInterruptives.encoreSuivant()) {
            periodeInterruptive = (ObjetChronoPeriode)p_periodesInterruptives.elementSuivant();
          } else {
            periodeInterruptive = null;
          }
          traiterBlocageActuPourLAvant(pbjcNcpAvant, p_dateBlocageActualisation, p_libelleBlocageActualisation);
          ajouterPBJCSurLAvant(p_chronologiePbjcs, pbjcNcpAvant, p_dateGeneration);
        }
        dateDebutPbjcSup = Damj.max(dateDebutPbjcSup, p_dateDebut);
        if (dateDebutPbjcSup.estAvantOuCoincideAvec(p_dateFin))
        {
          if (!p_isDiffere) {
            pbjcNcpAvant = creerPBJCAvantTypeCarence(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, dateDebutPbjcSup, p_dateFin, p_duree, p_periodeCarence, p_positionJustifOuverture, true);
          } else {
            pbjcNcpAvant = creerPBJCAvantTypeDiffere(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, dateDebutPbjcSup, p_dateFin, p_periodeCarence, p_positionJustifOuverture, p_positionJustifFermeture);
          }
          pbjcNcpAvant.ajouterComplementDeJustification("E9");
          if ((periodeInterruptive != null) && (p_dateFin.estAvant(periodeInterruptive.getDateFin()))) {
            pbjcNcpAvant.ajouterComplementDeJustification("R9");
          }
          traiterBlocageActuPourLAvant(pbjcNcpAvant, p_dateBlocageActualisation, p_libelleBlocageActualisation);
          ajouterPBJCSurLAvant(p_chronologiePbjcs, pbjcNcpAvant, p_dateGeneration);
        }
        dateRetournee = p_dateFin.lendemain();
      }
    }
    else
    {
      if (!p_isDiffere) {
        pbjcNcpAvant = creerPBJCAvantTypeCarence(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateDebut, p_dateFin, p_duree, p_periodeCarence, p_positionJustifOuverture, p_positionJustifFermeture);
      } else {
        pbjcNcpAvant = creerPBJCAvantTypeDiffere(p_attribution, p_periodesAER, p_periodesFormation, p_actionsFormation, p_dateDebut, p_dateFin, p_periodeCarence, p_positionJustifOuverture, p_positionJustifFermeture);
      }
      traiterBlocageActuPourLAvant(pbjcNcpAvant, p_dateBlocageActualisation, p_libelleBlocageActualisation);
      ajouterPBJCSurLAvant(p_chronologiePbjcs, pbjcNcpAvant, p_dateGeneration);
      dateRetournee = p_dateFin.lendemain();
    }
    return dateRetournee;
  }
  
  protected List filtrerPeriodesSuspensivesPeriodesInterruptives(List p_periodesSuspensives, ChronologiePeriodes p_periodesInterruptives)
  {
    List chronoARetourner = new ArrayList();
    ObjetChronoPeriode periodeSuspensive = null;
    ObjetChronoPeriode periodeSuspensiveCopie = null;
    ObjetChronoPeriode periodeInterruptive = null;
    
    Iterator iterateurPeriodesSuspensives = p_periodesSuspensives.iterator();
    while (iterateurPeriodesSuspensives.hasNext())
    {
      boolean continueParcours = true;
      periodeSuspensive = (ObjetChronoPeriode)((ObjetChronoPeriode)iterateurPeriodesSuspensives.next()).copie();
      if (p_periodesInterruptives.getTaille() > 0)
      {
        p_periodesInterruptives.iterer();
        while ((p_periodesInterruptives.encoreSuivant()) && (continueParcours))
        {
          periodeInterruptive = (ObjetChronoPeriode)p_periodesInterruptives.elementSuivant().copie();
          if (periodeSuspensive.getDateDebut().estAvant(periodeInterruptive.getDateDebut()))
          {
            if (periodeSuspensive.getDateFin().estAvant(periodeInterruptive.getDateDebut()))
            {
              chronoARetourner.add(periodeSuspensive);
              continueParcours = false;
            }
            else if (periodeSuspensive.getDateFin().estApresOuCoincideAvec(periodeInterruptive.getDateDebut()))
            {
              periodeSuspensiveCopie = (ObjetChronoPeriode)periodeSuspensive.copie();
              periodeSuspensiveCopie.setDateFin(periodeInterruptive.getDateDebut().veille());
              if (periodeSuspensive.getDateFin().estAvantOuCoincideAvec(periodeInterruptive.getDateFin())) {
                continueParcours = false;
              } else {
                periodeSuspensive.setDateDebut(periodeInterruptive.getDateFin().lendemain());
              }
            }
          }
          else if (periodeSuspensive.getDateDebut().estAvant(periodeInterruptive.getDateFin())) {
            if (periodeSuspensive.getDateFin().estAvantOuCoincideAvec(periodeInterruptive.getDateFin())) {
              continueParcours = false;
            } else {
              periodeSuspensive.setDateDebut(periodeInterruptive.getDateFin().lendemain());
            }
          }
        }
      }
      chronoARetourner = p_periodesSuspensives;
    }
    return chronoARetourner;
  }
  
  protected void filtrerPbjcAvantPeriodesInterruptives(ChronologiePeriodes p_periodesInterruptives, ChronologiePeriodes p_pbjcsAvant)
  {
    ChronologiePeriodes chronologiePbjcsARetourner = new ChronologiePeriodes();
    chronologiePbjcsARetourner.setComparateur(new ComparateurTemporelsSurDateDebut());
    
    p_pbjcsAvant.iterer();
    while (p_pbjcsAvant.encoreSuivant())
    {
      boolean AAjouter = true;
      PbjcNcp pbjc = (PbjcNcp)p_pbjcsAvant.elementSuivant();
      p_periodesInterruptives.iterer();
      while (p_periodesInterruptives.encoreSuivant())
      {
        ObjetChronoPeriode periodeInterruptive = (ObjetChronoPeriode)p_periodesInterruptives.elementSuivant().copie();
        if (pbjc.getDateDebut().estAvant(periodeInterruptive.getDateDebut()))
        {
          if ((pbjc.getDateFin().estAvantOuCoincideAvec(periodeInterruptive.getDateFin())) && (pbjc.getDateFin().estApresOuCoincideAvec(periodeInterruptive.getDateDebut())))
          {
            pbjc.setDateFinPbjcsTrans(periodeInterruptive.getDateDebut().veille());
          }
          else if (pbjc.getDateFin().estApres(periodeInterruptive.getDateFin()))
          {
            PbjcNcp pbjcAvantDecoupe = (PbjcNcp)pbjc.copie();
            pbjcAvantDecoupe.setDateFinPbjcsTrans(periodeInterruptive.getDateDebut().veille());
            chronologiePbjcsARetourner.ajouter(pbjcAvantDecoupe);
            pbjc.setDateDebutPbjcsTrans(periodeInterruptive.getDateFin().lendemain());
          }
        }
        else if (pbjc.getDateDebut().estAvantOuCoincideAvec(periodeInterruptive.getDateFin())) {
          if (pbjc.getDateFin().estApres(periodeInterruptive.getDateFin())) {
            pbjc.setDateDebutPbjcsTrans(periodeInterruptive.getDateFin().lendemain());
          } else {
            AAjouter = false;
          }
        }
      }
      if (AAjouter) {
        chronologiePbjcsARetourner.ajouter(pbjc);
      }
    }
    p_pbjcsAvant.vider();
    p_pbjcsAvant.ajouter(chronologiePbjcsARetourner);
  }
  
  public void positionnerInfoConventionGestion(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution)
  {
    boolean estTopApplicationCRC = true;
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)p_attribution;
    ConventionGestionSpec convention = attribution.getConventionGestion();
    if (attribution.getCompetenceFinanciere() == 2)
    {
      if ((attribution.getCompetenceAdministrative() != 1) || ((convention != null) && (!convention.estPrecompteCRC()))) {
        estTopApplicationCRC = false;
      }
      if (OutilConventionGestion.estTypeConventionGestionEtSignataireUnedic("556", true, convention)) {
        p_pbjcNcp.ajouterTypeSousTypePopulation("CG", "PE");
      }
    }
    if (OutilConventionGestion.estConventionGestionFraisReel(convention))
    {
      if (!convention.estPrecompteCRC()) {
        estTopApplicationCRC = false;
      }
      p_pbjcNcp.ajouterTypeSousTypePopulation("CG", "FR");
    }
    p_pbjcNcp.setTopApplicationCRC(estTopApplicationCRC);
  }
  
  public boolean creerPBJCsurSomme(AttributionSpec p_attribution, Somme p_somme)
  {
    return true;
  }
  
  private int initialiserCompteurFormation(AttributionSpec p_attribution)
  {
    int nbJourFormation = 0;
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)p_attribution;
    if ((attribution instanceof RepriseSpec))
    {
      AttributionSpec attributionPrecedente = attribution.getAttributionPrecedente();
      if ((attribution.getAttributionPrecedente() != null) && (attribution.getAttributionPrecedente().getTypeExamen().equals("ASU_17"))) {
        attributionPrecedente = OutilAsr.rechercherDernierDroitAsr(attributionPrecedente.getDemande());
      }
      if ((attributionPrecedente != null) && (attributionPrecedente.getCalendrierExecutionCalcul() != null) && (attributionPrecedente.getCalendrierExecutionCalcul().getEtatAuDJI() != null))
      {
        EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)attributionPrecedente.getCalendrierExecutionCalcul().getEtatAuDJI();
        nbJourFormation = etatAuDji.getNbJourAREF();
      }
    }
    return nbJourFormation;
  }
}

/* Location:
 * Qualified Name:     FacadePBJCLigneImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */