package fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.parametres.AccesListeUnitesReglement;
import fr.unedic.cali.asu.parametres.ValeurListeUnitesReglement;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.util.TableQuantites;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Periode;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class OutilCalculAffiliation
{
  public static QuantitesAppartenance calculer(Periode p_periode, Chronologie p_listeActivitesParticipantes, Reglement p_reglementRecherche, JustificationAffiliation p_justifAffi)
  {
    ProduitAsuSpec produitReglement = (ProduitAsuSpec)p_reglementRecherche.getProduit();
    Convertisseur convertisseurUniteAffiliation = produitReglement.determinerConvertisseurUniteAffiliation();
    
    List listeZMEs = OutilConstitutionZme.constituerZMEs(p_periode, p_listeActivitesParticipantes, convertisseurUniteAffiliation);
    for (Iterator iter = listeZMEs.iterator(); iter.hasNext();)
    {
      ZoneMemeExercice zme = (ZoneMemeExercice)iter.next();
      zme.regrouperActivites();
    }
    Iterator iter;
    if (p_justifAffi != null) {
      for (iter = listeZMEs.iterator(); iter.hasNext();)
      {
        ZoneMemeExercice zme = (ZoneMemeExercice)iter.next();
        p_justifAffi.ajouterZme(zme);
      }
    }
    TableQuantites tableQuantitesAffiliation = determinerAffiliation(p_periode, listeZMEs, p_reglementRecherche);
    
    determinerQuantiteAssimilationMaximum(p_periode, p_reglementRecherche, tableQuantitesAffiliation);
    
    TableQuantites tableQuantitesAssimilation = determinerAssimilation(p_periode, listeZMEs, p_reglementRecherche);
    
    QuantitesAppartenance quantitesAppartenance = new QuantitesAppartenance();
    quantitesAppartenance.setListeQuantitesAffiliation(tableQuantitesAffiliation);
    quantitesAppartenance.setListeQuantitesAssimilation(tableQuantitesAssimilation);
    return quantitesAppartenance;
  }
  
  private static void determinerQuantiteAssimilationMaximum(Periode p_periode, Reglement p_reglementRecherche, TableQuantites p_tableQuantitesAffiliation)
  {
    ((ProduitAsuSpec)p_reglementRecherche.getProduit()).positionnerQuantiteAssimilationMaximum(p_periode, p_tableQuantitesAffiliation);
  }
  
  private static TableQuantites determinerAffiliation(Periode p_periode, List p_listeZMEs, Reglement p_reglement)
  {
    return cumulerAffiliation(p_periode, p_listeZMEs, p_reglement);
  }
  
  private static TableQuantites determinerAssimilation(Periode p_periode, List p_listeZMEs, Reglement p_reglementRecherche)
  {
    List listeUnite = AccesListeUnitesReglement.get(p_reglementRecherche, null).getListeUnites();
    
    ProduitAsuSpec produitReglement = (ProduitAsuSpec)p_reglementRecherche.getProduit();
    Convertisseur convertisseurUniteAffiliation = produitReglement.determinerConvertisseurUniteAffiliation();
    
    TableQuantites tableQuantitesAssimilation = cumulerAssimilation(p_listeZMEs, listeUnite, convertisseurUniteAffiliation);
    for (Iterator iter = listeUnite.iterator(); iter.hasNext();)
    {
      Unite unite = (Unite)iter.next();
      Quantite qteAssimilation = tableQuantitesAssimilation.get(unite);
      if ((p_periode instanceof Pra))
      {
        Quantite plafondAssimilation = ((Pra)p_periode).getQuantiteAssimilationMaximale(unite);
        if (plafondAssimilation != null) {
          qteAssimilation = plafondAssimilation.min(qteAssimilation);
        }
      }
      tableQuantitesAssimilation.put(qteAssimilation);
    }
    return tableQuantitesAssimilation;
  }
  
  private static TableQuantites cumulerAffiliation(Periode p_periode, List p_listeZMEs, Reglement p_reglement)
  {
    TableQuantites tableCumuls = new TableQuantites();
    Unite jour = UniteAffiliation.JOUR;
    Unite heure = UniteAffiliation.HEURE_TRAVAIL;
    List listeUnites = AccesListeUnitesReglement.get(p_reglement, null).getListeUnites();
    
    ProduitAsuSpec produitReglement = (ProduitAsuSpec)p_reglement.getProduit();
    Convertisseur convertisseurUniteAffiliation = produitReglement.determinerConvertisseurUniteAffiliation();
    
    Hashtable tableQtesDernierJourFev = DernierJourFevrier.calculerAffiliation(p_periode, p_listeZMEs);
    for (Iterator iterUnite = listeUnites.iterator(); iterUnite.hasNext();)
    {
      Unite unite = (Unite)iterUnite.next();
      Quantite qteCumulee = tableCumuls.get(unite);
      if (qteCumulee == null) {
        qteCumulee = new Quantite("0", unite);
      }
      if ((!jour.equals(unite)) && (!heure.equals(unite)))
      {
        Quantite cumulHeureConvertie = convertisseurUniteAffiliation.convertir(cumulAffiliationParUnite(p_listeZMEs, heure), unite);
        Quantite cumulJourConvertie = convertisseurUniteAffiliation.convertir(cumulAffiliationParUnite(p_listeZMEs, jour), unite);
        if (cumulHeureConvertie.compareTo(cumulJourConvertie) > 0)
        {
          Quantite qteDernierJourFev = (Quantite)tableQtesDernierJourFev.get(unite);
          if (qteDernierJourFev != null) {
            cumulHeureConvertie = cumulHeureConvertie.ajouter(qteDernierJourFev);
          }
          tableCumuls.put(cumulHeureConvertie);
        }
        else
        {
          Quantite qteDernierJourFev = (Quantite)tableQtesDernierJourFev.get(unite);
          if (qteDernierJourFev != null) {
            cumulJourConvertie = cumulJourConvertie.ajouter(qteDernierJourFev);
          }
          tableCumuls.put(cumulJourConvertie);
        }
      }
      else
      {
        Quantite affiliation = cumulAffiliationParUnite(p_listeZMEs, unite);
        
        Quantite qteDernierJourFev = (Quantite)tableQtesDernierJourFev.get(unite);
        if (qteDernierJourFev != null) {
          affiliation = affiliation.ajouter(qteDernierJourFev);
        }
        tableCumuls.put(affiliation);
      }
    }
    return tableCumuls;
  }
  
  private static TableQuantites cumulerAssimilation(List p_listeZMEs, List p_listeUnite, Convertisseur p_convertisseurUniteAffiliation)
  {
    TableQuantites tableCumuls = new TableQuantites();
    Unite heure = UniteAffiliation.HEURE_TRAVAIL;
    for (Iterator iterUnite = p_listeUnite.iterator(); iterUnite.hasNext();)
    {
      Unite unite = (Unite)iterUnite.next();
      Quantite qteCumulee = tableCumuls.get(unite);
      if (qteCumulee == null) {
        qteCumulee = new Quantite("0", unite);
      }
      for (Iterator iterZME = p_listeZMEs.iterator(); iterZME.hasNext();)
      {
        ZoneMemeExercice zme = (ZoneMemeExercice)iterZME.next();
        Quantite qteZME = zme.getQuantiteAssimilation(unite);
        if (qteZME == null) {
          qteZME = p_convertisseurUniteAffiliation.convertir(zme.getQuantiteAssimilation(heure), unite);
        }
        qteCumulee = qteCumulee.ajouter(qteZME);
      }
      tableCumuls.put(qteCumulee);
    }
    return tableCumuls;
  }
  
  private static Quantite cumulAffiliationParUnite(List p_listeZMEs, Unite p_unite)
  {
    Quantite qteCumulee = new Quantite("0", p_unite);
    for (Iterator iterZME = p_listeZMEs.iterator(); iterZME.hasNext();)
    {
      ZoneMemeExercice zme = (ZoneMemeExercice)iterZME.next();
      Quantite qteZME = zme.getQuantiteAffiliation(p_unite);
      qteCumulee = qteCumulee.ajouter(qteZME);
    }
    return qteCumulee;
  }
}

/* Location:
 * Qualified Name:     OutilCalculAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */