package fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.dom.ActiviteProratisee;
import fr.unedic.cali.asu.liquidation.outilsaffiliation.ZoneMemeExerciceSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.AppartenanceSpec;
import fr.unedic.cali.dom.PeriodeElementaire;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.util.TableQuantites;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

public class ZoneMemeExercice
  extends ObjetChronoPeriode
  implements ZoneMemeExerciceSpec
{
  private static final long serialVersionUID = 469367491295570379L;
  private static final UniteAffiliation JOURS = UniteAffiliation.JOUR;
  private static final UniteAffiliation HEURES = UniteAffiliation.HEURE_TRAVAIL;
  private static final UniteAffiliation VACATION = UniteAffiliation.VACATION;
  private static final UniteAffiliation CACHE_GROUPE = UniteAffiliation.CACHET_GROUPE;
  private static final UniteAffiliation CACHE_ISOLE = UniteAffiliation.CACHET_ISOLE;
  private static final UniteAffiliation JOUR_EMBARQUEMENT = UniteAffiliation.EMBARQUEMENT_ADMINISTRATIF;
  private static final Quantite ZERO_JOUR = new Quantite("0", JOURS);
  private static final Quantite ZERO_HEURES = new Quantite("0", HEURES);
  private List m_listeActiviteProratisee;
  private TableQuantites m_tableQuantitesRegroupees;
  private TableQuantites m_tableQuantitesAffiliation;
  private TableQuantites m_tableQuantitesAssimilation;
  private Quantite m_quantiteActiviteAssimilable;
  private Reglement m_reglementOrigine;
  private Convertisseur m_convertisseurUniteAffiliation;
  private boolean m_chevauchePnds;
  private Quantite m_qteAppartenanceZmeJustification;
  private TableQuantites m_tableQuantitesAssimilationFevrier;
  private Collection m_listeReglementAssimilables;
  
  public ZoneMemeExercice(Periode p_periode, Convertisseur p_convertisseurUniteAffiliation)
  {
    super(p_periode.getDebut(), p_periode.getFin());
    m_listeActiviteProratisee = new ArrayList();
    m_tableQuantitesRegroupees = new TableQuantites();
    m_tableQuantitesAffiliation = new TableQuantites();
    m_tableQuantitesAssimilation = new TableQuantites();
    m_tableQuantitesAssimilationFevrier = new TableQuantites();
    m_quantiteActiviteAssimilable = new Quantite("0", HEURES);
    m_listeReglementAssimilables = new ArrayList();
    m_convertisseurUniteAffiliation = p_convertisseurUniteAffiliation;
  }
  
  public int constituerListeActiviteProratisee(Chronologie p_listePeriodeActivite)
  {
    m_listeActiviteProratisee.clear();
    for (Iterator iter = p_listePeriodeActivite.iterer(); iter.hasNext();)
    {
      AppartenanceSpec periodeActivite = (AppartenanceSpec)iter.next();
      Periode intersection = periodeActivite.getPeriode().periodeIntersection(new Periode(getDateDebut(), getDateFin()));
      if (intersection != null)
      {
        ActiviteProratisee activiteProratisee = new ActiviteProratisee();
        activiteProratisee.setPeriodeOrigine(periodeActivite);
        if ((periodeActivite instanceof PeriodeElementaire))
        {
          PeriodeElementaire periode = (PeriodeElementaire)periodeActivite;
          if (!m_listeReglementAssimilables.contains(periode.getReglementAppartenance())) {
            m_listeReglementAssimilables.add(periode.getReglementAppartenance());
          }
        }
        if (periodeActivite.estSanctionne())
        {
          activiteProratisee.proratiser(0);
          
          setChevauchePnds(true);
        }
        else
        {
          activiteProratisee.proratiser(intersection.getDuree());
        }
        m_listeActiviteProratisee.add(activiteProratisee);
      }
    }
    return m_listeActiviteProratisee.size();
  }
  
  public void regrouperActivites()
  {
    regrouperActivitesAffiliationParUnite();
    regrouperActivitesAssimilation();
    
    determinerAffiliation();
  }
  
  private void regrouperActivitesAffiliationParUnite()
  {
    m_tableQuantitesRegroupees.clear();
    for (Iterator iter = m_listeActiviteProratisee.iterator(); iter.hasNext();)
    {
      ActiviteProratisee activiteProratisee = (ActiviteProratisee)iter.next();
      if (activiteProratisee.getNatureAppartenance() == 0) {
        regrouperActiviteAffiliation(activiteProratisee);
      }
    }
  }
  
  private void regrouperActivitesAssimilation()
  {
    m_quantiteActiviteAssimilable = new Quantite("0", HEURES);
    for (Iterator iter = m_listeActiviteProratisee.iterator(); iter.hasNext();)
    {
      ActiviteProratisee activiteProratisee = (ActiviteProratisee)iter.next();
      if (activiteProratisee.getNatureAppartenance() == 1)
      {
        Quantite qteActivite = activiteProratisee.getQuantiteProratisee();
        m_quantiteActiviteAssimilable = m_quantiteActiviteAssimilable.ajouter(qteActivite);
      }
    }
  }
  
  public void determinerAffiliation()
  {
    determinerAppartenanceEnJour();
    determinerAppartenanceEnHeure();
  }
  
  public void ajouterAssimilationFevrier(Hashtable p_tableQuantites)
  {
    Unite jour = UniteAffiliation.get("jour d'affiliation");
    Unite heure = UniteAffiliation.get("heure de travail");
    Unite jourEmbarquement = UniteAffiliation.get("embarquement administratif");
    
    m_tableQuantitesAssimilationFevrier.put((Quantite)p_tableQuantites.get(jour));
    m_tableQuantitesAssimilationFevrier.put((Quantite)p_tableQuantites.get(heure));
    m_tableQuantitesAssimilationFevrier.put((Quantite)p_tableQuantites.get(jourEmbarquement));
  }
  
  private void determinerAssimilation(Unite p_uniteRecherchee, Quantite p_affiliationParticipante, Quantite p_affiliationNonParticipante)
  {
    Quantite qteAssimilationRecherchee = m_convertisseurUniteAffiliation.convertir(m_quantiteActiviteAssimilable, p_uniteRecherchee);
    Quantite assimilationPlafond = m_convertisseurUniteAffiliation.convertir(m_quantiteActiviteAssimilable, p_uniteRecherchee);
    Quantite zero = new Quantite("0", p_uniteRecherchee);
    
    qteAssimilationRecherchee = qteAssimilationRecherchee.ajouter(m_convertisseurUniteAffiliation.convertir(p_affiliationNonParticipante, p_uniteRecherchee));
    qteAssimilationRecherchee = qteAssimilationRecherchee.soustraire(m_convertisseurUniteAffiliation.convertir(p_affiliationParticipante, p_uniteRecherchee));
    if (qteAssimilationRecherchee.compareTo(zero) < 0) {
      qteAssimilationRecherchee = zero;
    } else if (qteAssimilationRecherchee.compareTo(assimilationPlafond) > 0) {
      qteAssimilationRecherchee = assimilationPlafond;
    }
    m_tableQuantitesAssimilation.put(qteAssimilationRecherchee);
  }
  
  public Quantite getCumulNonJour(Unite p_uniteRecherchee)
  {
    Quantite qteCumulNonJour = new Quantite("0", p_uniteRecherchee);
    for (Enumeration enumQuantite = m_tableQuantitesRegroupees.elements(); enumQuantite.hasMoreElements();)
    {
      Quantite qteRegroupee = (Quantite)enumQuantite.nextElement();
      if ((!qteRegroupee.getUnite().equals(JOURS)) && (!qteRegroupee.getUnite().equals(JOUR_EMBARQUEMENT)))
      {
        Quantite qteConvertie = m_convertisseurUniteAffiliation.convertir(qteRegroupee, p_uniteRecherchee);
        qteCumulNonJour = qteCumulNonJour.ajouter(qteConvertie);
      }
    }
    return qteCumulNonJour;
  }
  
  private Quantite cumulerJourActiviteJourHeure()
  {
    Quantite cumul = new Quantite(0, JOURS);
    for (Iterator iterActiviteProratise = m_listeActiviteProratisee.iterator(); iterActiviteProratise.hasNext();)
    {
      ActiviteProratisee activiteProratisee = (ActiviteProratisee)iterActiviteProratise.next();
      Quantite quantiteJour = activiteProratisee.getQuantiteProratisee(JOURS);
      Quantite quantiteHeure = activiteProratisee.getQuantiteProratisee(HEURES);
      if ((quantiteHeure != null) && (quantiteJour != null) && (quantiteJour.compareTo(cumul) > 0)) {
        cumul = quantiteJour;
      }
    }
    return cumul;
  }
  
  private Quantite cumulerHeureActiviteJourHeureAutreUniteHeure()
  {
    Quantite qteRegroupeHeure = new Quantite(0, HEURES);
    for (Iterator iterActiviteProratise = m_listeActiviteProratisee.iterator(); iterActiviteProratise.hasNext();)
    {
      ActiviteProratisee activiteProratisee = (ActiviteProratisee)iterActiviteProratise.next();
      Quantite quantiteJour = activiteProratisee.getQuantiteProratisee(JOURS);
      Quantite quantiteHeure = activiteProratisee.getQuantiteProratisee(HEURES);
      if (activiteProratisee.getNatureAppartenance() != 1)
      {
        if (((quantiteJour != null) && (quantiteHeure != null)) || ((quantiteJour == null) && (quantiteHeure != null))) {
          qteRegroupeHeure = qteRegroupeHeure.ajouter(quantiteHeure);
        }
        Quantite quantiteAutreUnite = activiteProratisee.getQuantiteProratisee(VACATION);
        if (quantiteAutreUnite != null) {
          qteRegroupeHeure = qteRegroupeHeure.ajouter(m_convertisseurUniteAffiliation.convertir(quantiteAutreUnite, HEURES));
        }
        quantiteAutreUnite = activiteProratisee.getQuantiteProratisee(CACHE_ISOLE);
        if (quantiteAutreUnite != null) {
          qteRegroupeHeure = qteRegroupeHeure.ajouter(m_convertisseurUniteAffiliation.convertir(quantiteAutreUnite, HEURES));
        }
        quantiteAutreUnite = activiteProratisee.getQuantiteProratisee(CACHE_GROUPE);
        if (quantiteAutreUnite != null) {
          qteRegroupeHeure = qteRegroupeHeure.ajouter(m_convertisseurUniteAffiliation.convertir(quantiteAutreUnite, HEURES));
        }
      }
    }
    return qteRegroupeHeure;
  }
  
  public List getListeActivitesAffiliation()
  {
    List listeActivitesAffiliation = new ArrayList();
    for (Iterator iter = m_listeActiviteProratisee.iterator(); iter.hasNext();)
    {
      ActiviteProratisee activiteProratisee = (ActiviteProratisee)iter.next();
      if (activiteProratisee.getNatureAppartenance() == 0) {
        listeActivitesAffiliation.add(activiteProratisee);
      }
    }
    return listeActivitesAffiliation;
  }
  
  public LinkedList getListeActivitesProratisees()
  {
    return new LinkedList(m_listeActiviteProratisee);
  }
  
  private void regrouperActiviteAffiliation(ActiviteProratisee p_activiteProratisee)
  {
    Hashtable tableQuantitesAffiliation = p_activiteProratisee.getListeQuantitesProratisees();
    Enumeration enumQuantite;
    if ((tableQuantitesAffiliation.get(JOURS) == null) || (tableQuantitesAffiliation.get(HEURES) == null)) {
      for (enumQuantite = tableQuantitesAffiliation.elements(); enumQuantite.hasMoreElements();)
      {
        Quantite qteActivite = (Quantite)enumQuantite.nextElement();
        Unite unite = qteActivite.getUnite();
        
        Quantite qteRegroupee = m_tableQuantitesRegroupees.get(unite);
        if (unite.equals(UniteAffiliation.JOUR_SUSPENSION))
        {
          unite = JOURS;
          qteActivite = m_convertisseurUniteAffiliation.convertir(qteActivite, JOURS);
        }
        if (qteRegroupee == null) {
          qteRegroupee = new Quantite("0", unite);
        }
        if ((unite.equals(JOURS)) && (qteActivite.compareTo(qteRegroupee) > 0)) {
          qteRegroupee = new Quantite(qteActivite.getValeur(), JOURS);
        }
        if (!unite.equals(JOURS)) {
          qteRegroupee = qteRegroupee.ajouter(qteActivite);
        }
        m_tableQuantitesRegroupees.put(qteRegroupee);
      }
    }
  }
  
  private void determinerAppartenanceEnJour()
  {
    Quantite qteRechercheeJour = ZERO_JOUR;
    
    Quantite qteAffiliationActiviteJourHeure = cumulerJourActiviteJourHeure();
    Quantite qteRegroupeNonJour = getCumulNonJour(JOURS);
    Quantite qteRegroupeeActiviteJour = m_tableQuantitesRegroupees.get(JOURS);
    Quantite qteRegroupeeActiviteJourEmbarquement = m_tableQuantitesRegroupees.get(JOUR_EMBARQUEMENT);
    if (qteRegroupeNonJour == null) {
      qteRegroupeNonJour = ZERO_JOUR;
    }
    if (qteRegroupeeActiviteJour == null) {
      qteRegroupeeActiviteJour = ZERO_JOUR;
    }
    if (qteRegroupeeActiviteJourEmbarquement == null) {
      qteRegroupeeActiviteJourEmbarquement = ZERO_JOUR;
    } else {
      qteRegroupeeActiviteJourEmbarquement = getQuantiteJourEmbarquementPourUnite(JOURS, qteRegroupeeActiviteJourEmbarquement);
    }
    qteRechercheeJour = qteAffiliationActiviteJourHeure;
    determinerAssimilation(JOURS, qteAffiliationActiviteJourHeure, qteRegroupeeActiviteJour.ajouter(qteRegroupeNonJour));
    if ((qteRegroupeeActiviteJour != null) && (qteRegroupeeActiviteJour.compareTo(qteRechercheeJour) > 0))
    {
      qteRechercheeJour = qteRegroupeeActiviteJour;
      determinerAssimilation(JOURS, qteRegroupeeActiviteJour, qteAffiliationActiviteJourHeure.ajouter(qteRegroupeNonJour));
    }
    if ((qteRegroupeNonJour != null) && (qteRegroupeNonJour.compareTo(qteRechercheeJour) > 0))
    {
      qteRechercheeJour = qteRegroupeNonJour;
      determinerAssimilation(JOURS, qteRegroupeNonJour, qteRegroupeeActiviteJour.ajouter(qteAffiliationActiviteJourHeure));
    }
    if ((qteRegroupeeActiviteJourEmbarquement != null) && (qteRegroupeeActiviteJourEmbarquement.compareTo(qteRechercheeJour) > 0))
    {
      qteRechercheeJour = qteRegroupeeActiviteJourEmbarquement;
      determinerAssimilation(JOURS, qteRegroupeeActiviteJour, qteAffiliationActiviteJourHeure.ajouter(qteRegroupeeActiviteJourEmbarquement));
    }
    m_tableQuantitesAffiliation.put(qteRechercheeJour);
  }
  
  public void determinerAppartenanceEnHeure()
  {
    Quantite qteRechercheeHeure = ZERO_HEURES;
    
    Quantite qteAffiliationActiviteJourHeure = cumulerHeureActiviteJourHeureAutreUniteHeure();
    Quantite qteRegroupeJourEmbarquement = m_tableQuantitesRegroupees.get(JOUR_EMBARQUEMENT);
    Quantite qteRegroupeeActiviteJour = m_tableQuantitesRegroupees.get(JOURS);
    if (qteAffiliationActiviteJourHeure == null) {
      qteAffiliationActiviteJourHeure = ZERO_HEURES;
    }
    if (qteRegroupeJourEmbarquement == null) {
      qteRegroupeJourEmbarquement = ZERO_HEURES;
    }
    if (qteRegroupeeActiviteJour == null) {
      qteRegroupeeActiviteJour = ZERO_JOUR;
    }
    determinerAssimilation(HEURES, ZERO_HEURES, ZERO_HEURES);
    
    qteRegroupeJourEmbarquement = m_convertisseurUniteAffiliation.convertir(qteRegroupeJourEmbarquement, HEURES);
    if (qteAffiliationActiviteJourHeure.compareTo(qteRegroupeJourEmbarquement) > 0) {
      qteRechercheeHeure = qteAffiliationActiviteJourHeure;
    } else {
      qteRechercheeHeure = qteRegroupeJourEmbarquement;
    }
    qteRegroupeeActiviteJour = m_convertisseurUniteAffiliation.convertir(qteRegroupeeActiviteJour, HEURES);
    if (qteRegroupeeActiviteJour.compareTo(qteRechercheeHeure) > 0)
    {
      determinerAssimilation(HEURES, qteRegroupeeActiviteJour, qteRechercheeHeure);
      qteRechercheeHeure = qteRegroupeeActiviteJour;
    }
    m_tableQuantitesAffiliation.put(qteRechercheeHeure);
  }
  
  public Quantite getQuantiteAffiliation(Unite p_unite)
  {
    return m_tableQuantitesAffiliation.get(p_unite);
  }
  
  public Quantite getQuantiteAssimilationFevrier(Unite p_unite)
  {
    return m_tableQuantitesAssimilationFevrier.get(p_unite);
  }
  
  public Quantite getQuantiteAssimilation(Unite p_unite)
  {
    return m_tableQuantitesAssimilation.get(p_unite);
  }
  
  public ObjetMetierSpec copie()
  {
    return this;
  }
  
  public boolean chevauchePnds()
  {
    return m_chevauchePnds;
  }
  
  public void setChevauchePnds(boolean p_chevauchePnds)
  {
    m_chevauchePnds = p_chevauchePnds;
  }
  
  public Quantite getQteAppartenanceZmeJustification()
  {
    return m_qteAppartenanceZmeJustification;
  }
  
  public void setQteAppartenanceZmeJustification(Quantite p_qteAppartenanceZmeJustification)
  {
    m_qteAppartenanceZmeJustification = p_qteAppartenanceZmeJustification;
  }
  
  public Reglement getReglementOrigine()
  {
    return m_reglementOrigine;
  }
  
  public void setReglementOrigine(Reglement p_reglementOrigine)
  {
    m_reglementOrigine = p_reglementOrigine;
  }
  
  public String toString()
  {
    String str = "ZME ";
    str = str.concat("[");
    str = str.concat(getDateDebut().toString());
    str = str.concat(" - ");
    str = str.concat(getDateFin().toString());
    str = str.concat("]");
    return str;
  }
  
  public Collection getListeReglementAssimilables()
  {
    return m_listeReglementAssimilables;
  }
  
  public void setListeReglementAssimilables(Collection p_listeReglementAssimilables)
  {
    m_listeReglementAssimilables = p_listeReglementAssimilables;
  }
  
  private Quantite getQuantiteJourEmbarquementPourUnite(Unite p_uniteRecherchee, Quantite p_quantiteJoursEmbarquement)
  {
    return m_convertisseurUniteAffiliation.convertir(p_quantiteJoursEmbarquement, p_uniteRecherchee);
  }
  
  public Convertisseur getConvertisseurUniteAffiliation()
  {
    return m_convertisseurUniteAffiliation;
  }
  
  public void setConvertisseurUniteAffiliation(Convertisseur p_convertisseurUniteAffiliation)
  {
    m_convertisseurUniteAffiliation = p_convertisseurUniteAffiliation;
  }
}

/* Location:
 * Qualified Name:     ZoneMemeExercice
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */