package fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.strategies;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatRechercheConditionChomageInvolontaire;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.fabriques.FabriqueStrategieConditionChomageInvolontaireAre17;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.strategies.spec.StrategieConditionChomageInvolontaireAre14Spec;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.strategies.spec.StrategieConditionChomageInvolontaireAre17Spec;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.strategies.spec.StrategieInnoposabiliteSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.strategies.spec.StrategiePointDepartDelaiRechercheChomageInvolontaireSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.capachomageinvolontaire.OutilConditionChomageInvolontaire;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.EreDvAuFilEau;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeIntensite;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.ConstructionPRASpec;
import fr.unedic.cali.fabriques.outilsfonctionnels.FabriqueStrategieGenerique;
import fr.unedic.cali.outilsfonctionnels.DetectionTypeChomage;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeE301;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class StrategieConditionChomageInvolontaireAre14Apres
  implements StrategieConditionChomageInvolontaireAre14Spec
{
  private static final int DUREE_INOPPOSABILITE_DV_FIL_EAU = 8;
  private static final int INTENSITE_HEBDO_INOPPOSABILITE_DV_FIL_EAU = 17;
  private static final double INTENSITE_MENSUELLE_INOPPOSABILITE_DV_FIL_EAU = 73.67D;
  private static final double INTENSITE_ANNUELLE_INOPPOSABILITE_DV_FIL_EAU = 780.54D;
  private static final int DUREE_HEBDOMADAIRE_TEMPS_PLEIN = 35;
  private static StrategieConditionChomageInvolontaireAre14Apres instance;
  
  public static StrategieConditionChomageInvolontaireAre14Apres getInstance()
  {
    if (instance == null) {
      instance = new StrategieConditionChomageInvolontaireAre14Apres();
    }
    return instance;
  }
  
  public ResultatRechercheConditionChomageInvolontaire rechercheConditionChomageInvolontaire(Demande demande)
    throws ApplicativeException
  {
    ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire = new ResultatRechercheConditionChomageInvolontaire();
    ResultatElementDroit resultatElementDroit = new ResultatElementDroit();
    resultatRechercheConditionChomageInvolontaire.setResultatElementDroit(resultatElementDroit);
    resultatElementDroit.setEtatSatisfait(true);
    
    boolean continuerExecutionCondition = true;
    int sousTypeObjectif = demande.getObjectifCourant().getSousType();
    
    DonneesTemporaires donneesTemporaires = demande.getDonneesTemporaires();
    verifierConditionChomageInvolontaireForceEnCoursDisponibilite(demande, donneesTemporaires);
    if ((donneesTemporaires.isConditionChomageInvolontaireSatistaite()) || (donneesTemporaires.isRejetConditionChomageInvolontaire()))
    {
      if ("ASU_30".equals(demande.getEvenementReferenceExamen().getTypeExamen())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_L_CALI_DF_CAP09_DV_FIL_EAU");
      }
      if (donneesTemporaires.isRejetConditionChomageInvolontaire())
      {
        resultatElementDroit.setEtatSatisfait(false);
        resultatElementDroit.setCodeMotifEchec(91);
      }
      continuerExecutionCondition = false;
    }
    if (continuerExecutionCondition) {
      continuerExecutionCondition = traiterFaitGenerateurEnDvSurObjectifOD(demande, sousTypeObjectif, resultatRechercheConditionChomageInvolontaire);
    }
    if (continuerExecutionCondition)
    {
      Periode delaiRechercheDv = determinationDelaiRechercheDv(demande);
      if (delaiRechercheDv != null) {
        traiterFctDvDansDelaiRecherche(demande, resultatRechercheConditionChomageInvolontaire, sousTypeObjectif, delaiRechercheDv);
      }
    }
    return resultatRechercheConditionChomageInvolontaire;
  }
  
  public void verifierConditionChomageInvolontaireForceEnCoursDisponibilite(Demande demande, DonneesTemporaires donneesForcees)
    throws CoucheLogiqueException
  {
    if ((demande.estEnContexteDemande("COURSDISPO")) && (!donneesForcees.isConditionChomageInvolontaireSatistaite()) && (!donneesForcees.isRejetConditionChomageInvolontaire()) && (demande.getEvenementReferenceExamen().getTypeExamen() != "ASU_30")) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_ERR_EN_COURS_DISPO_CHGE_INV_NON_FORCEE", "DE en cours de disponibilité ou suspension: Veuillez vérifier les constituants du droit et forcer la condition de chômage involontaire");
    }
  }
  
  private void traiterFctDvDansDelaiRecherche(Demande demande, ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire, int sousTypeObjectif, Periode delaiRechercheDv)
    throws ApplicativeException
  {
    Reglement reglement = fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.recupererReglement(demande);
    Chronologie chronologieDvNonAttesteOuEnConflit = recupererChronoDvOuNonAttesteOuEnConflit(demande, delaiRechercheDv);
    TravailSpec dernierDv;
    TravailSpec dernierDv;
    if ("A3".equals(reglement.getNomReglement()))
    {
      dernierDv = trouverDernierDvPourAnnexe3(demande);
    }
    else
    {
      TravailSpec dernierDv;
      if ((demande.getEvenementReferenceExamen() instanceof EreDvAuFilEau)) {
        dernierDv = ((EreDvAuFilEau)demande.getEvenementReferenceExamen()).getDernierDV();
      } else {
        dernierDv = trouverDernierDvOuNonAttesteOuEnConflit(chronologieDvNonAttesteOuEnConflit);
      }
    }
    if (dernierDv != null)
    {
      resultatRechercheConditionChomageInvolontaire.setIdentifiantActivitePortantDV(dernierDv.getIdentifiant());
      
      boolean continuerExecutionCondition = traiterConditionInopposabilite(demande, sousTypeObjectif, reglement, dernierDv, chronologieDvNonAttesteOuEnConflit, resultatRechercheConditionChomageInvolontaire);
      if (continuerExecutionCondition) {
        traiterConditionCouverture(demande, delaiRechercheDv, dernierDv, reglement, resultatRechercheConditionChomageInvolontaire);
      }
    }
  }
  
  private boolean traiterFaitGenerateurEnDvSurObjectifOD(Demande demande, int sousTypeObjectif, ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire)
    throws CoucheLogiqueException
  {
    boolean continuerCondition = true;
    boolean estObjectifOd = NaturesDecisions.estdeTypeOd(sousTypeObjectif);
    
    StrategiePointDepartDelaiRechercheChomageInvolontaireSpec strategie = (StrategiePointDepartDelaiRechercheChomageInvolontaireSpec)FabriqueStrategieGenerique.choisirStrategie(demande.getDateExamen(), "Correction point depart recherche DV INC0129309", new StrategiePointDepartDelaiRechercheChomageInvolontaireAvant(), new StrategiePointDepartDelaiRechercheChomageInvolontaireApres());
    
    Damj pointDepartDelaiRecherche = strategie.determinationPointDepartDelaiRechercheDvPourTraitementFG(demande);
    if ((estObjectifOd) && (!estFaitGenerateurLegitime(demande)) && (demande.getFaitGenerateur().getDateFaitGenerateur().estApresOuCoincideAvec(pointDepartDelaiRecherche)))
    {
      if (!FabriqueStrategieConditionChomageInvolontaireAre17.getInstance().getStrategie(demande).estInopposablePourContratCourt(demande, demande.getFaitGenerateur().getPeriodeFaitGenerateur(), resultatRechercheConditionChomageInvolontaire))
      {
        resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(false);
        resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setCodeMotifEchec(91);
        
        resultatRechercheConditionChomageInvolontaire.setIdentifiantActivitePortantDV(demande.getFaitGenerateur().getPeriodeFaitGenerateur().getIdentifiant());
      }
      continuerCondition = false;
    }
    return continuerCondition;
  }
  
  private boolean traiterConditionInopposabilite(Demande demande, int sousTypeObjectif, Reglement reglement, TravailSpec dernierDv, Chronologie chronologieDvNonAttesteOuEnConflit, ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire)
    throws ApplicativeException
  {
    boolean continuerCondition = true;
    boolean estObjectifVerifiantInopposabilite = (NaturesDecisions.estdeTypeReprise(sousTypeObjectif)) || (NaturesDecisions.estdeTypeNovation(sousTypeObjectif)) || (NaturesDecisions.estdeTypePoursuite(sousTypeObjectif));
    
    Periode delaiRechercheInopposabilite = determinationDelaiRechercheInopposabilite(demande);
    
    boolean estInopposabiliteAre14 = (estObjectifVerifiantInopposabilite) && (!estDepartVolontaireOpposable(demande, delaiRechercheInopposabilite, reglement, dernierDv, resultatRechercheConditionChomageInvolontaire));
    
    boolean estInopposabiliteAre17 = FabriqueStrategieConditionChomageInvolontaireAre17.getInstance().getStrategie(demande).estInopposablePourContratCourt(demande, dernierDv, resultatRechercheConditionChomageInvolontaire);
    if ((estInopposabiliteAre14) || (estInopposabiliteAre17))
    {
      Chronologie chronologiePeriodesQuiEmpechentCalculAffiliation = recupereChronoNonAttesteOuEnConflit(chronologieDvNonAttesteOuEnConflit);
      if ((chronologiePeriodesQuiEmpechentCalculAffiliation != null) && (!chronologiePeriodesQuiEmpechentCalculAffiliation.estVide())) {
        fr.unedic.cali.asu.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.getInstance().verifierConditionChomageInvolontaireVerifiable((TravailSpec)chronologiePeriodesQuiEmpechentCalculAffiliation.premierElement());
      }
      continuerCondition = false;
    }
    return continuerCondition;
  }
  
  private void traiterConditionCouverture(Demande demande, Periode delaiRechercheDv, TravailSpec dernierDv, Reglement reglement, ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire)
    throws ApplicativeException
  {
    if ("A3".equals(reglement.getNomReglement())) {
      traiterConditionCouvertureAnnexe3(dernierDv, resultatRechercheConditionChomageInvolontaire);
    } else {
      traiterConditionCouvertureClassique(demande, delaiRechercheDv, dernierDv, reglement, resultatRechercheConditionChomageInvolontaire);
    }
  }
  
  private void traiterConditionCouvertureAnnexe3(TravailSpec dernierDv, ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire)
  {
    resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(false);
    resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setCodeMotifEchec(92);
    
    resultatRechercheConditionChomageInvolontaire.setIdentifiantActivitePortantDV(dernierDv.getIdentifiant());
  }
  
  private void traiterConditionCouvertureClassique(Demande demande, Periode delaiRechercheDv, TravailSpec dernierDv, Reglement reglement, ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire)
    throws ApplicativeException
  {
    ResultatRechercheConditionChomageInvolontaire resultatConditionAffiliation = calculerTravailDepuisDernierDv(demande, delaiRechercheDv, dernierDv, reglement);
    
    resultatRechercheConditionChomageInvolontaire.setQuantiteAffiliationPrincipaleCouverture(resultatConditionAffiliation.getQuantiteAffiliationPrincipaleCalculee());
    
    resultatRechercheConditionChomageInvolontaire.setQuantiteAffiliationSecondaireCouverture(resultatConditionAffiliation.getQuantiteAffiliationSecondaireCalculee());
    
    OutilConditionChomageInvolontaire outilConditionChomageInvolontaire = new OutilConditionChomageInvolontaire();
    if (!resultatConditionAffiliation.isConditionAffiliationVerifiee())
    {
      resultatConditionAffiliation = outilConditionChomageInvolontaire.etudierJurisprudence(demande, reglement, dernierDv, resultatRechercheConditionChomageInvolontaire);
      if (!resultatConditionAffiliation.isConditionAffiliationVerifiee())
      {
        fr.unedic.cali.asu.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.getInstance().verifierConditionChomageInvolontaireVerifiable(dernierDv);
        
        resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setEtatSatisfait(false);
        resultatRechercheConditionChomageInvolontaire.getResultatElementDroit().setCodeMotifEchec(92);
        
        resultatRechercheConditionChomageInvolontaire.setIdentifiantActivitePortantDV(dernierDv.getIdentifiant());
      }
    }
  }
  
  private boolean estAttributionPrecedenteRevisionEnDV(Demande demande)
  {
    DossierExamenAssuranceSpec attributionPrecedente = demande.rechercherAttributionPrecedenteDuMemeType();
    return (attributionPrecedente != null) && (attributionPrecedente.estRejetDV());
  }
  
  private Chronologie recupereChronoNonAttesteOuEnConflit(Chronologie chronoDv)
  {
    return chronoDv.copier(fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.creerFiltrePeriodeNonAttesteesDnjOuConflit());
  }
  
  private boolean estFaitGenerateurLegitime(Demande demande)
  {
    ActiviteSalarie periodeFaitGenerateur = demande.getFaitGenerateur().getPeriodeFaitGenerateur();
    int codeMotifFin = periodeFaitGenerateur.getCodeMotifFin();
    int contexteDemisison = periodeFaitGenerateur.getContrat().getContexteDemission();
    
    return DetectionTypeChomage.estChomageLegitime(codeMotifFin, contexteDemisison);
  }
  
  private TravailSpec trouverDernierDvOuNonAttesteOuEnConflit(Chronologie chronologieDv)
    throws CoucheLogiqueException
  {
    TravailSpec dernierDv = null;
    if ((chronologieDv != null) && (!chronologieDv.estVide())) {
      dernierDv = (TravailSpec)chronologieDv.premierElement();
    }
    return dernierDv;
  }
  
  private TravailSpec trouverDernierDvPourAnnexe3(Demande demande)
  {
    TravailSpec dernierDv = null;
    TravailSpec dernierSinistre = demande.getDossierAffectationAdmission().getSinistre();
    if ((dernierSinistre instanceof ActiviteSalarie))
    {
      int codeMotifFin = ((ActiviteSalarie)dernierSinistre).getCodeMotifFin();
      int contexteDemission = ((ActiviteSalarie)dernierSinistre).getContrat().getContexteDemission();
      if (!DetectionTypeChomage.estChomageLegitime(codeMotifFin, contexteDemission)) {
        dernierDv = dernierSinistre;
      }
    }
    return dernierDv;
  }
  
  private Chronologie recupererChronoDvOuNonAttesteOuEnConflit(Demande demande, Periode delaiRechercheDv)
    throws CoucheLogiqueException
  {
    Chronologie chronologiePeriodesPortantDv = fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.determinerChronologiePeriodesPortantDv(demande, delaiRechercheDv, demande.getFaitGenerateur());
    if (!demande.getDonneesTemporaires().isEstCoordCee())
    {
      FiltrePeriodeActiviteSalarieeE301 filtreE301 = new FiltrePeriodeActiviteSalarieeE301(false);
      chronologiePeriodesPortantDv = chronologiePeriodesPortantDv.copier(filtreE301);
    }
    return chronologiePeriodesPortantDv;
  }
  
  private boolean estDepartVolontaireOpposable(Demande demande, Periode delaiRechercheDv, Reglement reglement, TravailSpec dernierDv, ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire)
    throws ApplicativeException
  {
    ResultatRechercheConditionChomageInvolontaire resultatCalculAffiliation = calculerTravailDepuisDernierDroit(demande, delaiRechercheDv, reglement);
    
    resultatRechercheConditionChomageInvolontaire.setQuantiteAffiliationPrincipaleInopposabilite(resultatCalculAffiliation.getQuantiteAffiliationPrincipaleCalculee());
    
    resultatRechercheConditionChomageInvolontaire.setQuantiteAffiliationSecondaireInopposabilite(resultatCalculAffiliation.getQuantiteAffiliationSecondaireCalculee());
    
    boolean dvInopposable = (resultatCalculAffiliation.isConditionAffiliationVerifiee()) || (estAttributionPrecedenteRevisionEnDV(demande));
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "DVFILEAU")) {
      dvInopposable = (estContratLong(dernierDv, resultatRechercheConditionChomageInvolontaire)) && (dvInopposable);
    }
    return dvInopposable;
  }
  
  public static boolean estContratLong(TravailSpec dernierDv, ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire)
  {
    boolean dvInopposable = false;
    if ((dernierDv instanceof ActiviteSalarie))
    {
      ActiviteSalarie activite = (ActiviteSalarie)dernierDv;
      
      resultatRechercheConditionChomageInvolontaire.setDureeAeDV(activite.getDuree());
      dvInopposable = activite.getDuree() >= 8;
      
      Chronologie listeIntensites = activite.getListePeriodeIntensite();
      if ((listeIntensites != null) && (!listeIntensites.estVide()))
      {
        PeriodeIntensite periode = (PeriodeIntensite)listeIntensites.dernierElement();
        dvInopposable = determinerInopposabiliteIntensiteHoraireAeDv(periode, resultatRechercheConditionChomageInvolontaire, dvInopposable);
      }
    }
    return dvInopposable;
  }
  
  public static boolean determinerInopposabiliteIntensiteHoraireAeDv(PeriodeIntensite periode, ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire, boolean dvInopposable)
  {
    boolean retour = dvInopposable;
    BigDecimal horaires = periode.getHorairesSalarie();
    String uniteIntensiteHoraire = "34";
    if (horaires == null) {
      horaires = BigDecimal.valueOf(35L);
    } else {
      switch (periode.getUniteHoraire())
      {
      case 3: 
        uniteIntensiteHoraire = "35";
        retour = (dvInopposable) && (horaires.compareTo(BigDecimal.valueOf(73.67D)) >= 0);
        break;
      case 2: 
        uniteIntensiteHoraire = "36";
        retour = (dvInopposable) && (horaires.compareTo(BigDecimal.valueOf(780.54D)) >= 0);
        break;
      case 1: 
      default: 
        retour = (dvInopposable) && (horaires.compareTo(BigDecimal.valueOf(17L)) >= 0);
      }
    }
    resultatRechercheConditionChomageInvolontaire.setIntensiteHoraireAeDV(new Quantite(horaires, Unite.getParCode(uniteIntensiteHoraire)));
    return retour;
  }
  
  private static ResultatRechercheConditionChomageInvolontaire calculerTravailDepuisDernierDroit(Demande demande, Periode delaiRechercheDv, Reglement reglement)
    throws ApplicativeException
  {
    OutilConditionChomageInvolontaire outilConditionChomageInvolontaire = new OutilConditionChomageInvolontaire();
    Chronologie chronologiesParticipantesCalculAffi = outilConditionChomageInvolontaire.determinerChronoParticipantesCalculAffiliation(demande, delaiRechercheDv);
    
    ProduitAsuSpec produit = (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
    
    Pra pra = (Pra)produit.getOutilConstructionPRA().determinerPraOppositionDV(reglement.getNomReglement(), demande.getDateExamen());
    pra.setDebut(delaiRechercheDv.getDebut());
    pra.setFin(delaiRechercheDv.getFin());
    
    StrategieInnoposabiliteSpec strategie = (StrategieInnoposabiliteSpec)FabriqueStrategieGenerique.choisirStrategie(demande.getDateExamen(), "Non prise en compte de l'assimilation pour l'innoposabilité", new StrategieInnoposabiliteAvant(), new StrategieInnoposabiliteApres());
    
    return fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.verifierConditionAffiliation(demande, pra, chronologiesParticipantesCalculAffi, true, true, strategie.prendreEnCompteAssimilation(), true);
  }
  
  private static ResultatRechercheConditionChomageInvolontaire calculerTravailDepuisDernierDv(Demande demande, Periode delaiRechercheDv, TravailSpec dernierDv, Reglement reglement)
    throws ApplicativeException
  {
    Periode periodePra = new Periode();
    delaiRechercheDv.copieElements(periodePra);
    periodePra.setDebut(dernierDv.getDateFin().lendemain());
    OutilConditionChomageInvolontaire outilConditionChomageInvolontaire = new OutilConditionChomageInvolontaire();
    Chronologie chronologiesParticipantesCalculAffi = outilConditionChomageInvolontaire.determinerChronoParticipantesCalculAffiliation(demande, periodePra);
    
    ProduitAsuSpec produit = (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
    
    Pra pra = (Pra)produit.getOutilConstructionPRA().determinerPraCouvertureSuiteDV(reglement.getNomReglement());
    pra.setDebut(periodePra.getDebut());
    pra.setFin(periodePra.getFin());
    
    return fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.verifierConditionAffiliation(demande, pra, chronologiesParticipantesCalculAffi, produit.neDoitPasSanctionnerPndsPourCouvertureDv(), true, true, false);
  }
  
  static Damj determinerDateBorneDecision(Demande demande)
    throws CoucheLogiqueException
  {
    Damj pointDepartDelaiRecherche = Damj.NUIT_DES_TEMPS;
    if (!demande.estEnContexteDroitAnterieurSecteurPublic())
    {
      FiltreCaliSpec filtreDerniereDecision = FabriqueStrategieConditionChomageInvolontaireAre17.getInstance().getStrategie(demande).recupererFiltreDecisionPositiveAUtiliserPourBorneDelaiRechercheDv(demande);
      
      DecisionSpec derniereDecision = OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreDerniereDecision);
      if (derniereDecision != null) {
        pointDepartDelaiRecherche = gererContexteSortieCRA(derniereDecision);
      }
    }
    else
    {
      pointDepartDelaiRecherche = demande.getDonneesTemporaires().getDateAttributionDroitAnterieurSp();
    }
    return pointDepartDelaiRecherche;
  }
  
  private Damj determinerDateBorneDecisionInopposabilite(Demande demande)
    throws CoucheLogiqueException
  {
    Damj pointDepartDelaiRecherche = Damj.NUIT_DES_TEMPS;
    if (!demande.estEnContexteDroitAnterieurSecteurPublic())
    {
      FiltreCaliSpec filtreDerniereDecision = StrategieConditionChomageInvolontaireAre17Avant.getInstance().recupererFiltreDecisionPositiveAUtiliserPourBorneDelaiRechercheDv(demande);
      
      DecisionSpec derniereDecision = OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreDerniereDecision);
      if (derniereDecision != null) {
        pointDepartDelaiRecherche = gererContexteSortieCRA(derniereDecision);
      }
    }
    else
    {
      pointDepartDelaiRecherche = demande.getDonneesTemporaires().getDateAttributionDroitAnterieurSp();
    }
    return pointDepartDelaiRecherche;
  }
  
  private static Damj gererContexteSortieCRA(DecisionSpec decision)
  {
    Damj pointDepartDelaiRecherche;
    Damj pointDepartDelaiRecherche;
    if (((decision instanceof OdSpec)) && (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(((Demande)decision.getDemande()).getListContexteDemande(), "SORTIECRA"))) {
      pointDepartDelaiRecherche = Damj.max(((OdAssuranceSpec)decision).getDateFaitGenerateur(), decision.getDateAttribution());
    } else {
      pointDepartDelaiRecherche = decision.getDateEffetDecision();
    }
    return pointDepartDelaiRecherche;
  }
  
  private Periode determinationDelaiRechercheDv(Demande demande)
    throws CoucheLogiqueException
  {
    Damj pointDepartDelaiRecherche = determinationPointDepartDelaiRechercheDv(demande);
    return determinationDelaiRecherche(demande, pointDepartDelaiRecherche);
  }
  
  private Periode determinationDelaiRecherche(Demande demande, Damj pointDepartDelaiRecherche)
    throws CoucheLogiqueException
  {
    Damj termeDelaiRecherche = demande.getDateExamen().veille();
    
    Chronologie chronoPeriodesParticipantesRechercherDernierSinistre = fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre.determinerChronologieActivitesRechercheDernierSinistre(demande);
    TravailSpec dernierSinistre = fr.unedic.cali.asu.outilsfonctionnels.RechercherDernierSinistre.rechercherDernierSinistre(demande, chronoPeriodesParticipantesRechercherDernierSinistre);
    if (dernierSinistre != null) {
      termeDelaiRecherche = dernierSinistre.getDateFin();
    }
    if (pointDepartDelaiRecherche.estApres(termeDelaiRecherche)) {
      return null;
    }
    return new Periode(pointDepartDelaiRecherche, termeDelaiRecherche);
  }
  
  private Periode determinationDelaiRechercheInopposabilite(Demande demande)
    throws CoucheLogiqueException
  {
    Damj pointDepartDelaiRecherche = determinationPointDepartDelaiRechercheInopposabilite(demande);
    return determinationDelaiRecherche(demande, pointDepartDelaiRecherche);
  }
  
  public Damj determinationPointDepartDelaiRechercheDv(Demande demande)
    throws CoucheLogiqueException
  {
    Damj pointDepartDelaiRecherche = determinerDateBorneDecision(demande);
    
    pointDepartDelaiRecherche = FabriqueStrategieConditionChomageInvolontaireAre17.getInstance().getStrategie(demande).gestionIPRRepriseDV(pointDepartDelaiRecherche, demande);
    
    pointDepartDelaiRecherche = gestionCspSurPointDepartDelaiRecherche(demande, pointDepartDelaiRecherche);
    
    return pointDepartDelaiRecherche;
  }
  
  protected Damj gestionCspSurPointDepartDelaiRecherche(Demande demande, Damj pointDepartDelaiRecherche)
  {
    if ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTCSPDC")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTPAPDC")))
    {
      Damj finDispositifCSP = OutilAsp.getInstance().determinerDateFinDernierDispositifCSP(demande.getDemandeur(), demande.getDateExamen());
      if ((finDispositifCSP != null) && (finDispositifCSP.lendemain().estApres(pointDepartDelaiRecherche))) {
        pointDepartDelaiRecherche = finDispositifCSP.lendemain();
      }
    }
    else if ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTCSPARE")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTPAPARE")))
    {
      Damj finAeCSP = OutilAsp.getInstance().recupererAeCspPourEntreeEnDispositifCSP(demande.getDemandeur(), demande.getDateExamen()).getDateFin();
      if (finAeCSP.lendemain().estApres(pointDepartDelaiRecherche)) {
        pointDepartDelaiRecherche = finAeCSP.lendemain();
      }
    }
    return pointDepartDelaiRecherche;
  }
  
  private Damj determinationPointDepartDelaiRechercheInopposabilite(Demande demande)
    throws CoucheLogiqueException
  {
    Damj pointDepartDelaiRecherche = determinerDateBorneDecisionInopposabilite(demande);
    pointDepartDelaiRecherche = StrategieConditionChomageInvolontaireAre17Avant.getInstance().gestionIPRRepriseDV(pointDepartDelaiRecherche, demande);
    
    pointDepartDelaiRecherche = gestionCspSurPointDepartDelaiRecherche(demande, pointDepartDelaiRecherche);
    
    return pointDepartDelaiRecherche;
  }
  
  public ResultatRechercheConditionChomageInvolontaire rechercheConditionChomageInvolontairePourReprise(Demande demande)
    throws ApplicativeException
  {
    return rechercheConditionChomageInvolontaire(demande);
  }
  
  public ResultatRechercheConditionChomageInvolontaire rechercheConditionChomageInvolontairePourOd(Demande demande)
    throws ApplicativeException
  {
    return rechercheConditionChomageInvolontaire(demande);
  }
  
  protected DecisionSpec rechercherDecisionPrecedente(Chronologie demandesDecisions, Object pointDepartRecherche, FiltreCaliSpec filtreCali)
  {
    return OutilRecherche.rechercherDecisionPrecedente(demandesDecisions, pointDepartRecherche, filtreCali);
  }
}

/* Location:
 * Qualified Name:     StrategieConditionChomageInvolontaireAre14Apres
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */