package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.dom.ConteneurConditionActiviteConservee;
import fr.unedic.cali.asu.cge01.liquidation.dom.spec.ConstitutionDelaisSpec;
import fr.unedic.cali.asu.cge01.parametres.Parametres;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.JustificationAffiliationJoursTravailles;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.PeriodeElementaire;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionChomageInvolontaire;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Echec;
import fr.unedic.cali.asu.produits.liquidation.dom.Reprise;
import fr.unedic.cali.asu.produits.liquidation.dom.Revision;
import fr.unedic.cali.asu.produits.liquidation.dom.RevisionAdmission;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Metier;
import fr.unedic.cali.autresdoms.ga.dom.RegimeRetraite;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.RejetSpec;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChronoPeriodeSpec;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.List;

public class AlimenterBaseEchanges
{
  private static AlimenterBaseEchanges instance = null;
  
  public static AlimenterBaseEchanges getInstance()
  {
    if (instance == null) {
      instance = new AlimenterBaseEchanges();
    }
    return instance;
  }
  
  public void alimenterDonneesProduit(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.dom.echange.Decision demandeEchangeLocal = demandeEchange;
    if (demandeEchangeLocal == null) {
      demandeEchangeLocal = new fr.unedic.cali.dom.echange.Decision();
    }
    demandeEchangeLocal.setLigne(determinerLigneProduitCourant(fr.unedic.cali.asu.outilsfonctionnels.AlimenterBaseEchanges.determinerProduitDecision((Demande)dossierExamen.getDemande())));
    if ((dossierExamen.getDemande().estNotifieeCourrier()) && ((dossierExamen instanceof fr.unedic.cali.asu.produits.liquidation.dom.Decision)))
    {
      fr.unedic.cali.asu.produits.liquidation.dom.Decision decision = (fr.unedic.cali.asu.produits.liquidation.dom.Decision)dossierExamen;
      alimenterDonneesCourrierECAX(decision, demandeEchangeLocal);
      if ((decision instanceof Reprise))
      {
        Reprise reprise = (Reprise)decision;
        
        BigDecimal sjrrp = reprise.getConstitutionSjr().getSjrrp().getSalaire();
        demandeEchangeLocal.setMontantSJRSuiteRevision(sjrrp);
      }
      if ((decision instanceof RevisionAdmission)) {
        alimenterDonneesCourrierECB7PourRevision(decision, demandeEchangeLocal);
      }
      if ((decision instanceof Revision))
      {
        alimenterDonneesCourrierECB7PourRevision(decision, demandeEchangeLocal);
      }
      else if ((decision instanceof Echec))
      {
        alimenterDonneesCourrierECB7PourEchecRevision(decision, demandeEchangeLocal);
      }
      else if (!(decision instanceof RejetSpec))
      {
        alimenterDonneesCourrier(decision, demandeEchangeLocal);
        alimenterDonneesCourrierEcep(decision, demandeEchangeLocal);
      }
      alimenterDateDepartDelai121Jours(decision, demandeEchangeLocal);
      
      alimenterDonneesRejetSP(decision, demandeEchangeLocal);
      
      alimenterTopPNDS(decision, demandeEchangeLocal);
      
      alimenterDonneesEnCoursDeDisponibilite(decision.getDemande(), demandeEchangeLocal);
    }
  }
  
  protected void alimenterDonneesEnCoursDeDisponibilite(DemandeSpec demandeCali, fr.unedic.cali.dom.echange.Decision demandeEchange)
  {
    ContexteDemande contexte = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance((Demande)demandeCali, "COURSDISPO");
    if (contexte != null)
    {
      IncidentSpec periodeSuspensiveEnCours = contexte.getPeriodeSuspensiveEnCours();
      if (periodeSuspensiveEnCours != null)
      {
        demandeEchange.setNaturePeriodeSuspensive(periodeSuspensiveEnCours.getNature());
        demandeEchange.setDateFinPeriodeSuspensive(periodeSuspensiveEnCours.getPeriode().getFin());
      }
    }
  }
  
  protected void alimenterDonneesCourrier(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.produits.liquidation.dom.Decision decision = (fr.unedic.cali.asu.produits.liquidation.dom.Decision)dossierExamen;
    switch (decision.getNatureDecision())
    {
    case 11: 
    case 26: 
      alimenterDonneesCourrierReadAntecedent(decision, demandeEchange);
      break;
    default: 
      alimenterDonneesCourrierNonReadAntecedent(decision, demandeEchange);
    }
    demandeEchange.setLibelleEmployeur(decision.getCompetence().getLibelleEmployeurCompetent());
  }
  
  private void alimenterDonneesCourrierNonReadAntecedent(fr.unedic.cali.asu.produits.liquidation.dom.Decision dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    ConstitutionMontantsBruts cepaMontantsBruts = dossierExamen.getConstitutionMontantsBruts();
    if (cepaMontantsBruts != null)
    {
      if (cepaMontantsBruts.getMontantBrutSansDeduction() != null) {
        demandeEchange.setMontantAllocationJournalierBrutCourrier(cepaMontantsBruts.getMontantBrutSansDeduction().getValeur());
      }
      if (cepaMontantsBruts.getPensionInvaliditeADeduirePriseEnCompte() != null) {
        demandeEchange.setMontantPensionInvaliditeAreCourrier(cepaMontantsBruts.getPensionInvaliditeADeduirePriseEnCompte().getValeur());
      }
      if (cepaMontantsBruts.getCrc() != null) {
        demandeEchange.setMontantCrcCourrier(cepaMontantsBruts.getCrc().getValeur());
      }
      if (cepaMontantsBruts.getMontantJournalierAvantageVieillesseDeduit() != null) {
        demandeEchange.setMontantAllocation(cepaMontantsBruts.getMontantJournalierAvantageVieillesseDeduit().getValeur());
      }
    }
    ConstitutionDurees cepaDureesReglementaires = dossierExamen.getConstitutionDurees();
    if ((cepaDureesReglementaires != null) && (cepaDureesReglementaires.getDureeIndemnisation() != null) && (cepaDureesReglementaires.getDureeIndemnisation().getDureeTheorique() != null))
    {
      demandeEchange.setDureeTheoriqueDroitServiCourrier(bornerDureeSiPmvs(dossierExamen, cepaDureesReglementaires.getDureeIndemnisation().getDureeTheorique().getValeurEntiere()));
      
      demandeEchange.setDureeRenouvellementAreCourrier(cepaDureesReglementaires.getDureeIndemnisation().getDureeEffective().getValeurEntiere());
    }
  }
  
  public int bornerDureeSiPmvs(fr.unedic.cali.asu.produits.liquidation.dom.Decision dossierExamen, int duree)
    throws CoucheLogiqueException
  {
    int dureeARetourner = duree;
    ContexteDemandeSpec contexteDemande = OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent((Demande)dossierExamen.getDemande(), 2);
    if ((contexteDemande != null) && ((dossierExamen instanceof Attribution)))
    {
      Attribution attrib = (Attribution)dossierExamen;
      Damj pji = attrib.getPremierJourIndemnisable();
      Damj finPmvs = contexteDemande.getDateFinJustifContexte();
      if (duree > 0)
      {
        Damj djiTh = pji.deplacerVersAvant(new DureeCalendaire(0, 0, duree - 1));
        if (djiTh.estApres(finPmvs)) {
          dureeARetourner = pji.joursEntre(finPmvs) + 1;
        }
        if (pji.estApresOuCoincideAvec(finPmvs)) {
          dureeARetourner = 0;
        }
      }
    }
    return dureeARetourner;
  }
  
  private void alimenterDonneesCourrierReadAntecedent(fr.unedic.cali.asu.produits.liquidation.dom.Decision dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    ConstitutionProduitResultant constitutionProduitResultant = dossierExamen.getConstitutionProduitResultant();
    if (constitutionProduitResultant != null)
    {
      if (constitutionProduitResultant.getMontantBrutSansDeduction() != null) {
        demandeEchange.setMontantAllocationJournalierBrutCourrier(constitutionProduitResultant.getMontantBrutSansDeduction().getValeur());
      }
      if (constitutionProduitResultant.getPensionInvaliditeADeduirePriseEnCompte() != null) {
        demandeEchange.setMontantPensionInvaliditeAreCourrier(constitutionProduitResultant.getPensionInvaliditeADeduirePriseEnCompte().getValeur());
      }
      if (constitutionProduitResultant.getCrc() != null) {
        demandeEchange.setMontantCrcCourrier(constitutionProduitResultant.getCrc().getValeur());
      }
      if (constitutionProduitResultant.getMontantJournalierAvantageVieillesseDeduit() != null) {
        demandeEchange.setMontantAllocation(constitutionProduitResultant.getMontantJournalierAvantageVieillesseDeduit().getValeur());
      }
    }
    if (dossierExamen.getConstitutionProduitResultant() != null)
    {
      demandeEchange.setDureeTheoriqueDroitServiCourrier(bornerDureeSiPmvs(dossierExamen, dossierExamen.getConstitutionProduitResultant().getDureeTheorique().getValeurEntiere()));
      
      demandeEchange.setDureeRenouvellementAreCourrier(dossierExamen.getConstitutionProduitResultant().getDureeEffective().getValeurEntiere());
    }
  }
  
  protected void alimenterDonneesCourrierECAX(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
  {
    fr.unedic.cali.asu.produits.liquidation.dom.Decision decision = (fr.unedic.cali.asu.produits.liquidation.dom.Decision)dossierExamen;
    demandeEchange.setLibelleEmployeur(decision.getCompetence().getLibelleEmployeurCompetent());
    
    ConditionActiviteConservee capaConditionActiviteConservee = decision.getConditionActiviteConservee();
    if (capaConditionActiviteConservee != null)
    {
      BigDecimal montantSjc = capaConditionActiviteConservee.getMontantMensuelActiviteConservee();
      BigDecimal montantSjcMax = capaConditionActiviteConservee.getSeuilMontantMensuelActiviteConservee();
      if ((montantSjc != null) && (montantSjcMax != null) && (montantSjc.compareTo(montantSjcMax) > 0)) {
        demandeEchange.setMontantSJC(capaConditionActiviteConservee.getMontantMensuelActiviteConservee());
      }
      demandeEchange.setMontantSJCMax(capaConditionActiviteConservee.getSeuilMontantMensuelActiviteConservee());
      
      Chronologie listeActivitesConservee = decision.getListeActiviteConservee();
      int autreActiviteConservee = 0;
      if ((listeActivitesConservee != null) && (listeActivitesConservee.getTaille() > 0)) {
        autreActiviteConservee = 1;
      }
      demandeEchange.setAuMoinsUneActiviteConservee(autreActiviteConservee);
      
      BigDecimal nombreHeures = capaConditionActiviteConservee.getNombreHeuresMensuelActiviteConservee();
      BigDecimal nombreHeuresMax = Parametres.PLAFOND_HORAIRE_ACTIVITES_CONSERVEES;
      if ((nombreHeures != null) && (nombreHeuresMax != null) && (nombreHeures.compareTo(nombreHeuresMax) > 0))
      {
        demandeEchange.setNombreHeureUn(nombreHeuresMax);
        
        demandeEchange.setNombreHeureDeux(nombreHeures);
      }
    }
  }
  
  protected void alimenterDonneesCourrierEcep(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    int topCaisseInconnue = 0;
    
    fr.unedic.cali.asu.produits.liquidation.dom.Decision decision = (fr.unedic.cali.asu.produits.liquidation.dom.Decision)dossierExamen;
    if ((decision.getConditionFaitGenerateur() != null) && (decision.getConditionFaitGenerateur().getPeriodeFaitGenerateur().getMetier().getListeRegimeRetraite() != null))
    {
      List<RegimeRetraite> listeRegimeRetraite = decision.getConditionFaitGenerateur().getPeriodeFaitGenerateur().getMetier().getListeRegimeRetraite();
      for (RegimeRetraite regimeRetraiteGa : listeRegimeRetraite) {
        if (regimeRetraiteGa.estCaisseRetraiteAbsente()) {
          topCaisseInconnue = 1;
        }
      }
    }
    demandeEchange.setTopCaisseInconnue(topCaisseInconnue);
  }
  
  protected void alimenterDonneesCourrierECB7PourRevision(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    Attribution revision = (Attribution)dossierExamen;
    Demande demande = (Demande)dossierExamen.getDemande();
    
    BigDecimal montantsNets = revision.getConstitutionMontantsBruts().getMontantAAttribution().getMontantPrecompte();
    
    Damj pji = revision.getPji();
    
    Damj dateEffetRevision = revision.getDateEffet();
    
    Damj dateBanalisee = dateEffetRevision;
    if (pji != null) {
      dateBanalisee = Damj.max(dateEffetRevision, pji);
    }
    demandeEchange.setMontantAllocationJournalierNetCourrier(montantsNets);
    
    BigDecimal sjrrp = revision.getConstitutionSjr().getSjrrp().getSalaire();
    demandeEchange.setMontantSJRSuiteRevision(sjrrp);
    
    demandeEchange.setDateBanalisee(dateBanalisee);
    if ("ASU_07".equals(dossierExamen.getDemande().getEvenementReferenceExamen().getTypeExamen())) {
      demandeEchange.setMontantSJCMax(determinerPlafondMensuelRemuneration(dossierExamen, demande));
    }
  }
  
  protected void alimenterDonneesCourrierECB7PourEchecRevision(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)dossierExamen.getDemande();
    if ("ASU_07".equals(dossierExamen.getDemande().getEvenementReferenceExamen().getTypeExamen())) {
      demandeEchange.setMontantSJCMax(determinerPlafondMensuelRemuneration(dossierExamen, demande));
    }
  }
  
  private BigDecimal determinerPlafondMensuelRemuneration(DossierExamenSpec dossierExamen, Demande demandeCourante)
    throws CoucheLogiqueException
  {
    Demande demande = demandeCourante;
    AttributionSpec odOrigine;
    if ((dossierExamen instanceof Echec))
    {
      Echec echec = (Echec)dossierExamen;
      AttributionSpec odOrigine = echec.getOuvertureDroit();
      demande = (Demande)odOrigine.getDemande();
    }
    else
    {
      Revision revision = (Revision)dossierExamen;
      odOrigine = revision.getOuvertureDroit();
    }
    Demande demandeOrigine = (Demande)odOrigine.getDemande();
    
    RechercheConditionCumulActiviteConservee rechercheConditionCumulActiviteConservee = RechercheConditionCumulActiviteConservee.getInstance();
    BigDecimal plafondMensuelRemuneration;
    BigDecimal plafondMensuelRemuneration;
    if (demandeOrigine.estMigree())
    {
      BigDecimal seuilMontantMensuel = rechercheConditionCumulActiviteConservee.determinerSeuilMensuelPansSurODMigree(demandeOrigine);
      plafondMensuelRemuneration = rechercheConditionCumulActiviteConservee.determinerPlafondMensuelRemunerationSurODMigree(demande, seuilMontantMensuel, demandeCourante.getDateExamen());
    }
    else
    {
      ConteneurConditionActiviteConservee conteneurConditionActiviteConservee = new ConteneurConditionActiviteConservee();
      DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierAffectation().getDossierExamen();
      rechercheConditionCumulActiviteConservee.mapperConditionActiviteConserveeVersConteneur(conteneurConditionActiviteConservee, dossierExamenCourant.getConditionActiviteConservee());
      plafondMensuelRemuneration = rechercheConditionCumulActiviteConservee.determinerPlafondMensuelRemuneration(conteneurConditionActiviteConservee, demande, demandeCourante.getDateExamen());
    }
    return plafondMensuelRemuneration;
  }
  
  private String determinerLigneProduitCourant(ProduitSpec produitCourant)
  {
    return produitCourant.getLigne().getNomUnique();
  }
  
  protected void alimenterDateDepartDelai121Jours(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
  {
    if ((dossierExamen instanceof fr.unedic.cali.asu.produits.liquidation.dom.Decision))
    {
      fr.unedic.cali.asu.produits.liquidation.dom.Decision decision = (fr.unedic.cali.asu.produits.liquidation.dom.Decision)dossierExamen;
      ConditionChomageInvolontaire capaConditionActiviteConservee = decision.getConditionChomageInvolontaire();
      if (capaConditionActiviteConservee != null) {
        demandeEchange.setDateDepartDelai121j(capaConditionActiviteConservee.getDateDepartDelai121j());
      }
    }
  }
  
  public void alimenterDonneesRejetSP(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
  {
    fr.unedic.cali.asu.produits.liquidation.dom.Decision decision = (fr.unedic.cali.asu.produits.liquidation.dom.Decision)dossierExamen;
    
    ConstitutionDelaisSpec cepDelai = decision.getConstitutionDelais();
    if (cepDelai != null) {
      demandeEchange.setDateDebutDernierDelaiAttente(cepDelai.getDateDebutDernierDelaiAttente());
    }
    CompetenceSpec competence = decision.getCompetence();
    if ((competence != null) && (competence.estCompetenceAdministrativeSecteurPublic()))
    {
      if (competence.isEstCoeffTPAppliqueRAC()) {
        demandeEchange.setCoeffTPAppliqueRAC(1);
      } else {
        demandeEchange.setCoeffTPAppliqueRAC(0);
      }
      if (competence.isEstCoeffTPAppliqueSP()) {
        demandeEchange.setCoeffTPAppliqueSP(1);
      } else {
        demandeEchange.setCoeffTPAppliqueSP(0);
      }
      demandeEchange.setDureeActiviteEmployeursRAC(competence.getDureeActiviteSecteurPrive() + competence.getDureeActiviteSecteurPublicAffilie() + competence.getDureeActiviteSecteurPriveCaCae());
      
      demandeEchange.setDureeActiviteEmployeursSP(competence.getDureeActiviteSecteurPublicAutoAssurance() + competence.getDureeActiviteSecteurPublicConventionGestion());
    }
    if (decision.getReglementApplicable() != null) {
      demandeEchange.setReglementApplicableDroit(decision.getReglementApplicable().getReglement().getLibelleCourt());
    }
    demandeEchange.setDateFaitGenerateurDroitPrecedent(decision.getDemandeAssurance().getDateFaitGenerateurOdPrecedente());
    
    ObjetChronoPeriodeSpec periode = OutillagePEC.getPeriodePECIndemnisableContenant(decision.getDemandeAssurance().getDemandeur(), decision.getDateAttribution());
    if (periode != null) {
      demandeEchange.setDateIDE(periode.getDateDebut());
    }
  }
  
  protected void alimenterTopPNDS(fr.unedic.cali.asu.produits.liquidation.dom.Decision decisionAssurance, fr.unedic.cali.dom.echange.Decision decisionEchange)
    throws CoucheLogiqueException
  {
    boolean estPresencePNDS;
    boolean estPresencePNDS;
    if (estAffiliationForcee(recupererDonneesForcees(decisionAssurance)))
    {
      estPresencePNDS = verifierPresencePNDSSurDemande((Demande)decisionAssurance.getDemande());
    }
    else
    {
      JustificationAffiliationSpec justifAffi = recupererJustificationAffiliation(decisionAssurance);
      boolean estPresencePNDS;
      if ((justifAffi != null) && ("justifJoursTravailles".equals(justifAffi.getTypeJustificationAffiliation()))) {
        estPresencePNDS = verifierPresencePNDSSurJustifAffiJoursOuvres((JustificationAffiliationJoursTravailles)justifAffi);
      } else {
        estPresencePNDS = verifierPresencePNDSSurJustifAffi((JustificationAffiliation)justifAffi);
      }
    }
    if (estPresencePNDS) {
      decisionEchange.setEstPresencePNDS(1);
    }
  }
  
  protected boolean estAffiliationForcee(DonneesTemporaires donneesForcees)
  {
    return donneesForcees.getQuantiteAffiliation() != null;
  }
  
  protected boolean verifierPresencePNDSSurJustifAffi(JustificationAffiliation justifAffi)
  {
    boolean estPresencePNDS = false;
    if (justifAffi != null)
    {
      Collection<PeriodeElementaire> periodesElementaires = justifAffi.getCollectionPeriodeElementaire();
      for (PeriodeElementaire periodeCourante : periodesElementaires) {
        if (periodeCourante.isEstSanctionnee())
        {
          estPresencePNDS = true;
          break;
        }
      }
    }
    return estPresencePNDS;
  }
  
  protected boolean verifierPresencePNDSSurDemande(Demande demande)
    throws CoucheLogiqueException
  {
    boolean estPresencePNDS = false;
    if (demande.getDossierAffectationAdmission().getValidationProduit() != null)
    {
      Periode pra = demande.getDossierAffectationAdmission().getValidationProduit().getPeriodePra();
      if (pra != null) {
        try
        {
          Chronologie chrono = demande.getChronologiePNDS(pra);
          estPresencePNDS = (chrono != null) && (!chrono.estVide());
        }
        catch (ApplicativeException ex)
        {
          throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle(), ex);
        }
      }
    }
    return estPresencePNDS;
  }
  
  protected boolean verifierPresencePNDSSurJustifAffiJoursOuvres(JustificationAffiliationJoursTravailles justif)
  {
    boolean estPresencePNDS = false;
    if (justif != null) {
      estPresencePNDS = justif.isPresencePNDS();
    }
    return estPresencePNDS;
  }
  
  protected JustificationAffiliationSpec recupererJustificationAffiliation(fr.unedic.cali.asu.produits.liquidation.dom.Decision decision)
  {
    JustificationAffiliationSpec justification;
    JustificationAffiliationSpec justification;
    if ((decision instanceof RevisionAdmission)) {
      justification = ((Attribution)decision).getAttributionAssociee().getJustificationAffiliation();
    } else {
      justification = decision.getJustificationAffiliation();
    }
    return justification;
  }
  
  protected DonneesTemporaires recupererDonneesForcees(fr.unedic.cali.asu.produits.liquidation.dom.Decision decision)
  {
    return ((Demande)decision.getDemande()).getDonneesTemporaires();
  }
}

/* Location:
 * Qualified Name:     AlimenterBaseEchanges
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */