package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategiePriseEnCompteIccp;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategiePriseEnCompteIccpSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.DeterminationCarenceAsu;
import fr.unedic.cali.asu.produits.liquidation.dom.BaseCarence;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJourTravailDansSemaineSpec;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Iterator;

public class ConstructionBaseCarence
{
  private static final int MOIS_JUIN = 6;
  private static final int PREMIER_JOUR_MOIS = 1;
  private static ConstructionBaseCarence instance = new ConstructionBaseCarence();
  
  public static ConstructionBaseCarence getInstance()
  {
    return instance;
  }
  
  public BaseCarence determinerBaseCarence(ActiviteSalarie periodeActiviteSalarie, Damj dateFg)
  {
    QuantiteEuro quantiteEuroIccp = determinerMontantIccp(periodeActiviteSalarie, dateFg);
    QuantiteJourTravailDansSemaineSpec quantiteJourIccp = (QuantiteJourTravailDansSemaineSpec)periodeActiviteSalarie.getQuantiteJourIccp();
    QuantiteEuro quantiteEuroIslr = periodeActiviteSalarie.getQuantiteEuroIslr();
    BaseCarence baseCarence = new BaseCarence(quantiteJourIccp, quantiteEuroIccp, quantiteEuroIslr);
    
    baseCarence.setPeriodeActiviteSalarieOrigine(periodeActiviteSalarie);
    
    baseCarence.setLicenciementEconomique(periodeActiviteSalarie.isLicenciementEconomique());
    
    return baseCarence;
  }
  
  private QuantiteEuro determinerMontantIccp(ActiviteSalarie periodeActiviteSalarie, Damj dateFg)
  {
    Reglement reglementAppartenance = periodeActiviteSalarie.getReglement();
    ProduitSpec produit = reglementAppartenance.getProduit();
    QuantiteEuro quantiteEuroIccpRetournee;
    QuantiteEuro quantiteEuroIccpRetournee;
    if (reglementAppartenance.equals(produit.getReglement("A5"))) {
      quantiteEuroIccpRetournee = determinerMontantIccpA5(periodeActiviteSalarie, dateFg);
    } else {
      quantiteEuroIccpRetournee = determinerMontantIccpALaFctOdRg(periodeActiviteSalarie, dateFg);
    }
    return quantiteEuroIccpRetournee;
  }
  
  private QuantiteEuro determinerMontantIccpALaFctOdRg(ActiviteSalarie periodeActiviteSalarie, Damj dateFg)
  {
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(periodeActiviteSalarie.getDateFin());
    StrategiePriseEnCompteIccpSpec strategiePriseEnCompteIccpCourante = (StrategiePriseEnCompteIccpSpec)FabriqueStrategiePriseEnCompteIccp.getInstance().getStrategie(critereStrategie);
    
    return strategiePriseEnCompteIccpCourante.determinerMontantIccpALaFctOdRg(periodeActiviteSalarie, dateFg);
  }
  
  private QuantiteEuro determinerMontantIccpA5(ActiviteSalarie periodeActiviteSalarie, Damj dateFg)
  {
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(periodeActiviteSalarie.getDateFin());
    StrategiePriseEnCompteIccpSpec strategiePriseEnCompteIccpCourante = (StrategiePriseEnCompteIccpSpec)FabriqueStrategiePriseEnCompteIccp.getInstance().getStrategie(critereStrategie);
    
    return strategiePriseEnCompteIccpCourante.determinerMontantIccpA5(periodeActiviteSalarie, dateFg);
  }
  
  protected QuantiteEuro determinerMontantIccpA5Salaires(ActiviteSalarie periodeActiviteSalarie, Damj dateFg)
  {
    QuantiteEuro quantiteEuroIccpRetournee = null;
    
    Periode periodeReference = determinerPeriodeReferenceA5(dateFg);
    
    Chronologie chronologieResultante = periodeActiviteSalarie.getListeSalaires().copier(new FiltreChevauchePeriode(periodeReference));
    Iterator iter = chronologieResultante.iterer();
    BigDecimal txICCP = null;
    BigDecimal txIPE = null;
    BigDecimal cumulMontantsIccp = null;
    while (iter.hasNext())
    {
      Salaire salaire = (Salaire)iter.next();
      
      QuantiteEuro montantICCPSalaire = (QuantiteEuro)salaire.getMontantIccp();
      if (montantICCPSalaire != null)
      {
        if (cumulMontantsIccp == null) {
          cumulMontantsIccp = BigDecimal.ZERO;
        }
        cumulMontantsIccp = cumulMontantsIccp.add(salaire.getMontantIccp().getValeur());
      }
      else
      {
        txICCP = salaire.getTauxIccp();
        txIPE = salaire.getTauxIndemnisationPrecarite();
      }
      if (txICCP != null)
      {
        if (cumulMontantsIccp == null) {
          cumulMontantsIccp = BigDecimal.ZERO;
        }
        cumulMontantsIccp = cumulMontantsIccp.add(salaire.getMontantBrutBase().getValeur());
      }
    }
    if (txICCP != null) {
      quantiteEuroIccpRetournee = new QuantiteEuro(determinerMontantIccpA5AvecMajorationRemuneration(cumulMontantsIccp, txICCP, txIPE));
    } else if (cumulMontantsIccp != null) {
      quantiteEuroIccpRetournee = new QuantiteEuro(cumulMontantsIccp);
    }
    return quantiteEuroIccpRetournee;
  }
  
  private Periode determinerPeriodeReferenceA5(Damj dateFg)
  {
    Damj datePivot = new Damj(dateFg.getAnnee(), 6, 1);
    Damj dateDebutPeriode;
    Damj dateDebutPeriode;
    if (dateFg.estApres(datePivot)) {
      dateDebutPeriode = new Damj(dateFg.getAnnee() - 1, 6, 1);
    } else {
      dateDebutPeriode = new Damj(dateFg.getAnnee() - 2, 6, 1);
    }
    return new Periode(dateDebutPeriode, dateFg);
  }
  
  private BigDecimal determinerMontantIccpA5AvecMajorationRemuneration(BigDecimal cumulSalaires, BigDecimal txIccp, BigDecimal txIpe)
  {
    BigDecimal denominateur;
    BigDecimal nominateur;
    BigDecimal denominateur;
    if (txIpe == null)
    {
      BigDecimal nominateur = txIccp;
      denominateur = txIccp.add(BigDecimal.ONE);
    }
    else
    {
      nominateur = txIccp;
      denominateur = txIccp.add(BigDecimal.ONE).multiply(txIpe.add(BigDecimal.ONE));
    }
    BigDecimal montantIccpCalcule = Mathematiques.proratiser(cumulSalaires, nominateur, denominateur);
    montantIccpCalcule = Mathematiques.arrondiASup(montantIccpCalcule, 2);
    
    return montantIccpCalcule;
  }
  
  public BaseCarence determinerBaseCarenceOdA4(ActiviteSalarie periodeFg, Chronologie chronologie, Demande demande)
    throws ApplicativeException
  {
    QuantiteEuro quantiteEuroIccp = determinerMontantIccpChronoFctOdA4(chronologie, demande);
    
    QuantiteEuro quantiteEuroIslr = periodeFg.getQuantiteEuroIslr();
    BaseCarence baseCarence = new BaseCarence(null, quantiteEuroIccp, quantiteEuroIslr);
    
    baseCarence.setPeriodeActiviteSalarieOrigine(periodeFg);
    
    baseCarence.setLicenciementEconomique(periodeFg.isLicenciementEconomique());
    
    return baseCarence;
  }
  
  private QuantiteEuro determinerMontantIccpChronoFctOdA4(Chronologie chronologie, Demande demande)
    throws ApplicativeException
  {
    BigDecimal cumulMontantsIccpOdA4 = BigDecimal.ZERO;
    
    Chronologie chronologieHorsAttributions = chronologie;
    Chronologie chronologiePendantAttributionsAvecIccpRupture = new ChronologiePeriodes();
    
    Periode periodeAttributionAsuPrecedente = DeterminationCarenceAsu.determinerPeriodePriseEnCompteActiviteReduiteAsuPrecedente(demande);
    Damj finPeriodeAttributionAsuPrecedente = null;
    if (periodeAttributionAsuPrecedente != null)
    {
      chronologieHorsAttributions = DeterminationCarenceAsu.determinerChronoHorsPeriodePriseEnCompteActiviteReduite(chronologieHorsAttributions, periodeAttributionAsuPrecedente);
      
      chronologiePendantAttributionsAvecIccpRupture.ajouter(DeterminationCarenceAsu.determinerChronoPendantPeriodePriseEnCompteActiviteReduite(chronologie, periodeAttributionAsuPrecedente));
      
      finPeriodeAttributionAsuPrecedente = periodeAttributionAsuPrecedente.getFin();
    }
    Periode periodeAttributionAssPrecedente = DeterminationCarenceAsu.determinerPeriodePriseEnCompteActiviteReduiteAssPrecedente(demande);
    Damj finPeriodeAttributionAssPrecedente = null;
    if (periodeAttributionAssPrecedente != null)
    {
      chronologieHorsAttributions = DeterminationCarenceAsu.determinerChronoHorsPeriodePriseEnCompteActiviteReduite(chronologieHorsAttributions, periodeAttributionAssPrecedente);
      
      chronologiePendantAttributionsAvecIccpRupture.ajouter(DeterminationCarenceAsu.determinerChronoPendantPeriodePriseEnCompteActiviteReduite(chronologie, periodeAttributionAssPrecedente));
      
      finPeriodeAttributionAssPrecedente = periodeAttributionAssPrecedente.getFin();
    }
    Periode periodeDelaiRechercheCarences = ((DossierExamen)demande.getDossierExamen()).getConstitutionDelais().getPeriodeReference91jours();
    chronologieHorsAttributions.iterer();
    while (chronologieHorsAttributions.encoreSuivant())
    {
      ActiviteSalarie periodeTraitee = (ActiviteSalarie)chronologieHorsAttributions.elementSuivant();
      
      QuantiteEuro quantiteEuroIccpCourante = determinerMontantIccpOdA4(periodeTraitee, periodeDelaiRechercheCarences, finPeriodeAttributionAsuPrecedente, finPeriodeAttributionAssPrecedente);
      if ((quantiteEuroIccpCourante != null) && (quantiteEuroIccpCourante.getValeurMontant().compareTo(BigDecimal.ZERO) > 0)) {
        cumulMontantsIccpOdA4 = cumulMontantsIccpOdA4.add(quantiteEuroIccpCourante.getValeurMontant());
      }
    }
    chronologiePendantAttributionsAvecIccpRupture.iterer();
    while (chronologiePendantAttributionsAvecIccpRupture.encoreSuivant())
    {
      ActiviteSalarie periodeTraitee = (ActiviteSalarie)chronologiePendantAttributionsAvecIccpRupture.elementSuivant();
      
      BigDecimal montantIccpProratise = determinerMontantIccpRuptureOdA4(periodeTraitee, finPeriodeAttributionAsuPrecedente, finPeriodeAttributionAssPrecedente, true);
      if (montantIccpProratise != null) {
        cumulMontantsIccpOdA4 = cumulMontantsIccpOdA4.add(montantIccpProratise);
      }
    }
    QuantiteEuro quantiteEuroIccpRetournee = new QuantiteEuro(cumulMontantsIccpOdA4);
    return quantiteEuroIccpRetournee;
  }
  
  private QuantiteEuro determinerMontantIccpOdA4(ActiviteSalarie periodeActiviteSalarie, Periode periodeDelaiRechercheCarences, Damj finPeriodeAttributionAsuPrecedente, Damj finPeriodeAttributionAssPrecedente)
  {
    BigDecimal cumulMontantsIccpOdA4 = BigDecimal.ZERO;
    Chronologie chronoPeriodesSalaireCourante = periodeActiviteSalarie.getListeSalaires();
    
    BigDecimal montantICCPProratise = determinerMontantIccpRuptureOdA4(periodeActiviteSalarie, finPeriodeAttributionAsuPrecedente, finPeriodeAttributionAssPrecedente, false);
    if (montantICCPProratise != null) {
      cumulMontantsIccpOdA4 = cumulMontantsIccpOdA4.add(montantICCPProratise);
    }
    chronoPeriodesSalaireCourante.iterer();
    while (chronoPeriodesSalaireCourante.encoreSuivant())
    {
      Salaire periodeSalaireCourante = (Salaire)chronoPeriodesSalaireCourante.elementSuivant();
      Damj datePeriodeSalaireCourante = periodeSalaireCourante.getDatePaie() != null ? periodeSalaireCourante.getDatePaie() : periodeSalaireCourante.getDateFin();
      if (periodeDelaiRechercheCarences.contient(datePeriodeSalaireCourante))
      {
        BigDecimal montantIccpSalaireCourant = periodeSalaireCourante.determinerMontantIccp();
        if (montantIccpSalaireCourant != null)
        {
          montantIccpSalaireCourant = DeterminationCarenceIccpA4.getInstance().proratiserMontantICCP(montantIccpSalaireCourant, periodeSalaireCourante.getPeriode(), finPeriodeAttributionAsuPrecedente, finPeriodeAttributionAssPrecedente);
          
          cumulMontantsIccpOdA4 = cumulMontantsIccpOdA4.add(montantIccpSalaireCourant);
        }
      }
    }
    QuantiteEuro quantiteEuroIccpRetournee = new QuantiteEuro(cumulMontantsIccpOdA4);
    return quantiteEuroIccpRetournee;
  }
  
  private BigDecimal determinerMontantIccpRuptureOdA4(ActiviteSalarie periodeActiviteSalarie, Damj finPeriodeAttributionAsuPrecedente, Damj finPeriodeAttributionAssPrecedente, boolean estUneChronoPendantAttribution)
  {
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(periodeActiviteSalarie.getDateFin());
    StrategiePriseEnCompteIccpSpec strategiePriseEnCompteIccpCourante = (StrategiePriseEnCompteIccpSpec)FabriqueStrategiePriseEnCompteIccp.getInstance().getStrategie(critereStrategie);
    
    return strategiePriseEnCompteIccpCourante.determinerMontantIccpOdA4(periodeActiviteSalarie, finPeriodeAttributionAsuPrecedente, finPeriodeAttributionAssPrecedente, estUneChronoPendantAttribution);
  }
}

/* Location:
 * Qualified Name:     ConstructionBaseCarence
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */