package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.competence.DeterminationCompetenceAsp;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.competence.DeterminationCompetenceCge;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.competence.OutilDeterminationCompetence;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.EreDemandeAssociee;
import fr.unedic.cali.asu.dom.ResultatDeterminationCompetence;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import java.util.List;

public class DeterminationCompetence
  implements OutilFonctionnel
{
  public static DeterminationCompetence getInstance()
  {
    return new DeterminationCompetence();
  }
  
  public void alimenterCompetenceProduitCourant(Demande demandeCourante, CompetenceSpec competence, CompetenceSpec competenceSousJacente)
    throws CoucheLogiqueException
  {
    if (estReconductionSurObjectifAdmission(demandeCourante))
    {
      reconduireCompetenceSurObjectifAdmission(demandeCourante, competence, competenceSousJacente);
    }
    else
    {
      ResultatDeterminationCompetence resultatDeterminationCompetence = determinationCompetencesProduitCourant(demandeCourante);
      
      OutilDeterminationCompetence.mapperResultatSurCompetence(resultatDeterminationCompetence, competence);
      if ((resultatDeterminationCompetence != null) && (resultatDeterminationCompetence.getResultatDeterminationCompetenceSousJacente() != null)) {
        OutilDeterminationCompetence.mapperResultatSurCompetence(resultatDeterminationCompetence.getResultatDeterminationCompetenceSousJacente(), competenceSousJacente);
      }
    }
  }
  
  public ResultatDeterminationCompetence determinationCompetencesProduitCourant(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    ResultatDeterminationCompetence resultatDeterminationCompetence = null;
    
    ResultatDeterminationCompetence resultatDeterminationCompetenceCge = recupererOfDeterminationCompetenceCgeActif().determinationCompetencesProduitCourant(demandeCourante);
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, 7))
    {
      resultatDeterminationCompetence = DeterminationCompetenceAsp.getInstance().determinationCompetencesProduitCourant(demandeCourante);
      ResultatDeterminationCompetence resultatDeterminationCompetenceSouJacente = resultatDeterminationCompetenceCge;
      resultatDeterminationCompetence.setResultatDeterminationCompetenceSousJacente(resultatDeterminationCompetenceSouJacente);
    }
    else
    {
      resultatDeterminationCompetence = resultatDeterminationCompetenceCge;
    }
    return resultatDeterminationCompetence;
  }
  
  private boolean estReconductionSurObjectifAdmission(Demande demandeCourante)
  {
    List<ContexteDemandeSpec> listeContexteDemande = demandeCourante.getListContexteDemande();
    
    boolean enCoursAspDC = (OutilGestionContexteDemande.estContextePresentDansRegroupement(listeContexteDemande, 9)) && (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(listeContexteDemande, "ARECOURCSP"));
    
    boolean enCoursAspSousJacent = OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(listeContexteDemande, "ASPSJACENT");
    
    return (enCoursAspDC) || (enCoursAspSousJacent);
  }
  
  private void reconduireCompetenceSurObjectifAdmission(Demande demandeCourante, CompetenceSpec competence, CompetenceSpec competenceSousJacente)
    throws CoucheLogiqueException
  {
    DossierExamenAssuranceSpec dossierExamenPortantCompetenceARecuperer = trouverDossierExamenPortantCompetenceAReconduire(demandeCourante);
    if (dossierExamenPortantCompetenceARecuperer != null)
    {
      CompetenceSpec competenceMere = dossierExamenPortantCompetenceARecuperer.getCompetence();
      ResultatDeterminationCompetence sauvegardeCompetence = new ResultatDeterminationCompetence();
      OutilDeterminationCompetence.mapperCompetenceSurResultat(competenceMere, sauvegardeCompetence);
      OutilDeterminationCompetence.mapperResultatSurCompetence(sauvegardeCompetence, competence);
    }
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, 7))
    {
      ResultatDeterminationCompetence resultatDeterminationCompetenceCge = recupererOfDeterminationCompetenceCgeActif().determinationCompetencesProduitCourant(demandeCourante);
      
      OutilDeterminationCompetence.mapperResultatSurCompetence(resultatDeterminationCompetenceCge, competenceSousJacente);
    }
  }
  
  public DossierExamenAssuranceSpec trouverDossierExamenPortantCompetenceAReconduire(Demande demande)
  {
    boolean enCoursAspDC = (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 9)) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP"));
    
    DossierExamenAssuranceSpec dossierExamenPortantCompetenceARecuperer = null;
    if (enCoursAspDC)
    {
      Demande demandePrecedenteEntreeCsp = (Demande)OutilRecherche.rechercherDemandePrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, new FiltreDemandePourTypeContexteDemande("AREENTRCSP"));
      if (demandePrecedenteEntreeCsp != null) {
        dossierExamenPortantCompetenceARecuperer = (DossierExamenAssuranceSpec)demandePrecedenteEntreeCsp.getDossierExamen();
      }
    }
    else
    {
      DemandeAssuranceSpec demandeMere = ((EreDemandeAssociee)demande.getEvenementReferenceExamen()).getDemandeMere();
      dossierExamenPortantCompetenceARecuperer = (DossierExamenAssuranceSpec)demandeMere.getDossierExamen();
    }
    return dossierExamenPortantCompetenceARecuperer;
  }
  
  protected DeterminationCompetenceCge recupererOfDeterminationCompetenceCgeActif()
  {
    return DeterminationCompetenceCge.getInstance();
  }
}

/* Location:
 * Qualified Name:     DeterminationCompetence
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */