package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieMontantICCP;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.CriteresStrategieMontantICCP;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.StrategiePriseEnCompteMontantCarencesSurActiviteConserveeApres;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.StrategiePriseEnCompteMontantCarencesSurActiviteConserveeAvant;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieMontantICCPSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategiePriseEnCompteMontantCarencesSurActiviteConserveeSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.BaseDelaiReport;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.fabriques.outilsfonctionnels.FabriqueStrategieGenerique;
import fr.unedic.cali.outilsfonctionnels.ComparateurTemporelSurDateFinDecroissante;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class OutilDeterminationMontantICCP
  implements OutilFonctionnel
{
  protected static final BigDecimal ZERO = BigDecimal.ZERO;
  
  public static BaseDelaiReport determinerBaseDelaiReportICCPCasGeneral(DemandeAssuranceSpec demande, ActiviteSalarie activiteSalarie, ChronologiePeriodes chronoPeriodesIndemnisation)
    throws ApplicativeException
  {
    BaseDelaiReport baseDelaiReportActiviteCourante = new BaseDelaiReport(activiteSalarie);
    
    CriteresStrategieMontantICCP criteres = new CriteresStrategieMontantICCP();
    criteres.setDatePivot(activiteSalarie.getDateFin());
    criteres.setReglementAppartenanceActiviteSalarie(activiteSalarie.getReglement());
    StrategieMontantICCPSpec strategieMontantICCP = FabriqueStrategieMontantICCP.getInstance().determinerStrategieMontantICCPCasGeneral(criteres);
    
    activiteSalarie.setPresenceMontantICCPAvantProratisation(false);
    activiteSalarie.setMontantIccpProratise(false);
    QuantiteEuro quantiteMontantICCP = strategieMontantICCP.determinerMontantICCP(demande, activiteSalarie, chronoPeriodesIndemnisation);
    
    baseDelaiReportActiviteCourante.setQuantiteEuroIccp(quantiteMontantICCP);
    
    baseDelaiReportActiviteCourante.setPresenceMontantIccpAvantPriseEnCompteAR(activiteSalarie.estPresenceMontantICCPAvantProratisation());
    baseDelaiReportActiviteCourante.setDateExamen(demande.getDateExamen());
    baseDelaiReportActiviteCourante.setMontantIccpProratise(activiteSalarie.estMontantIccpProratise());
    baseDelaiReportActiviteCourante.setSousTypeObjectif(demande.getObjectifCourant().getSousType());
    
    return baseDelaiReportActiviteCourante;
  }
  
  public static BaseDelaiReport determinerBaseDelaiReportICCPA4(DemandeAssuranceSpec demande, ActiviteSalarie activiteSalarie)
    throws ApplicativeException
  {
    BaseDelaiReport baseDelaiReportActiviteCourante = new BaseDelaiReport(activiteSalarie);
    BigDecimal cumulMontantsICCPA4 = ZERO;
    
    Attribution attributionCourante = (Attribution)((Demande)demande).getAttribution();
    Periode periodeReference = attributionCourante.getConstitutionDelais().getPeriodeReference91jours();
    
    ChronologiePeriodes chronoPeriodesIndemnisationPrecedentes = OutilChronologiePourDelaisReports.determinerChronologiePeriodesIndemnisation(demande);
    
    Chronologie chronoActivitesParticipantesMontantICCPA4 = OutilChronologiePourDelaisReports.determinerChronologieActivitesPourDifferes(demande);
    if ((chronoActivitesParticipantesMontantICCPA4 != null) && (!chronoActivitesParticipantesMontantICCPA4.estVide()))
    {
      ActiviteSalarie activiteSalarieCourante = null;
      BigDecimal montantICCPA4Courant = null;
      chronoActivitesParticipantesMontantICCPA4.iterer();
      ChronologiePeriodes chronoPeriodesIndemnisationPourActiviteCourante = null;
      while (chronoActivitesParticipantesMontantICCPA4.encoreSuivant())
      {
        activiteSalarieCourante = (ActiviteSalarie)chronoActivitesParticipantesMontantICCPA4.elementSuivant();
        
        StrategiePriseEnCompteMontantCarencesSurActiviteConserveeSpec strategiePriseEnCompteMontantICCPActiviteConservee = (StrategiePriseEnCompteMontantCarencesSurActiviteConserveeSpec)FabriqueStrategieGenerique.choisirStrategie(activiteSalarie.getDateFin(), "Prise en compte des montants ICCP et ISLR sur les activités conservées", new StrategiePriseEnCompteMontantCarencesSurActiviteConserveeAvant(), new StrategiePriseEnCompteMontantCarencesSurActiviteConserveeApres());
        
        chronoPeriodesIndemnisationPourActiviteCourante = strategiePriseEnCompteMontantICCPActiviteConservee.formaterPeriodesIndemnisation(chronoPeriodesIndemnisationPrecedentes, strategiePriseEnCompteMontantICCPActiviteConservee.estUneActiviteConservee(activiteSalarie, demande.getDemandeur()));
        
        montantICCPA4Courant = determinerMontantICCPA4(activiteSalarieCourante, periodeReference, chronoPeriodesIndemnisationPourActiviteCourante);
        if (montantICCPA4Courant != null) {
          cumulMontantsICCPA4 = cumulMontantsICCPA4.add(montantICCPA4Courant);
        }
      }
    }
    baseDelaiReportActiviteCourante.setQuantiteEuroIccp(new QuantiteEuro(cumulMontantsICCPA4));
    
    return baseDelaiReportActiviteCourante;
  }
  
  private static BigDecimal determinerMontantICCPA4(ActiviteSalarie activiteSalarie, Periode periodeReference, ChronologiePeriodes chronoPeriodesIndemnisationPrecedentes)
  {
    BigDecimal cumulMontantsICCPA4Retour = ZERO;
    
    Salaire periodeSalaireCourante = null;
    Damj datePeriodeSalaireCourante = null;
    BigDecimal montantIccpSalaireCourant = null;
    BigDecimal montantIccpSalaireProratiseCourant = null;
    Chronologie chronoPeriodesSalaireCourante = activiteSalarie.getListeSalaires();
    chronoPeriodesSalaireCourante.iterer();
    while (chronoPeriodesSalaireCourante.encoreSuivant())
    {
      periodeSalaireCourante = (Salaire)chronoPeriodesSalaireCourante.elementSuivant();
      datePeriodeSalaireCourante = periodeSalaireCourante.getDatePaie() != null ? periodeSalaireCourante.getDatePaie() : periodeSalaireCourante.getDateFin();
      if (periodeReference.contient(datePeriodeSalaireCourante))
      {
        montantIccpSalaireCourant = periodeSalaireCourante.determinerMontantIccp();
        if (montantIccpSalaireCourant != null)
        {
          montantIccpSalaireProratiseCourant = proratiserMontantSurPeriodeHorsChronologie(montantIccpSalaireCourant, periodeSalaireCourante.getPeriode(), chronoPeriodesIndemnisationPrecedentes);
          
          cumulMontantsICCPA4Retour = cumulMontantsICCPA4Retour.add(montantIccpSalaireProratiseCourant);
        }
      }
    }
    CriteresStrategieMontantICCP criteres = new CriteresStrategieMontantICCP();
    criteres.setDatePivot(activiteSalarie.getDateFin());
    StrategieMontantICCPSpec strategieMontantICCP = FabriqueStrategieMontantICCP.getInstance().determinerStrategieMontantICCPA4(criteres);
    
    QuantiteEuro quantiteEuroICCPRupture = strategieMontantICCP.determinerMontantICCPRuptureA4(activiteSalarie, chronoPeriodesIndemnisationPrecedentes);
    if (quantiteEuroICCPRupture != null) {
      cumulMontantsICCPA4Retour = cumulMontantsICCPA4Retour.add(quantiteEuroICCPRupture.getValeurMontant());
    }
    return cumulMontantsICCPA4Retour;
  }
  
  public static BigDecimal proratiserMontantRuptureICCPSurActivite(ActiviteSalarie activiteSalarie, BigDecimal montantICCPRupture, Salaire salaireChevauchantFCT, ChronologiePeriodes chronoPeriodesIndemnisation)
  {
    BigDecimal montantICCPRuptureProratiseRetour = montantICCPRupture;
    if ((chronoPeriodesIndemnisation != null) && (!chronoPeriodesIndemnisation.estVide()))
    {
      Periode periodeConstruiteProratisation = null;
      if (salaireChevauchantFCT != null)
      {
        periodeConstruiteProratisation = salaireChevauchantFCT.getPeriode();
      }
      else
      {
        activiteSalarie.getListeSalaires().setComparateur(new ComparateurTemporelSurDateFinDecroissante());
        if ((activiteSalarie.getListeSalaires() == null) || (activiteSalarie.getListeSalaires().estVide())) {
          return ZERO;
        }
        Salaire dernierSalaire = (Salaire)activiteSalarie.getListeSalaires().premierElement();
        
        Damj dateDebut = Damj.max(activiteSalarie.getDateFin().getDebutMois(), activiteSalarie.getDateDebut());
        dateDebut = Damj.max(dateDebut, dernierSalaire.getDateFin().lendemain());
        periodeConstruiteProratisation = new Periode(dateDebut, activiteSalarie.getDateFin());
      }
      montantICCPRuptureProratiseRetour = proratiserMontantSurPeriodeHorsChronologie(montantICCPRupture, periodeConstruiteProratisation, chronoPeriodesIndemnisation);
    }
    return montantICCPRuptureProratiseRetour;
  }
  
  public static BigDecimal proratiserMontantSurPeriodeHorsChronologie(BigDecimal montant, Periode periodeMontant, ChronologiePeriodes chronoPourProratisation)
  {
    BigDecimal montantProratiseRetour = null;
    
    ChronologiePeriodes chronoPeriodesComplementaires = OutillageChronologiePeriodes.donnerPeriodesComplementaires(chronoPourProratisation, periodeMontant);
    
    int dureeTotale = periodeMontant.getDuree();
    int dureeProratisee = periodeMontant.inter(chronoPeriodesComplementaires);
    
    montantProratiseRetour = Mathematiques.proratiser(montant, new BigDecimal(dureeProratisee), new BigDecimal(dureeTotale));
    
    return montantProratiseRetour;
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationMontantICCP
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */