package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieContexteRepriseSystematique;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieObjectifSousJacent;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieContexteRepriseSystematiqueSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieObjectifSousJacentSpec;
import fr.unedic.cali.asu.cge01.parametres.Parametres;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.EreDemandeExpresse;
import fr.unedic.cali.asu.dom.EreDvAuFilEau;
import fr.unedic.cali.asu.dom.ErePassageCPSuiteRejetDV;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDeterminationObjectifReprise;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsActiviteConserve;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.util.ArrayList;
import java.util.List;

public class OutilDeterminationOrdreObjectifs
  implements OutilFonctionnel
{
  public static final Damj DATE_FCT_DU_FAIT_GENERATEUR = new Damj(2010, 1, 1);
  private transient int numeroOrdre = 1;
  
  public static OutilDeterminationOrdreObjectifs getInstance()
  {
    return new OutilDeterminationOrdreObjectifs();
  }
  
  public void determinerOrdreObjectifs(Demande demande, int contexteExamen, ProduitAsuSpec produitPrecedent, boolean estContexteRepriseContextuelle, boolean estReliquatDroitMaintenu)
    throws ApplicativeException
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ASPSJACENT")) {
      listeTypesObjectifs = determinerObjectifsSansAntecedent();
    } else if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "RECHARGE")) {
      listeTypesObjectifs = determinerObjectifsRechargement();
    } else if (fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeFinDroitCasGeneral(demande)) {
      listeTypesObjectifs = determinerObjectifsDemandeRechargement();
    } else if (demande.estLiquideeAvecDroitOptionReprise()) {
      listeTypesObjectifs = determinerObjectifsDroitOptionReprise();
    } else if (demande.getDecisionAutomatique() == 2) {
      listeTypesObjectifs = determinerObjectifsRepriseAutomatique();
    } else if (demande.getDecisionAutomatique() == 1) {
      listeTypesObjectifs = determinerObjectifsRejetAutomatique(contexteExamen);
    } else if ((demande.getEvenementReferenceExamen() instanceof ErePassageCPSuiteRejetDV)) {
      listeTypesObjectifs = recupererStrategieRepriseSystematique(demande).determinerObjectifsExamenDv122Jour(demande, contexteExamen);
    } else if (OutilsActiviteConserve.estUneDemandeDeRevision(demande)) {
      listeTypesObjectifs = determinerObjectifsRevision();
    } else if (OutilsActiviteConserve.estUneDemandeDeRevisionAdmission(demande)) {
      listeTypesObjectifs = determinerObjectifsRevisionAdmission();
    } else if (fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeFinDroitAsr(demande)) {
      listeTypesObjectifs = determinerObjectifsFddAsr(contexteExamen);
    } else if (fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeFinDroitAtp(demande)) {
      listeTypesObjectifs = determinerObjectifsFinAtp(contexteExamen);
    } else if (fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeFinDroitAsp(demande)) {
      listeTypesObjectifs = determinerObjectifsFinAsp(demande, contexteExamen);
    } else if (traitementSpecifiqueDemandeAssociee(demande)) {
      listeTypesObjectifs = determinerObjectifsDemandeAssociee(contexteExamen);
    } else if ((demande.getEvenementReferenceExamen() instanceof EreDvAuFilEau)) {
      listeTypesObjectifs = determinerObjectifPoursuiteIndemnisation();
    } else {
      switch (contexteExamen)
      {
      case 1: 
        listeTypesObjectifs = determinerObjectifsSansAntecedent();
        break;
      case 2: 
        listeTypesObjectifs = determinerObjectifsAvecAntecedentNonValide(demande);
        break;
      case 3: 
        listeTypesObjectifs = determinerObjectifsAvecAntecedentValide(demande, estContexteRepriseContextuelle, estReliquatDroitMaintenu);
        break;
      case 4: 
        listeTypesObjectifs = determinerObjectifsAntecedentSecteurPublic(demande);
        break;
      }
    }
    creationObjectifEtMiseAJourDemande(demande, produitPrecedent, listeTypesObjectifs);
  }
  
  private StrategieContexteRepriseSystematiqueSpec recupererStrategieRepriseSystematique(Demande demande)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demande.getDateExamen());
    return (StrategieContexteRepriseSystematiqueSpec)FabriqueStrategieContexteRepriseSystematique.getInstance().getStrategie(critere);
  }
  
  protected void creationObjectifEtMiseAJourDemande(Demande demande, ProduitAsuSpec produitPrecedent, List<Integer> listeTypesObjectifs)
    throws CoucheLogiqueException
  {
    demande.viderListeObjectifsExamen();
    for (int i = 0; i < listeTypesObjectifs.size(); i++)
    {
      int sousTypeObjectif = ((Integer)listeTypesObjectifs.get(i)).intValue();
      ObjectifExamen objectif = demande.creerObjectifExamen(sousTypeObjectif, getProduit(demande, produitPrecedent, sousTypeObjectif));
      ajouteObjectifSurDemande(objectif, demande);
    }
    if ((demande.getDecisionAutomatique() == 2) && (demande.getListObjectifExamen() != null) && (demande.getListObjectifExamen().size() < 1)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ERR_PAS_OBJECTIF_POUR_REPRISE_AUTO");
    }
  }
  
  protected List<Integer> determinerObjectifsRechargement()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(44));
    
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsDemandeRechargement()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(12));
    
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsDroitOptionReprise()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(13));
    
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsFinAsp(Demande demande, int contexteExamen)
    throws CoucheLogiqueException
  {
    return recupererStrategieRepriseSystematique(demande).determinerObjectifsFinAsp(demande, contexteExamen);
  }
  
  protected List<Integer> determinerObjectifsFinAtp(int contexteExamen)
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    if (contexteExamen == 1) {
      listeTypesObjectifs.add(Integer.valueOf(10));
    } else {
      listeTypesObjectifs.add(Integer.valueOf(12));
    }
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsRepriseAutomatique()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(27));
    
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsRejetAutomatique(int contexteExamen)
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(10));
    if (contexteExamen == 3) {
      listeTypesObjectifs.add(Integer.valueOf(27));
    }
    return listeTypesObjectifs;
  }
  
  public List<Integer> determinerObjectifsExamenDv122Jour(Demande demande, int resultatContexteExamen)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demande.getDateExamen());
    StrategieContexteRepriseSystematiqueSpec strategieContexteRepriseSystematique = (StrategieContexteRepriseSystematiqueSpec)FabriqueStrategieContexteRepriseSystematique.getInstance().getStrategie(critere);
    
    List<Integer> listeTypesObjectifs = strategieContexteRepriseSystematique.determinerObjectifsExamenDv122Jour(demande, resultatContexteExamen);
    
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsRevision()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(30));
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsRevisionAdmission()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    listeTypesObjectifs.add(Integer.valueOf(45));
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsSansAntecedent()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(10));
    
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsDemandeAssociee(int contexteExamen)
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    if (contexteExamen == 1) {
      listeTypesObjectifs.add(Integer.valueOf(10));
    } else {
      listeTypesObjectifs.add(Integer.valueOf(12));
    }
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsFddAsr(int contexteExamen)
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    if (contexteExamen == 1) {
      listeTypesObjectifs.add(Integer.valueOf(32));
    } else {
      listeTypesObjectifs.add(Integer.valueOf(40));
    }
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsAntecedentSecteurPublic(Demande demande)
    throws CoucheLogiqueException
  {
    return recupererStrategieRepriseSystematique(demande).determinerObjectifsAntecedentSecteurPublic(demande);
  }
  
  protected List<Integer> determinerObjectifsAvecAntecedentNonValide(Demande demande)
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(12));
    if ((!demande.estEnContexteDroitAnterieurSecteurPublic()) && (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "SORTIECRA"))) {
      listeTypesObjectifs.add(Integer.valueOf(13));
    }
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsAvecAntecedentValide(Demande demande, boolean estEnRepriseContextuelle, boolean estReliquatDroitMaintenu)
    throws CoucheLogiqueException
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    EvenementReferenceExamenSpec ere = demande.getEvenementReferenceExamen();
    if (demande.estDroitOptionReadmission())
    {
      listeTypesObjectifs.add(Integer.valueOf(12));
    }
    else if (OutilDeterminationObjectifReprise.getInstance().determineDateExtinctionReliquatSurObjectifReprise(demande) != null)
    {
      listeTypesObjectifs.add(Integer.valueOf(12));
      ajouterObjectifReprise(demande, listeTypesObjectifs, 13);
    }
    else
    {
      AttributionAssuranceSpec odOrigine = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
      FaitGenerateurSpec fgPrecedent = odOrigine.getFaitGenerateur();
      if (demande.getDemandeur().getAgeALaDate(fgPrecedent.getDateFaitGenerateur()).compareTo(getAgeMinPourRepriseSystematique(demande)) >= 0)
      {
        if ((ere instanceof EreDemandeExpresse))
        {
          listeTypesObjectifs.addAll(determinerObjectifDemandeExpresseAvecReliquatValide(demande));
        }
        else
        {
          StrategieContexteRepriseSystematiqueSpec strategie = recupererStrategieRepriseSystematique(demande);
          listeTypesObjectifs.addAll(strategie.determinerObjectifsExamenPourRepriseSystematique(demande));
        }
      }
      else if ((ere instanceof EreDemandeExpresse))
      {
        listeTypesObjectifs.addAll(determinerObjectifDemandeExpresseAvecReliquatValide(demande));
      }
      else if (estReliquatDroitMaintenu)
      {
        StrategieContexteRepriseSystematiqueSpec strategie = recupererStrategieRepriseSystematique(demande);
        listeTypesObjectifs.addAll(strategie.determinerObjectifsExamenPourRepriseSystematique(demande));
      }
      else
      {
        StrategieContexteRepriseSystematiqueSpec strategie = recupererStrategieRepriseSystematique(demande);
        if (strategie.determinerContexteRepriseSystematique(demande))
        {
          demande.setContexteDeRepriseSansFCT(true);
          listeTypesObjectifs.addAll(strategie.determinerObjectifsExamenPourRepriseSystematique(demande));
        }
        else
        {
          listeTypesObjectifs.add(Integer.valueOf(12));
          ajouterObjectifReprise(demande, listeTypesObjectifs, 13);
          if (estEnRepriseContextuelle)
          {
            listeTypesObjectifs = new ArrayList();
            ajouterObjectifReprise(demande, listeTypesObjectifs, 14);
            listeTypesObjectifs.add(Integer.valueOf(12));
          }
        }
      }
    }
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifDemandeExpresseAvecReliquatValide(Demande demande)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demande.getDateExamen());
    
    StrategieContexteRepriseSystematiqueSpec strategie = (StrategieContexteRepriseSystematiqueSpec)FabriqueStrategieContexteRepriseSystematique.getInstance().getStrategie(critere);
    
    return strategie.determinerObjectifsExamenDemandeExpresseAvecReliquatValide(demande);
  }
  
  protected List<Integer> determinerObjectifPoursuiteIndemnisation()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(49));
    
    return listeTypesObjectifs;
  }
  
  protected DureeCalendaire getAgeMinPourRepriseSystematique(Demande demande)
  {
    Damj dateFgdPrecedent = null;
    AttributionAssuranceSpec odOrigine = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
    if (odOrigine != null) {
      dateFgdPrecedent = odOrigine.getFaitGenerateur().getDateFaitGenerateur();
    }
    if ((dateFgdPrecedent != null) && (dateFgdPrecedent.estApresOuCoincideAvec(DATE_FCT_DU_FAIT_GENERATEUR))) {
      return Parametres.AGE_58_ANS;
    }
    return Parametres.AGE_57_ANS_6_MOIS;
  }
  
  private void ajouterObjectifReprise(Demande demande, List<Integer> listeTypesObjectifs, int typeReprise)
  {
    boolean ajouterReprise = true;
    if ("S".equalsIgnoreCase(demande.getModeLiquidation())) {
      listeTypesObjectifs.add(Integer.valueOf(34));
    } else {
      listeTypesObjectifs.add(Integer.valueOf(typeReprise));
    }
  }
  
  protected void ajouteObjectifSurDemande(ObjectifExamen objectif, Demande demandeCourante)
  {
    objectif.setNumeroOrdre(numeroOrdre);
    demandeCourante.ajouterObjectifExamen(objectif);
    numeroOrdre += 1;
  }
  
  protected ProduitAsuSpec getProduit(Demande demande, ProduitAsuSpec produitPrecedent, int sousTypeObjectif)
  {
    ProduitAsuSpec produit = null;
    if ((sousTypeObjectif == 14) || (sousTypeObjectif == 15) || (sousTypeObjectif == 13) || (sousTypeObjectif == 34) || (sousTypeObjectif == 27) || (sousTypeObjectif == 47) || (sousTypeObjectif == 48) || (sousTypeObjectif == 49)) {
      produit = produitPrecedent;
    } else if ((sousTypeObjectif == 12) || (sousTypeObjectif == 11) || (sousTypeObjectif == 26) || (sousTypeObjectif == 10) || (sousTypeObjectif == 44) || (sousTypeObjectif == 30) || (sousTypeObjectif == 45) || (sousTypeObjectif == 32) || (sousTypeObjectif == 40)) {
      produit = (ProduitAsuSpec)demande.getDossierAffectationAdmission().getProduit();
    } else if (sousTypeObjectif == 50) {
      produit = (ProduitAsuSpec)LigneAsuCge01.getInstance().getProduitActif(demande.getDateExamen());
    }
    return produit;
  }
  
  private boolean traitementSpecifiqueDemandeAssociee(Demande demande)
    throws CoucheLogiqueException
  {
    if (!fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeAssociee(demande)) {
      return false;
    }
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demande.getDateExamen());
    
    StrategieObjectifSousJacentSpec strategie = (StrategieObjectifSousJacentSpec)FabriqueStrategieObjectifSousJacent.getInstance().getStrategie(critere);
    
    return strategie.estTraitementSpecifique(demande);
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationOrdreObjectifs
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */