package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.produits.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComplementairesDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesResultatDeterminationSjcSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.ArrayList;

public class OutilDeterminationSjcAncienneRegle
  extends OutilDeterminationSjc
{
  private static OutilDeterminationSjcAncienneRegle s_instance = new OutilDeterminationSjcAncienneRegle();
  
  public static OutilDeterminationSjc getInstance()
  {
    return s_instance;
  }
  
  protected DonneesResultatDeterminationSjcSpec determinerListeSjrActiviteConservee(DonneesEntreeDeterminationSjrSpec p_donneesEntree)
    throws CoucheLogiqueException
  {
    DonneesResultatDeterminationSjcSpec resultatDeterminationSjc = OutilDonneesDeterminationSjr.getInstance().initialiserDonneesResultatSjc();
    
    DonneesEntreeComplementairesDeterminationSjrSpec donneesEntreeComplementaires = p_donneesEntree.getDonneesEntreeComplementaires();
    Chronologie chronoActivitesSalarieesConserveesPrc = donneesEntreeComplementaires.getChronologieActiviteSalariePrc();
    
    chronoActivitesSalarieesConserveesPrc.iterer();
    ActiviteSalarie activiteSalarieeConserveeCourante = null;
    SjrActiviteConservee sjrActiviteConserveeCourante = null;
    ArrayList resultatListeSjrActiviteConservee = new ArrayList();
    BigDecimal resultatSjci = ZERO;
    while (chronoActivitesSalarieesConserveesPrc.encoreSuivant())
    {
      activiteSalarieeConserveeCourante = (ActiviteSalarie)chronoActivitesSalarieesConserveesPrc.elementSuivant();
      if (activiteSalarieeConserveeCourante.estEnConflit()) {
        leverAlerteNonBloquante(resultatDeterminationSjc.getListeAlertesNonBloquantes(), "A11MNB6", activiteSalarieeConserveeCourante);
      }
      if (activiteSalarieeConserveeCourante.getEntreprise().getIdentifiantBNE() == null)
      {
        Damj dateFCTDamj = activiteSalarieeConserveeCourante.getDateDebut();
        String dateFCTString = dateFCTDamj.formater();
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB10", new String[] { dateFCTString });
      }
      sjrActiviteConserveeCourante = determinerSjrActiviteConservee(activiteSalarieeConserveeCourante, p_donneesEntree, resultatDeterminationSjc.getListeDonneesResultatDeterminationSjr());
      
      resultatListeSjrActiviteConservee.add(sjrActiviteConserveeCourante);
      
      resultatSjci = resultatSjci.add(sjrActiviteConserveeCourante.getSjrInitial().getValeurMontant());
    }
    OutilDonneesDeterminationSjr.getInstance().completerDonneesResultatSjc(resultatDeterminationSjc, resultatSjci, resultatListeSjrActiviteConservee);
    
    return resultatDeterminationSjc;
  }
  
  public DonneesResultatDeterminationSjcSpec determinerSjcip(DonneesEntreeDeterminationSjrSpec p_donneesEntree)
    throws CoucheLogiqueException
  {
    DonneesResultatDeterminationSjcSpec resultatDeterminationSjc = null;
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la détermination du SJCI." });
    
    Quantite quantiteSjcForce = p_donneesEntree.getDonneesEntreeDemande().getDonneeForceeSjc();
    Chronologie chronoActivitesSalarieesConserveesPrc = p_donneesEntree.getDonneesEntreeComplementaires().getChronologieActiviteSalariePrc();
    
    resultatDeterminationSjc = determinerListeSjrActiviteConservee(p_donneesEntree);
    
    boolean toutesActivitesAvecSuspensionTotaleOuAbsence = false;
    Chronologie chronoActivitesSalarieesConserveesAvecSuspensionOuAbsence = determinerChronoActivitesSalarieesConserveesAvecSuspensionOuAbsence(p_donneesEntree);
    if (chronoActivitesSalarieesConserveesAvecSuspensionOuAbsence.equals(chronoActivitesSalarieesConserveesPrc)) {
      toutesActivitesAvecSuspensionTotaleOuAbsence = true;
    }
    if ((quantiteSjcForce == null) && 
      (!chronoActivitesSalarieesConserveesPrc.estVide()) && (resultatDeterminationSjc.getSjci().compareTo(ZERO) == 0) && (!toutesActivitesAvecSuspensionTotaleOuAbsence))
    {
      Damj dateFCTDamj = chronoActivitesSalarieesConserveesPrc.dernierElement().getDateDebut();
      String dateFCTString = dateFCTDamj.formater();
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB9", new String[] { dateFCTString });
    }
    return resultatDeterminationSjc;
  }
  
  public void completerSjcipAvecActivitesConserveesNonRetenues(DonneesEntreeDeterminationSjrSpec p_donneesEntree, Sjcip p_sjcip, Chronologie p_chronoGlobaleActivitesConservees, boolean p_modeInitialisationSjcip)
    throws CoucheLogiqueException
  {
    p_chronoGlobaleActivitesConservees.iterer();
    TravailSpec activiteConserveeCourante = null;
    SjrActiviteConservee sjrActiviteConserveNonRetenue = null;
    while (p_chronoGlobaleActivitesConservees.encoreSuivant())
    {
      activiteConserveeCourante = (TravailSpec)p_chronoGlobaleActivitesConservees.elementSuivant();
      if ((p_modeInitialisationSjcip) || (!activiteConserveeDejaRetenueSjcip(p_sjcip, activiteConserveeCourante)))
      {
        sjrActiviteConserveNonRetenue = new SjrActiviteConservee(QUANTITE_EURO_ZERO);
        sjrActiviteConserveNonRetenue.setPeriodeActiviteConservee(activiteConserveeCourante);
        p_sjcip.ajouterSjrActiviteConservee(sjrActiviteConserveNonRetenue);
      }
    }
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationSjcAncienneRegle
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */