package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSrPrcSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Metier;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneeEntreeParametre;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComportementSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeProduitDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesResultatDeterminationSjrSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeMemeReglement;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltresTemporel;
import java.math.BigDecimal;

public class OutilDeterminationSjr
  implements OutilDeterminationSjrSpec
{
  private static final BigDecimal ZERO = new BigDecimal("0");
  private static final BigDecimal NBRE_MOIS_AN = new BigDecimal("12");
  private static final BigDecimal NBRE_JOURS_AN = new BigDecimal("365");
  private static OutilDeterminationSjr instance = new OutilDeterminationSjr();
  
  public static OutilDeterminationSjr getInstance()
  {
    return instance;
  }
  
  public int determinerCodeEmploiA2b(DonneesEntreeDeterminationSjrSpec donneesEntree)
  {
    int codeEmploiA2bRetourne = 0;
    
    DonneesEntreeDemandeDeterminationSjrSpec donneesEntreeDemande = donneesEntree.getDonneesEntreeDemande();
    
    FiltresTemporel listeFiltres = new FiltresTemporel();
    listeFiltres.ajouterFiltre(new FiltreActiviteSalarie());
    listeFiltres.ajouterFiltre(new FiltrePeriodeActiviteSalarieeMemeReglement("A2b"));
    listeFiltres.ajouterFiltre(new FiltreFinAvantOuCoincideAvecDate(donneesEntreeDemande.getDateExamen()));
    Chronologie chronoActivitesSalarieesA2bRetenues = donneesEntreeDemande.getIndividu().getChronoPeriodePasseProfessionnelLiquidation().copier(listeFiltres);
    if ((chronoActivitesSalarieesA2bRetenues != null) && (!chronoActivitesSalarieesA2bRetenues.estVide()))
    {
      chronoActivitesSalarieesA2bRetenues.setComparateur(new ComparateurTemporelsSurDateFin());
      ActiviteSalarie activiteSalarieeA2bRetenue = (ActiviteSalarie)chronoActivitesSalarieesA2bRetenues.premierElement();
      if (activiteSalarieeA2bRetenue != null) {
        codeEmploiA2bRetourne = activiteSalarieeA2bRetenue.getMetier().getCodeEmploi();
      }
    }
    return codeEmploiA2bRetourne;
  }
  
  public BigDecimal determinerPlafondSjr(Damj termePrc, DonneesEntreeDeterminationSjrSpec donneesEntreeDeterminationSjr)
  {
    DonneesEntreeProduitDeterminationSjrSpec donneesEntreeProduitDeterminationSjr = donneesEntreeDeterminationSjr.getDonneesEntreeProduit();
    DonneesEntreeDemandeDeterminationSjrSpec donneesEntreeDemandeDeterminationSjr = donneesEntreeDeterminationSjr.getDonneesEntreeDemande();
    
    DonneeEntreeParametre parametreActif = donneesEntreeProduitDeterminationSjr.getParametreActif("FACULTATIF PLAFOND JOURNALIER SJR", termePrc);
    BigDecimal plafondSjrRetourne;
    BigDecimal plafondSjrRetourne;
    if (parametreActif != null)
    {
      plafondSjrRetourne = parametreActif.getValeurParametre();
    }
    else
    {
      String contexteDemande = null;
      if (donneesEntreeDemandeDeterminationSjr != null) {
        contexteDemande = donneesEntreeDemandeDeterminationSjr.getContexteDemande();
      }
      if ((contexteDemande != null) && (contexteDemande.equals("AREMAYOTTE"))) {
        parametreActif = donneesEntreeProduitDeterminationSjr.getParametreActif("PLAFOND MENSUEL SR SJR MAYOTTE", termePrc);
      } else {
        parametreActif = donneesEntreeProduitDeterminationSjr.getParametreActif("PLAFOND MENSUEL SR SJR", termePrc);
      }
      BigDecimal plafondMensuelApplicable = parametreActif.getValeurParametre();
      
      BigDecimal valeurPlafondSjr = Mathematiques.proratiser(NBRE_MOIS_AN, plafondMensuelApplicable, NBRE_JOURS_AN);
      
      plafondSjrRetourne = Mathematiques.tronque(valeurPlafondSjr, 2);
    }
    return plafondSjrRetourne;
  }
  
  protected BigDecimal determinerSjri(Prc prc)
    throws CoucheLogiqueException
  {
    if (prc.getDiviseur().compareTo(ZERO) == 0) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_SC_L_ES_ED_CDR09_CDR10_INCOHERENCE_DIVISEUR", 2);
    }
    BigDecimal sjriCourant = Mathematiques.diviseParDefaut(prc.getSrip(), prc.getDiviseur());
    BigDecimal sjriRetourne = Mathematiques.tronque(sjriCourant, 2);
    return sjriRetourne;
  }
  
  public DonneesResultatDeterminationSjr determinerSjrip(DonneesEntreeDeterminationSjrSpec donneesEntree)
    throws CoucheLogiqueException
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la détermination du SJRIP." });
    
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)donneesEntree.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
    
    DonneesResultatDeterminationSjr resultatDeterminationSjr = fabriqueOutilFonctionnel.getOutilDeterminationSrPrc().determinerSrip(donneesEntree);
    
    BigDecimal resultatSjri = determinerSjri(resultatDeterminationSjr.getPrc());
    
    resultatSjri = appliquerCoefficientDureeSjr(resultatSjri, donneesEntree, resultatDeterminationSjr);
    
    BigDecimal resultatPsjr = determinerPlafondSjr(resultatDeterminationSjr.getPrc().getDateFin(), donneesEntree);
    
    OutilDonneesDeterminationSjr.getInstance().completerDonneesResultatSjr(resultatDeterminationSjr, resultatSjri, resultatPsjr);
    
    return resultatDeterminationSjr;
  }
  
  protected BigDecimal appliquerCoefficientDureeSjr(BigDecimal resultatSjri, DonneesEntreeDeterminationSjrSpec donneesEntree, DonneesResultatDeterminationSjr resultatDeterminationSjr)
  {
    return resultatSjri;
  }
  
  public DonneesResultatDeterminationSjr determinerSjripPourA2B(DonneesEntreeDeterminationSjrSpec donneesEntree)
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la détermination du SFJ pour A2B." });
    
    DonneesEntreeDemandeDeterminationSjrSpec donneesEntreeDemande = donneesEntree.getDonneesEntreeDemande();
    int numeroCategorieA2b = 0;
    if (donneesEntreeDemande.getCategorieA2bForcee() != null)
    {
      numeroCategorieA2b = determinerNumeroCategorieA2b(donneesEntreeDemande.getCategorieA2bForcee().intValue());
    }
    else
    {
      FiltresTemporel listeFiltres = new FiltresTemporel();
      listeFiltres.ajouterFiltre(new FiltreActiviteSalarie());
      listeFiltres.ajouterFiltre(new FiltrePeriodeActiviteSalarieeMemeReglement("A2b"));
      listeFiltres.ajouterFiltre(new FiltreFinAvantOuCoincideAvecDate(donneesEntreeDemande.getDateExamen()));
      Chronologie chronoActivitesSalarieesA2bRetenues = donneesEntreeDemande.getIndividu().getChronoPeriodePasseProfessionnelLiquidation().copier(listeFiltres);
      
      chronoActivitesSalarieesA2bRetenues.setComparateur(new ComparateurTemporelsSurDateFin());
      ActiviteSalarie activiteSalarieeA2bRetenue = (ActiviteSalarie)chronoActivitesSalarieesA2bRetenues.premierElement();
      
      numeroCategorieA2b = determinerNumeroCategorieA2b(activiteSalarieeA2bRetenue.getMetier().getCodeEmploi());
    }
    String nomParametreCourant = "SFJ A2B CATEGORIE " + numeroCategorieA2b;
    DonneeEntreeParametre parametreActif = donneesEntree.getDonneesEntreeProduit().getParametreActif(nomParametreCourant, donneesEntreeDemande.getDateAttribution());
    
    BigDecimal salaireForfaitaireJournalier = parametreActif.getValeurParametre();
    
    DonneesResultatDeterminationSjr resultatDeterminationSjr = OutilDonneesDeterminationSjr.getInstance().initialiserDonneesResultatSjr(salaireForfaitaireJournalier, salaireForfaitaireJournalier);
    
    return resultatDeterminationSjr;
  }
  
  private int determinerNumeroCategorieA2b(int codeCategorieA2b)
  {
    int numeroCategorieA2bRetourne = 0;
    switch (codeCategorieA2b)
    {
    case 90: 
      numeroCategorieA2bRetourne = 1;
      break;
    case 91: 
      numeroCategorieA2bRetourne = 2;
      break;
    case 92: 
      numeroCategorieA2bRetourne = 3;
      break;
    case 93: 
      numeroCategorieA2bRetourne = 4;
      break;
    case 94: 
      numeroCategorieA2bRetourne = 5;
      break;
    case 95: 
      numeroCategorieA2bRetourne = 6;
      break;
    case 96: 
      numeroCategorieA2bRetourne = 7;
      break;
    case 97: 
      numeroCategorieA2bRetourne = 8;
      break;
    case 98: 
      numeroCategorieA2bRetourne = 9;
      break;
    case 99: 
      numeroCategorieA2bRetourne = 10;
      break;
    case 100: 
      numeroCategorieA2bRetourne = 11;
      break;
    case 101: 
      numeroCategorieA2bRetourne = 12;
      break;
    case 102: 
      numeroCategorieA2bRetourne = 13;
      break;
    case 103: 
      numeroCategorieA2bRetourne = 14;
      break;
    case 104: 
      numeroCategorieA2bRetourne = 15;
      break;
    case 105: 
      numeroCategorieA2bRetourne = 16;
      break;
    case 106: 
      numeroCategorieA2bRetourne = 17;
      break;
    case 107: 
      numeroCategorieA2bRetourne = 18;
      break;
    case 108: 
      numeroCategorieA2bRetourne = 19;
      break;
    case 109: 
      numeroCategorieA2bRetourne = 20;
      break;
    }
    return numeroCategorieA2bRetourne;
  }
  
  public DonneesResultatDeterminationSjrSpec determinerSjripEtMapperResultatSimplifie(DonneesEntreeDeterminationSjrSpec donneesEntree)
    throws CoucheLogiqueException
  {
    DonneeEntreeParametre parametrePlafondMensuelActif = donneesEntree.getDonneesEntreeProduit().getParametreActif("PLAFOND MENSUEL SR SJR", donneesEntree.getDonneesEntreeDemande().getDateExamen());
    if (parametrePlafondMensuelActif == null) {
      OutilDonneesDeterminationSjr.getInstance().chargerParametresPlafondSecuMensuel(donneesEntree.getDonneesEntreeProduit());
    }
    Reglement reglementApplicable = donneesEntree.getDonneesEntreeDemande().getReglementApplicable();
    DonneesResultatDeterminationSjr resultatCompletDeterminationSjrip;
    DonneesResultatDeterminationSjr resultatCompletDeterminationSjrip;
    if ((reglementApplicable != null) && (reglementApplicable.estNomReglementIdentique("A2b"))) {
      resultatCompletDeterminationSjrip = determinerSjripPourA2B(donneesEntree);
    } else {
      resultatCompletDeterminationSjrip = determinerSjrip(donneesEntree);
    }
    DonneesResultatDeterminationSjrSpec resultatDeterminationSjripRetourne;
    DonneesResultatDeterminationSjrSpec resultatDeterminationSjripRetourne;
    if (donneesEntree.getDonneesEntreeComportement().isRetournerResultatSimplifieSjr()) {
      resultatDeterminationSjripRetourne = OutilDonneesDeterminationSjr.getInstance().mapperDonneesResultatSimplifieSjr(resultatCompletDeterminationSjrip);
    } else {
      resultatDeterminationSjripRetourne = resultatCompletDeterminationSjrip;
    }
    return resultatDeterminationSjripRetourne;
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationSjr
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */