package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.PostTraitementJustificationAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.OutilJustificationAffiliation;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.EreInscriptionDemandeurEmploi;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.ParcoursRechercheAlertesNonBloquantes;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDateAttribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ObjectifExamenAdmission;
import fr.unedic.cali.asu.produits.liquidation.dom.Od;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DomSimulationAffiliation;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ResultatSimulationAffiliation;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeE301;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class OutilSimulationAffiliation
  implements OutilFonctionnel
{
  public static ResultatSimulationAffiliation calculAffi(DomSimulationAffiliation p_domSimulationAffiliation)
    throws ApplicativeException
  {
    ResultatSimulationAffiliation resultat = new ResultatSimulationAffiliation();
    JustificationAffiliationSpec jutifaffiretour = null;
    
    Demande demandeFictive = (Demande)creerDemandeAsu(p_domSimulationAffiliation);
    
    fr.unedic.cali.asu.outilsfonctionnels.OutilSimulationAffiliation.chargementListePNDSIndividu(demandeFictive, demandeFictive.getDateExamen());
    if (p_domSimulationAffiliation.getTypeCoordinationEuropeenne() != 0)
    {
      demandeFictive.getDemandeur().setChronoPeriodePasseProfessionnelLiquidation(demandeFictive.getDemandeur().getChronoPeriodePasseProfessionnel());
    }
    else
    {
      ChronologiePeriodes chronoPeriodesGa = demandeFictive.getDemandeur().getChronoPeriodePasseProfessionnel();
      
      ChronologiePeriodes chronoPeriodesSansE301 = (ChronologiePeriodes)chronoPeriodesGa.copier(new FiltrePeriodeActiviteSalarieeE301(false));
      
      demandeFictive.getDemandeur().setChronoPeriodePasseProfessionnelLiquidation(chronoPeriodesSansE301);
    }
    boolean periodeNonAtteste = false;
    SimuRechercheReglementApplicable simuRechercheReglementApplicable = (SimuRechercheReglementApplicable)SimuRechercheReglementApplicable.getInstance();
    
    ValidationProduit validationProduitRetour = simuRechercheReglementApplicable.rechercherValidationProduit(demandeFictive, periodeNonAtteste, p_domSimulationAffiliation);
    if ((validationProduitRetour == null) || (validationProduitRetour.getJustificationCalculAffiliation() == null)) {
      validationProduitRetour = simuRechercheReglementApplicable.determinerAppartenanceInsuffisante(demandeFictive, periodeNonAtteste, p_domSimulationAffiliation);
    }
    if (validationProduitRetour != null)
    {
      ProduitAsuSpec produitFctEtudiee = (ProduitAsuSpec)p_domSimulationAffiliation.getActivite().getReglement().getProduit();
      Convertisseur convertisseurUniteAffiliation = null;
      if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demandeFictive.getListContexteDemande(), "AREMAYOTTE")) {
        convertisseurUniteAffiliation = new ConvertisseurUniteAffiliation();
      } else {
        convertisseurUniteAffiliation = produitFctEtudiee.determinerConvertisseurUniteAffiliation();
      }
      jutifaffiretour = simuRechercheReglementApplicable.getJustificationAffiliation();
      
      resultat.setDatePraDebut(validationProduitRetour.getPeriodePra().getDebut());
      resultat.setDatePraFin(validationProduitRetour.getPeriodePra().getFin());
      
      resultat.setreglementApplicable(validationProduitRetour.getReglementApplicable().getLibelleCourt());
      
      String categ = Integer.toString(validationProduitRetour.getCatEmploiPart());
      resultat.setcatEmploi(categ);
      
      Quantite qteAcquiseUn = validationProduitRetour.getQuantiteAcquise();
      resultat.setAffiCalcule(qteAcquiseUn.getValeur());
      resultat.setUniteAffiCalcule(qteAcquiseUn.getUnite().getNom());
      if (validationProduitRetour.getQuantiteAssimilationAcquise() != null)
      {
        resultat.setAssimilation(validationProduitRetour.getQuantiteAssimilationAcquise().getValeur());
        resultat.setUniteAssimilation(validationProduitRetour.getQuantiteAssimilationAcquise().getUnite().getNom());
      }
      Quantite qteAcquiseDeux = validationProduitRetour.getQuantiteAcquiseSecondaire();
      if (qteAcquiseDeux != null) {
        if (qteAcquiseUn.getUnite().equals(Unite.getParCode("23")))
        {
          resultat.setQuantiteAffiSecondaire(qteAcquiseDeux.getValeur());
          resultat.setUniteAffiSecondaire(qteAcquiseDeux.getUnite().getNom());
        }
        else
        {
          Quantite qteAcquiseDeuxConvertie = convertisseurUniteAffiliation.convertir(qteAcquiseDeux, qteAcquiseUn.getUnite());
          if (qteAcquiseDeuxConvertie.compareTo(qteAcquiseUn) > 0)
          {
            resultat.setAffiCalcule(qteAcquiseDeux.getValeur());
            resultat.setUniteAffiCalcule(qteAcquiseDeux.getUnite().getNom());
            if (validationProduitRetour.getQuantiteAssimilationAcquiseSecondaire() != null)
            {
              resultat.setAssimilation(validationProduitRetour.getQuantiteAssimilationAcquiseSecondaire().getValeur());
              resultat.setUniteAssimilation(validationProduitRetour.getQuantiteAssimilationAcquise().getUnite().getNom());
            }
          }
        }
      }
      if ("justifCGENouveauModele".equals(jutifaffiretour.getTypeJustificationAffiliation()))
      {
        OutilJustificationAffiliation outilJustification = new OutilJustificationAffiliation();
        outilJustification.consoliderJustificationAffiliation((JustificationAffiliation)jutifaffiretour);
      }
      else if (!"justifJoursTravailles".equals(jutifaffiretour.getTypeJustificationAffiliation()))
      {
        PostTraitementJustificationAffiliation.traiterAffiliationZme(jutifaffiretour, convertisseurUniteAffiliation);
      }
      resultat.setJustifAffi(jutifaffiretour);
      
      ParcoursRechercheAlertesNonBloquantes.getInstance().presencePeriodeDeclareeNonJustifiee(demandeFictive, validationProduitRetour.getPeriodePra(), p_domSimulationAffiliation.getIndividu().getChronoPeriodePasseProfessionnelLiquidation());
      
      Damj dateRecherche = p_domSimulationAffiliation.getDateFgd() != null ? p_domSimulationAffiliation.getDateFgd() : p_domSimulationAffiliation.getDateFct();
      
      ParcoursRechercheAlertesNonBloquantes.getInstance().presenceDVDansLes91Jours(demandeFictive, p_domSimulationAffiliation.getIndividu(), dateRecherche);
      
      resultat.setDemande(demandeFictive);
    }
    return resultat;
  }
  
  public static DemandeAssuranceSpec creerDemandeAsu(DomSimulationAffiliation p_domSimulation)
  {
    Demande demandeTemporaire = new Demande();
    
    PeriodeGaecSpec periodeFG = p_domSimulation.getIndividu().rechercherPeriodePasseProfessionnel(p_domSimulation.getPeriodeFG());
    if (((periodeFG instanceof ActiviteSalarie)) && (((ActiviteSalarie)periodeFG).isEstPeriodeMayotte()))
    {
      ContexteDemande contexteDemande = new ContexteDemande();
      contexteDemande.setTypeContexteDemande("AREMAYOTTE");
      demandeTemporaire.ajouterContexteDemande(contexteDemande);
    }
    demandeTemporaire.setDemandeur(p_domSimulation.getIndividu());
    EvenementReferenceExamenSpec ereFictif = new EreInscriptionDemandeurEmploi();
    ereFictif.setDateEvenement(p_domSimulation.getDateFct().lendemain());
    demandeTemporaire.setEvenementReferenceExamen(ereFictif);
    demandeTemporaire.createDonneesTemporaires();
    demandeTemporaire.setDemandeLiquidee(true);
    
    demandeTemporaire.getDonneesTemporaires().setTypeCoordinationEuropeenne(p_domSimulation.getTypeCoordinationEuropeenne());
    
    Od dossierExamen = new Od();
    DossierAffecte dossierAffecte = new DossierAffecte(1);
    
    dossierAffecte.setIdentifiantSinistre(p_domSimulation.getPeriodeFG());
    dossierAffecte.setDossierExamen(dossierExamen);
    dossierAffecte.setDecorReglementaire(p_domSimulation.getDecor());
    
    dossierAffecte.setProduitForce(p_domSimulation.getProduitAppelant());
    dossierAffecte.setValidationProduit(new ValidationProduit());
    demandeTemporaire.setDossierAffectation(dossierAffecte);
    demandeTemporaire.setObjectifCourant(new ObjectifExamenAdmission());
    
    dossierExamen.createConstitutionDateAttribution().setDateAttribution(p_domSimulation.getDateFct().lendemain());
    dossierExamen.createConditionFaitGenerateur().setDateFaitGenerateur(p_domSimulation.getDateFgd());
    FormulaireAsu formulaire = demandeTemporaire.createFormulaireAsu();
    demandeTemporaire.setEstFormulaireCharge(true);
    
    formulaire.setDateDepot(Damj.NUIT_DES_TEMPS);
    
    return demandeTemporaire;
  }
}

/* Location:
 * Qualified Name:     OutilSimulationAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */