package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieExtinctionReliquatSurDroitOption;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieExtinctionReliquatSurDroitOptionSpec;
import fr.unedic.cali.asu.dom.AccesseurDroitsSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.outilsfonctionnels.GestionDemandeDv122eJour;
import fr.unedic.cali.asu.outilsfonctionnels.VerificationDonneesForcees;
import fr.unedic.cali.asu.parcours.ResultatTraitementReliquat;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeFormationAssimilable;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.ResultatTraitementReliquatSpec;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitInrSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.fabriques.FabriqueConvention2014;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateDeclenchementExamenApresOuCoincideDateEtInclusParPriorite;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateDeclenchementExamenAvantOuCoincideDateEtInclusParPriorite;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourProduit;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreReexamenSurDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreAttributionInrPourDateAttributionAreLiee;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.UniteDuree;
import java.math.BigDecimal;
import java.util.ListIterator;

public class OutilTraitementReliquat
  extends fr.unedic.cali.asu.outilsfonctionnels.OutilTraitementReliquat
{
  private static final BigDecimal TRENTE = new BigDecimal("30");
  
  public static OutilTraitementReliquat getInstance()
  {
    return new OutilTraitementReliquat();
  }
  
  protected boolean preTraitement(ResultatTraitementReliquat resultatTraitement, DemandeSpec demande, DecisionSpec decisionPrecedente, ResultatExecutionCalculSpec resultatExecutionCalcul)
    throws CoucheLogiqueException
  {
    boolean retour = true;
    if (!resultatTraitement.getReliquatValide()) {
      retour = false;
    }
    return retour;
  }
  
  protected Quantite traiterImputation(DemandeSpec demande, DecisionSpec decisionPrecedente, ResultatExecutionCalculSpec resultatExecutionCalcul, ResultatTraitementReliquatSpec resultatReliquat, Damj dateEtude)
    throws ApplicativeException
  {
    Quantite qteReliquatAvantImputation = resultatExecutionCalcul.getReliquatAREAvecMaintien();
    
    Quantite qteFormationAImputer = determinerDureeImputationFormation(decisionPrecedente.getDossierAffecte().getProduit(), demande, qteReliquatAvantImputation, (DossierExamenAssuranceSpec)decisionPrecedente, dateEtude);
    
    Quantite qteReliquatApresImputationFormation = imputerQuantite(qteReliquatAvantImputation, qteFormationAImputer);
    
    Quantite qteAidesAImputer = determinerDureeImputationAide(demande, (DossierExamenAssuranceSpec)decisionPrecedente, dateEtude, resultatReliquat);
    
    Quantite qteReliquatApresImputationAides = imputerQuantite(qteReliquatApresImputationFormation, qteAidesAImputer);
    
    Quantite qteJoursSuspensionAimputer = determinerImputationPourSuppressionTemporaireRevenuDeRemplacement(demande, resultatExecutionCalcul, dateEtude);
    
    Quantite qteReliquatApresImputationJoursSuspension = imputerQuantite(qteReliquatApresImputationAides, qteJoursSuspensionAimputer);
    
    Quantite qteJoursDonneesForceesAimputer = determinerImputationNombreJoursDonneesForcees(demande);
    
    Quantite qteReliquatApresImputationJoursDonneesForcees = imputerQuantite(qteReliquatApresImputationJoursSuspension, qteJoursDonneesForceesAimputer);
    
    Quantite qteReliquatApresImputationFinale = qteReliquatApresImputationJoursDonneesForcees;
    
    ResultatTraitementReliquat resultatTraitementReliquat = (ResultatTraitementReliquat)resultatReliquat;
    
    resultatTraitementReliquat.setQuantiteReliquat(qteReliquatApresImputationFinale);
    resultatTraitementReliquat.setQuantiteAide(qteAidesAImputer);
    
    resultatTraitementReliquat.setQuantiteFormation(qteFormationAImputer);
    resultatTraitementReliquat.setQuantiteJourImputationDonneesForcees(qteJoursDonneesForceesAimputer);
    
    return qteReliquatApresImputationFinale;
  }
  
  protected void postTraitement(ResultatTraitementReliquat resultatTraitement, ResultatExecutionCalculSpec resultatCalcul)
  {
    super.postTraitement(resultatTraitement, resultatCalcul);
  }
  
  protected Damj traiterDecheance(DemandeSpec demande, DecisionSpec decisionPrecedente, Damj dateEtude)
    throws CoucheLogiqueException
  {
    Damj finDelaiDechance = null;
    boolean produitDechu = false;
    boolean inopposabilite = false;
    if ((demande instanceof Demande)) {
      inopposabilite = isInopposabiliteDelaiDecheance((Demande)demande);
    }
    if (!inopposabilite)
    {
      AttributionAssuranceSpec attributionPrecedente = (AttributionAssuranceSpec)decisionPrecedente;
      if (attributionPrecedente != null)
      {
        finDelaiDechance = getDateFinDelaiDecheance(attributionPrecedente, demande);
        Damj dateEtudeDecheance = dateEtude;
        if (("ASU_04".equals(demande.getEvenementReferenceExamen().getTypeExamen())) && (FabriqueConvention2014.DATE_APPLICATION.estAvant(demande.getDateExamen())))
        {
          Demande rejetDV = GestionDemandeDv122eJour.retrouverDemandePortantDv(demande);
          if ((rejetDV != null) && (rejetDV.getDateExamen().veille().estAvant(dateEtude))) {
            dateEtudeDecheance = rejetDV.getDateExamen().veille();
          }
        }
        produitDechu = !dateEtudeDecheance.lendemain().estAvantOuCoincideAvec(finDelaiDechance);
      }
    }
    if (!produitDechu) {
      finDelaiDechance = null;
    }
    return finDelaiDechance;
  }
  
  protected Damj traiterExtinction(DemandeSpec demande, DecisionSpec decisionPrecedente, ResultatExecutionCalculSpec resultatExecutionCalcul, Damj dateEtude)
    throws CoucheLogiqueException
  {
    return getDateExtinction(demande, decisionPrecedente, resultatExecutionCalcul, dateEtude);
  }
  
  protected Damj getDateExtinction(DemandeSpec demande, DecisionSpec decisionPrecedente, ResultatExecutionCalculSpec resultatExecutionCalcul, Damj dateEtude)
    throws CoucheLogiqueException
  {
    Damj dateExtinction = null;
    if (((AttributionAssuranceSpec)decisionPrecedente).estTopeeRenoncement())
    {
      dateExtinction = decisionPrecedente.getDateAttribution();
    }
    else
    {
      Chronologie chronoRechercheClassementSP = demande.getDemandeur().getChronoDemandeAssurance().copier(new FiltreDateDeclenchementExamenApresOuCoincideDateEtInclusParPriorite(decisionPrecedente.getDateEffet(), decisionPrecedente.getDemande()));
      
      chronoRechercheClassementSP = chronoRechercheClassementSP.copier(new FiltreDateDeclenchementExamenAvantOuCoincideDateEtInclusParPriorite(dateEtude.lendemain(), demande));
      
      dateExtinction = estPresenceClassementSecteurPublic(chronoRechercheClassementSP);
      if (dateExtinction == null) {
        dateExtinction = determinerExtinctionPourExclusionDefinitiveRevenuDeRemplacement(demande, resultatExecutionCalcul, dateEtude);
      }
      if ((dateExtinction == null) && (GammeAsu.getInstance().equals(demande.getGamme())) && (((Demande)demande).estDroitOptionReadmission()))
      {
        CritereStrategie critere = new CritereStrategie();
        critere.setDatePivot(demande.getDateRecherche());
        
        StrategieExtinctionReliquatSurDroitOptionSpec strategie = (StrategieExtinctionReliquatSurDroitOptionSpec)FabriqueStrategieExtinctionReliquatSurDroitOption.getInstance().getStrategie(critere);
        
        dateExtinction = strategie.calculerDateExtinction((Demande)demande);
      }
    }
    return dateExtinction;
  }
  
  public static Quantite determinerDureeImputationFormation(ProduitSpec produit, DemandeSpec demande, Quantite quantiteInitiale, DossierExamenAssuranceSpec decisionPrecedente, Periode periode, Damj dateEtude)
  {
    if (effectuerCalculImputationFormation(produit, decisionPrecedente, quantiteInitiale, dateEtude, demande)) {
      return determinerDureeImputationFormationDroitCourant(produit, demande, quantiteInitiale, periode);
    }
    return new Quantite(0, UniteDuree.JOUR);
  }
  
  public static Quantite determinerDureeImputationAide(DemandeSpec demandeSpec, DossierExamenAssuranceSpec decisionPrecedente, Damj dateEtude, ResultatTraitementReliquatSpec resultatTraitementReliquat)
    throws CoucheLogiqueException, ApplicativeException
  {
    Quantite qteAidesAImputer = new Quantite(0, UniteDuree.JOUR);
    String typeAide = null;
    int joursAide = 0;
    
    Competences conteneurCompetences = new Competences();
    conteneurCompetences.setCompetenceAdministrative(((AttributionAssuranceSpec)decisionPrecedente).getCompetenceAdministrative());
    conteneurCompetences.setCompetenceFinanciere(((AttributionAssuranceSpec)decisionPrecedente).getCompetenceFinanciere());
    conteneurCompetences.setConventionGestion(((AttributionAssuranceSpec)decisionPrecedente).getConventionGestion());
    if (((demandeSpec instanceof Demande)) && (((Demande)demandeSpec).getDonneesTemporaires().getMontantAide() != null))
    {
      Demande demande = (Demande)demandeSpec;
      
      Damj dateAttributionAide = demande.getDonneesTemporaires().getDateAttributionAide();
      if (dateAttributionAide == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ABSENCE_DATE_ATTRIBUTION_AIDE");
      } else if ((demandeSpec.getDateExamen() != null) && (dateAttributionAide.estApres(demandeSpec.getDateExamen()))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DATE_ATTRIBUTION_AIDE_INCORRECTE");
      } else {
        VerificationDonneesForcees.verifierDonneesForceesAide(demande);
      }
      GammeAsuSpec gamme = (GammeAsuSpec)((AttributionAssuranceSpec)decisionPrecedente).getGamme();
      DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant = gamme.mapperDonneesEntreesRecuperationMontant((AttributionAssuranceSpec)decisionPrecedente);
      donneesEntreesRecuperationMontant.setDateCalculMontant(dateAttributionAide);
      MontantBaseSpec montant = DeterminationMontant.determinerMontant(donneesEntreesRecuperationMontant);
      
      BigDecimal montantPrecompte = ((MontantAsuSpec)montant).getMontantPrecompte();
      if (demande.getDonneesTemporaires().getMontantAide() != null) {
        joursAide = demande.getDonneesTemporaires().getMontantAide().divide(montantPrecompte, 0, 1).intValue();
      }
      qteAidesAImputer = new Quantite(new BigDecimal(joursAide), UniteDuree.JOUR);
      typeAide = Reliquat.determinerTypeAide(demande.getDonneesTemporaires().getNatureMontantAide());
    }
    else
    {
      FiltreET filtreDeRechercheAttributionArce = new FiltreET();
      filtreDeRechercheAttributionArce.ajouterFiltre(new FiltreDecisionPourProduit(18));
      filtreDeRechercheAttributionArce.ajouterFiltre(new FiltreAttributionInrPourDateAttributionAreLiee(decisionPrecedente.getDateAttribution()));
      filtreDeRechercheAttributionArce.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
      AttributionSpec attributionArce = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demandeSpec.getDemandeur().getChronoDemandeIncitationReclassement(), demandeSpec, filtreDeRechercheAttributionArce);
      if (attributionArce != null)
      {
        int dureeAImputer = 0;
        BigDecimal capitalArce = null;
        
        ProduitInrSpec produit = (ProduitInrSpec)attributionArce.getDemande().getDossierAffectation().getProduit();
        
        ResultatExecutionCalculSpec resultat = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionArce, dateEtude, true);
        if ((resultat == null) || (resultat.getCapitalVerse() == null)) {
          capitalArce = BigDecimal.ZERO;
        } else {
          capitalArce = resultat.getCapitalVerse().getValeur();
        }
        BigDecimal montantArce = produit.getMontantJournalierAttributionArce(attributionArce);
        
        dureeAImputer = capitalArce.divide(montantArce, 0, 1).intValue();
        qteAidesAImputer = new Quantite(new BigDecimal(dureeAImputer), UniteDuree.JOUR);
        typeAide = "ARC";
      }
      else
      {
        FiltreET filtreDeRechercheAttributionAdr = new FiltreET();
        filtreDeRechercheAttributionAdr.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
        filtreDeRechercheAttributionAdr.ajouterFiltre(new FiltreDecisionPourProduit(38));
        filtreDeRechercheAttributionAdr.ajouterFiltre(new FiltreAttributionInrPourDateAttributionAreLiee(decisionPrecedente.getDateAttribution()));
        
        AttributionSpec attributionADR = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demandeSpec.getDemandeur().getChronoDemandeIncitationReclassement(), demandeSpec, filtreDeRechercheAttributionAdr);
        if (attributionADR != null)
        {
          int dureeAImputer = 0;
          BigDecimal capitalADRConsomme = null;
          BigDecimal montantARE = null;
          
          ProduitInrSpec produit = (ProduitInrSpec)attributionADR.getDemande().getDossierAffectation().getProduit();
          
          ResultatExecutionCalculSpec resultat = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionADR, dateEtude, true);
          
          montantARE = produit.getMontantJournalierAttributionADR(attributionADR);
          if ((resultat.getCapitalADR() != null) && (resultat.getCapitalADR().getValeur() != null)) {
            capitalADRConsomme = resultat.getCapitalADR().getValeur();
          } else {
            capitalADRConsomme = BigDecimal.ZERO;
          }
          dureeAImputer = capitalADRConsomme.divide(montantARE, 0, 1).intValue();
          qteAidesAImputer = new Quantite(new BigDecimal(dureeAImputer), UniteDuree.JOUR);
          typeAide = "ARC";
        }
      }
    }
    ((ResultatTraitementReliquat)resultatTraitementReliquat).setTypeAide(typeAide);
    return qteAidesAImputer;
  }
  
  private static boolean effectuerCalculImputationFormation(ProduitSpec produit, DossierExamenAssuranceSpec decisionPrecedente, Quantite quantiteInitiale, Damj dateEtude, DemandeSpec demande)
  {
    ChronologiePeriodes chronoPeriodes = (ChronologiePeriodes)OutillagePEC.getPeriodesPecDebutAvantDate(demande.getDemandeur(), dateEtude.lendemain());
    if ((chronoPeriodes == null) || (chronoPeriodes.estVide())) {
      return false;
    }
    Quantite dureeIndemnisationTheoriquePrecedente = decisionPrecedente.getAccesseurDroits().getDureeIndemnisationTheorique();
    return (dureeIndemnisationTheoriquePrecedente.getValeurEntiere() > getDureeDroitMinImputationFormation(produit)) && (quantiteInitiale.getValeur().compareTo(TRENTE) > 0);
  }
  
  private static Periode getPeriodeValiditeFormation(IndividuSpec individu, Damj dateEtude)
  {
    Damj debutValidite = getDebutValiditeFormation(individu, dateEtude);
    Damj finValidite = getFinValiditeFormation(dateEtude);
    Periode periodeValidite = new Periode(debutValidite, finValidite);
    
    return periodeValidite;
  }
  
  public static Quantite determinerDureeImputationFormation(ProduitSpec produit, DemandeSpec demande, Quantite quantiteInitiale, DossierExamenAssuranceSpec decisionPrecedente, Damj dateEtude)
  {
    if (effectuerCalculImputationFormation(produit, decisionPrecedente, quantiteInitiale, dateEtude, demande))
    {
      Periode periodeValiditeFormation = getPeriodeValiditeFormation(demande.getDemandeur(), dateEtude);
      
      return determinerDureeImputationFormation(produit, demande, quantiteInitiale, decisionPrecedente, periodeValiditeFormation, dateEtude);
    }
    return new Quantite(0, UniteDuree.JOUR);
  }
  
  private static int getDureeDroitMinImputationFormation(ProduitSpec produit)
  {
    return ((ProduitAsuSpec)produit).getDureeMinimumPourImputationFormation();
  }
  
  private static Damj getDebutValiditeFormation(IndividuSpec individu, Damj dateEtude)
  {
    Damj dateDebutValiditeFormation = null;
    ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = null;
    ChronologiePeriodes chronoPeriodes = (ChronologiePeriodes)OutillagePEC.getPeriodesPecDebutAvantDate(individu, dateEtude.lendemain());
    if ((chronoPeriodes != null) && (!chronoPeriodes.estVide())) {
      periodePEC = (ObjetChronoPeriodePriseEnChargeSansFiltre)chronoPeriodes.dernierElement();
    }
    if (periodePEC != null) {
      dateDebutValiditeFormation = periodePEC.getDateFin();
    }
    return dateDebutValiditeFormation;
  }
  
  private static Damj getFinValiditeFormation(Damj dateEtude)
  {
    return dateEtude.lendemain();
  }
  
  public static Quantite determinerDureeImputationFormationDroitCourant(ProduitSpec produit, Demande demande, Quantite quantiteInitiale, Periode periode, int dureeTheorique)
  {
    if (dureeTheorique > ((ProduitAsuSpec)produit).getDureeMinimumPourImputationFormation()) {
      return determinerDureeImputationFormationDroitCourant(produit, demande, quantiteInitiale, periode);
    }
    return new Quantite(0, UniteDuree.JOUR);
  }
  
  private static Quantite determinerDureeImputationFormationDroitCourant(ProduitSpec produit, DemandeSpec demande, Quantite quantiteInitiale, Periode periode)
  {
    Quantite quantiteInitialeApresImputation = determinerReliquatApresImputationPourFormation(produit, demande, quantiteInitiale, periode);
    if (quantiteInitialeApresImputation != null) {
      return quantiteInitiale.soustraire(quantiteInitialeApresImputation);
    }
    return quantiteInitiale;
  }
  
  private static Quantite determinerReliquatApresImputationPourFormation(ProduitSpec produit, DemandeSpec demande, Quantite quantiteInitiale, Periode periode)
  {
    Periode periodeImputation = periode;
    
    Chronologie chronologieFormationImputable = determinerChronologieFormationImputableSurDuree(periodeImputation, demande.getDemandeur());
    
    Quantite quantiteFormation = calculerDureeTotaleFormation(chronologieFormationImputable);
    
    return calculerDureeImputationFormation(quantiteFormation, produit, quantiteInitiale);
  }
  
  public static Periode determinerPeriodeImputationFormationDroitCourant(Demande demande, Damj dateEtude)
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Détermination de la période d'imputation du droit courant." });
    
    Damj dateDebut = demande.getFaitGenerateur().getDateFaitGenerateur();
    Damj dateFin = dateEtude.lendemain();
    
    return new Periode(dateDebut, dateFin);
  }
  
  private static Chronologie determinerChronologieFormationImputableSurDuree(Periode periodeContenantFormation, IndividuSpec demandeur)
  {
    return ConstructionChronologie.determinerChronoFormationAImputer(periodeContenantFormation, demandeur.getChronoPeriodePasseProfessionnelLiquidation());
  }
  
  private static Quantite calculerDureeTotaleFormation(Chronologie chronologie)
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début du calcul da la durée d'imputation." });
    
    Quantite dureeFormationImputable = new Quantite(0, UniteAffiliation.HEURE_TRAVAIL);
    if (chronologie != null)
    {
      chronologie.iterer();
      while (chronologie.encoreSuivant())
      {
        PeriodeFormationAssimilable periodeFormation = (PeriodeFormationAssimilable)chronologie.elementSuivant();
        Quantite quantiteFormationImputableSurDuree = periodeFormation.getDureeTotale();
        dureeFormationImputable = dureeFormationImputable.ajouter(quantiteFormationImputableSurDuree);
      }
    }
    return dureeFormationImputable;
  }
  
  private static Quantite calculerDureeImputationFormation(Quantite quantiteFormation, ProduitSpec produit, Quantite quantiteInitiale)
  {
    return AppelCalculParLiquidationAsu.determinerDureeEffectiveReliquat(produit, quantiteInitiale, quantiteFormation);
  }
  
  private boolean isInopposabiliteDelaiDecheance(Demande demandeCourante)
  {
    return demandeCourante.getDonneesTemporaires().isInopposabiliteDelaiDecheance();
  }
  
  private DureeCalendaire getDureeDecheance(AttributionSpec decisionPrecedente, DemandeSpec demandeCourante)
  {
    AttributionAssuranceSpec attributionPrecedente = (AttributionAssuranceSpec)decisionPrecedente;
    int dureeIndemnisationPrecedente = attributionPrecedente.getDureeTheoriquePourDelaiDecheance().getValeurEntiere();
    DureeCalendaire duree = fr.unedic.cali.asu.outilsfonctionnels.OutilTraitementReliquat.getDureeDecheance(dureeIndemnisationPrecedente);
    if ((demandeCourante instanceof Demande))
    {
      DureeCalendaire allongement = ((Demande)demandeCourante).getDonneesTemporaires().getAllongementDelaiDecheance();
      if (allongement != null) {
        duree = duree.ajouter(allongement);
      }
    }
    return duree;
  }
  
  private Damj estPresenceClassementSecteurPublic(Chronologie chronoRechercheClassementSP)
  {
    ListIterator it = chronoRechercheClassementSP.iterer();
    while (it.hasNext())
    {
      Demande courante = (Demande)it.next();
      if (courante.estClasseeEnCompetenceSecteurPublic()) {
        return courante.getDateExamen();
      }
    }
    return null;
  }
  
  public Damj getDateFinDelaiDecheance(AttributionSpec attributionPrecedente, DemandeSpec demandeCourante)
  {
    Damj debutDelaiDecheance = null;
    DureeCalendaire dureeDecheance = null;
    Damj finDelaiDechance = null;
    if (attributionPrecedente != null)
    {
      debutDelaiDecheance = ((AttributionAssuranceSpec)attributionPrecedente).getDateDebutDelaiDecheance();
      
      dureeDecheance = getDureeDecheance(attributionPrecedente, demandeCourante);
      
      finDelaiDechance = debutDelaiDecheance.deplacerVersAvant(dureeDecheance);
    }
    return finDelaiDechance;
  }
}

/* Location:
 * Qualified Name:     OutilTraitementReliquat
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */