package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.dom.ParametresCalculAppartenance;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatRechercheConditionChomageInvolontaire;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieReglementAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieReglementAffiliationSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.parametres.OutilAccesListeUnitesReglement;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.affectation.ValidationProduitSpec;
import fr.unedic.cali.dom.spec.CalculAppartenanceSpec;
import fr.unedic.cali.outilsfonctionnels.ComparateurTemporelSurDateFinDecroissante;
import fr.unedic.cali.outilsfonctionnels.DetectionTypeChomage;
import fr.unedic.cali.outilsfonctionnels.OutilChronologie;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieeMotifDvNonLegitime;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteNonSalarieePeriodique;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAvecConflit;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesJustifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSpec;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;

public final class RechercheConditionChomageInvolontaire
  implements OutilFonctionnel
{
  public static RechercheConditionChomageInvolontaire getInstance()
  {
    return new RechercheConditionChomageInvolontaire();
  }
  
  public static void traiterSituation1(Demande demandeAssurance, Reglement reglementApplicable, ResultatRechercheConditionChomageInvolontaire resultat)
  {
    ProduitSpec produit = ((DossierAffectation)demandeAssurance.getDossierAffectation()).getProduit();
    if ((reglementApplicable != null) && (reglementApplicable.equals(produit.getReglement("A3"))))
    {
      resultat.getResultatElementDroit().setEtatSatisfait(false);
      resultat.setSituationConditionChomageInvolontaire(1);
      resultat.getResultatElementDroit().setCodeMotifEchec(91);
      
      resultat.setIdentifiantActivitePortantDV(demandeAssurance.getFaitGenerateur().getPeriodeFaitGenerateur().getIdentifiant());
    }
    else
    {
      boolean conditionQuantiteAffiliationObjectifAdmissionSatisfaite = false;
      DossierExamenSpec dossierExamenObjectifAdmission = demandeAssurance.getDossierExamen(1);
      if ((dossierExamenObjectifAdmission != null) && (((DossierExamenAssuranceSpec)dossierExamenObjectifAdmission).getConditionQuantiteAffiliation() != null)) {
        conditionQuantiteAffiliationObjectifAdmissionSatisfaite = ((DossierExamenAssuranceSpec)dossierExamenObjectifAdmission).getConditionQuantiteAffiliation().estSatisfait();
      }
      if (dossierExamenObjectifAdmission != null)
      {
        if (!conditionQuantiteAffiliationObjectifAdmissionSatisfaite)
        {
          resultat.getResultatElementDroit().setEtatSatisfait(true);
          resultat.setSituationConditionChomageInvolontaire(2);
        }
        else
        {
          resultat.getResultatElementDroit().setEtatSatisfait(false);
          resultat.setSituationConditionChomageInvolontaire(1);
          resultat.getResultatElementDroit().setCodeMotifEchec(91);
        }
      }
      else
      {
        resultat.getResultatElementDroit().setEtatSatisfait(true);
        resultat.setSituationConditionChomageInvolontaire(2);
      }
    }
  }
  
  public static void traiterSituation2(Demande demandeAssurance, Reglement reglementApplicable, ResultatRechercheConditionChomageInvolontaire resultatCondition)
    throws ApplicativeException
  {
    ProduitSpec produit = ((DossierAffectation)demandeAssurance.getDossierAffectation()).getProduit();
    if (reglementApplicable.equals(produit.getReglement("A3")))
    {
      resultatCondition.getResultatElementDroit().setEtatSatisfait(true);
      resultatCondition.setSituationConditionChomageInvolontaire(2);
    }
    else
    {
      Chronologie chronologieActivitesDV = ConstructionChronologie.determinerChronoActivitesDV(demandeAssurance);
      
      FiltresTemporel filtreJustifieeEnConflit = new FiltresTemporel();
      filtreJustifieeEnConflit.ajouterFiltre(new FiltrePeriodesAvecConflit());
      filtreJustifieeEnConflit.ajouterFiltre(new FiltrePeriodesJustifiees());
      if (!chronologieActivitesDV.copier(filtreJustifieeEnConflit).estVide()) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB3");
      }
      if (chronologieActivitesDV.estVide())
      {
        resultatCondition.getResultatElementDroit().setEtatSatisfait(true);
        resultatCondition.setSituationConditionChomageInvolontaire(2);
      }
      else
      {
        TravailSpec derniereActivite = (TravailSpec)chronologieActivitesDV.premierElement();
        
        ResultatRechercheConditionChomageInvolontaire resultat = rechercherConditionChomageInvolontaire(demandeAssurance, derniereActivite, reglementApplicable);
        
        resultatCondition.getResultatElementDroit().setCodeMotifEchec(resultat.getResultatElementDroit().getCodeMotifEchec());
        resultatCondition.getResultatElementDroit().setEtatSatisfait(resultat.getResultatElementDroit().estSatisfait());
        resultatCondition.setSituationConditionChomageInvolontaire(resultat.getSituationConditionChomageInvolontaire());
      }
    }
  }
  
  public static ResultatRechercheConditionChomageInvolontaire verifierChomageInvolontaireDemandeAssurance(Demande demandeAssurance, FaitGenerateurSpec faitGenerateur)
    throws ApplicativeException
  {
    ResultatRechercheConditionChomageInvolontaire resultat = initialiserResultat();
    
    int codeMotifFin = faitGenerateur.getPeriodeFaitGenerateur().getCodeMotifFin();
    int contexteDemisison = faitGenerateur.getPeriodeFaitGenerateur().getContrat().getContexteDemission();
    
    ProduitSpec produit = ((DossierAffectation)demandeAssurance.getDossierAffectation()).getProduit();
    
    Reglement reglementApplicableCourant = ((DossierAffectation)demandeAssurance.getDossierAffectation()).getReglementPeriodeValidationProduit();
    if (!DetectionTypeChomage.estChomageLegitime(codeMotifFin, contexteDemisison))
    {
      resultat.setSituationConditionChomageInvolontaire(1);
      resultat.getResultatElementDroit().setEtatSatisfait(false);
      resultat.getResultatElementDroit().setCodeMotifEchec(91);
      
      resultat.setIdentifiantActivitePortantDV(demandeAssurance.getFaitGenerateur().getPeriodeFaitGenerateur().getIdentifiant());
    }
    else
    {
      reglementApplicableCourant = verificationReglementNonNull(produit, reglementApplicableCourant, demandeAssurance.getDossierAffectationAdmission().getJustificationAffectation());
      if (reglementApplicableCourant != null) {
        if (reglementApplicableCourant.equals(produit.getReglement("A3")))
        {
          resultat.setSituationConditionChomageInvolontaire(2);
          resultat.getResultatElementDroit().setEtatSatisfait(true);
        }
        else
        {
          Damj dateDebutRechercheDV = Damj.NUIT_DES_TEMPS;
          Damj dateFinRechercheDV = faitGenerateur.getDateFaitGenerateur();
          
          OdSpec odOrigine = demandeAssurance.rechercherOuvertureDroitPrecedenteDuMemeType();
          if (odOrigine != null) {
            dateDebutRechercheDV = ((DossierExamenAssuranceSpec)odOrigine).getFaitGenerateur().getDateFaitGenerateur().lendemain();
          }
          Chronologie chronoFiltreeDansDelaiRecherche = determinerChronologiePeriodesPortantDv(demandeAssurance, new Periode(dateDebutRechercheDV, dateFinRechercheDV), faitGenerateur);
          if (chronoFiltreeDansDelaiRecherche.estVide())
          {
            resultat.setSituationConditionChomageInvolontaire(2);
            resultat.getResultatElementDroit().setEtatSatisfait(true);
          }
          else
          {
            chronoFiltreeDansDelaiRecherche.setComparateur(new ComparateurTemporelSurDateFinDecroissante());
            TravailSpec dernierePeriode = (TravailSpec)chronoFiltreeDansDelaiRecherche.premierElement();
            
            resultat = rechercherConditionChomageInvolontaire(demandeAssurance, dernierePeriode, reglementApplicableCourant);
            
            boolean estContexteChomageNonLegitime = fr.unedic.cali.asu.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.getInstance().determinerChomageNonLegitime(dernierePeriode);
            if (estContexteChomageNonLegitime) {
              return resultat;
            }
            if (!resultat.getResultatElementDroit().estSatisfait()) {
              fr.unedic.cali.asu.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.getInstance().verifierConditionChomageInvolontaireVerifiable(dernierePeriode);
            }
          }
        }
      }
    }
    return resultat;
  }
  
  public static Chronologie determinerChronologiePeriodesPortantDv(Demande demandeAssurance, Periode delaiRecherche, FaitGenerateurSpec faitGenerateur)
  {
    Chronologie chronoDansDelaiRecherche = filtrerTravailSpecDansBorneSansFg(demandeAssurance, delaiRecherche, faitGenerateur);
    
    FiltrePeriodesSurFiltresExclusifs listeFiltres = creerFiltrePeriodeNonAttesteesDnjOuConflit();
    
    listeFiltres.ajouterFiltre(new FiltreActiviteSalarieeMotifDvNonLegitime());
    
    Chronologie chronoFiltreeDansDelaiRecherche = chronoDansDelaiRecherche.copier(listeFiltres);
    chronoFiltreeDansDelaiRecherche.setComparateur(new ComparateurTemporelSurDateFinDecroissante());
    return chronoFiltreeDansDelaiRecherche;
  }
  
  public static FiltrePeriodesSurFiltresExclusifs creerFiltrePeriodeNonAttesteesDnjOuConflit()
  {
    FiltrePeriodesSurFiltresExclusifs listeFiltres = new FiltrePeriodesSurFiltresExclusifs();
    
    listeFiltres.ajouterFiltre(new FiltrePeriodesAttestees(false));
    
    listeFiltres.ajouterFiltre(new FiltrePeriodesJustifiees(false));
    
    listeFiltres.ajouterFiltre(new FiltrePeriodesAvecConflit());
    return listeFiltres;
  }
  
  private static Chronologie filtrerTravailSpecDansBorneSansFg(Demande demandeAssurance, Periode delaiRecherche, FaitGenerateurSpec faitGenerateur)
  {
    Damj dateDebutRechercheDV = delaiRecherche.getDebut();
    Damj dateFinRechercheDV = delaiRecherche.getFin();
    Chronologie chronoToutesPeriodes = demandeAssurance.getDemandeur().getChronoPeriodePasseProfessionnelPourLiquidationSansFiltrageDNJ();
    
    FiltresTemporel filtreChevauchePeriodeEtActiviteSalarie = new FiltresTemporel();
    filtreChevauchePeriodeEtActiviteSalarie.ajouterFiltre(new FiltreFinDansBornes(new Periode(dateDebutRechercheDV, dateFinRechercheDV)));
    filtreChevauchePeriodeEtActiviteSalarie.ajouterFiltre(new FiltreTravailSpec());
    Chronologie chronoDansDelaiRecherche = chronoToutesPeriodes.copier(filtreChevauchePeriodeEtActiviteSalarie);
    if (faitGenerateur != null) {
      OutilChronologie.supprimerPeriodeParIdentifiant(chronoDansDelaiRecherche, faitGenerateur.getPeriodeFaitGenerateur());
    }
    FiltrePeriodesSurFiltresExclusifs filtreASupprimer = new FiltrePeriodesSurFiltresExclusifs();
    filtreASupprimer.ajouterFiltre(new FiltrePeriodeActiviteNonSalarieePeriodique());
    filtreASupprimer.ajouterFiltre(new FiltrePeriodesLiquidables(false));
    Chronologie chronoPans = chronoDansDelaiRecherche.copier(filtreASupprimer);
    if (!chronoPans.estVide())
    {
      ListIterator<?> pans = chronoPans.iterer();
      while (pans.hasNext()) {
        chronoDansDelaiRecherche.supprimer((Temporel)pans.next());
      }
    }
    return chronoDansDelaiRecherche;
  }
  
  public static ResultatRechercheConditionChomageInvolontaire verifierChomageInvolontaireExamen122Jour(Demande demandeAssurance)
    throws CoucheLogiqueException
  {
    ResultatRechercheConditionChomageInvolontaire resultat = initialiserResultat();
    if (demandeAssurance.getDonneesTemporaires().estAvisFavorableCommissionParitaire())
    {
      resultat.getResultatElementDroit().setEtatSatisfait(true);
    }
    else if (demandeAssurance.getDonneesTemporaires().estAvisDefavorableCommissionParitaire())
    {
      resultat.getResultatElementDroit().setEtatSatisfait(false);
      resultat.getResultatElementDroit().setCodeMotifEchec(93);
    }
    else
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB5");
    }
    fr.unedic.cali.asu.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.getInstance().leverAlerteA11MB26(demandeAssurance);
    return resultat;
  }
  
  public static ResultatRechercheConditionChomageInvolontaire rechercherConditionChomageInvolontaire(Demande demande, TravailSpec derniereActivite, Reglement reglementApplicable)
    throws ApplicativeException
  {
    ResultatRechercheConditionChomageInvolontaire resultat = initialiserResultat();
    
    Pra pra = ConstructionPra.determinerPraDv(demande, derniereActivite.getDateFin(), reglementApplicable);
    
    Chronologie chronoActivitesAssimilables = ConstructionChronologie.determinerChronoAssimilablePra(demande, pra, demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    
    Chronologie chronoActiviteParticipanteTousReglements = ConstructionChronologie.determinerChronoActiviteSalarieTousReglements(demande, demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation(), pra);
    
    Chronologie chronoActiviteParticipante = new ChronologiePeriodes();
    chronoActiviteParticipante.ajouter(chronoActivitesAssimilables);
    chronoActiviteParticipante.ajouter(chronoActiviteParticipanteTousReglements);
    
    chronoActiviteParticipante = chronoActiviteParticipante.copier(new FiltreFinDansBornes(pra.getDebut(), pra.getFin()));
    
    boolean quantiteAppartenance = verifierConditionAffiliation(demande, pra, chronoActiviteParticipante, false, false, true, false).isConditionAffiliationVerifiee();
    if (quantiteAppartenance)
    {
      resultat.getResultatElementDroit().setEtatSatisfait(true);
      resultat.setSituationConditionChomageInvolontaire(3);
    }
    else
    {
      resultat.getResultatElementDroit().setEtatSatisfait(false);
      resultat.setSituationConditionChomageInvolontaire(4);
      resultat.getResultatElementDroit().setCodeMotifEchec(92);
      
      resultat.setIdentifiantActivitePortantDV(derniereActivite.getIdentifiant());
    }
    return resultat;
  }
  
  private static Reglement verificationReglementNonNull(ProduitSpec produit, Reglement reglement, int justificationAffectation)
    throws CoucheLogiqueException
  {
    Reglement reglementRetour = reglement;
    if (reglement == null)
    {
      if ((justificationAffectation == 5) || (justificationAffectation == 6)) {
        reglementRetour = produit.getReglement("RG");
      }
      if (reglementRetour == null)
      {
        OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Règlement porté par la période de validation du produit nul et affectation différente ", "du produit de secours : règlement indéterminable" });
        
        throw new CoucheLogiqueException("HG_PR_CALI_L_ERR_CONTEXTE", "Règlement porté par la période de validation du produit nul et affectation différente du produit de secours : règlement indéterminable");
      }
    }
    return reglementRetour;
  }
  
  public static ResultatRechercheConditionChomageInvolontaire verifierConditionAffiliation(DemandeSpec demande, Pra pra, Chronologie chronoPAS, boolean nePasTenirCompteDesPnds, boolean reinitialiserCalculPeriodeElementaire, boolean prendreEnCompteAssimilation, boolean estEnContexteInnoposabiliteDv)
    throws ApplicativeException
  {
    ResultatRechercheConditionChomageInvolontaire resultatConditionAffiliation = initialiserResultat();
    ValidationProduitSpec validationProduit = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit();
    if ((validationProduit == null) || (!validationProduit.isEstProduitValide()))
    {
      AttributionSpec attributionOrigine = ((DemandeAssuranceSpec)demande).rechercherOuvertureDroitPrecedenteDuMemeType();
      if (attributionOrigine != null)
      {
        DossierAffectation dossierAffectationOrigine = (DossierAffectation)attributionOrigine.getDemande().getDossierAffectation();
        validationProduit = dossierAffectationOrigine.getValidationProduit();
      }
    }
    ActiviteSalarie periodeActiviteSalariee;
    ActiviteSalarie periodeActiviteSalariee;
    if ((validationProduit != null) && (validationProduit.isEstProduitValide())) {
      periodeActiviteSalariee = validationProduit.getPeriodeValidationProduit();
    } else {
      periodeActiviteSalariee = (ActiviteSalarie)((DossierAffectation)demande.getDossierAffectation()).getSinistre();
    }
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demande.getDateExamen());
    
    StrategieReglementAffiliationSpec strategie = (StrategieReglementAffiliationSpec)FabriqueStrategieReglementAffiliation.getInstance().getStrategie(critere);
    
    Reglement reglementAppartenance = strategie.recupererReglementApplicable(periodeActiviteSalariee, validationProduit);
    
    ProduitAsuSpec produitValide = (ProduitAsuSpec)((ValidationProduit)validationProduit).getProduitValide();
    
    CalculAppartenanceSpec outilCalculAppartenance = produitValide.getOutilCalculAppartenance(demande, true);
    
    ParametresCalculAppartenance parametres = new ParametresCalculAppartenance();
    parametres.setEffectuerImputationAffiliationPmvs(true);
    parametres.setPrendreEnCompteDernierJourFevrier(prendreEnCompteAssimilation);
    parametres.setPrendreEnCompteDonneesForcees(false);
    parametres.setActiverSpecificitesRechargement(false);
    parametres.setNePasSanctionnerPnds(nePasTenirCompteDesPnds);
    parametres.setReinitialiserCalculPeriodesElementaires(reinitialiserCalculPeriodeElementaire);
    if (estEnContexteInnoposabiliteDv)
    {
      parametres.setListeUnitesReglement(OutilAccesListeUnitesReglement.getInstance().recupererListeUniteInpposabiliteChomageInvolontaire(reglementAppartenance.getNomReglement(), reglementAppartenance.getProduit()));
      
      parametres.setContexteAppel("inopposabiliteChomageInvolontaire");
    }
    else
    {
      parametres.setListeUnitesReglement(OutilAccesListeUnitesReglement.getInstance().recupererListeUniteCouvetureChomageInvolontaire(reglementAppartenance.getNomReglement(), reglementAppartenance.getProduit()));
      
      parametres.setContexteAppel("couvertureChomageInvolontaire");
    }
    QuantitesAppartenance quantitesAppartenance = (QuantitesAppartenance)outilCalculAppartenance.calculer(demande, pra, chronoPAS, reglementAppartenance, parametres);
    
    alimenterResultatConditionAffiliation(quantitesAppartenance, prendreEnCompteAssimilation, reglementAppartenance, pra, resultatConditionAffiliation, estEnContexteInnoposabiliteDv, demande.getDateExamen());
    
    return resultatConditionAffiliation;
  }
  
  private static void alimenterResultatConditionAffiliation(QuantitesAppartenance quantitesAppartenance, boolean prendreEnCompteAssimilation, Reglement reglementAppartenance, Pra pra, ResultatRechercheConditionChomageInvolontaire resultatConditionAffiliation, boolean estEnContexteInnoposabiliteDv, Damj dateExamen)
    throws CoucheLogiqueException
  {
    Damj dateApplicationOppositionA4 = GestionnaireDateApplication.getInstance().recupererDateApplication("Prise en compte des heures pour la pra d'opposition en A4");
    List<Unite> listeUnites;
    List<Unite> listeUnites;
    if ((estEnContexteInnoposabiliteDv) && (dateApplicationOppositionA4.estAvantOuCoincideAvec(dateExamen))) {
      listeUnites = OutilAccesListeUnitesReglement.getInstance().recupererListeUniteInpposabiliteChomageInvolontaire(reglementAppartenance.getNomReglement(), reglementAppartenance.getProduit());
    } else {
      listeUnites = OutilAccesListeUnitesReglement.getInstance().recupererListeUniteCouvetureChomageInvolontaire(reglementAppartenance.getNomReglement(), reglementAppartenance.getProduit());
    }
    boolean estQuantiteAffiliationPrincipale = true;
    for (Iterator<Unite> iter = listeUnites.iterator(); iter.hasNext();)
    {
      Unite unite = (Unite)iter.next();
      Quantite qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
      Quantite qteAcquise = qteAffiliation;
      if (prendreEnCompteAssimilation)
      {
        Quantite qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
        qteAcquise = qteAffiliation.ajouter(qteAssimilation);
      }
      if (estQuantiteAffiliationPrincipale)
      {
        resultatConditionAffiliation.setQuantiteAffiliationPrincipaleCalculee(qteAcquise);
        estQuantiteAffiliationPrincipale = false;
      }
      else
      {
        resultatConditionAffiliation.setQuantiteAffiliationSecondaireCalculee(qteAcquise);
      }
      Quantite qteRequise = pra.getQuantiteAffiliationRequise(unite);
      if ((qteRequise != null) && (qteAcquise.compareTo(qteRequise) >= 0))
      {
        resultatConditionAffiliation.setConditionAffiliationVerifiee(true);
        break;
      }
    }
  }
  
  private static ResultatRechercheConditionChomageInvolontaire initialiserResultat()
  {
    ResultatRechercheConditionChomageInvolontaire resultat = new ResultatRechercheConditionChomageInvolontaire();
    ResultatElementDroit resultatElementDroit = new ResultatElementDroit();
    resultat.setResultatElementDroit(resultatElementDroit);
    return resultat;
  }
  
  public static Reglement recupererReglement(Demande demande)
  {
    Reglement reglementApplicableCourant = ((DossierAffectation)demande.getDossierAffectation()).getReglementPeriodeValidationProduit();
    if (reglementApplicableCourant == null)
    {
      AttributionAssuranceSpec odAttributionPrecedente = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
      reglementApplicableCourant = odAttributionPrecedente.getReglementApplicable().getReglement();
    }
    return reglementApplicableCourant;
  }
}

/* Location:
 * Qualified Name:     RechercheConditionChomageInvolontaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */