package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.dom.ComportementAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.dom.ParametresAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.CalculAffiliationSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.ParametresDernierJourFevrierSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.PlafonnementAffiliationSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.TraitementAssimilationSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.TraitementJustificationAffiliationSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.TraitementPeriodeElementaireSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.TraitementZoneMemeExerciceSpec;
import fr.unedic.cali.asu.cge01.parametres.ParametresDerniersJoursFevrier;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ElementZoneMemeExercice;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.PeriodeAffiliationSpec;
import fr.unedic.cali.asu.dom.PeriodeElementaire;
import fr.unedic.cali.asu.dom.ZoneMemeExercice;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSuspensionChomageSansRCT;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeFormationAssimilable;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesQualifiables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSansConflit;
import fr.unedic.cali.util.TableQuantites;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalariePourIdentifiant;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class OutilCalculAffiliation
  implements CalculAffiliationSpec
{
  public static final int ZERO = 0;
  public static final String CHRONOLOGIE_ACTIVITE_AFFILIATION = "ChronologieAffiliation";
  public static final String CHRONOLOGIE_ACTIVITE_ASSIMILATION = "ChronologieAssimilation";
  
  public JustificationAffiliation calculerAffiliation(Chronologie chronologiePeriodes, ParametresAffiliation parametres)
    throws CoucheLogiqueException, ApplicativeException
  {
    JustificationAffiliation justification = new JustificationAffiliation();
    
    verifierParametresCalcul(parametres);
    
    ComportementAffiliationSpec comportement = initialiserComportement(parametres);
    TraitementJustificationAffiliationSpec outilJustificationAffiliation = comportement.getOutilTraitementJustificationAffiliation();
    
    Map<String, Chronologie> chronologies = determinerChronologieActivitesParticipantes(chronologiePeriodes, parametres, justification);
    Chronologie chronologiePeriodesAffiliation = (Chronologie)chronologies.get("ChronologieAffiliation");
    Chronologie chronologiePeriodesAssimilation = (Chronologie)chronologies.get("ChronologieAssimilation");
    
    TraitementPeriodeElementaireSpec outilTraitementPeriodesElementaires = comportement.getOutilTraitementPeriodeElementaire();
    outilTraitementPeriodesElementaires.constituerPeriodesElementaires(chronologiePeriodesAffiliation, parametres, comportement);
    
    PlafonnementAffiliationSpec outilPlafonnementAffiliation = comportement.getOutilPlafonnementAffiliation();
    
    List<?> listeCoefficientsPlafonnement = outilPlafonnementAffiliation.determinerCoefficientsPlafonnementAffiliation(parametres.getPra(), chronologiePeriodesAffiliation, comportement, justification);
    
    List<?> listePeriodesElementairePlafonnees = outilPlafonnementAffiliation.plafonnerPeriodesElementaires(chronologiePeriodesAffiliation, listeCoefficientsPlafonnement, comportement);
    
    List<?> listeAffiliationSupplementairePlafonnees = outilPlafonnementAffiliation.plafonnerAffiliationSupplementaire(chronologiePeriodesAffiliation, listeCoefficientsPlafonnement, comportement);
    if (!parametres.isCalculerUniquementCoefficientPlafonnement())
    {
      outilTraitementPeriodesElementaires.consoliderPeriodesElementaire(parametres.getUniteCalcul(), listePeriodesElementairePlafonnees, comportement);
      
      TraitementAssimilationSpec outilTraitementAssimilation = comportement.getOutilTraitementAssimilation();
      
      List<?> listeAffiliationAssimilee = outilTraitementAssimilation.traiterAffiliationAssimilable(parametres.getPra(), chronologiePeriodesAssimilation, comportement, parametres);
      
      TraitementZoneMemeExerciceSpec outilTraitementZoneMemeExercice = comportement.getOutilTraitementZoneMemeExercice();
      
      outilTraitementZoneMemeExercice.traiterZonesMemeExercice(parametres.getPra(), listePeriodesElementairePlafonnees, listeAffiliationSupplementairePlafonnees, listeAffiliationAssimilee, justification, parametres, comportement);
      
      Quantite quantiteAffiliation = outilTraitementZoneMemeExercice.cumulerAffiliationZoneMemeExercice(justification.getListZoneMemeExercice(), parametres);
      
      Quantite quantiteAffiliationFevrier = determinerAffiliationDernierJourFevrier(justification.getListZoneMemeExercice(), parametres.getPra(), parametres, comportement);
      
      Quantite quantiteImputeeEnJours = determinerQuantiteImputeeEnJour(parametres, comportement, chronologies, parametres.getPra());
      
      Quantite quantiteImputeeEnUniteAffi = determinerQuantiteImputeeEnUnite(parametres, comportement, quantiteImputeeEnJours);
      
      Quantite quantiteAssimilation = outilTraitementZoneMemeExercice.cumulerAssimilationZoneMemeExercice(justification.getListZoneMemeExercice(), parametres);
      
      Quantite quantiteAffiliationAvecFevrier = quantiteAffiliation.ajouter(quantiteAffiliationFevrier);
      
      Quantite plafondAssimilation = determinerPlafondAssimilation(quantiteAffiliationAvecFevrier, parametres);
      
      Quantite quantiteAffiliationAvecImputation = traiterImputation(quantiteAffiliationAvecFevrier, quantiteImputeeEnUniteAffi);
      
      Quantite quantiteAffiliationARetenir = OutilQuantiteAffiliation.getInstance().arrondirQuantite(quantiteAffiliationAvecImputation);
      Quantite quantiteAssimilationARetenir;
      Quantite quantiteAssimilationARetenir;
      if (plafondAssimilation != null) {
        quantiteAssimilationARetenir = plafonnerAssimilation(quantiteAssimilation, plafondAssimilation);
      } else {
        quantiteAssimilationARetenir = quantiteAssimilation;
      }
      Chronologie chronologieActiviteParticipantes = new ChronologiePeriodes();
      chronologieActiviteParticipantes.ajouter(chronologiePeriodesAffiliation);
      chronologieActiviteParticipantes.ajouter(chronologiePeriodesAssimilation);
      
      justification.setPeriodeRechercheAffiliation(parametres.getPra());
      justification.setPlafondAssimilation(plafondAssimilation);
      justification.setQuantiteAffiliation(quantiteAffiliationARetenir);
      justification.setQuantiteAssimilation(quantiteAssimilationARetenir);
      justification.setQuantiteDernierJourFevrier(quantiteAffiliationFevrier);
      justification.setQuantiteImputee(quantiteImputeeEnJours);
      justification.setChronologieActivitesParticipantes(chronologieActiviteParticipantes);
      
      outilJustificationAffiliation.justifierListeAffiliationAssimilee(justification, listeAffiliationAssimilee);
    }
    outilJustificationAffiliation.justifierListePeriodesElementaires(justification, listePeriodesElementairePlafonnees);
    outilJustificationAffiliation.justifierListeAffiliationSupplementaire(justification, listeAffiliationSupplementairePlafonnees);
    
    return justification;
  }
  
  private Quantite traiterImputation(Quantite quantiteAffiliationAvecFevrier, Quantite quantiteImputeeEnUniteAffi)
  {
    Quantite quantiteAffiliationAvecImputation = quantiteAffiliationAvecFevrier.soustraire(quantiteImputeeEnUniteAffi);
    if (quantiteAffiliationAvecImputation.getValeurEntiere() < 0) {
      quantiteAffiliationAvecImputation = new Quantite(0, quantiteAffiliationAvecImputation.getUnite());
    }
    return quantiteAffiliationAvecImputation;
  }
  
  protected Quantite determinerQuantiteImputeeEnJour(ParametresAffiliation parametres, ComportementAffiliationSpec comportement, Map<String, Chronologie> mapChronologieParticipantes, Pra pra)
    throws ApplicativeException
  {
    int nombreDeJourIndemnises = 0;
    Periode periodePra = new Periode(pra.getDebut(), pra.getFin());
    boolean estDemandeEnContexteSuitePmvs = OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(parametres.getListeContexte(), "SUITEPMVS");
    
    boolean estImputerAffiDemandee = parametres.isEffectuerImputationAffiliationPmvs();
    
    Chronologie chronologieAttributionEnCoursPmvsDansPra = parametres.getChronologieAttributionEnCoursPmvsDansPra();
    
    boolean estImputationAEffectuer = (estDemandeEnContexteSuitePmvs) && (estImputerAffiDemandee) && (chronologieAttributionEnCoursPmvsDansPra != null) && (!chronologieAttributionEnCoursPmvsDansPra.estVide());
    if (estImputationAEffectuer)
    {
      Iterator<AttributionAssuranceSpec> iterateur = chronologieAttributionEnCoursPmvsDansPra.iterer();
      while (iterateur.hasNext())
      {
        AttributionAssuranceSpec attributionPmvs = (AttributionAssuranceSpec)iterateur.next();
        if (estActiviteSuspenduePriseEnCompteDansAffiliation(attributionPmvs, mapChronologieParticipantes)) {
          nombreDeJourIndemnises += AppelCalculParLiquidationAsu.determinerNbJoursImputesContextePmvs(attributionPmvs, periodePra);
        }
      }
    }
    return new Quantite(nombreDeJourIndemnises, UniteAffiliation.JOUR);
  }
  
  protected Quantite determinerQuantiteImputeeEnUnite(ParametresAffiliation parametres, ComportementAffiliationSpec comportement, Quantite nombreDeJourIndemnisesEnJour)
    throws ApplicativeException
  {
    Convertisseur convertisseur = comportement.getConvertisseurUnite();
    return convertisseur.convertir(nombreDeJourIndemnisesEnJour, parametres.getUniteCalcul());
  }
  
  protected boolean estActiviteSuspenduePriseEnCompteDansAffiliation(AttributionAssuranceSpec attributionAEtudier, Map<String, Chronologie> mapChronologieParticipantes)
  {
    boolean retour = false;
    Chronologie chronoAffi = (Chronologie)mapChronologieParticipantes.get("ChronologieAffiliation");
    if ((chronoAffi != null) && (!chronoAffi.estVide()))
    {
      ContexteDemande contexteDemandeEtudiee = (ContexteDemande)OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent((Demande)attributionAEtudier.getDemande(), 2);
      
      Chronologie periodePortantPmvsAttributionAEtudier = chronoAffi.copier(new FiltreActiviteSalariePourIdentifiant(contexteDemandeEtudiee.getIdentifiantPeriodeCaliJustifContexte(), ""));
      if ((periodePortantPmvsAttributionAEtudier != null) && (!periodePortantPmvsAttributionAEtudier.estVide())) {
        retour = true;
      }
    }
    return retour;
  }
  
  protected void verifierParametresCalcul(ParametresAffiliation parametres)
    throws CoucheLogiqueException
  {
    if (parametres.getDateExamen() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_L_CALI_ASU_AFFI_PARAM_DATEEXAMEN");
    }
    if (parametres.getIndividu() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_L_CALI_ASU_AFFI_PARAM_INDIVIDU");
    }
    if (parametres.getPra() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_L_CALI_ASU_AFFI_PARAM_PRA");
    }
    if (parametres.getUniteCalcul() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_L_CALI_ASU_AFFI_PARAM_UNITE_CALCUL");
    }
    if (parametres.getProduit() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_L_CALI_ASU_AFFI_PARAM_PRODUIT");
    }
  }
  
  protected ComportementAffiliationSpec initialiserComportement(ParametresAffiliation parametres)
  {
    ComportementAffiliation comportement = new ComportementAffiliation();
    
    comportement.setConvertisseurUnite(parametres.getProduit().determinerConvertisseurUniteAffiliation());
    comportement.setParametresFevrier(new ParametresDerniersJoursFevrier());
    comportement.setOutilPlafonnementAffiliation(new OutilPlafonnementAffiliation());
    comportement.setOutilTraitementAssimilation(new OutilTraitementAssimilation());
    comportement.setOutilTraitementJustificationAffiliation(new OutilJustificationAffiliation());
    comportement.setOutilTraitementPeriodeElementaire(new OutilTraitementPeriodeElementaire());
    comportement.setOutilTraitementZoneMemeExercice(new OutilTraitementZonesMemeExercice());
    
    parametres.getProduit().initialiserComportementCalculAffiliation(comportement, parametres);
    
    return comportement;
  }
  
  public Map<String, Chronologie> determinerChronologieActivitesParticipantes(Chronologie chronologiePeriodes, ParametresAffiliation parametres, JustificationAffiliation justificationAffiliation)
  {
    Map<String, Chronologie> chronologieCalculAffiliation = new HashMap();
    
    FiltresTemporel filtreActivitesParticipantes = new FiltresTemporel();
    
    filtreActivitesParticipantes.ajouterFiltre(ConstructionChronologie.filtreChevauchePeriodeAvecPriseEnComptePmvs(parametres.getListeContexte(), parametres.getPra(), true));
    
    filtreActivitesParticipantes.ajouterFiltre(ConstructionChronologie.filtreFinAvantDateAvecPriseEnComptePmvs(parametres.getListeContexte(), parametres.getDateExamen(), true));
    
    Chronologie chronologieActivitesParticipantesSurPra = chronologiePeriodes.copier(filtreActivitesParticipantes);
    
    Chronologie chronologieActiviteAffiliation = determinerChronologieActivitesPourAffiliation(chronologieActivitesParticipantesSurPra, justificationAffiliation);
    
    chronologieCalculAffiliation.put("ChronologieAffiliation", chronologieActiviteAffiliation);
    
    Chronologie chronologieActiviteAssimilation = determinerChronologieActivitesPourAssimilation(chronologieActivitesParticipantesSurPra);
    
    chronologieCalculAffiliation.put("ChronologieAssimilation", chronologieActiviteAssimilation);
    
    return chronologieCalculAffiliation;
  }
  
  protected Chronologie determinerChronologieActivitesPourAffiliation(Chronologie chronologiePeriodes, JustificationAffiliation justificationAffiliation)
  {
    FiltresTemporel filtreActivitesParticipantesPourAffiliation = new FiltresTemporel();
    filtreActivitesParticipantesPourAffiliation.ajouterFiltre(new FiltreActiviteSalarie());
    filtreActivitesParticipantesPourAffiliation.ajouterFiltre(new FiltrePeriodesQualifiables());
    filtreActivitesParticipantesPourAffiliation.ajouterFiltre(new FiltrePeriodesLiquidables());
    filtreActivitesParticipantesPourAffiliation.ajouterFiltre(new FiltreNegation(new FiltreActiviteSalarieSuspensionChomageSansRCT()));
    
    Chronologie chronologieActiviteSalarieLiquidables = chronologiePeriodes.copier(filtreActivitesParticipantesPourAffiliation);
    Chronologie chronologieActiviteSalarieLiquidablesSansConflit = chronologieActiviteSalarieLiquidables.copier(new FiltrePeriodesSansConflit());
    if (chronologieActiviteSalarieLiquidablesSansConflit.getTaille() != chronologieActiviteSalarieLiquidables.getTaille()) {
      justificationAffiliation.setTopConflits(true);
    }
    return chronologieActiviteSalarieLiquidablesSansConflit;
  }
  
  protected Chronologie determinerChronologieActivitesPourAssimilation(Chronologie chronologiePeriodes)
  {
    FiltresTemporel filtreActivitesParticipantesPourAssimilation = new FiltresTemporel();
    filtreActivitesParticipantesPourAssimilation.ajouterFiltre(new FiltrePeriodeFormationAssimilable());
    
    return chronologiePeriodes.copier(filtreActivitesParticipantesPourAssimilation);
  }
  
  protected Quantite determinerAffiliationDernierJourFevrier(List listeZME, Periode pra, ParametresAffiliation parametres, ComportementAffiliationSpec comportement)
  {
    Quantite affiliationDerniersJourFevrier = initialiserQuantiteDansUniteRecherche(parametres);
    if (parametres.isComptabiliserAffiliationDernierJourFevrier())
    {
      int anneeDebutPra = pra.getDebut().getAnnee();
      int anneeFinPra = pra.getFin().getAnnee();
      for (int annee = anneeDebutPra; annee <= anneeFinPra; annee++)
      {
        Damj dernierJourFevrierAnneeCourante = new Damj(annee, 2, 1).getFinMois();
        if (pra.contient(dernierJourFevrierAnneeCourante))
        {
          ZoneMemeExercice zoneMemeExercice = comportement.getOutilTraitementZoneMemeExercice().determinerZoneMemeExerciceActivteALaDate(listeZME, dernierJourFevrierAnneeCourante);
          if (zoneMemeExercice != null)
          {
            List<?> listePeriodeElementairePourDernierJourFevrier = determinerPeriodesElementairesPourDernierJourFevrier(zoneMemeExercice, dernierJourFevrierAnneeCourante);
            
            Quantite quantiteDernierJourFevrierPourAnneeCourante = determinerQuantiteAffiliationDernierJourFevrierPourPeriodesElementaires(listePeriodeElementairePourDernierJourFevrier, comportement, parametres);
            
            affiliationDerniersJourFevrier = affiliationDerniersJourFevrier.ajouter(quantiteDernierJourFevrierPourAnneeCourante);
          }
        }
      }
    }
    return affiliationDerniersJourFevrier;
  }
  
  protected List<?> determinerPeriodesElementairesPourDernierJourFevrier(ZoneMemeExercice zoneMemeExercice, Damj dernierJourFevrier)
  {
    List listePeriodeElementairePourDernierJourFevrier = new ArrayList();
    
    Iterator<?> it = zoneMemeExercice.getListElementZoneMemeExercice().iterator();
    while (it.hasNext())
    {
      ElementZoneMemeExercice elementZoneMemeExercice = (ElementZoneMemeExercice)it.next();
      
      boolean dernierJourFevrierSurPeriode = elementZoneMemeExercice.getPeriodeAffiliation().getPeriode().contient(dernierJourFevrier);
      
      boolean elementDeTypeAffiliation = elementZoneMemeExercice.getPeriodeAffiliation().getNature() == 1;
      if ((dernierJourFevrierSurPeriode) && (elementDeTypeAffiliation))
      {
        PeriodeElementaire periodeElementaire = (PeriodeElementaire)elementZoneMemeExercice.getPeriodeAffiliation();
        if (!periodeElementaire.isEstSanctionnee()) {
          listePeriodeElementairePourDernierJourFevrier.add(periodeElementaire);
        }
      }
    }
    return listePeriodeElementairePourDernierJourFevrier;
  }
  
  protected Quantite determinerQuantiteAffiliationDernierJourFevrierPourPeriodesElementaires(List listePeriodesElementaires, ComportementAffiliationSpec comportement, ParametresAffiliation parametres)
  {
    ParametresDernierJourFevrierSpec parametresDernierJourFevrier = comportement.getParametresFevrier();
    
    Quantite quantiteDernierJourFevrierARetenir = initialiserQuantiteDansUniteRecherche(parametres);
    boolean quantiteDansUniteRechercheTrouve = false;
    List listeQuantiteAutreQueUniteRecherche = new ArrayList();
    
    Iterator<?> itPeriodeElementaires = listePeriodesElementaires.iterator();
    while (itPeriodeElementaires.hasNext())
    {
      PeriodeElementaire periodeElementaire = (PeriodeElementaire)itPeriodeElementaires.next();
      
      Map quantitesAffiliationPourReglement = parametresDernierJourFevrier.recupererQuantiteDernierJourFevrierPourReglement(periodeElementaire.getActiviteSalarie().getReglement().getLibelleCourt());
      if (quantitesAffiliationPourReglement != null)
      {
        Quantite quantiteReglementPourUniteRecherche = (Quantite)quantitesAffiliationPourReglement.get(parametres.getUniteCalcul());
        if (quantiteReglementPourUniteRecherche != null)
        {
          quantiteDernierJourFevrierARetenir = quantiteDernierJourFevrierARetenir.max(quantiteReglementPourUniteRecherche);
          quantiteDansUniteRechercheTrouve = true;
        }
        else
        {
          listeQuantiteAutreQueUniteRecherche.addAll(quantitesAffiliationPourReglement.values());
        }
      }
    }
    if (!quantiteDansUniteRechercheTrouve)
    {
      Iterator itQuantite = listeQuantiteAutreQueUniteRecherche.iterator();
      while (itQuantite.hasNext())
      {
        Quantite quantite = (Quantite)itQuantite.next();
        Quantite quantiteConvertie = comportement.getConvertisseurUnite().convertir(quantite, parametres.getUniteCalcul());
        quantiteDernierJourFevrierARetenir = quantiteDernierJourFevrierARetenir.max(quantiteConvertie);
      }
    }
    return quantiteDernierJourFevrierARetenir;
  }
  
  private Quantite initialiserQuantiteDansUniteRecherche(ParametresAffiliation parametres)
  {
    return new Quantite(new BigDecimal(0), parametres.getUniteCalcul());
  }
  
  protected Quantite determinerPlafondAssimilation(Quantite quantiteAffiliation, ParametresAffiliation parametres)
  {
    TableQuantites tableQuantiteAffiliation = new TableQuantites();
    tableQuantiteAffiliation.put(quantiteAffiliation);
    
    Pra pra = parametres.getPra();
    
    parametres.getProduit().positionnerQuantiteAssimilationMaximum(pra, tableQuantiteAffiliation);
    
    return pra.getQuantiteAssimilationMaximale(parametres.getUniteCalcul());
  }
  
  protected Quantite plafonnerAssimilation(Quantite quantiteAssimilation, Quantite plafondAssimilation)
  {
    return plafondAssimilation.min(quantiteAssimilation);
  }
}

/* Location:
 * Qualified Name:     OutilCalculAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */