package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.PlafonnementAffiliationSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.TraitementJustificationAffiliationSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.TraitementPeriodeElementaireSpec;
import fr.unedic.cali.asu.dom.AffiliationSupplementaire;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.PeriodeElementaire;
import fr.unedic.cali.asu.dom.PlafonnementAffiliation;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltrePeriodeElementairePlafonnementAffiliation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class OutilPlafonnementAffiliation
  implements PlafonnementAffiliationSpec
{
  public static final int PLAFOND_HEURE_MOIS_CIVIL = 260;
  private FiltreTemporel m_filtreActiviteParticipantAuPlafonnement;
  
  public OutilPlafonnementAffiliation()
  {
    m_filtreActiviteParticipantAuPlafonnement = new FiltrePeriodeElementairePlafonnementAffiliation();
  }
  
  public List determinerCoefficientsPlafonnementAffiliation(Periode p_pra, Chronologie p_chronologieActivites, ComportementAffiliationSpec p_comportement, JustificationAffiliation p_justificationAffiliation)
  {
    Chronologie chronologieActivitesPourPlafonnement = determinerChronologiePeriodes(p_chronologieActivites, true);
    
    List listePeriodesElementaires = p_comportement.getOutilTraitementPeriodeElementaire().recupererListPeriodeElementaire(chronologieActivitesPourPlafonnement);
    
    List listePeriodesAffiliationSupplementaire = p_comportement.getOutilTraitementPeriodeElementaire().recupererListAffiliationSupplementaire(chronologieActivitesPourPlafonnement);
    
    Periode periodePRA = new Periode(p_pra.getDebut(), p_pra.getFin());
    List listeMoisCivilsPRA = periodePRA.decouperEnMoisCivils();
    Iterator it = listeMoisCivilsPRA.iterator();
    while (it.hasNext())
    {
      Periode moisCivil = (Periode)it.next();
      
      moisCivil.setDebut(moisCivil.getDebut().getDebutMois());
      moisCivil.setFin(moisCivil.getFin().getFinMois());
      
      Quantite cumulAffiliationBaseSurMoisCivil = cumulerQuantiteHeureAffiliationBase(moisCivil, listePeriodesElementaires);
      
      Quantite cumulAffiliationSupplementaireSurMoisCivil = cumulerQuantiteHeureAffiliationSupplementaire(moisCivil, listePeriodesAffiliationSupplementaire);
      
      Quantite plafondMoisCivil = determinerPlafondAffiliationMoisCivil();
      
      PlafonnementAffiliation plafonnementAffiliation = determinerCoefficientsPlafonnementMoisCivil(moisCivil, cumulAffiliationBaseSurMoisCivil, cumulAffiliationSupplementaireSurMoisCivil, plafondMoisCivil);
      
      p_comportement.getOutilTraitementJustificationAffiliation().ajouterPlafonnementAffiliation(p_justificationAffiliation, plafonnementAffiliation);
    }
    return p_justificationAffiliation.getListPlafonnementAffiliation();
  }
  
  protected Quantite cumulerQuantiteHeureAffiliationBase(Periode p_moisCivil, List p_listePeriodesElementaires)
  {
    BigDecimal resultat = new BigDecimal(0);
    Unite uniteHeure = Unite.getParCode("18");
    if (p_listePeriodesElementaires != null)
    {
      Iterator it = p_listePeriodesElementaires.iterator();
      while (it.hasNext())
      {
        PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
        if (p_moisCivil.contient(periodeElementaire.getPeriodePE())) {
          if (!periodeElementaire.isEstSanctionnee())
          {
            Quantite quantiteHeure = periodeElementaire.getQuantiteInitialeHeure();
            if (quantiteHeure != null) {
              resultat = resultat.add(quantiteHeure.getValeur());
            }
          }
        }
      }
    }
    return new Quantite(resultat, uniteHeure);
  }
  
  protected Quantite cumulerQuantiteHeureAffiliationSupplementaire(Periode p_moisCivil, List p_listePeriodesAffiliationSupplementaire)
  {
    BigDecimal resultat = new BigDecimal(0);
    Unite uniteHeure = Unite.getParCode("18");
    if (p_listePeriodesAffiliationSupplementaire != null)
    {
      Iterator it = p_listePeriodesAffiliationSupplementaire.iterator();
      while (it.hasNext())
      {
        AffiliationSupplementaire affiliationSupplementaire = (AffiliationSupplementaire)it.next();
        if (p_moisCivil.contient(affiliationSupplementaire.getPeriodeAffiliationSupplementaire()))
        {
          Quantite quantiteHeure = affiliationSupplementaire.getQuantiteInitiale();
          if (quantiteHeure != null) {
            resultat = resultat.add(quantiteHeure.getValeur());
          }
        }
      }
    }
    return new Quantite(resultat, uniteHeure);
  }
  
  protected Quantite determinerPlafondAffiliationMoisCivil()
  {
    Unite uniteHeure = Unite.getParCode("18");
    return new Quantite(new BigDecimal(260), uniteHeure);
  }
  
  protected PlafonnementAffiliation determinerCoefficientsPlafonnementMoisCivil(Periode p_moisCivil, Quantite p_cumulAffiliationBase, Quantite p_cumulAffiliationSupplementaire, Quantite p_plafond)
  {
    PlafonnementAffiliation plafonnementAffiliation = creerInstancePlafonnementAffiliation();
    plafonnementAffiliation.setMoisCivil(p_moisCivil);
    
    BigDecimal coefficientPlafonnementAffiliationBase = null;
    BigDecimal coefficientPlafonnementAffiliationSupplementaire = null;
    if (p_cumulAffiliationBase.compareTo(p_plafond) > 0)
    {
      coefficientPlafonnementAffiliationBase = new BigDecimal(p_plafond.getValeur().floatValue() / p_cumulAffiliationBase.getValeur().floatValue());
      
      coefficientPlafonnementAffiliationSupplementaire = new BigDecimal(0);
    }
    else
    {
      Quantite quantiteTotalHeureMoisCivil = p_cumulAffiliationBase.ajouter(p_cumulAffiliationSupplementaire);
      if (quantiteTotalHeureMoisCivil.compareTo(p_plafond) > 0)
      {
        BigDecimal plafondAffiliationSupplementaire = p_plafond.getValeur().subtract(p_cumulAffiliationBase.getValeur());
        
        coefficientPlafonnementAffiliationBase = new BigDecimal(1);
        coefficientPlafonnementAffiliationSupplementaire = new BigDecimal(plafondAffiliationSupplementaire.floatValue() / p_cumulAffiliationSupplementaire.getValeur().floatValue());
      }
      else
      {
        coefficientPlafonnementAffiliationBase = new BigDecimal(1);
        coefficientPlafonnementAffiliationSupplementaire = new BigDecimal(1);
      }
    }
    plafonnementAffiliation.setCoefficientReducteurAffiliation(coefficientPlafonnementAffiliationBase);
    plafonnementAffiliation.setCoefficientReducteurAffiliationSupplementaire(coefficientPlafonnementAffiliationSupplementaire);
    plafonnementAffiliation.setPlafondMensuel(p_plafond);
    
    return plafonnementAffiliation;
  }
  
  public List plafonnerPeriodesElementaires(Chronologie p_chronologiePeriodes, List p_listePlafonnement, ComportementAffiliationSpec p_comportement)
  {
    List resultat = new ArrayList();
    if (p_chronologiePeriodes != null)
    {
      Chronologie chronologiePeriodeAvecPlafonnement = determinerChronologiePeriodes(p_chronologiePeriodes, true);
      Chronologie chronologiePeriodeSansPlafonnement = determinerChronologiePeriodes(p_chronologiePeriodes, false);
      
      List listePeriodesElementaireAvecPlafonnement = p_comportement.getOutilTraitementPeriodeElementaire().recupererListPeriodeElementaire(chronologiePeriodeAvecPlafonnement);
      
      List listePeriodesElementaireSansPlafonnement = p_comportement.getOutilTraitementPeriodeElementaire().recupererListPeriodeElementaire(chronologiePeriodeSansPlafonnement);
      
      appliquerCoefficientSurPeriodesElementaires(listePeriodesElementaireAvecPlafonnement, p_listePlafonnement);
      
      resultat.addAll(listePeriodesElementaireAvecPlafonnement);
      resultat.addAll(listePeriodesElementaireSansPlafonnement);
    }
    return resultat;
  }
  
  protected void appliquerCoefficientSurPeriodesElementaires(List p_listePeriodeElementaires, List p_listePlafonnementAffiliation)
  {
    if ((p_listePlafonnementAffiliation != null) && (p_listePlafonnementAffiliation.size() > 0))
    {
      Iterator it = p_listePeriodeElementaires.iterator();
      while (it.hasNext())
      {
        PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
        if (periodeElementaire.getQuantiteInitialeHeure() != null)
        {
          PlafonnementAffiliation plafonnementAffiliation = trouverPlafonnementAffiliationPourPeriode(periodeElementaire.getPeriodePE(), p_listePlafonnementAffiliation);
          if (plafonnementAffiliation != null)
          {
            BigDecimal quantiteInitialeHeure = periodeElementaire.getQuantiteInitialeHeure().getValeur();
            BigDecimal quantitePlafonneeHeure = quantiteInitialeHeure.multiply(plafonnementAffiliation.getCoefficientReducteurAffiliation());
            
            periodeElementaire.setQuantitePlafonnee(new Quantite(quantitePlafonneeHeure, periodeElementaire.getQuantiteInitialeHeure().getUnite()));
          }
        }
      }
    }
  }
  
  protected PlafonnementAffiliation trouverPlafonnementAffiliationPourPeriode(Periode p_periode, List p_listePlafonnementAffiliation)
  {
    if (p_listePlafonnementAffiliation != null)
    {
      Iterator it = p_listePlafonnementAffiliation.iterator();
      while (it.hasNext())
      {
        PlafonnementAffiliation plafonnementAffiliation = (PlafonnementAffiliation)it.next();
        if (plafonnementAffiliation.getMoisCivil().contient(p_periode)) {
          return plafonnementAffiliation;
        }
      }
    }
    return null;
  }
  
  public List plafonnerAffiliationSupplementaire(Chronologie p_chronologiePeriodes, List p_listePlafonnement, ComportementAffiliationSpec p_comportement)
  {
    List resultat = new ArrayList();
    if (p_chronologiePeriodes != null)
    {
      Chronologie chronologiePeriodeAvecPlafonnement = determinerChronologiePeriodes(p_chronologiePeriodes, true);
      Chronologie chronologiePeriodeSansPlafonnement = determinerChronologiePeriodes(p_chronologiePeriodes, false);
      
      List listeAffiliationSupplementaireAvecPlafonnement = p_comportement.getOutilTraitementPeriodeElementaire().recupererListAffiliationSupplementaire(chronologiePeriodeAvecPlafonnement);
      
      List listeAffiliationSupplementaireSansPlafonnement = p_comportement.getOutilTraitementPeriodeElementaire().recupererListAffiliationSupplementaire(chronologiePeriodeSansPlafonnement);
      
      appliquerCoefficientSurAffiliationSupplementaire(listeAffiliationSupplementaireAvecPlafonnement, p_listePlafonnement);
      
      Iterator it = listeAffiliationSupplementaireSansPlafonnement.iterator();
      while (it.hasNext())
      {
        AffiliationSupplementaire affiliationSupplementaire = (AffiliationSupplementaire)it.next();
        affiliationSupplementaire.setQuantiteRetenue(affiliationSupplementaire.getQuantiteInitiale());
      }
      resultat.addAll(listeAffiliationSupplementaireAvecPlafonnement);
      resultat.addAll(listeAffiliationSupplementaireSansPlafonnement);
    }
    return resultat;
  }
  
  protected void appliquerCoefficientSurAffiliationSupplementaire(List p_listeAffiliationSupplementaire, List p_listePlafonnementAffiliation)
  {
    if ((p_listePlafonnementAffiliation != null) && (p_listePlafonnementAffiliation.size() > 0))
    {
      Iterator it = p_listeAffiliationSupplementaire.iterator();
      while (it.hasNext())
      {
        AffiliationSupplementaire affiliationSupplementaire = (AffiliationSupplementaire)it.next();
        
        PlafonnementAffiliation plafonnementAffiliation = trouverPlafonnementAffiliationPourPeriode(affiliationSupplementaire.getPeriodeAffiliationSupplementaire(), p_listePlafonnementAffiliation);
        if (plafonnementAffiliation != null)
        {
          BigDecimal quantiteInitialeHeure = affiliationSupplementaire.getQuantiteInitiale().getValeur();
          BigDecimal quantitePlafonneeHeure = quantiteInitialeHeure.multiply(plafonnementAffiliation.getCoefficientReducteurAffiliationSupplementaire());
          
          affiliationSupplementaire.setQuantiteRetenue(new Quantite(quantitePlafonneeHeure, affiliationSupplementaire.getQuantiteInitiale().getUnite()));
        }
        else
        {
          affiliationSupplementaire.setQuantiteRetenue(affiliationSupplementaire.getQuantiteInitiale());
        }
      }
    }
  }
  
  protected Chronologie determinerChronologiePeriodes(Chronologie p_chronologie, boolean p_participeAuPlafonnement)
  {
    FiltreTemporel filtre = null;
    if (p_participeAuPlafonnement) {
      filtre = m_filtreActiviteParticipantAuPlafonnement;
    } else {
      filtre = new FiltreNegation(m_filtreActiviteParticipantAuPlafonnement);
    }
    return p_chronologie.copier(filtre);
  }
  
  protected PlafonnementAffiliation creerInstancePlafonnementAffiliation()
  {
    return new PlafonnementAffiliation();
  }
}

/* Location:
 * Qualified Name:     OutilPlafonnementAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */