package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.competence;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ConteneurInfosEmployeurSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ResultatDeterminationCompetence;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDroitResultant;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ConventionGestion;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.RepriseSecteurPublicSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.ComparateurSurDateDeclenchementDemandeDecroissante;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateDeclenchementExamenAvantOuCoincideDateEtInclusParPriorite;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeSecteurPublicConventionGestion;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.ChronologiePeriodes;
import java.math.BigDecimal;
import java.util.List;
import java.util.ListIterator;

public class DeterminationCompetenceProduitResultant
{
  private static final int SP_RAC_SP_RAC = 1;
  private static final int SP_SP_SP_RAC = 2;
  private static final int SP_RAC_SP_SP = 3;
  private static final int SP_SP_SP_SP = 4;
  private static final int RAC_RAC_RAC_RAC = 5;
  private static final int SP_RAC_RAC_RAC = 6;
  private static final int SP_SP_RAC_RAC = 7;
  private static final int RAC_RAC_SP_RAC = 8;
  private static final int RAC_RAC_SP_SP = 9;
  
  public static DeterminationCompetenceProduitResultant getInstance()
  {
    return new DeterminationCompetenceProduitResultant();
  }
  
  public void determinerCompetencesProduitResultant(Demande demandeCourante, BigDecimal capitalCourant, BigDecimal capitalPrecedent, ResultatDeterminationCompetence resultatDeterminationCompetence)
    throws CoucheLogiqueException
  {
    CompetenceSpec competencePrecedent = null;
    
    int codeCompAdmCourante = resultatDeterminationCompetence.getCompetenceAdministrative();
    int codeCompFinanceCourante = resultatDeterminationCompetence.getCompetenceFinanciere();
    
    resultatDeterminationCompetence.setCompetenceAdministrativeDroitCourant(resultatDeterminationCompetence.getCompetenceAdministrative());
    resultatDeterminationCompetence.setCompetenceFinanciereDroitCourant(resultatDeterminationCompetence.getCompetenceFinanciere());
    String employeurPrecedent;
    int codeCompAdmPrecedente;
    int codeCompFinancePrecedente;
    String employeurPrecedent;
    if (demandeCourante.estEnContexteDroitAnterieurSecteurPublicValide())
    {
      int codeCompAdmPrecedente = 2;
      int codeCompFinancePrecedente = 2;
      employeurPrecedent = rechercherDerniereDemandePortantDroitSp(demandeCourante);
    }
    else
    {
      DossierExamenAssuranceSpec dossierExamenPrecedent = (DossierExamenAssuranceSpec)demandeCourante.getAttribution().getAttributionPrecedente().getDossierAffecte().getDossierExamen();
      
      codeCompAdmPrecedente = dossierExamenPrecedent.getCompetence().getCompetenceAdministrative();
      codeCompFinancePrecedente = dossierExamenPrecedent.getCompetence().getCompetenceFinanciere();
      competencePrecedent = dossierExamenPrecedent.getCompetence();
      employeurPrecedent = competencePrecedent.getLibelleEmployeurCompetent();
    }
    JustificationDroitResultant justif = null;
    if (((DossierExamen)demandeCourante.getDossierExamen()).getConstitutionProduitResultant() != null) {
      justif = ((DossierExamen)demandeCourante.getDossierExamen()).getConstitutionProduitResultant().getJustificationDroitResultant();
    }
    if (justif != null)
    {
      justif.setCompetenceFinanciereDroitCourant(resultatDeterminationCompetence.getCompetenceFinanciereDroitCourant());
      justif.setCompetenceFinanciereDroitPrecedent(codeCompFinancePrecedente);
    }
    int combinaisonCompetence = determinationCombinaisonCompetenceAdmFinance(codeCompFinancePrecedente, codeCompAdmPrecedente, codeCompFinanceCourante, codeCompAdmCourante);
    
    determinationCompetences(competencePrecedent, employeurPrecedent, combinaisonCompetence, resultatDeterminationCompetence, capitalCourant, capitalPrecedent, demandeCourante);
    if (justif != null) {
      justif.setCompetenceFinanciereDroitRetenu(resultatDeterminationCompetence.getCompetenceFinanciere());
    }
  }
  
  private void determinationCompetences(CompetenceSpec competencePrecedent, String employeurPrecedent, int combinaisonCompetence, ResultatDeterminationCompetence resultatDeterminationCompetence, BigDecimal capitalCourant, BigDecimal capitalPrecedent, Demande demandeCourante)
    throws CoucheLogiqueException
  {
    ConventionGestionSpec conventionGestion = new ConventionGestion("", "", false, false, false, false, false, "", false, null, null, null, false);
    if ((competencePrecedent != null) && (competencePrecedent.getConventionGestion() != null)) {
      conventionGestion = competencePrecedent.getConventionGestion();
    }
    switch (combinaisonCompetence)
    {
    case 9: 
      if (capitalPrecedent.compareTo(capitalCourant) > 0)
      {
        resultatDeterminationCompetence.setCompetenceAdministrative(1);
        resultatDeterminationCompetence.setCompetenceFinanciere(1);
        resultatDeterminationCompetence.setLibelleEmployeurCompetent("");
        resultatDeterminationCompetence.setEstPCRCForce(false);
      }
      break;
    case 5: 
      break;
    case 8: 
      if (capitalPrecedent.compareTo(capitalCourant) > 0)
      {
        resultatDeterminationCompetence.setCompetenceAdministrative(1);
        resultatDeterminationCompetence.setCompetenceFinanciere(1);
        OutilDeterminationCompetence.alimenterConventionGestion(resultatDeterminationCompetence, recupererConventionGestionVide());
        resultatDeterminationCompetence.setLibelleEmployeurCompetent("");
      }
      break;
    case 1: 
      if (capitalPrecedent.compareTo(capitalCourant) > 0)
      {
        OutilDeterminationCompetence.alimenterConventionGestion(resultatDeterminationCompetence, conventionGestion);
        resultatDeterminationCompetence.setLibelleEmployeurCompetent(employeurPrecedent);
        
        resultatDeterminationCompetence.setIdExterneEmployeurSp(competencePrecedent.getIdExterneEmployeurSp());
      }
      break;
    case 3: 
      if (capitalPrecedent.compareTo(capitalCourant) > 0)
      {
        resultatDeterminationCompetence.setCompetenceAdministrative(1);
        resultatDeterminationCompetence.setCompetenceFinanciere(2);
        OutilDeterminationCompetence.alimenterConventionGestion(resultatDeterminationCompetence, conventionGestion);
        resultatDeterminationCompetence.setLibelleEmployeurCompetent(employeurPrecedent);
        
        resultatDeterminationCompetence.setIdExterneEmployeurSp(competencePrecedent.getIdExterneEmployeurSp());
        resultatDeterminationCompetence.setEstPCRCForce(false);
      }
      break;
    case 6: 
      if (capitalPrecedent.compareTo(capitalCourant) > 0)
      {
        resultatDeterminationCompetence.setCompetenceAdministrative(1);
        resultatDeterminationCompetence.setCompetenceFinanciere(2);
        OutilDeterminationCompetence.alimenterConventionGestion(resultatDeterminationCompetence, conventionGestion);
        resultatDeterminationCompetence.setLibelleEmployeurCompetent(employeurPrecedent);
        
        resultatDeterminationCompetence.setIdExterneEmployeurSp(competencePrecedent.getIdExterneEmployeurSp());
      }
      break;
    case 7: 
      if (capitalPrecedent.compareTo(capitalCourant) > 0)
      {
        resultatDeterminationCompetence.setCompetenceAdministrative(2);
        resultatDeterminationCompetence.setCompetenceFinanciere(2);
        resultatDeterminationCompetence.setEstPCRCForce(demandeCourante.getDonneesTemporaires().isEstPCRCForceDroitPrecedent());
      }
      break;
    case 2: 
      if (capitalPrecedent.compareTo(capitalCourant) > 0)
      {
        resultatDeterminationCompetence.setCompetenceAdministrative(2);
        resultatDeterminationCompetence.setCompetenceFinanciere(2);
        OutilDeterminationCompetence.alimenterConventionGestion(resultatDeterminationCompetence, recupererConventionGestionVide());
        resultatDeterminationCompetence.setLibelleEmployeurCompetent(employeurPrecedent);
        resultatDeterminationCompetence.setEstPCRCForce(demandeCourante.getDonneesTemporaires().isEstPCRCForceDroitPrecedent());
      }
      break;
    case 4: 
      if (capitalPrecedent.compareTo(capitalCourant) > 0)
      {
        resultatDeterminationCompetence.setLibelleEmployeurCompetent(employeurPrecedent);
        resultatDeterminationCompetence.setEstPCRCForce(demandeCourante.getDonneesTemporaires().isEstPCRCForceDroitPrecedent());
      }
      break;
    }
  }
  
  private static ConventionGestionSpec recupererConventionGestionVide()
  {
    return new ConventionGestion("", "", false, false, false, false, false, "", false, null, null, null, false);
  }
  
  private int determinationCombinaisonCompetenceAdmFinance(int codeCompFinancePrecedente, int codeCompAdmPrecedente, int codeCompFinanceCourante, int codeCompAdmCourante)
  {
    int combinaisonCompetences = 0;
    if ((estCompRAC(codeCompFinancePrecedente)) && (estCompRAC(codeCompAdmPrecedente)) && (estCompSP(codeCompFinanceCourante)) && (estCompRAC(codeCompAdmCourante))) {
      combinaisonCompetences = 8;
    } else if ((estCompRAC(codeCompFinancePrecedente)) && (estCompRAC(codeCompAdmPrecedente)) && (estCompSP(codeCompFinanceCourante)) && (estCompSP(codeCompAdmCourante))) {
      combinaisonCompetences = 9;
    } else if ((estCompRAC(codeCompFinancePrecedente)) && (estCompRAC(codeCompAdmPrecedente)) && (estCompRAC(codeCompFinanceCourante)) && (estCompRAC(codeCompAdmCourante))) {
      combinaisonCompetences = 5;
    } else if ((estCompSP(codeCompFinancePrecedente)) && (estCompRAC(codeCompAdmPrecedente)) && (estCompSP(codeCompFinanceCourante)) && (estCompRAC(codeCompAdmCourante))) {
      combinaisonCompetences = 1;
    } else if ((estCompSP(codeCompFinancePrecedente)) && (estCompRAC(codeCompAdmPrecedente)) && (estCompSP(codeCompFinanceCourante)) && (estCompSP(codeCompAdmCourante))) {
      combinaisonCompetences = 3;
    } else if ((estCompSP(codeCompFinancePrecedente)) && (estCompRAC(codeCompAdmPrecedente)) && (estCompRAC(codeCompFinanceCourante)) && (estCompRAC(codeCompAdmCourante))) {
      combinaisonCompetences = 6;
    } else if ((estCompSP(codeCompFinancePrecedente)) && (estCompSP(codeCompAdmPrecedente)) && (estCompSP(codeCompFinanceCourante)) && (estCompRAC(codeCompAdmCourante))) {
      combinaisonCompetences = 2;
    } else if ((estCompSP(codeCompFinancePrecedente)) && (estCompSP(codeCompAdmPrecedente)) && (estCompSP(codeCompFinanceCourante)) && (estCompSP(codeCompAdmCourante))) {
      combinaisonCompetences = 4;
    } else if ((estCompSP(codeCompFinancePrecedente)) && (estCompSP(codeCompAdmPrecedente)) && (estCompRAC(codeCompFinanceCourante)) && (estCompRAC(codeCompAdmCourante))) {
      combinaisonCompetences = 7;
    }
    return combinaisonCompetences;
  }
  
  private boolean estCompSP(int competence)
  {
    return competence == 2;
  }
  
  private boolean estCompRAC(int competence)
  {
    return competence == 1;
  }
  
  public void determinerCompetenceAdministrativeProduitResultant(Demande demande, ResultatDeterminationCompetence resultatDeterminationCompetence)
    throws CoucheLogiqueException
  {
    if (resultatDeterminationCompetence.getCompetenceFinanciere() == 1)
    {
      resultatDeterminationCompetence.setCompetenceAdministrative(1);
    }
    else
    {
      ChronologiePeriodes chronoPeriodesActiviteEmployeurCompetent = resultatDeterminationCompetence.getConteneurInfosEmployeur().getChronoEmployeur();
      ChronologiePeriodes chronoPeriodesActiviteSecteurPublicConventionGestion = (ChronologiePeriodes)chronoPeriodesActiviteEmployeurCompetent.copier(new FiltrePeriodeActiviteSalarieeSecteurPublicConventionGestion());
      if ((chronoPeriodesActiviteSecteurPublicConventionGestion != null) && (!chronoPeriodesActiviteSecteurPublicConventionGestion.estVide())) {
        resultatDeterminationCompetence.setCompetenceAdministrative(1);
      } else {
        resultatDeterminationCompetence.setCompetenceAdministrative(2);
      }
    }
  }
  
  public static String rechercherDerniereDemandePortantDroitSp(DemandeAssuranceSpec demande)
  {
    String employeurPrecedent = "";
    
    ChronologieDebuts chronoDemandesAssurancePrecedentes = (ChronologieDebuts)demande.getDemandeur().getChronoDemandeAssurance().copier(new FiltreDateDeclenchementExamenAvantOuCoincideDateEtInclusParPriorite(demande.getDateRecherche(), demande));
    if (!chronoDemandesAssurancePrecedentes.estVide())
    {
      chronoDemandesAssurancePrecedentes.supprimer(demande);
      
      chronoDemandesAssurancePrecedentes.setComparateur(new ComparateurSurDateDeclenchementDemandeDecroissante());
      ListIterator<?> it = chronoDemandesAssurancePrecedentes.iterer();
      while ((it.hasNext()) && ("".equals(employeurPrecedent)))
      {
        Demande courante = (Demande)it.next();
        AttributionAssuranceSpec attribution = demande.getAttribution();
        ProduitAsuSpec produit = (ProduitAsuSpec)attribution.getProduit();
        if ((courante.estDecisionnee()) && (!courante.getListeDossiersExamen().isEmpty()) && (((courante.getListeDossiersExamen().get(0) instanceof AttributionSpec)) || ((courante.getListeDossiersExamen().get(0) instanceof RepriseSecteurPublicSpec))) && (!produit.estCompetenceAdministrativeRac(attribution)))
        {
          DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)courante.getAttribution().getDossierAffecte().getDossierExamen();
          CompetenceSpec competence = dossierExamen.getCompetence();
          employeurPrecedent = competence.getLibelleEmployeurCompetent();
        }
        else if (courante.estClasseeEnCompetenceSecteurPublic())
        {
          employeurPrecedent = courante.getDonneesTemporaires().getEmployeurSecteurPublicCompetent();
        }
      }
    }
    return employeurPrecedent;
  }
}

/* Location:
 * Qualified Name:     DeterminationCompetenceProduitResultant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */