package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.dureeReglementaire.asp;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatDeterminationDureePostPrime;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.affectation.ProduitInrPar09P01Spec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreAttributionSurDecisions;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.math.RoundingMode;

public final class DeterminationDureeReglementaire
{
  public static ResultatDeterminationDureePostPrime determinerDureeReglementairePostPrime(Demande demande)
    throws ApplicativeException
  {
    ResultatDeterminationDureePostPrime resultat = new ResultatDeterminationDureePostPrime();
    boolean estContextePostPrime = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ASPPOSTPRI");
    
    boolean estContexteEnCoursCsp = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP");
    if ((estContexteEnCoursCsp) && (estContextePostPrime)) {
      determinerDureePostPrimeEnCspSuitePrime(demande, resultat);
    } else if (estContexteEnCoursCsp) {
      determinerDureePostPrimeEnCoursCsp(demande, resultat);
    }
    return resultat;
  }
  
  private static void determinerDureePostPrimeEnCspSuitePrime(Demande demande, ResultatDeterminationDureePostPrime resultat)
    throws ApplicativeException
  {
    Damj dateRepriseCspPostPrime = demande.getDateExamen();
    AttributionAssuranceSpec attributionAssurance = (AttributionAssuranceSpec)demande.getDossierExamen();
    Damj dateFinCsp = attributionAssurance.getDateLimiteIndemnisation();
    
    Periode periodeRepriseCsp = new Periode(dateRepriseCspPostPrime, dateFinCsp);
    
    int dureePeriodeCsp = periodeRepriseCsp.getDuree();
    
    BigDecimal dureeVerseeBigDecimal = calculDureeImputationSurPostPrime(demande, dateRepriseCspPostPrime);
    
    int dureePostPrime = dureePeriodeCsp - dureeVerseeBigDecimal.intValue();
    if (dureePostPrime < 0) {
      dureePostPrime = 0;
    }
    Quantite dureePostPrimeQuantite = new Quantite(dureePostPrime, DureeReglementaire.UNITE_DEFAUT);
    resultat.setDureePostPrime(dureePostPrimeQuantite);
    resultat.setDureeImputationPostPrime(Integer.valueOf(dureeVerseeBigDecimal.intValue()));
  }
  
  private static BigDecimal calculDureeImputationSurPostPrime(Demande demande, Damj dateRepriseCspPostPrime)
    throws ApplicativeException
  {
    BigDecimal dureeImputation = demande.getDonneesTemporaires().getDureeImputation();
    if (dureeImputation == null)
    {
      FiltreET filtrePrimeAttribuee = new FiltreET();
      filtrePrimeAttribuee.ajouterFiltre(new FiltreAttributionSurDecisions());
      filtrePrimeAttribuee.ajouterFiltre(new FiltreDemandePourERE("INR_04"));
      AttributionSpec dernierePrimeAttribuee = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesSansCourante(), demande, filtrePrimeAttribuee);
      
      ProduitInrPar09P01Spec produitPrime = (ProduitInrPar09P01Spec)dernierePrimeAttribuee.getProduit();
      
      BigDecimal montantAsp = produitPrime.recupererMontantAsp(dernierePrimeAttribuee.getDemande());
      ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(dernierePrimeAttribuee, dateRepriseCspPostPrime.veille(), true, true);
      
      Quantite capitalVerse = resultatCalcul.getCapitalVerse();
      if (capitalVerse == null) {
        capitalVerse = new Quantite(0, DureeReglementaire.UNITE_DEFAUT);
      }
      dureeImputation = capitalVerse.getValeur().divide(montantAsp, RoundingMode.FLOOR);
    }
    return dureeImputation;
  }
  
  private static void determinerDureePostPrimeEnCoursCsp(Demande demande, ResultatDeterminationDureePostPrime resultat)
    throws ApplicativeException
  {
    Quantite dureePostPrime = demande.getReliquat().getDureePostPrime();
    if (dureePostPrime != null)
    {
      BigDecimal bd = dureePostPrime.getValeur().setScale(0);
      dureePostPrime = new Quantite(bd, dureePostPrime.getUnite());
    }
    resultat.setDureePostPrime(dureePostPrime);
  }
}

/* Location:
 * Qualified Name:     DeterminationDureeReglementaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */