package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieDelaiAttenteSpec;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ResultatDeterminationDelaisReports;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CarenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P05;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P06;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionAssurance;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreAttributionAssuranceAvecDiffere;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieFinApresDate;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieFinAvantDate;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class StrategieDelaiAttenteApresARE14
  implements StrategieDelaiAttenteSpec
{
  private static final int DOUZE_MOIS = 12;
  private static final int DELAI_SEPT_JOURS = 7;
  
  public boolean determinerApplicabiliteDelaiAttente(DemandeAssuranceSpec demande, ResultatDeterminationDelaisReports resultat)
    throws ApplicativeException
  {
    boolean creationDelaiAttente = false;
    
    DecisionSpec decisionPrecedente = OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesSansCourante(), demande, null);
    if (decisionPrecedente == null)
    {
      creationDelaiAttente = true;
    }
    else if (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "ARESJASPDC"))
    {
      DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
      Attribution attributionCourante = (Attribution)dossierExamenCourant;
      if (!verifierPresenceReliquatDelaiAttente(attributionCourante))
      {
        boolean estAreEnCoursCSP = OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "ARECOURCSP");
        
        boolean estAreSuiteSortieASPARE = OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "POSTCSPARE");
        
        boolean estAreSuiteSortieASPDC = OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "POSTCSPDC");
        
        boolean estContexteAreCsp = estContexteAreCsp(estAreEnCoursCSP, estAreSuiteSortieASPARE, estAreSuiteSortieASPDC);
        
        Damj dateDebutTheoriqueDelaiAttente = null;
        
        ResultatExecutionCalculSpec resultatAvantCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionCourante, null, false);
        
        dateDebutTheoriqueDelaiAttente = resultatAvantCalcul.getPji();
        Periode periodeDifferePrecedent = rechercherPeriodeDifferePrecedent(demande);
        Damj termeDifferePrecedent = null;
        if (periodeDifferePrecedent != null)
        {
          Damj debutEffectifDelaiAttributionPrecedente = periodeDifferePrecedent.getDebut();
          resultat.setDateDebutDernierDelaiAttente(debutEffectifDelaiAttributionPrecedente);
          termeDifferePrecedent = periodeDifferePrecedent.getFin();
          
          Damj termePeriode = dateDebutTheoriqueDelaiAttente;
          DureeCalendaire duree12Mois = new DureeCalendaire(0, 12, 0);
          Periode periode12MoisSurOdCourante = CalculDelais.determinerDelai(termePeriode, duree12Mois);
          if (debutEffectifDelaiAttributionPrecedente.estAvantOuCoincideAvec(periode12MoisSurOdCourante.getDebut())) {
            creationDelaiAttente = true;
          }
        }
        else
        {
          if (estContexteAreCsp) {
            termeDifferePrecedent = Damj.NUIT_DES_TEMPS;
          }
          creationDelaiAttente = true;
        }
        if ((creationDelaiAttente) && ((attributionCourante.estType(RepriseSpec.class)) || (estContexteAreCsp))) {
          creationDelaiAttente = estCreationDelaiAttenteReprise(demande, termeDifferePrecedent, estAreEnCoursCSP, estAreSuiteSortieASPARE, estAreSuiteSortieASPDC);
        }
      }
    }
    return creationDelaiAttente;
  }
  
  private boolean estContexteAreCsp(boolean estAreEnCoursCSP, boolean estAreSuiteSortieASPARE, boolean estAreSuiteSortieASPDC)
  {
    return (estAreEnCoursCSP) || (estAreSuiteSortieASPARE) || (estAreSuiteSortieASPDC);
  }
  
  protected boolean estCreationDelaiAttenteReprise(DemandeAssuranceSpec demande, Damj terme, boolean estAreEnCoursCSP, boolean estAreSuiteSortieASPARE, boolean estAreSuiteSortieASPDC)
  {
    boolean creationDelaiAttente = true;
    Damj termeDifferePrecedent = terme;
    if (termeDifferePrecedent != null)
    {
      if ((estAreEnCoursCSP) || (estAreSuiteSortieASPARE)) {
        termeDifferePrecedent = Damj.max(termeDifferePrecedent, OutilAsp.getInstance().recupererAeCspPourEntreeEnDispositifCSP(demande.getDemandeur(), demande.getDateExamen()).getDateFin());
      } else if (estAreSuiteSortieASPDC) {
        termeDifferePrecedent = Damj.max(termeDifferePrecedent, OutilAsp.getInstance().determinerDateFinDernierDispositifCSP(demande.getDemandeur(), demande.getDateExamen()));
      }
      DecisionSpec decision = (DecisionSpec)demande.getDossierExamen();
      Damj dateReprise = decision.getDateEffetDecision();
      ChronologiePeriodes passeProfessionnel = demande.getDemandeur().getChronoPeriodePasseProfessionnel();
      FiltresTemporel filtreEt = new FiltresTemporel();
      FiltreTemporel filtreAvant = new FiltreActiviteSalarieFinAvantDate(dateReprise);
      FiltreTemporel filtreApres = new FiltreActiviteSalarieFinApresDate(termeDifferePrecedent);
      filtreEt.ajouterFiltre(filtreAvant);
      filtreEt.ajouterFiltre(filtreApres);
      Chronologie listeFinDeContrat = passeProfessionnel.copier(filtreEt);
      if ((listeFinDeContrat != null) && (!listeFinDeContrat.estVide())) {
        creationDelaiAttente = true;
      } else {
        creationDelaiAttente = false;
      }
    }
    return creationDelaiAttente;
  }
  
  private boolean verifierPresenceReliquatDelaiAttente(Attribution attributionCourante)
  {
    boolean presenceReliquatDelaiAttente = false;
    Collection<CarencePrefixeAFixer> listeCarences = attributionCourante.getListeCarences();
    if (listeCarences != null)
    {
      Iterator<CarencePrefixeAFixer> it = listeCarences.iterator();
      while (it.hasNext())
      {
        CarencePrefixeAFixer carence = (CarencePrefixeAFixer)it.next();
        if ("Différé".equals(carence.getTypeCarence())) {
          presenceReliquatDelaiAttente = true;
        }
      }
    }
    return presenceReliquatDelaiAttente;
  }
  
  private Periode rechercherPeriodeDifferePrecedent(DemandeAssuranceSpec demande)
    throws ApplicativeException
  {
    Periode applicationCarence = null;
    FiltreET filtreAttributionAssuranceAvecDiffere = new FiltreET();
    filtreAttributionAssuranceAvecDiffere.ajouterFiltre(new FiltreAttributionAssurance(true, true, false, false, null));
    filtreAttributionAssuranceAvecDiffere.ajouterFiltre(new FiltreAttributionAssuranceAvecDiffere());
    
    AttributionAssuranceSpec attributionPrecedenteAvecDiffere = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreAttributionAssuranceAvecDiffere);
    Iterator<CarenceSpec> iterator;
    if (attributionPrecedenteAvecDiffere != null)
    {
      leverBlocageAntecedentOuPoursuite(attributionPrecedenteAvecDiffere);
      
      demande.getDemandeur().desactiverChronoPasseProPourLiquidationRevision();
      
      ResultatExecutionCalculSpec resultatAvantCalculAttributionPrecedente = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionPrecedenteAvecDiffere, demande.getDateExamen().veille(), true);
      
      demande.getDemandeur().reactiverChronoPasseProPourLiquidationRevision();
      if ((ProduitAsuSpe02P05.getInstance().getNomUnique().equals(attributionPrecedenteAvecDiffere.getProduit().getNomUnique())) || (ProduitAsuSpe02P06.getInstance().getNomUnique().equals(attributionPrecedenteAvecDiffere.getProduit().getNomUnique())))
      {
        applicationCarence = retournerPeriodeApplicationCarenceSpectacle(resultatAvantCalculAttributionPrecedente);
      }
      else
      {
        if (!attributionPrecedenteAvecDiffere.isUnJourDiffereConsomme()) {
          return null;
        }
        if (resultatAvantCalculAttributionPrecedente != null)
        {
          List<CarenceSpec> listeCarencesAttributionPrecedente = resultatAvantCalculAttributionPrecedente.getListeCarencesEffectives();
          for (iterator = listeCarencesAttributionPrecedente.iterator(); iterator.hasNext();)
          {
            CarenceSpec carence = (CarenceSpec)iterator.next();
            if (("Différé".equals(carence.getTypeCarence())) || ("5".equals(carence.getTypeCarence())))
            {
              applicationCarence = carence.getPeriodeApplicationCarence();
              break;
            }
          }
        }
      }
    }
    return applicationCarence;
  }
  
  protected Periode retournerPeriodeApplicationCarenceSpectacle(ResultatExecutionCalculSpec resultatCalculAttributionPrecedente)
  {
    Periode applicationCarence = null;
    boolean reliquatNonNull = (resultatCalculAttributionPrecedente != null) && (resultatCalculAttributionPrecedente.getReliquatDelaiAttente() != null);
    if ((reliquatNonNull) && (resultatCalculAttributionPrecedente.getReliquatDelaiAttente().getValeur().intValue() < 7)) {
      applicationCarence = resultatCalculAttributionPrecedente.getPeriodeApplicationDelaiAttente();
    }
    return applicationCarence;
  }
  
  private void leverBlocageAntecedentOuPoursuite(AttributionAssuranceSpec attributionPrecedenteAvecDiffere)
    throws ApplicativeException
  {
    if ((attributionPrecedenteAvecDiffere.getNatureDecision() == 38) || (attributionPrecedenteAvecDiffere.getNatureDecision() == 39)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ERR_FORCAGE_DIFFERE_ANTECEDENT");
    }
  }
  
  public void alimenterListeCarencesForcees(DemandeAssuranceSpec demande, Collection<CarencePrefixeAFixer> collectionCarences)
  {
    Iterator<CarencePrefixeAFixer> i;
    if (collectionCarences != null) {
      for (i = collectionCarences.iterator(); i.hasNext();)
      {
        CarencePrefixeAFixer delaiReportCourant = (CarencePrefixeAFixer)i.next();
        ((Attribution)demande.getAttribution()).ajouterCarencesForcees(delaiReportCourant);
      }
    }
  }
  
  public void supprimerListeCarencesForcees(DemandeAssuranceSpec demande)
  {
    ((Attribution)demande.getAttribution()).supprimerCarencesForcees();
  }
  
  public Quantite calculerReliquatDiffere(Damj dateAttribution, Damj pjiAttributionPrecedente, Damj dernierJourApplicationDiffere, Quantite reliquatInitial, CarencePrefixeAFixer delaiReportAttributionPrecedente)
  {
    Quantite reliquatCalcule = null;
    int reliquatARetenirALaDateAttribution = reliquatInitial.getValeur().intValue() - dateAttribution.veille().joursEntre(dernierJourApplicationDiffere);
    if (reliquatARetenirALaDateAttribution > 0) {
      reliquatCalcule = new QuantiteJour(new BigDecimal(reliquatARetenirALaDateAttribution));
    }
    return reliquatCalcule;
  }
}

/* Location:
 * Qualified Name:     StrategieDelaiAttenteApresARE14
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */