package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilJustificationSjrSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDiviseur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComplementairesDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeMemeReglement;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public abstract class StrategieDeterminationDiviseurSjrA3A4A5Abstrait
  extends StrategieDeterminationDiviseurSjrAbstrait
{
  private static final BigDecimal DENOMINATEUR_DROIT_CONGES = new BigDecimal("52");
  
  protected boolean estAbsenceDeductible()
  {
    return true;
  }
  
  protected Chronologie determinerChronoActivitePourAbsence(DonneesEntreeComplementairesDeterminationSjrSpec donneesEntreeComplementaires)
  {
    FiltrePeriodesSurFiltresExclusifs listeFiltresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    listeFiltresExclusifs.ajouterFiltre(new FiltrePeriodeActiviteSalarieeMemeReglement("RG"));
    listeFiltresExclusifs.ajouterFiltre(new FiltrePeriodeActiviteSalarieeMemeReglement("A1"));
    listeFiltresExclusifs.ajouterFiltre(new FiltrePeriodeActiviteSalarieeMemeReglement("A2a"));
    return donneesEntreeComplementaires.getChronologieActiviteSalariePrc().copier(listeFiltresExclusifs);
  }
  
  public void determinerDiviseur(DonneesEntreeDeterminationSjrSpec donneesEntree, DonneesResultatDeterminationSjr donneesResultat)
    throws CoucheLogiqueException
  {
    Prc resultatPrc = donneesResultat.getPrc();
    
    determinerDureePrc(resultatPrc, donneesEntree.getDonneesEntreeProduit());
    BigDecimal resultatDureePrc = new BigDecimal(resultatPrc.getDureePrc().intValue());
    
    calculerNombreJourDeductible(donneesEntree, donneesResultat);
    
    BigDecimal resultatDiviseur = determinerDiviseurSpecifique(donneesEntree, donneesResultat, resultatDureePrc);
    
    donneesResultat.getPrc().setDiviseur(resultatDiviseur);
  }
  
  private void calculerNombreJourDeductible(DonneesEntreeDeterminationSjrSpec donneesEntree, DonneesResultatDeterminationSjr donneesResultat)
    throws CoucheLogiqueException
  {
    DonneesEntreeComplementairesDeterminationSjrSpec donneesEntreeComplementaires = donneesEntree.getDonneesEntreeComplementaires();
    
    OutilJustificationSjrSpec outilJustificationSjr = recupererOutilJustificationSjr(donneesEntree.getDonneesEntreeComportement());
    JustificationDiviseur resultatJustificationDiviseur = donneesResultat.getJustificationSjr().getJustificationDiviseur();
    
    Prc resultatPrc = donneesResultat.getPrc();
    
    Chronologie chronoPeriodesDeductibles = donneesEntreeComplementaires.getChronologiePeriodeDeductiblePrc();
    
    int cumulJoursDeductibles = 0;
    if (chronoPeriodesDeductibles.getTaille() > 0)
    {
      ChronologiePeriodes chronoPeriodesDeductiblesSansChevauchement;
      ChronologiePeriodes chronoPeriodesDeductiblesSansChevauchement;
      if (chronoPeriodesDeductibles.contientChevauchementElements()) {
        chronoPeriodesDeductiblesSansChevauchement = ((ChronologiePeriodes)chronoPeriodesDeductibles).fusionnerChevauchementPeriodes();
      } else {
        chronoPeriodesDeductiblesSansChevauchement = (ChronologiePeriodes)chronoPeriodesDeductibles;
      }
      cumulJoursDeductibles = resultatPrc.inter(chronoPeriodesDeductiblesSansChevauchement);
      if (outilJustificationSjr != null)
      {
        chronoPeriodesDeductibles.iterer();
        while (chronoPeriodesDeductibles.encoreSuivant())
        {
          ObjetChronoPeriode periodeDeductibleCourante = (ObjetChronoPeriode)chronoPeriodesDeductibles.elementSuivant();
          Periode periodeCourante = new Periode(periodeDeductibleCourante.getDateDebut(), periodeDeductibleCourante.getDateFin());
          
          int nombreJoursDeductiblesPrc = resultatPrc.inter(periodeCourante);
          
          outilJustificationSjr.justifierDiviseurPeriodeParticipanteJoursDeductibles(resultatJustificationDiviseur, periodeCourante, periodeDeductibleCourante, nombreJoursDeductiblesPrc);
        }
      }
    }
    BigDecimal cumulJoursAbsenceDeductibles = calculerNombreJourAbsence(donneesEntree, donneesResultat);
    if ((cumulJoursAbsenceDeductibles != null) && (cumulJoursAbsenceDeductibles.compareTo(BigDecimal.ZERO) > 0)) {
      cumulJoursDeductibles += cumulJoursAbsenceDeductibles.intValue();
    }
    resultatPrc.setNombreJourDeductible(Integer.valueOf(cumulJoursDeductibles));
  }
  
  protected abstract BigDecimal determinerDiviseurSpecifique(DonneesEntreeDeterminationSjrSpec paramDonneesEntreeDeterminationSjrSpec, DonneesResultatDeterminationSjr paramDonneesResultatDeterminationSjr, BigDecimal paramBigDecimal)
    throws CoucheLogiqueException;
  
  protected BigDecimal calculerNombreHeuresActiviteDansPrc(Chronologie chronoActivites, Prc prc, Reglement reglementApplicable, OutilJustificationSjrSpec outilJustificationSjr, JustificationDiviseur resultatJustificationDiviseur, boolean premiereJustificationHeures)
  {
    BigDecimal cumulHeuresActiviteDansPrc = BigDecimal.ZERO;
    
    chronoActivites.iterer();
    while (chronoActivites.encoreSuivant())
    {
      ActiviteSalarie periodeActiviteSalarieCourante = (ActiviteSalarie)chronoActivites.elementSuivant();
      BigDecimal nombreHeuresJustifieesParActivite = BigDecimal.ZERO;
      
      Chronologie chronoPeriodeMesureActiviteCourante = periodeActiviteSalarieCourante.getListePeriodesMesureActivite();
      chronoPeriodeMesureActiviteCourante.iterer();
      while (chronoPeriodeMesureActiviteCourante.encoreSuivant())
      {
        PeriodeMesureActivite periodeMesureActiviteCourante = (PeriodeMesureActivite)chronoPeriodeMesureActiviteCourante.elementSuivant();
        
        Quantite quantiteAffiliationCourante = periodeMesureActiviteCourante.getQuantiteAffiliation(Unite.get("heure de travail"));
        if (quantiteAffiliationCourante != null)
        {
          Periode periodeCourante = new Periode(periodeMesureActiviteCourante.getDateDebut(), periodeMesureActiviteCourante.getDateFin());
          BigDecimal nominateur1 = new BigDecimal(String.valueOf(prc.inter(periodeCourante)));
          BigDecimal nominateur2 = quantiteAffiliationCourante.getValeur();
          BigDecimal denominateur = new BigDecimal(String.valueOf(periodeCourante.getDuree()));
          BigDecimal nombreHeuresProratiseSurPrc = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
          
          cumulHeuresActiviteDansPrc = cumulHeuresActiviteDansPrc.add(nombreHeuresProratiseSurPrc);
          
          nombreHeuresJustifieesParActivite = nombreHeuresJustifieesParActivite.add(nombreHeuresProratiseSurPrc);
        }
      }
      if ((premiereJustificationHeures) && (nombreHeuresJustifieesParActivite.compareTo(BigDecimal.ZERO) > 0) && (outilJustificationSjr != null)) {
        outilJustificationSjr.justifierDiviseurPeriodeParticipanteHeures(resultatJustificationDiviseur, reglementApplicable, periodeActiviteSalarieCourante, nombreHeuresJustifieesParActivite.intValue());
      }
    }
    return Mathematiques.tronque(cumulHeuresActiviteDansPrc, 0);
  }
  
  protected void calculerDroitCongesA4ouA5(DonneesEntreeDeterminationSjrSpec donneesEntree, DonneesResultatDeterminationSjr donneesResultat)
  {
    calculerNombreHeuresA4ouA5(donneesEntree, donneesResultat);
    
    Prc resultatPrc = donneesResultat.getPrc();
    resultatPrc.setDroitCongesA4ouA5(Mathematiques.tronque(Mathematiques.diviseParDefaut(resultatPrc.getNombreHeuresA4ouA5(), DENOMINATEUR_DROIT_CONGES), 0));
  }
  
  private void calculerNombreHeuresA4ouA5(DonneesEntreeDeterminationSjrSpec donneesEntree, DonneesResultatDeterminationSjr donneesResultat)
  {
    int nombreHeuresA4ouA5ActiviteDansPrc = 0;
    
    OutilJustificationSjrSpec outilJustificationSjr = recupererOutilJustificationSjr(donneesEntree.getDonneesEntreeComportement());
    JustificationDiviseur resultatJustificationDiviseur = donneesResultat.getJustificationSjr().getJustificationDiviseur();
    
    Prc resultatPrc = donneesResultat.getPrc();
    Reglement reglementApplicable = donneesEntree.getDonneesEntreeDemande().getReglementApplicable();
    
    Chronologie chronoActiviteSalariePrc = donneesEntree.getDonneesEntreeComplementaires().getChronologieActiviteSalariePrc();
    FiltrePeriodesSurFiltresExclusifs listeFiltresA4OuA5 = new FiltrePeriodesSurFiltresExclusifs();
    listeFiltresA4OuA5.ajouterFiltre(new FiltrePeriodeActiviteSalarieeMemeReglement("A4"));
    listeFiltresA4OuA5.ajouterFiltre(new FiltrePeriodeActiviteSalarieeMemeReglement("A5"));
    Chronologie chronoActivitesA4OuA5ChevauchantPrc = chronoActiviteSalariePrc.copier(listeFiltresA4OuA5);
    if (!chronoActivitesA4OuA5ChevauchantPrc.estVide()) {
      nombreHeuresA4ouA5ActiviteDansPrc = calculerNombreHeuresActiviteDansPrc(chronoActivitesA4OuA5ChevauchantPrc, resultatPrc, reglementApplicable, outilJustificationSjr, resultatJustificationDiviseur, false).intValue();
    }
    resultatPrc.setNombreHeuresA4ouA5(new BigDecimal(nombreHeuresA4ouA5ActiviteDansPrc));
  }
}

/* Location:
 * Qualified Name:     StrategieDeterminationDiviseurSjrA3A4A5Abstrait
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */