package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieProduitResultant;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieProduitResultantSpec;
import fr.unedic.cali.asu.cge01.liquidation.parcours.fabrique.FabriqueParcoursConstitutionProduitResultant;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDroitResultant;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.services.Resultat;

public class ConstitutionProduitResultant
  extends ParcoursCali
  implements ParcoursAssurance
{
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException, ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCEPA15 = new Resultat(0);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    dossierExamenCourant.createConstitutionProduitResultant();
    if (verifierPreconditions(p_contexte))
    {
      alimentationCapitalDroitCourant(demandeCourante);
      
      CritereStrategie critere = new CritereStrategie();
      critere.setDatePivot(demandeCourante.getDateExamen());
      
      StrategieProduitResultantSpec strategie = (StrategieProduitResultantSpec)FabriqueStrategieProduitResultant.getInstance().getStrategie(critere);
      if (strategie.appliquerProduitResultant())
      {
        Parcours parcours = getParcours(getContexteExamen(p_contexte), demandeCourante);
        if (parcours != null)
        {
          JustificationDroitResultant justif = new JustificationDroitResultant();
          dossierExamenCourant.getConstitutionProduitResultant().setJustificationDroitResultant(justif);
          
          parcours.effectuerParcours(p_contexte);
        }
      }
    }
    OutilTrace.tracerFinParcours();
    
    return resultatCEPA15;
  }
  
  protected Parcours getParcours(int p_contexteExamen, Demande p_demande)
    throws ApplicativeException
  {
    return FabriqueParcoursConstitutionProduitResultant.getParcoursProduitResultant(p_contexteExamen, p_demande);
  }
  
  protected boolean verifierPreconditions(Contexte p_contexte)
  {
    boolean preconditionsValides = true;
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    if ((dossierExamenCourant.getConditionsAttributionAdmission() != null) && (dossierExamenCourant.getConditionsAttributionAdmission().estSatisfait())) {
      preconditionsValides = true;
    } else {
      preconditionsValides = false;
    }
    return preconditionsValides;
  }
  
  protected int getContexteExamen(Contexte p_contexte)
  {
    return ((DomLiquidationAssurance)p_contexte.getDonnees()).getContexteExamen();
  }
  
  protected void alimentationCapitalDroitCourant(Demande p_demande)
    throws ApplicativeException
  {
    Attribution attribution = (Attribution)p_demande.getDossierExamen();
    ConstitutionMontantsBruts cepMontant = attribution.getConstitutionMontantsBruts();
    
    Quantite nbJourIndemnisesTheorique = attribution.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    Quantite capitalProduitCourant = AppelCalculParLiquidationAsu.calculerCapital(attribution, cepMontant.getMontantAAttribution(), attribution.getDateAttribution(), nbJourIndemnisesTheorique);
    
    cepMontant.setCapitalInitialBrut(capitalProduitCourant);
  }
}

/* Location:
 * Qualified Name:     ConstitutionProduitResultant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */