package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSjrSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPrc;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.DelaiRecherche;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComportementSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class ParcoursConstitutionSjr
  extends ParcoursConstitutionSjrAbstrait
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Sjr impossible.");
    }
    if (DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen() == null) {
      throw new ContexteException("ASU_PR_CALI_L_CONTEXTE_ABSENCE_DOSSIER_EXAMEN", "Le dossier examen est null: constitution du Sjr impossible.");
    }
    DossierExamenAssuranceSpec dossierExamenCourant = (DossierExamenAssuranceSpec)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant.getReglementApplicable() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Le règlement applicable est null: constitution du Sjr impossible.");
    }
  }
  
  protected void alimenterCEPCodeEmploiA2B(ConstitutionSjr p_constitutionSjr, DonneesEntreeDeterminationSjrSpec p_donneesEntree)
  {
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)p_donneesEntree.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
    
    p_constitutionSjr.setCodeEmploiA2b(fabriqueOutilFonctionnel.getOutilDeterminationSjr().determinerCodeEmploiA2b(p_donneesEntree));
  }
  
  protected Chronologie determinerChronoActiviteSalariePrc(Demande p_demande, Periode p_periodePrc)
  {
    Chronologie chronologieActiviteSalarie = ConstructionChronologie.determinerChronoActivitesPrc(p_demande, p_periodePrc);
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Chronologie des ActiviteSalarie chevauchant la Prc : ", chronologieActiviteSalarie });
    return chronologieActiviteSalarie;
  }
  
  protected JustificationPrc determinerEtJustifierPeriodePrc(Demande p_demande)
    throws ApplicativeException
  {
    JustificationPrc justificationPrc = DelaiRecherche.getInstance().determinerEtJustifierPrc(p_demande);
    return justificationPrc;
  }
  
  protected Sjrip verifierSjripForce(Demande p_demande, DonneesEntreeDeterminationSjrSpec p_donneesEntree)
    throws ApplicativeException
  {
    Sjrip sjripRetourne = null;
    
    Quantite sjrSaisi = p_donneesEntree.getDonneesEntreeDemande().getDonneeForceeSjr();
    if (sjrSaisi != null)
    {
      BigDecimal resultatSjr = sjrSaisi.getValeur();
      
      Reglement reglementApplicableCourant = p_donneesEntree.getDonneesEntreeDemande().getReglementApplicable();
      if (reglementApplicableCourant.estNomReglementIdentique("A2b")) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A16MB2");
      }
      Prc prcCourante = determinerPrc(p_demande);
      
      FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)p_donneesEntree.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
      
      BigDecimal resultatPlafondSjr = fabriqueOutilFonctionnel.getOutilDeterminationSjr().determinerPlafondSjr(prcCourante.getDateFin(), p_donneesEntree);
      
      sjripRetourne = construireSjrip(prcCourante, resultatPlafondSjr, resultatSjr, p_donneesEntree.getDonneesEntreeDemande().getContexteDemande());
    }
    return sjripRetourne;
  }
  
  protected Chronologie determinerChronoActivitePourConditionCoordEuropeenne(Prc p_prc, Chronologie p_chronoActiviteSalariePrc)
  {
    Chronologie chronoActivitePostE301Retour = null;
    if (p_prc.getJustification().getTypeBornagePrc() == 2) {
      chronoActivitePostE301Retour = p_chronoActiviteSalariePrc;
    }
    return chronoActivitePostE301Retour;
  }
}

/* Location:
 * Qualified Name:     ParcoursConstitutionSjr
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */