package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilChronologiePourDelaisReports;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDelaiReport;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDeterminationDelaisReports;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieAppliquerISLR;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieDelaiAttente;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieISLR;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleDelaiReportSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleICCPSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.StrategiePriseEnCompteMontantCarencesSurActiviteConserveeApres;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.StrategiePriseEnCompteMontantCarencesSurActiviteConserveeAvant;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieAppliquerISLRSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieDelaiAttenteSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieFormuleISLRSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategiePriseEnCompteMontantCarencesSurActiviteConserveeSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ConteneurISLRSpec;
import fr.unedic.cali.asu.dom.ConteneurPMCSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.BaseDelaiReport;
import fr.unedic.cali.asu.produits.liquidation.dom.CarenceIslr;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.produits.liquidation.dom.ConteneurISLR;
import fr.unedic.cali.asu.produits.liquidation.dom.PreavisMesureConservatoireIndemnisable;
import fr.unedic.cali.asu.produits.liquidation.dom.PreavisMesureConservatoireNonIndemnisable;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.DelaiRecherche;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.fabriques.outilsfonctionnels.FabriqueStrategieGenerique;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.RechercherPeriodeIndemnisation;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.outilsfonctionnels.strategies.StrategieSpec;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.QuantiteJoursCalendaires;
import fr.unedic.util.QuantiteJoursOuvrables;
import fr.unedic.util.QuantiteJoursOuvres;
import fr.unedic.util.Unite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinApresOuCoincideAvecDate;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.List;

public abstract class ParcoursDeterminationDelaisReports
  extends ParcoursCali
  implements ParcoursAssurance
{
  protected static final BigDecimal ZERO = BigDecimal.ZERO;
  private static final int NBRE_JOURS_SEMAINE = 7;
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    ResultatDeterminationDelaisReports resultatCEP08 = new ResultatDeterminationDelaisReports(0);
    Collection<?> collectionDelaisReportsResultat = resultatCEP08.getListeDelaisReports();
    
    DemandeAssuranceSpec demande = DomLiquidationAssurance.getDemande(contexte);
    
    Periode periodeReferenceDifferes = DelaiRecherche.getInstance().determinerDelaiRechercheCarences((Demande)demande);
    alimenterCEPPeriodeReferenceDifferes(demande, periodeReferenceDifferes);
    if (estDemandeEligibleDelaisReport(demande))
    {
      determinerPMC(demande, collectionDelaisReportsResultat);
      determinerICCP(demande, collectionDelaisReportsResultat);
      determinerISLR(demande, collectionDelaisReportsResultat);
    }
    determinerDelaiAttente(demande, resultatCEP08);
    
    OutilTrace.tracerFinParcours();
    
    return resultatCEP08;
  }
  
  private boolean estDemandeEligibleDelaisReport(DemandeAssuranceSpec demande)
  {
    return (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "ARECOURCSP")) || ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, 10)) && (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "PAPPARLEM")));
  }
  
  private void alimenterCEPPeriodeReferenceDifferes(DemandeAssuranceSpec demande, Periode periodeReferenceDifferes)
  {
    if (periodeReferenceDifferes != null)
    {
      OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Alimentation de la CEP avec la période de référence de recherche des différés [", periodeReferenceDifferes.getDebut(), " - ", periodeReferenceDifferes.getFin(), "]." });
      
      Attribution attributionCourante = (Attribution)((Demande)demande).getAttribution();
      attributionCourante.getConstitutionDelais().setPeriodeReference91jours(periodeReferenceDifferes);
    }
  }
  
  protected void determinerPMC(DemandeAssuranceSpec demande, Collection<?> collectionDelaisReportsResultat)
    throws CoucheLogiqueException
  {
    if (demande.estEnContexteDemande("PAPPARLEM")) {
      determinerPmcPAP(demande, collectionDelaisReportsResultat);
    } else {
      determinerPmcClassique(demande, collectionDelaisReportsResultat);
    }
  }
  
  private void determinerPmcPAP(DemandeAssuranceSpec demande, Collection<?> collectionDelaisReportsResultat)
    throws CoucheLogiqueException
  {
    ActiviteSalarie pasPap = OutilAsp.getInstance().recupererAeCspPourEntreeEnDispositifCSP(demande.getDemandeur(), demande.getAttribution());
    BigDecimal montantPreavis = demande.getDonneesTemporaires().getMontantIndemnitePreavisContrib();
    if ((montantPreavis != null) && (BigDecimal.ZERO.compareTo(montantPreavis) < 0))
    {
      ConteneurPMCSpec conteneurPMC = OutilDeterminationDelaisReports.determinerPmcPapPourActivite(demande, pasPap, montantPreavis);
      
      alimenterCollectionDelaisReportsAvecPMC(collectionDelaisReportsResultat, conteneurPMC);
    }
  }
  
  private void determinerPmcClassique(DemandeAssuranceSpec demande, Collection<?> collectionDelaisReportsResultat)
    throws CoucheLogiqueException
  {
    Chronologie chronoActivitesPourPMC = determinerChronologieActivitesPourPMC(demande);
    if ((chronoActivitesPourPMC != null) && (!chronoActivitesPourPMC.estVide()))
    {
      chronoActivitesPourPMC.iterer();
      while (chronoActivitesPourPMC.encoreSuivant())
      {
        ActiviteSalarie activiteSalarieCourante = (ActiviteSalarie)chronoActivitesPourPMC.elementSuivant();
        ConteneurPMCSpec conteneurPMC = OutilDeterminationDelaisReports.determinerPMCPourActivite(demande, activiteSalarieCourante);
        
        alimenterCollectionDelaisReportsAvecPMC(collectionDelaisReportsResultat, conteneurPMC);
      }
    }
  }
  
  protected void determinerICCP(DemandeAssuranceSpec demande, Collection<?> collectionDelaisReportsResultat)
    throws ApplicativeException
  {
    CarencePrefixeAFixer differeICCPConservatoire = OutilDeterminationDelaisReports.determinerDiffereICCPConservatoireForce(demande);
    if (differeICCPConservatoire != null) {
      OutilDelaiReport.ajouterDelaiReportDansCollection(collectionDelaisReportsResultat, differeICCPConservatoire);
    }
    Chronologie chronoActivitesPourICCP = determinerChronologieActivitesPourICCPISLR(demande);
    
    ChronologiePeriodes chronoPeriodesIndemnisation = OutilChronologiePourDelaisReports.determinerChronologiePeriodesIndemnisation(demande);
    if ((chronoActivitesPourICCP != null) && (!chronoActivitesPourICCP.estVide()))
    {
      List<Temporel> listeActivitePourICCP = chronoActivitesPourICCP.mapperVersListe();
      
      chronoActivitesPourICCP.iterer();
      while (chronoActivitesPourICCP.encoreSuivant())
      {
        ActiviteSalarie activiteSalarieCourante = (ActiviteSalarie)chronoActivitesPourICCP.elementSuivant();
        
        Integer nbreJoursICCPForces = verifierNombreJoursICCPForcesPourActivite(demande, activiteSalarieCourante);
        int nbreJoursDiffereICCPActiviteSalarieCourante;
        int nbreJoursDiffereICCPActiviteSalarieCourante;
        if (nbreJoursICCPForces != null) {
          nbreJoursDiffereICCPActiviteSalarieCourante = nbreJoursICCPForces.intValue();
        } else {
          nbreJoursDiffereICCPActiviteSalarieCourante = gererCalculICCPAutomatique(demande, chronoPeriodesIndemnisation, activiteSalarieCourante, listeActivitePourICCP);
        }
        alimenterCollectionDelaisReportsAvecICCP(collectionDelaisReportsResultat, activiteSalarieCourante, nbreJoursDiffereICCPActiviteSalarieCourante);
      }
    }
  }
  
  protected int gererCalculICCPAutomatique(DemandeAssuranceSpec demande, ChronologiePeriodes chronoPeriodesIndemnisation, ActiviteSalarie activiteSalarieCourante, List<Temporel> listeActivitePourICCP)
    throws ApplicativeException
  {
    boolean calculerICCPConservatoireBatimentAutorise = determinerCalculICCPConservatoireBatimentAutorise((Demande)demande, listeActivitePourICCP, activiteSalarieCourante);
    
    BaseDelaiReport baseDelaiReport = determinerBaseDelaiReportICCP(demande, activiteSalarieCourante, chronoPeriodesIndemnisation, calculerICCPConservatoireBatimentAutorise);
    
    FormuleDelaiReportSpec formuleDiffereICCP = determinerFormuleICCP(baseDelaiReport, demande);
    if ((formuleDiffereICCP instanceof FormuleICCPSpec)) {
      activiteSalarieCourante.getPeriodeActiviteSalarieGaec().setIccpConservatoireCalculee(((FormuleICCPSpec)formuleDiffereICCP).estFormuleConservatoire());
    }
    int nbreJoursDiffereICCPActiviteSalarieCourante = appliquerFormuleICCP(baseDelaiReport, formuleDiffereICCP);
    return nbreJoursDiffereICCPActiviteSalarieCourante;
  }
  
  protected int appliquerFormuleICCP(BaseDelaiReport baseDelaiReport, FormuleDelaiReportSpec formuleDiffereICCP)
    throws CoucheLogiqueException
  {
    int nbreJoursDiffereICCPActiviteSalarieCourante = 0;
    if (formuleDiffereICCP != null)
    {
      QuantiteJour resultatFormuleIccp = (QuantiteJour)formuleDiffereICCP.appliquerFormule(baseDelaiReport);
      nbreJoursDiffereICCPActiviteSalarieCourante = resultatFormuleIccp.getNombreJours();
    }
    return nbreJoursDiffereICCPActiviteSalarieCourante;
  }
  
  protected abstract boolean determinerCalculICCPConservatoireBatimentAutorise(Demande paramDemande, List<Temporel> paramList, ActiviteSalarie paramActiviteSalarie)
    throws ApplicativeException;
  
  protected void determinerISLR(DemandeAssuranceSpec demande, Collection<?> collectionDelaisReportsResultat)
    throws CoucheLogiqueException
  {
    Chronologie chronoActivitesPourISLR = determinerChronologieActivitesPourICCPISLR(demande);
    if ((chronoActivitesPourISLR != null) && (!chronoActivitesPourISLR.estVide()))
    {
      chronoActivitesPourISLR.iterer();
      while (chronoActivitesPourISLR.encoreSuivant())
      {
        ActiviteSalarie activiteSalarieCourante = (ActiviteSalarie)chronoActivitesPourISLR.elementSuivant();
        
        OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Etude de détermination d'un différé ISLR sur l'activité salariée [", activiteSalarieCourante.getIdentifiant(), "]." });
        
        Integer nbreJoursISLRForces = verifierNombreJoursISLRForcesPourActivite(demande, activiteSalarieCourante);
        ConteneurISLRSpec conteneurISLRCourant;
        if (nbreJoursISLRForces != null)
        {
          ConteneurISLRSpec conteneurISLRCourant = ConteneurISLR.createInstance();
          
          conteneurISLRCourant.setActiviteSalarieOrigine(activiteSalarieCourante);
          conteneurISLRCourant.setNombreJoursDiffere(nbreJoursISLRForces.intValue());
        }
        else
        {
          ChronologiePeriodes chronologiePeriodeIndemnisee = RechercherPeriodeIndemnisation.getListePeriodesIndemnisationAssurance(demande.getDemandeur(), Damj.FIN_DES_TEMPS);
          
          StrategiePriseEnCompteMontantCarencesSurActiviteConserveeSpec strategiePriseEnCompteMontantICCPActiviteConservee = (StrategiePriseEnCompteMontantCarencesSurActiviteConserveeSpec)FabriqueStrategieGenerique.choisirStrategie(activiteSalarieCourante.getDateFin(), "Prise en compte des montants ICCP et ISLR sur les activités conservées", new StrategiePriseEnCompteMontantCarencesSurActiviteConserveeAvant(), new StrategiePriseEnCompteMontantCarencesSurActiviteConserveeApres());
          
          ChronologiePeriodes chronoPeriodesIndemnisationPourActiviteCourante = strategiePriseEnCompteMontantICCPActiviteConservee.formaterPeriodesIndemnisation(chronologiePeriodeIndemnisee, strategiePriseEnCompteMontantICCPActiviteConservee.estUneActiviteConservee(activiteSalarieCourante, demande.getDemandeur()));
          
          conteneurISLRCourant = determinerISLRPourActivite(demande, activiteSalarieCourante, chronoPeriodesIndemnisationPourActiviteCourante);
        }
        alimenterCollectionDelaisReportsAvecISLR(collectionDelaisReportsResultat, conteneurISLRCourant);
      }
    }
  }
  
  protected void determinerDelaiAttente(DemandeAssuranceSpec demande, ResultatDeterminationDelaisReports resultat)
    throws ApplicativeException
  {
    Collection<CarencePrefixeAFixer> collectionDelaisReportsResultat = resultat.getListeDelaisReports();
    
    IndividuSpec individu = demande.getDemandeur();
    individu.desactiverExclusionChronoPasseProPourLiquidationFCTRevision();
    
    Boolean forcageDelai = null;
    if (demande.getDonneesTemporaires() != null) {
      forcageDelai = demande.getDonneesTemporaires().isDelaiAttenteForce();
    }
    int nbreJoursDelaiAttente;
    int nbreJoursDelaiAttente;
    if ((forcageDelai != null) && (forcageDelai.booleanValue()))
    {
      nbreJoursDelaiAttente = 7;
    }
    else
    {
      int nbreJoursDelaiAttente;
      if (forcageDelai != null)
      {
        nbreJoursDelaiAttente = 0;
      }
      else
      {
        CritereStrategie critereStrategie = new CritereStrategie();
        critereStrategie.setDatePivot(demande.getDateExamen());
        StrategieDelaiAttenteSpec strategieDelaiAttente = (StrategieDelaiAttenteSpec)FabriqueStrategieDelaiAttente.getInstance().getStrategie(critereStrategie);
        
        strategieDelaiAttente.alimenterListeCarencesForcees(demande, collectionDelaisReportsResultat);
        nbreJoursDelaiAttente = appelerOutilCalculDelaiAttente(demande, resultat);
        strategieDelaiAttente.supprimerListeCarencesForcees(demande);
      }
    }
    alimenterCollectionDelaisReportsAvecDelaiAttente(collectionDelaisReportsResultat, nbreJoursDelaiAttente);
  }
  
  protected int appelerOutilCalculDelaiAttente(DemandeAssuranceSpec demande, ResultatDeterminationDelaisReports resultat)
    throws ApplicativeException
  {
    return OutilDeterminationDelaisReports.determinerDelaiAttente(demande, resultat);
  }
  
  private Chronologie determinerChronologieActivitesPourPMC(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Periode periodeReference = DelaiRecherche.getInstance().determinerDelaiRecherchePMC((Demande)demande);
    
    Chronologie chronoActivitesPourPMC = OutilChronologiePourDelaisReports.determinerChronologieActivitesPourDelaisReports(demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation(), periodeReference);
    
    return chronoActivitesPourPMC;
  }
  
  protected abstract Chronologie determinerChronologieActivitesPourICCPISLR(DemandeAssuranceSpec paramDemandeAssuranceSpec)
    throws CoucheLogiqueException;
  
  protected void alimenterCollectionDelaisReportsAvecPMC(Collection<?> collectionDelaisReports, ConteneurPMCSpec conteneurPMC)
  {
    OutilDelaiReport.ajouterDelaiReportDansCollection(collectionDelaisReports, (PreavisMesureConservatoireIndemnisable)conteneurPMC.getCarencePmcIndemnisable());
    
    OutilDelaiReport.ajouterDelaiReportDansCollection(collectionDelaisReports, (PreavisMesureConservatoireNonIndemnisable)conteneurPMC.getCarencePmcNonIndemnisable());
  }
  
  protected TravailSpec recupererPeriodeFaitGenerateur(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Attribution attributionCourante = (Attribution)((Demande)demande).getAttribution();
    TravailSpec periodeFaitGenerateur;
    TravailSpec periodeFaitGenerateur;
    if (attributionCourante.getFaitGenerateur() != null)
    {
      periodeFaitGenerateur = attributionCourante.getFaitGenerateur().getPeriodeFaitGenerateur();
    }
    else
    {
      Chronologie passeProfessionnel = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
      
      Damj dateFgdOdPrecedente = ((Demande)demande).getDateFaitGenerateurOdPrecedente();
      if (dateFgdOdPrecedente != null) {
        passeProfessionnel = passeProfessionnel.copier(new FiltreFinApresOuCoincideAvecDate(dateFgdOdPrecedente.lendemain()));
      }
      periodeFaitGenerateur = RechercherDernierSinistre.rechercherDernierSinistre(demande.getDateExamen().veille(), passeProfessionnel);
    }
    return periodeFaitGenerateur;
  }
  
  protected ConteneurISLRSpec determinerISLRPourActivite(DemandeAssuranceSpec demande, ActiviteSalarie activiteSalarie, ChronologiePeriodes chronologiePeriode)
    throws CoucheLogiqueException
  {
    Damj dateFCT = activiteSalarie.getDateFin();
    
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(dateFCT);
    StrategieAppliquerISLRSpec strategieISLR = (StrategieAppliquerISLRSpec)FabriqueStrategieAppliquerISLR.getInstance().getStrategie(critere);
    
    ConteneurISLRSpec conteneurISLRCourant = ConteneurISLR.createInstance();
    
    conteneurISLRCourant.setActiviteSalarieOrigine(activiteSalarie);
    
    Damj dateFaitGenerateur = ((Demande)demande).getDateFaitGenerateurOuDernierSinistre();
    if (strategieISLR.doitAppliquerISLR(chronologiePeriode, dateFCT))
    {
      OutilDeterminationDelaisReports.determinerMontantDiffereISLR(conteneurISLRCourant, dateFaitGenerateur);
      
      BaseDelaiReport baseDelaiReportISLRCourante = determinerBaseDelaiReportISLR(demande, activiteSalarie, dateFaitGenerateur);
      conteneurISLRCourant.setDatePivotPourRecupererFormuleISLR(recupererDatePivotPourFormuleISLR(demande));
      OutilDeterminationDelaisReports.determinerNombreJoursDiffereISLR(conteneurISLRCourant, baseDelaiReportISLRCourante, demande);
    }
    else
    {
      conteneurISLRCourant.setNombreJoursDiffere(0);
    }
    return conteneurISLRCourant;
  }
  
  protected abstract Damj recupererDatePivotPourFormuleISLR(DemandeSpec paramDemandeSpec)
    throws CoucheLogiqueException;
  
  private BaseDelaiReport determinerBaseDelaiReportISLR(DemandeAssuranceSpec demande, ActiviteSalarie activiteSalarie, Damj dateFaitGenerateurOuDernierSinistre)
  {
    Attribution attributionCourante = (Attribution)((Demande)demande).getAttribution();
    Sjr sjrrp = recupererSjrrp(attributionCourante);
    
    BaseDelaiReport baseDelaiReportISLRCourante = new BaseDelaiReport(activiteSalarie);
    baseDelaiReportISLRCourante.setQuantiteEuroIslr(activiteSalarie.getQuantiteEuroIslr());
    baseDelaiReportISLRCourante.setLicenciementEconomique(activiteSalarie.isLicenciementEconomique());
    baseDelaiReportISLRCourante.setDateFg(dateFaitGenerateurOuDernierSinistre);
    baseDelaiReportISLRCourante.setSjrrp(sjrrp);
    if (activiteSalarie.getContrat() != null) {
      baseDelaiReportISLRCourante.setMotifRupture(activiteSalarie.getContrat().getCodeMotifFin());
    }
    return baseDelaiReportISLRCourante;
  }
  
  protected Sjr recupererSjrrp(AttributionAssuranceSpec attributionAssurance)
  {
    return (Sjr)((ProduitAsuSpec)attributionAssurance.getDossierAffecte().getProduit()).recupererSJRPourDelaisReport(attributionAssurance.getDemande());
  }
  
  protected void alimenterCollectionDelaisReportsAvecISLR(Collection<?> collectionDelaisReports, ConteneurISLRSpec conteneurISLR)
  {
    int nombreJoursDiffereISLR = conteneurISLR.getNombreJoursDiffere();
    if (nombreJoursDiffereISLR > 0)
    {
      Quantite quantiteJoursISLR = new QuantiteJour(new BigDecimal(nombreJoursDiffereISLR));
      CarencePrefixeAFixer differeISLR = OutilDelaiReport.creerDelaiReport("ISLR", conteneurISLR.getActiviteSalarieOrigine(), quantiteJoursISLR);
      
      ((CarenceIslr)differeISLR).setAutresIndemnitesLegales(conteneurISLR.estAutresIndemnitesLegales());
      ((CarenceIslr)differeISLR).setPresenceTransaction(conteneurISLR.estPresenceTransaction());
      
      OutilDelaiReport.ajouterDelaiReportDansCollection(collectionDelaisReports, differeISLR);
    }
  }
  
  private void alimenterCollectionDelaisReportsAvecICCP(Collection<?> collectionDelaisReports, ActiviteSalarie activiteSalarieOrigine, int nbreJoursDiffereICCP)
  {
    if (nbreJoursDiffereICCP > 0)
    {
      Quantite quantiteJoursICCP = new QuantiteJour(new BigDecimal(nbreJoursDiffereICCP));
      CarencePrefixeAFixer differeICCP = OutilDelaiReport.creerDelaiReport("ICCP", activiteSalarieOrigine, quantiteJoursICCP);
      
      OutilDelaiReport.ajouterDelaiReportDansCollection(collectionDelaisReports, differeICCP);
    }
  }
  
  protected void alimenterCollectionDelaisReportsAvecDelaiAttente(Collection<?> collectionDelaisReports, int nbreJoursDelaiAttente)
  {
    if (nbreJoursDelaiAttente > 0)
    {
      Quantite quantiteJoursDelaiAttente = new QuantiteJour(new BigDecimal(nbreJoursDelaiAttente));
      CarencePrefixeAFixer delaiAttente = OutilDelaiReport.creerDelaiReport("Différé", null, quantiteJoursDelaiAttente);
      
      OutilDelaiReport.ajouterDelaiReportDansCollection(collectionDelaisReports, delaiAttente);
    }
  }
  
  protected abstract BaseDelaiReport determinerBaseDelaiReportICCP(DemandeAssuranceSpec paramDemandeAssuranceSpec, ActiviteSalarie paramActiviteSalarie, ChronologiePeriodes paramChronologiePeriodes, boolean paramBoolean)
    throws ApplicativeException;
  
  protected abstract FormuleDelaiReportSpec determinerFormuleICCP(BaseDelaiReport paramBaseDelaiReport, DemandeAssuranceSpec paramDemandeAssuranceSpec)
    throws CoucheLogiqueException;
  
  protected Integer verifierNombreJoursICCPForcesPourActivite(DemandeAssuranceSpec demande, ActiviteSalarie activiteSalarie)
  {
    Integer nbreJoursICCPForces = null;
    
    boolean estDiffereICCPForce = (demande.getDonneesTemporaires().getQuantiteJourICCP() != null) && (demande.getDonneesTemporaires().getIndentifiantFctPMC() != null);
    if ((estDiffereICCPForce) && (activiteSalarie.getIdentifiant().equalsIgnoreCase(demande.getDonneesTemporaires().getIndentifiantFctPMC())))
    {
      QuantiteJour quantiteJourICCPForce = demande.getDonneesTemporaires().getQuantiteJourICCP();
      
      int nombreJoursSemaine = 0;
      if ("jour ouvre".equalsIgnoreCase(quantiteJourICCPForce.getUnite().toString())) {
        nombreJoursSemaine = new QuantiteJoursOuvres(quantiteJourICCPForce.getValeur()).getNombreJoursSemaine();
      } else if ("jour calendaire".equalsIgnoreCase(quantiteJourICCPForce.getUnite().toString())) {
        nombreJoursSemaine = new QuantiteJoursCalendaires(quantiteJourICCPForce.getValeur()).getNombreJoursSemaine();
      } else if ("jour ouvrable".equalsIgnoreCase(quantiteJourICCPForce.getUnite().toString())) {
        nombreJoursSemaine = new QuantiteJoursOuvrables(quantiteJourICCPForce.getValeur()).getNombreJoursSemaine();
      }
      BigDecimal nominateur1 = quantiteJourICCPForce.getValeur().setScale(0, 0);
      BigDecimal nominateur2 = new BigDecimal(Integer.toString(7));
      BigDecimal denominateur = new BigDecimal(String.valueOf(nombreJoursSemaine));
      BigDecimal resultatFormule = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
      QuantiteJour quantiteJourCalculee = new QuantiteJour(Mathematiques.tronque(resultatFormule, 0));
      nbreJoursICCPForces = Integer.valueOf(quantiteJourCalculee.getNombreJours());
    }
    return nbreJoursICCPForces;
  }
  
  private Integer verifierNombreJoursISLRForcesPourActivite(DemandeAssuranceSpec demande, ActiviteSalarie activiteSalarie)
    throws CoucheLogiqueException
  {
    Integer nbreJoursISLRForces = null;
    
    boolean estDiffereISLRForce = (demande.getDonneesTemporaires().getQuantiteJourISLR() != null) && (demande.getDonneesTemporaires().getIndentifiantFctPMC() != null);
    if ((estDiffereISLRForce) && (activiteSalarie.getIdentifiant().equalsIgnoreCase(demande.getDonneesTemporaires().getIndentifiantFctPMC())))
    {
      nbreJoursISLRForces = Integer.valueOf(demande.getDonneesTemporaires().getQuantiteJourISLR().getNombreJours());
      
      verifierBlocageIslrForceSuperieurPlafond(demande, activiteSalarie, nbreJoursISLRForces.intValue());
    }
    return nbreJoursISLRForces;
  }
  
  private void verifierBlocageIslrForceSuperieurPlafond(DemandeAssuranceSpec demande, ActiviteSalarie activiteSalarie, int nbJourISLRForce)
    throws CoucheLogiqueException
  {
    BaseDelaiReport baseDelaiReport = determinerBaseDelaiReportISLR(demande, activiteSalarie, ((Demande)demande).getDateFaitGenerateurOuDernierSinistre());
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(recupererDatePivotPourFormuleISLR(demande));
    critere.setProduit(demande.getDossierAffectation() != null ? demande.getDossierAffectation().getProduit() : null);
    StrategieSpec strategie = FabriqueStrategieISLR.getInstance().getStrategie(critere);
    FormuleDelaiReportSpec formuleCarenceIslr = ((StrategieFormuleISLRSpec)strategie).getFormuleISLR();
    int plafondIslr = formuleCarenceIslr.recupererPlafondISLR(baseDelaiReport);
    if (nbJourISLRForce > plafondIslr) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_ERR_DIFFERE_ISLR_SUP_PLAFOND", new Object[] { Integer.valueOf(plafondIslr) });
    }
  }
}

/* Location:
 * Qualified Name:     ParcoursDeterminationDelaisReports
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */