package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDelaiReport;
import fr.unedic.cali.asu.cge01.liquidation.parcours.fabrique.FabriqueDeterminationDelaisReports;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

public class ParcoursDeterminationDelaisReportsFinancement
  extends ParcoursCali
  implements ParcoursAssurance
{
  private static final DureeCalendaire UN_MOIS = new DureeCalendaire(0, 1);
  private static final DureeCalendaire DEUX_MOIS = new DureeCalendaire(0, 2);
  private static final DureeCalendaire SIX_MOIS = new DureeCalendaire(0, 6);
  private static final DureeCalendaire DEUX_ANS = new DureeCalendaire(2);
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    ResultatDeterminationDelaisReports resultatCEP08 = new ResultatDeterminationDelaisReports(0);
    Collection collectionDelaisReports = null;
    
    DemandeAssuranceSpec demande = DomLiquidationAssurance.getDemande(p_contexte);
    
    demande.getDonneesTemporaires().setIndentifiantFctPMC(demande.getDonneesTemporaires().getIdentifiantPeriodeFctARetenir());
    
    ResultatDeterminationDelaisReports resultatDeterminationDelaisReports = null;
    ParcoursDeterminationDelaisReports parcoursDeterminationDelaisReports = FabriqueDeterminationDelaisReports.getParcoursDeterminationDelaisReports(demande);
    if (parcoursDeterminationDelaisReports != null)
    {
      resultatDeterminationDelaisReports = (ResultatDeterminationDelaisReports)parcoursDeterminationDelaisReports.effectuerParcours(p_contexte);
      
      collectionDelaisReports = resultatDeterminationDelaisReports.getListeDelaisReports();
    }
    ActiviteSalarie periodeFaitGenerateur = recupererPeriodeFaitGenerateur(demande);
    collectionDelaisReports = postTraitement(periodeFaitGenerateur, collectionDelaisReports);
    
    determinerPreavisLegal(demande, periodeFaitGenerateur, collectionDelaisReports);
    CarencePrefixeAFixer delaiReportCourant;
    Iterator i;
    if (collectionDelaisReports != null)
    {
      delaiReportCourant = null;
      for (i = collectionDelaisReports.iterator(); i.hasNext();)
      {
        delaiReportCourant = (CarencePrefixeAFixer)i.next();
        resultatCEP08.ajouterDelaiReport(delaiReportCourant);
      }
    }
    OutilTrace.tracerFinParcours();
    
    return resultatCEP08;
  }
  
  private Collection postTraitement(ActiviteSalarie p_activiteFaitGenerateur, Collection p_collectionDelaisReports)
  {
    Collection collectionDelaisReportsRetour = new ArrayList();
    
    boolean estPresentDelaiAttente = false;
    CarencePrefixeAFixer delaiReportCourant;
    Iterator i;
    if (p_collectionDelaisReports != null)
    {
      delaiReportCourant = null;
      for (i = p_collectionDelaisReports.iterator(); i.hasNext();)
      {
        delaiReportCourant = (CarencePrefixeAFixer)i.next();
        if (OutilDelaiReport.estDelaiReportDeType(delaiReportCourant, "Différé")) {
          estPresentDelaiAttente = true;
        }
        if ((estPresentDelaiAttente) || (delaiReportCourant.getIdentifiantPeriodeOrigine().equalsIgnoreCase(p_activiteFaitGenerateur.getIdentifiant()))) {
          OutilDelaiReport.ajouterDelaiReportDansCollection(collectionDelaisReportsRetour, delaiReportCourant);
        }
      }
    }
    if (!estPresentDelaiAttente) {
      OutilDelaiReport.ajouterDelaiReportDansCollection(collectionDelaisReportsRetour, OutilDelaiReport.creerDelaiReport("Différé", null, new QuantiteJour(new BigDecimal(Integer.toString(7)))));
    }
    return collectionDelaisReportsRetour;
  }
  
  private void determinerPreavisLegal(DemandeAssuranceSpec p_demande, ActiviteSalarie p_activiteFaitGenerateur, Collection p_collectionDelaisReportsResultat)
  {
    Demande demande = (Demande)p_demande;
    
    DureeCalendaire dureePreavis = null;
    DureeCalendaire anciennete = p_activiteFaitGenerateur.getPeriode().getDureeCalendaire();
    if (anciennete.compareTo(SIX_MOIS) >= 0) {
      if (anciennete.compareTo(DEUX_ANS) >= 0) {
        dureePreavis = DEUX_MOIS;
      } else {
        dureePreavis = UN_MOIS;
      }
    }
    if (dureePreavis != null)
    {
      Damj debutPreavis = p_activiteFaitGenerateur.getDateFin().lendemain();
      
      Damj termePreavis = null;
      if (demande.getDonneesTemporaires() != null) {
        termePreavis = demande.getDonneesTemporaires().getDateFinPreavisLegal();
      }
      if ((termePreavis == null) || (termePreavis.estAvant(p_activiteFaitGenerateur.getDateFin().lendemain()))) {
        termePreavis = debutPreavis.deplacerVersAvant(dureePreavis).veille();
      }
      Periode periodePreavis = new Periode(debutPreavis, termePreavis);
      
      OutilDelaiReport.ajouterDelaiReportDansCollection(p_collectionDelaisReportsResultat, OutilDelaiReport.creerDelaiReport("PREAVIS_LEGAL", p_activiteFaitGenerateur, new QuantiteJour(new BigDecimal(periodePreavis.getDuree()))));
    }
  }
  
  private ActiviteSalarie recupererPeriodeFaitGenerateur(DemandeAssuranceSpec p_demande)
  {
    Attribution attributionCourante = (Attribution)((Demande)p_demande).getAttribution();
    ActiviteSalarie periodeFaitGenerateur = attributionCourante.getFaitGenerateur().getPeriodeFaitGenerateur();
    return periodeFaitGenerateur;
  }
}

/* Location:
 * Qualified Name:     ParcoursDeterminationDelaisReportsFinancement
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */