package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.dom.ConteneurJustificationSjr;
import fr.unedic.cali.asu.cge01.liquidation.dom.DomSimulationSjrEtSjc;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatSimulationSjrEtSjc;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilSimulationSjrEtSjc;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSjcSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilSimulationSjrEtSjcSpec;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilPasseProfessionelAsu;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDiviseur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPlafonds;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPrc;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSr;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.PrcSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.produits.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.DelaiRecherche;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesEntreeConstructionChronologie;
import fr.unedic.cali.dom.conteneurs.DonneesEntreePRC;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComportementSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesResultatDeterminationSjcSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.ParcoursServiceAbstrait;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;

public class ParcoursSimulationSjrEtSjc
  extends ParcoursServiceAbstrait
{
  public Resultat demarrerParcours(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    OutilSimulationSjrEtSjcSpec outilSimulationSjrEtSjc = OutilSimulationSjrEtSjc.getInstance();
    
    ResultatSimulationSjrEtSjc resultat = new ResultatSimulationSjrEtSjc();
    
    resultat.setEtat(1);
    
    DomSimulationSjrEtSjc dom = (DomSimulationSjrEtSjc)p_contexte.getDonnees();
    
    outilSimulationSjrEtSjc.controleDesDonnees(dom);
    
    dom.getIndividu().setChronoPeriodePasseProfessionnelLiquidation(OutilPasseProfessionelAsu.trouverChronoPasseProfessionelAvecFiltrageE301etDNJ(dom.getIndividu(), dom.isEstCoordCee()));
    
    outilSimulationSjrEtSjc.chargementListePNDSIndividu(dom.getDateFgdOdPrecedente(), dom.getDateExamen(), dom.getIndividu());
    
    DecorReglementaire produitsDisponibles = outilSimulationSjrEtSjc.getDecorReglementaire(dom);
    dom.setDecor(produitsDisponibles);
    
    ProduitAsuSpec asu = outilSimulationSjrEtSjc.determinerProduitRelatifAuSinistre(dom);
    outilSimulationSjrEtSjc.controlerProduit(asu);
    dom.setProduitAppelant(asu);
    
    outilSimulationSjrEtSjc.controleCoherenceDonneesAvecReglement(dom);
    resultat.setReglement(dom.getActiviteSalarieRetenue().getReglement());
    
    Sjrip sjripRetourne = calculerSjrip(dom, resultat);
    
    resultat.setIndividu(dom.getIndividu());
    resultat.setDateFgd(dom.getDateFgd());
    resultat.setSjrip(sjripRetourne);
    Sjr sjr = new Sjr(sjripRetourne.getSjrInitial().getValeur(), sjripRetourne.getDateEffet(), sjripRetourne.getContexteParticulierSjr());
    Sjr sjrRevalorise = RevalorisationSalaire.revaloriserSjr(sjr, dom.getDateExamen());
    resultat.setSjrrp(sjrRevalorise);
    resultat.setDureePrc(sjripRetourne.getPrc().getDuree());
    resultat.setDiviseur(sjripRetourne.getPrc().getDiviseur());
    resultat.setProduitPropose(asu.getLibelleCourt());
    if (dom.getTypeSimulation() == 2)
    {
      Sjcip sjcipRetourne = calculerSjcip(dom, resultat);
      resultat.setSjcip(sjcipRetourne);
    }
    resultat.setEtat(0);
    OutilTrace.tracerFinParcours();
    return resultat;
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu p_individu)
  {
    return 2;
  }
  
  protected void alimenterAgregatGaec(Individu p_individu, String p_idDemande)
  {
    p_individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(2);
  }
  
  protected void controlerPostTraitement(Individu p_individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(p_individu.getDonneesChargementGaec().getAppelGaecReduit(), 2);
  }
  
  private DonneesEntreeDeterminationSjrSpec initialiserDonneesEntree(DomSimulationSjrEtSjc p_domSimulationSjrEtSjc, int p_typeTraitement)
    throws ApplicativeException
  {
    ProduitAsuSpec produitCourant = p_domSimulationSjrEtSjc.getProduitAppelant();
    DonneesEntreeDeterminationSjrSpec donneeEntree = OutilSimulationSjrEtSjc.getInstance().initialiserDonneesEntreeSimulation(p_domSimulationSjrEtSjc, p_typeTraitement, (FabriqueOutilFonctionnelDeterminationSjrSpec)produitCourant.determinerFabriqueOutilFonctionnelDeterminationSjr(p_domSimulationSjrEtSjc.getDateFgd()), true);
    
    return donneeEntree;
  }
  
  private Prc determinerPrc(DonneesEntreePRC p_donneesEntreePRC)
    throws CoucheLogiqueException
  {
    JustificationPrc justificationPrc = DelaiRecherche.getInstance().determinerEtJustifierPrc(p_donneesEntreePRC);
    
    Periode periodeReferenceCalcul = justificationPrc.getPeriodePrcEffective();
    Prc prcRetourne = new PrcSjr(periodeReferenceCalcul);
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Prc : ", periodeReferenceCalcul });
    
    prcRetourne.setJustification(justificationPrc);
    
    return prcRetourne;
  }
  
  protected Chronologie determinerChronoActiviteSalariePrcRevision(DonneesEntreeConstructionChronologie p_donneesEntreeConstructionChronologie)
  {
    Chronologie chronologieActiviteSalarie = fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionChronologie.determinerChronoActivitesPrcPourRevision(p_donneesEntreeConstructionChronologie);
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Chronologie des ActiviteSalarie chevauchant la Prc : ", chronologieActiviteSalarie });
    
    return chronologieActiviteSalarie;
  }
  
  protected Chronologie determinerChronoActiviteSalariePrcNonRevision(DonneesEntreeConstructionChronologie p_donneesEntreeConstructionChronologie)
  {
    Chronologie chronologieActiviteSalarie = fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.ConstructionChronologie.determinerChronoActivitesPrc(p_donneesEntreeConstructionChronologie);
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Chronologie des ActiviteSalarie chevauchant la Prc : ", chronologieActiviteSalarie });
    
    return chronologieActiviteSalarie;
  }
  
  private Sjrip calculerSjrip(DomSimulationSjrEtSjc p_domSimulationSjrEtSjc, ResultatSimulationSjrEtSjc p_resultat)
    throws ApplicativeException
  {
    OutilSimulationSjrEtSjcSpec outilSimulationSjrEtSjc = OutilSimulationSjrEtSjc.getInstance();
    
    DonneesEntreeDeterminationSjrSpec donneeEntree = initialiserDonneesEntree(p_domSimulationSjrEtSjc, 1);
    
    Sjrip sjripRetourne = verifierSjripA2b(donneeEntree);
    if (sjripRetourne == null)
    {
      DonneesEntreePRC donneesEntreePrc = outilSimulationSjrEtSjc.alimenterDonneesEntreePrc(p_domSimulationSjrEtSjc);
      Prc prc = determinerPrc(donneesEntreePrc);
      Chronologie chronoActiviteSalariePrc = null;
      DonneesEntreeConstructionChronologie donneesEntreeConstructionChronologie = outilSimulationSjrEtSjc.alimenterDonneesEntreeConstructionChronologie(p_domSimulationSjrEtSjc, prc.getPeriode());
      if (p_domSimulationSjrEtSjc.isEstRevision()) {
        chronoActiviteSalariePrc = determinerChronoActiviteSalariePrcRevision(donneesEntreeConstructionChronologie);
      } else {
        chronoActiviteSalariePrc = determinerChronoActiviteSalariePrcNonRevision(donneesEntreeConstructionChronologie);
      }
      Chronologie chronoActiviteInappartenancePrc = fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionChronologie.determinerChronoActivitesPrcPourInappartenance(donneesEntreeConstructionChronologie);
      Chronologie periodeDeductiblePrc = fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.ConstructionChronologie.determinerChronoPeriodesDeductiblesPrc(donneesEntreeConstructionChronologie);
      
      outilSimulationSjrEtSjc.alimenterDonneesEntreeComplementaires(donneeEntree, prc.getJustification(), chronoActiviteSalariePrc, chronoActiviteInappartenancePrc, periodeDeductiblePrc);
      
      FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)donneeEntree.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
      DonneesResultatDeterminationSjr resultatDeterminationSjr = fabriqueOutilFonctionnel.getOutilDeterminationSjr().determinerSjrip(donneeEntree);
      
      ConteneurJustificationSjr justificationSjr = alimenterJustificationSjr(resultatDeterminationSjr);
      
      sjripRetourne = construireSjrip(resultatDeterminationSjr.getPrc(), resultatDeterminationSjr.getPlafondSjr(), resultatDeterminationSjr.getSjri());
      
      p_resultat.setJustificationSjr(justificationSjr);
      
      p_resultat.setDatePrcDebut(resultatDeterminationSjr.getPrc().getDateDebut());
      p_resultat.setDatePrcFin(resultatDeterminationSjr.getPrc().getDateFin());
      p_resultat.setDureePrc(resultatDeterminationSjr.getPrc().getDureePrc().intValue());
      p_resultat.setEstCalculeSurBaseSmic(resultatDeterminationSjr.getPrc().isTopContratsDeTypeParticulier());
      p_resultat.setSalaireReference(sjripRetourne.getPrc().getSrip());
    }
    return sjripRetourne;
  }
  
  private Sjrip verifierSjripA2b(DonneesEntreeDeterminationSjrSpec p_donneesEntree)
  {
    Sjrip sjripRetourne = null;
    
    Reglement reglementApplicable = p_donneesEntree.getDonneesEntreeDemande().getReglementApplicable();
    if ((reglementApplicable != null) && (reglementApplicable.estNomReglementIdentique("A2b")))
    {
      FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)p_donneesEntree.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
      DonneesResultatDeterminationSjr resultatDeterminationSjr = fabriqueOutilFonctionnel.getOutilDeterminationSjr().determinerSjripPourA2B(p_donneesEntree);
      
      sjripRetourne = construireSjrip(p_donneesEntree.getDonneesEntreeDemande().getDateExamen(), resultatDeterminationSjr.getPlafondSjr(), resultatDeterminationSjr.getSjri());
    }
    return sjripRetourne;
  }
  
  protected Sjrip construireSjrip(Prc p_prc, BigDecimal p_plafondSjr, BigDecimal p_sjr)
  {
    Sjrip sjripRetourne = Sjrip.createNonPersistent();
    sjripRetourne.setDateEvenement(p_prc.getDateFin());
    sjripRetourne.setPrc(p_prc);
    sjripRetourne.setPlafondSjr(new QuantiteEuro(p_plafondSjr));
    sjripRetourne.setSjrInitial(new QuantiteEuro(p_sjr));
    
    return sjripRetourne;
  }
  
  protected Sjrip construireSjrip(Damj p_dateEffetSjr, BigDecimal p_plafondSjr, BigDecimal p_sjr)
  {
    Sjrip sjripRetourne = Sjrip.createNonPersistent();
    sjripRetourne.setDateEvenement(p_dateEffetSjr);
    sjripRetourne.setPlafondSjr(new QuantiteEuro(p_plafondSjr));
    sjripRetourne.setSjrInitial(new QuantiteEuro(p_sjr));
    
    return sjripRetourne;
  }
  
  private ConteneurJustificationSjr alimenterJustificationSjr(DonneesResultatDeterminationSjr p_donneesResultatDeterminationSjr)
  {
    JustificationSr justificationSrResultat = p_donneesResultatDeterminationSjr.getJustificationSjr().getJustificationSr();
    JustificationDiviseur justificationDiviseurResultat = p_donneesResultatDeterminationSjr.getJustificationSjr().getJustificationDiviseur();
    JustificationPlafonds justificationPlafondsResultat = p_donneesResultatDeterminationSjr.getJustificationSjr().getJustificationPlafonds();
    
    ConteneurJustificationSjr justificationSr = new ConteneurJustificationSjr();
    justificationSr.setListeActivitesSalarieesRetenues(justificationSrResultat.getListeActivitesSalarieesRetenues());
    justificationSr.setSalaireReferenceNonPlafonne(justificationSrResultat.getSalaireReferenceNonPlafonne());
    justificationSr.setSalaireReferencePlafonnne(justificationSrResultat.getSalaireReferencePlafonnne());
    justificationSr.setTotalSalairesRetenus(justificationSrResultat.getTotalSalairesRetenus());
    justificationSr.setTotalPrimesNormalesRetenues(justificationSrResultat.getTotalPrimesNormalesRetenues());
    justificationSr.setTotalPrimesExceptionnellesRetenues(justificationSrResultat.getTotalPrimesExceptionnellesRetenues());
    
    justificationSr.setJustificationDiviseur(justificationDiviseurResultat);
    
    justificationSr.setJustificationPlafonds(justificationPlafondsResultat);
    
    return justificationSr;
  }
  
  private Sjcip calculerSjcip(DomSimulationSjrEtSjc p_domSimulationSjrEtSjc, ResultatSimulationSjrEtSjc p_resultat)
    throws ApplicativeException
  {
    Sjcip sjcipRetourne = null;
    
    DonneesEntreeDeterminationSjrSpec donneesEntreeDeterminationSjc = initialiserDonneesEntree(p_domSimulationSjrEtSjc, 2);
    
    OutilSimulationSjrEtSjc outilSimulationSjrEtSjc = OutilSimulationSjrEtSjc.getInstance();
    DonneesEntreeConstructionChronologie donneeEntreeChrono = outilSimulationSjrEtSjc.alimenterDonneesEntreeConstructionChronologie(p_domSimulationSjrEtSjc, null);
    
    donneeEntreeChrono.setProduit(p_domSimulationSjrEtSjc.getProduitAppelant());
    Chronologie chronoGlobaleActivitesConservees = fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionChronologie.determinerChronoActivitesConservees(donneeEntreeChrono);
    
    Prc prcSjcipCourante = p_resultat.getSjrip().getPrc();
    BigDecimal plafondSjcipCourant = p_resultat.getSjrip().getPlafondSjr().getValeur();
    
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)donneesEntreeDeterminationSjc.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
    
    Damj termePrc = prcSjcipCourante.getDateFin();
    Chronologie chronoActivitesSalarieesConserveesPourSjcip = fabriqueOutilFonctionnel.getOutilDeterminationSjc().determinerChronoActivitesSalarieesConserveesPourSjcip(null, termePrc, chronoGlobaleActivitesConservees, p_domSimulationSjrEtSjc.getActiviteSalarieFgd().getDateFin());
    
    outilSimulationSjrEtSjc.alimenterDonneesEntreeComplementaires(donneesEntreeDeterminationSjc, prcSjcipCourante.getJustification(), chronoActivitesSalarieesConserveesPourSjcip, null, null);
    
    DonneesResultatDeterminationSjcSpec resultatDeterminationSjc = fabriqueOutilFonctionnel.getOutilDeterminationSjc().determinerSjcip(donneesEntreeDeterminationSjc);
    
    sjcipRetourne = construireSjcip(termePrc, plafondSjcipCourant, resultatDeterminationSjc.getSjci(), resultatDeterminationSjc.getListeSjrActiviteConservee());
    
    fabriqueOutilFonctionnel.getOutilDeterminationSjc().completerSjcipAvecActivitesConserveesNonRetenues(donneesEntreeDeterminationSjc, sjcipRetourne, chronoGlobaleActivitesConservees, false);
    
    return sjcipRetourne;
  }
  
  protected Sjcip construireSjcip(Damj p_dateEffetSjc, BigDecimal p_plafondSjc, BigDecimal p_sjc, ArrayList p_listeSjrActiviteConserve)
  {
    Sjcip sjcipRetourne = Sjcip.createNonPersistent();
    sjcipRetourne.setDateEvenement(p_dateEffetSjc);
    sjcipRetourne.setPlafond(new QuantiteEuro(p_plafondSjc));
    sjcipRetourne.setSjcInitial(new QuantiteEuro(p_sjc));
    if (p_listeSjrActiviteConserve != null) {
      for (int i = 0; i < p_listeSjrActiviteConserve.size(); i++) {
        sjcipRetourne.ajouterSjrActiviteConserve((SjrActiviteConservee)p_listeSjrActiviteConserve.get(i));
      }
    }
    return sjcipRetourne;
  }
}

/* Location:
 * Qualified Name:     ParcoursSimulationSjrEtSjc
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */