package fr.unedic.cali.asu.cge01.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMappingSjmSjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.asu.parametres.EvenementCategorieA2B;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.parametres.ParametresIndemnisationA2B;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.Reprise;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.cons.ConstantesRevalorisationSalaire;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ElementBaseIndemnisationSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public final class RevalorisationSalaire
{
  public static Sjr revalorisationSjr(AttributionSpec attribution, Damj date)
  {
    if (OutilsTrancheCalcul.estTrancheActive(attribution)) {
      return revaloriserSjrTranche((AttributionAssuranceSpec)attribution, date);
    }
    return revaloriserSjr((AttributionAssuranceSpec)attribution, date);
  }
  
  private static BigDecimal recupererPlafond(String contexteParticulier, EvenementParametre evenementParametre)
  {
    return "AREMAYOTTE".equals(contexteParticulier) ? evenementParametre.getPlafondMayotte() : evenementParametre.getPlafond();
  }
  
  public static Sjc revaloriserSjc(Sjc sjc, Damj date)
  {
    if (sjc.estRevalorise()) {
      throw new IllegalArgumentException("Le SJC est déjà revalorisé : seul un SJC initial peut être revalorisé");
    }
    if (sjc.getDateDepart().estApres(date)) {
      throw new IllegalArgumentException("La date de départ du SJC doit être antérieure à la date de revalorisation du SJC");
    }
    ParametresIndemnisation param = ParametresIndemnisation.getParametresIndemnisation();
    Chronologie chronoParam = param.getParametresActifs(new Periode(sjc.getDateDepart(), date));
    EvenementParametre evenementParametre = param.getElementActif(date);
    
    BigDecimal plafond = recupererPlafond(sjc.getContexteParticulier(), evenementParametre);
    
    BigDecimal plafondTronque = plafond.multiply(new BigDecimal("12")).divide(new BigDecimal("365"), 2, 1);
    
    chronoParam.iterer();
    if (!chronoParam.encoreSuivant()) {
      return new Sjc(sjc.getSalaire().min(plafondTronque), sjc.getDateDepart(), sjc.getContexteParticulier());
    }
    BigDecimal revalAAppliquer = ConstantesRevalorisationSalaire.INIT_REVAL_A_APPLIQUER;
    chronoParam.iterer();
    EvenementParametre evtCourant = null;
    Damj datePointDepart = sjc.getDateDepart();
    while (chronoParam.encoreSuivant())
    {
      evtCourant = (EvenementParametre)chronoParam.elementSuivant();
      if ((evtCourant.isNouveauRevalorisationSjr()) && (verifierDureePourReval(datePointDepart, evtCourant.getDateEffet()))) {
        revalAAppliquer = revalAAppliquer.multiply(ConstantesRevalorisationSalaire.COEFF_CENT_POURCENTS.add(evtCourant.getRevalorisationSjr()));
      }
    }
    BigDecimal valeurSjcRevalorise = null;
    valeurSjcRevalorise = sjc.getSalaire().multiply(revalAAppliquer);
    valeurSjcRevalorise = Mathematiques.tronque(valeurSjcRevalorise, 2);
    
    valeurSjcRevalorise = plafondTronque.min(valeurSjcRevalorise);
    
    Sjc sjcRetour = new Sjc(valeurSjcRevalorise, sjc.getDateDepart(), sjc.getContexteParticulier());
    sjcRetour.setRevalorise(true);
    return sjcRetour;
  }
  
  public static Sjr revaloriserSjr(AttributionSpec attribution, Damj date)
  {
    Sjr sjr = ((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation().getSjr();
    
    ProduitSpec produit = attribution.getProduit();
    
    Reglement reglementOdCourante = ((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation().getReglementApplicableMontantRetenu().getReglement();
    if (reglementOdCourante.equals(produit.getReglement("A2b")))
    {
      ParametresIndemnisationA2B param = ParametresIndemnisationA2B.getParametresIndemnisation();
      EvenementCategorieA2B evtParam = param.getElementActif(date);
      BigDecimal salaireForfaitaireJournalier = evtParam.getSalaireA2B(((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation().getCodeEmploiA2B());
      return new Sjr(salaireForfaitaireJournalier, sjr.getDateDepart(), sjr.getContexteParticulier());
    }
    return revaloriserSjr(sjr, date);
  }
  
  public static Sjr revaloriserSjr(Sjr sjr, Damj date)
  {
    return revaloriserSjr(sjr, date, true);
  }
  
  public static Sjr revaloriserSjr(Sjr sjr, Damj date, boolean plafonner)
  {
    if (sjr.estRevalorise()) {
      throw new IllegalArgumentException("Le SJR est déjà revalorisé : seul un SJR initial peut être revalorisé");
    }
    if (sjr.getDateDepart().estApres(date)) {
      throw new IllegalArgumentException("La date de fin de PRC doit être antérieure à la date de revalorisation du SJR");
    }
    ParametresIndemnisation param = ParametresIndemnisation.getParametresIndemnisation();
    Chronologie chronoParam = param.getParametresActifs(new Periode(sjr.getDateDepart(), date));
    EvenementParametre evtParam = param.getElementActif(date);
    
    BigDecimal plafond = recupererPlafond(sjr.getContexteParticulier(), evtParam);
    
    BigDecimal plafondTronque = plafond.multiply(new BigDecimal("12")).divide(new BigDecimal("365"), 2, 1);
    
    chronoParam.iterer();
    if (!chronoParam.encoreSuivant())
    {
      if (plafonner) {
        return new Sjr(sjr.getSalaire().min(plafondTronque), sjr.getDateDepart(), sjr.getContexteParticulier());
      }
      return sjr;
    }
    BigDecimal revalAAppliquer = ConstantesRevalorisationSalaire.INIT_REVAL_A_APPLIQUER;
    chronoParam.iterer();
    EvenementParametre evtCourant = null;
    Damj dateFinPrc = sjr.getDateDepart();
    while (chronoParam.encoreSuivant())
    {
      evtCourant = (EvenementParametre)chronoParam.elementSuivant();
      if ((evtCourant.isNouveauRevalorisationSjr()) && (!dateFinPrc.deplacerVersAvant(new DureeCalendaire(0, 6, 1)).estApres(evtCourant.getDateEffet()))) {
        revalAAppliquer = revalAAppliquer.multiply(ConstantesRevalorisationSalaire.COEFF_CENT_POURCENTS.add(evtCourant.getRevalorisationSjr()));
      }
    }
    BigDecimal valeurSjrRevalorise = null;
    valeurSjrRevalorise = sjr.getSalaire().multiply(revalAAppliquer);
    valeurSjrRevalorise = Mathematiques.tronque(valeurSjrRevalorise, 2);
    if (plafonner) {
      valeurSjrRevalorise = plafondTronque.min(valeurSjrRevalorise);
    }
    Sjr sjrRetour = new Sjr(valeurSjrRevalorise, sjr.getDateDepart(), sjr.getContexteParticulier());
    sjrRetour.setRevalorise(true);
    return sjrRetour;
  }
  
  public static Sjr revaloriserSjr(ElementBaseIndemnisation ebi, ProduitAsuSpec produit, Damj date)
  {
    return OutilMappingSjmSjr.convertirSjr(produit.revaloriserSalaireJournalier(ebi, date));
  }
  
  public static Sjr revaloriserSjr(AttributionSpec attribution, Damj date, boolean isPlafonne)
  {
    Sjr sjr = ((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation().getSjr();
    
    ProduitSpec produit = attribution.getProduit();
    
    Reglement reglementOdCourante = ((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation().getReglementApplicableMontantRetenu().getReglement();
    if (reglementOdCourante.equals(produit.getReglement("A2b")))
    {
      ParametresIndemnisationA2B param = ParametresIndemnisationA2B.getParametresIndemnisation();
      EvenementCategorieA2B evtParam = param.getElementActif(date);
      BigDecimal salaireForfaitaireJournalier = evtParam.getSalaireA2B(((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation().getCodeEmploiA2B());
      return new Sjr(salaireForfaitaireJournalier, sjr.getDateDepart(), sjr.getContexteParticulier());
    }
    return revaloriserSjr(sjr, date, isPlafonne);
  }
  
  public static boolean verifierDureePourReval(Damj dateSjr, Damj dateReval)
  {
    return !dateSjr.deplacerVersAvant(new DureeCalendaire(0, 6, 1)).estApres(dateReval);
  }
  
  public static boolean verifierDureePourReval(AttributionSpec attribution, Damj dateReval)
  {
    if (OutilsTrancheCalcul.estTrancheActive(attribution)) {
      return verifierDureePourRevalTranche(attribution, dateReval);
    }
    Damj dateSjrAttributionPrecedente = null;
    if ((attribution instanceof RepriseSpec)) {
      dateSjrAttributionPrecedente = ((AttributionAssuranceSpec)attribution).getAttributionPrecedente().getElementBaseIndemnisation().getSjr().getDateDepart();
    } else {
      dateSjrAttributionPrecedente = ((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation().getSjr().getDateDepart();
    }
    return verifierDureePourReval(dateSjrAttributionPrecedente, dateReval);
  }
  
  public static boolean verifierDureePourRevalTranche(AttributionSpec attribution, Damj dateReval)
  {
    Damj dateSjrAttributionPrecedente = null;
    TrancheExecutable tranche = null;
    if ((attribution instanceof Reprise))
    {
      tranche = OutilsTrancheCalcul.recupererTrancheInitiale(((Reprise)attribution).getAttributionPrecedente());
      dateSjrAttributionPrecedente = tranche.getSjr().getDateDepart();
    }
    else
    {
      tranche = OutilsTrancheCalcul.recupererTrancheInitiale((Attribution)attribution);
      dateSjrAttributionPrecedente = tranche.getSjr().getDateDepart();
    }
    return verifierDureePourReval(dateSjrAttributionPrecedente, dateReval);
  }
  
  public static Sjr revaloriserSjrTranche(AttributionSpec attribution, Damj date, TrancheExecutable tranche)
  {
    Sjr sjr = tranche.getSjr();
    ProduitSpec produit = attribution.getProduit();
    
    String reglementOdCourante = tranche.getReglementApplicableMontantRetenu();
    if (reglementOdCourante.equals(produit.getReglement("A2b")))
    {
      ParametresIndemnisationA2B param = ParametresIndemnisationA2B.getParametresIndemnisation();
      EvenementCategorieA2B evtParam = param.getElementActif(date);
      BigDecimal salaireForfaitaireJournalier = evtParam.getSalaireA2B(tranche.getCodeEmploiA2B());
      return new Sjr(salaireForfaitaireJournalier, sjr.getDateDepart(), sjr.getContexteParticulier());
    }
    return revaloriserSjr(sjr, date);
  }
  
  public static Sjr revaloriserSjrTranche(AttributionSpec attribution, Damj date)
  {
    TrancheExecutable tranche = OutilsTrancheCalcul.recupererTrancheInitiale(attribution);
    
    Sjr sjr = tranche.getSjr();
    
    ProduitSpec produit = attribution.getProduit();
    Reglement reglementOdCourante = tranche.getReglementMontantRetenu();
    if (reglementOdCourante.equals(produit.getReglement("A2b")))
    {
      ParametresIndemnisationA2B param = ParametresIndemnisationA2B.getParametresIndemnisation();
      EvenementCategorieA2B evtParam = param.getElementActif(date);
      BigDecimal salaireForfaitaireJournalier = evtParam.getSalaireA2B(tranche.getCodeEmploiA2B());
      return new Sjr(salaireForfaitaireJournalier, sjr.getDateDepart(), sjr.getContexteParticulier());
    }
    return revaloriserSjr(sjr, date);
  }
  
  public static Sjr revaloriserSjrTranche(TrancheExecutable tranche, Damj date)
  {
    Sjr sjr = tranche.getSjr();
    return revaloriserSjr(sjr, date);
  }
  
  public static Sjr revaloriserSjrTranche(ElementBaseIndemnisation ebi, Damj date)
  {
    return OutilMappingSjmSjr.convertirSjr(revaloriserSalaireJournalierTranche(ebi, date));
  }
  
  public static SalaireJournalierSpec revaloriserSalaireJournalierTranche(ElementBaseIndemnisationSpec ebi, Damj date)
  {
    return revaloriserSjr(((ElementBaseIndemnisation)ebi).getSjrInitial(), date);
  }
}

/* Location:
 * Qualified Name:     RevalorisationSalaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */