package fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.affectation.ValidationProduitSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteContenuDansPra;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteNatureSaisonniere;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreListeActiviteNatureSaisonniere;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.ArrayList;

public class DeterminationCaractereSaisonnier
  implements OutilFonctionnel
{
  private static final int UN = 1;
  private static final int DEUX = 2;
  private static final int TROIS = 3;
  private static final int CINQ = 5;
  private static final int QUINZE = 15;
  private static final int UN_AN = 365;
  private static final int TROIS_ANS = 1095;
  
  public static boolean rechercherCaractereSaisonnierParNature(Damj p_dateFCT, ChronologiePeriodes p_chronoPassePro)
    throws CoucheLogiqueException
  {
    boolean caractereSaisonnierParNature = false;
    DureeCalendaire unAn = new DureeCalendaire(1);
    DureeCalendaire deuxAns = new DureeCalendaire(2);
    Periode derniereAnneePrs = CalculDelais.determinerDelai(p_dateFCT, unAn);
    derniereAnneePrs.setDebut(derniereAnneePrs.getDebut().lendemain());
    Periode deuxPremieresAnneesPrs = CalculDelais.determinerDelai(derniereAnneePrs.getDebut().veille(), deuxAns);
    deuxPremieresAnneesPrs.setDebut(deuxPremieresAnneesPrs.getDebut().lendemain());
    
    FiltresTemporel filtres = null;
    
    filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteNatureSaisonniere());
    filtres.ajouterFiltre(new FiltreActiviteContenuDansPra(derniereAnneePrs));
    ChronologiePeriodes chronoASParNature = (ChronologiePeriodes)p_chronoPassePro.copier(filtres);
    if (!chronoASParNature.estVide())
    {
      ArrayList tableauActivitesDerniereAnnee = construireTableau(chronoASParNature);
      filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltreActiviteNatureSaisonniere());
      filtres.ajouterFiltre(new FiltreListeActiviteNatureSaisonniere(tableauActivitesDerniereAnnee));
      filtres.ajouterFiltre(new FiltreActiviteContenuDansPra(deuxPremieresAnneesPrs));
      ChronologiePeriodes chronoASParNatureRepetees = (ChronologiePeriodes)p_chronoPassePro.copier(filtres);
      if (!chronoASParNatureRepetees.estVide()) {
        caractereSaisonnierParNature = true;
      }
    }
    return caractereSaisonnierParNature;
  }
  
  public static boolean validerCaractereSaisonnierParNature(DemandeSpec p_demande, ChronologiePeriodes p_chronoPassePro, Periode p_pra, Quantite p_affiTotale)
    throws ApplicativeException
  {
    boolean caractereSaisonnierParNatureValide = false;
    
    FiltresTemporel filtres = null;
    filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteContenuDansPra(p_pra));
    filtres.ajouterFiltre(new FiltreActiviteNatureSaisonniere());
    ChronologiePeriodes chronoAffiSaisonnierePra = (ChronologiePeriodes)p_chronoPassePro.copier(filtres);
    
    Unite uniteAffiliation = p_affiTotale.getUnite();
    
    ValidationProduitSpec validationProduit = ((DossierAffectation)p_demande.getDossierAffectation()).getValidationProduit();
    ActiviteSalarie periodeActiviteSalariee = validationProduit.getPeriodeValidationProduit();
    Reglement reglementAppartenance = periodeActiviteSalariee.getReglement();
    
    QuantitesAppartenance listeAffiSaisonniere = fr.unedic.cali.asu.cge01.p02.liquidation.outilsaffiliation.CalculAppartenance.getInstance().calculer(p_demande, null, p_pra, chronoAffiSaisonnierePra, reglementAppartenance);
    
    Quantite affiSaisoniere = listeAffiSaisonniere.getQuantiteAffiliation(uniteAffiliation);
    Quantite doubleAffiSaisonniere = affiSaisoniere.multiplierPar(new Quantite(new BigDecimal("2"), uniteAffiliation));
    if (p_affiTotale.compareTo(doubleAffiSaisonniere) < 0) {
      caractereSaisonnierParNatureValide = true;
    }
    return caractereSaisonnierParNatureValide;
  }
  
  public static boolean rechercherCaractereSaisonnierParRythme(Damj p_dateFCT, ChronologiePeriodes p_chronoPassePro)
    throws CoucheLogiqueException
  {
    boolean caractereSaisonnierParRythme = false;
    DureeCalendaire troisAns = new DureeCalendaire(3);
    DureeCalendaire cinqAns = new DureeCalendaire(5);
    Periode prs = CalculDelais.determinerDelai(p_dateFCT, troisAns);
    prs.setDebut(prs.getDebut().lendemain());
    Periode pras = CalculDelais.determinerDelai(p_dateFCT, cinqAns);
    pras.setDebut(pras.getDebut().lendemain());
    
    ChronologiePeriodes chronoRythmeInactivite = OutillageChronologiePeriodes.donnerPeriodesComplementaires(p_chronoPassePro, prs);
    
    ChronologiePeriodes chronoRythmeInactiviteReference = (ChronologiePeriodes)chronoRythmeInactivite.clone();
    Periode periodeInactiviteTest = null;
    ObjetChronoPeriode objetChronoPeriodeCourant = null;
    chronoRythmeInactivite.iterer();
    while ((chronoRythmeInactivite.encoreSuivant()) && (!caractereSaisonnierParRythme))
    {
      objetChronoPeriodeCourant = (ObjetChronoPeriode)chronoRythmeInactivite.elementSuivant();
      
      periodeInactiviteTest = new Periode(objetChronoPeriodeCourant.getDateDebut().deplacerVersAvant(new DureeCalendaire(1, 0, 0)), objetChronoPeriodeCourant.getDateFin().deplacerVersAvant(new DureeCalendaire(1, 0, 0)));
      
      ChronologiePeriodes chronologiePeriodes1AN = periodeInter(periodeInactiviteTest, chronoRythmeInactiviteReference, 15);
      if (!chronologiePeriodes1AN.estVide())
      {
        periodeInactiviteTest = new Periode(objetChronoPeriodeCourant.getDateDebut().deplacerVersAvant(new DureeCalendaire(2, 0, 0)), objetChronoPeriodeCourant.getDateFin().deplacerVersAvant(new DureeCalendaire(2, 0, 0)));
        
        ChronologiePeriodes chronologiePeriodes2AN = periodeInter(periodeInactiviteTest, chronoRythmeInactiviteReference, 15);
        if (!chronologiePeriodes2AN.estVide())
        {
          ObjetChronoPeriode objetChronoPeriodeCourant1AN = null;
          Periode periode1AN = null;
          
          chronologiePeriodes1AN.iterer();
          while ((chronologiePeriodes1AN.encoreSuivant()) && (!caractereSaisonnierParRythme))
          {
            objetChronoPeriodeCourant1AN = (ObjetChronoPeriode)chronologiePeriodes1AN.elementSuivant();
            periode1AN = new Periode(objetChronoPeriodeCourant1AN.getDateDebut().deplacerVersAvant(new DureeCalendaire(1, 0, 0)), objetChronoPeriodeCourant1AN.getDateFin().deplacerVersAvant(new DureeCalendaire(1, 0, 0)));
            
            ChronologiePeriodes chronologiePeriodes = periodeInter(periode1AN, chronologiePeriodes2AN, 15);
            if (!chronologiePeriodes.estVide()) {
              caractereSaisonnierParRythme = true;
            }
          }
        }
      }
    }
    return caractereSaisonnierParRythme;
  }
  
  private static ChronologiePeriodes periodeInter(Periode p_periode, ChronologiePeriodes p_chronologie, int p_duree)
  {
    ChronologiePeriodes chronoPeriodesInter = new ChronologiePeriodes();
    ObjetChronoPeriode objetChronoPeriodeCourant = null;
    
    Periode periodeCourant = null;
    Periode periodeIntersection = null;
    
    p_chronologie.iterer();
    while (p_chronologie.encoreSuivant())
    {
      objetChronoPeriodeCourant = (ObjetChronoPeriode)p_chronologie.elementSuivant();
      
      periodeCourant = new Periode(objetChronoPeriodeCourant.getDateDebut(), objetChronoPeriodeCourant.getDateFin());
      
      periodeIntersection = p_periode.periodeIntersection(periodeCourant);
      if ((periodeIntersection != null) && 
      
        (periodeIntersection.getDuree() >= p_duree)) {
        chronoPeriodesInter.ajouter(objetChronoPeriodeCourant);
      }
    }
    return chronoPeriodesInter;
  }
  
  public static boolean validerCaractereSaisonnierParRythme(ChronologiePeriodes p_chronoPassePro, Periode p_prs)
    throws CoucheLogiqueException
  {
    boolean caractereSaisonnierParRythmeValide = false;
    
    FiltresTemporel filtres = null;
    filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarie());
    filtres.ajouterFiltre(new FiltreActiviteContenuDansPra(p_prs));
    ChronologiePeriodes chronoActivitePrs = (ChronologiePeriodes)p_chronoPassePro.copier(filtres);
    Periode amplitudeActivitePrs = new Periode(chronoActivitePrs.premierElement().getDateDebut(), chronoActivitePrs.dernierElement().getDateFin());
    if (amplitudeActivitePrs.getDuree() >= 365) {
      caractereSaisonnierParRythmeValide = true;
    }
    return caractereSaisonnierParRythmeValide;
  }
  
  public static boolean invaliderCaractereSaisonnierParRythme(ChronologiePeriodes p_chronoPassePro, Periode p_pras)
    throws CoucheLogiqueException
  {
    boolean activite3Sur5 = false;
    
    FiltresTemporel filtres = null;
    filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarie());
    ChronologiePeriodes chronoActivitePras = (ChronologiePeriodes)p_chronoPassePro.copier(filtres);
    if (p_pras.inter(chronoActivitePras) >= 1095) {
      activite3Sur5 = true;
    }
    return activite3Sur5;
  }
  
  public static ArrayList construireTableau(ChronologiePeriodes p_chronologieActivitesSaisonnieres)
    throws CoucheLogiqueException
  {
    ArrayList tableau = new ArrayList();
    p_chronologieActivitesSaisonnieres.iterer();
    while (p_chronologieActivitesSaisonnieres.encoreSuivant())
    {
      ActiviteSalarie periodeCourant = (ActiviteSalarie)p_chronologieActivitesSaisonnieres.elementSuivant();
      tableau.add(Integer.valueOf(periodeCourant.getSecteurActivite()));
    }
    return tableau;
  }
}

/* Location:
 * Qualified Name:     DeterminationCaractereSaisonnier
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */