package fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatDeterminationDuree;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionQuantiteAffiliation;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDuree;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeDroitPourPRA;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesDureeDroit;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class DeterminationDureeReglementaire
  implements OutilFonctionnel
{
  public static final int AGE_50_ANS = 50;
  public static final int AGE_57_ANS = 57;
  public static final int INF_50ANS = 1;
  public static final int SUP_EGAL_50ANS = 2;
  public static final int SUP_EGAL_57ANS = 3;
  static final int NB_JOURS_OUVRES = 5;
  static final Damj DATE_010103 = new Damj(2003, 1, 1);
  
  private static int calculerDureeImputable(Chronologie chronologie)
    throws PasAssezInformationException
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début du calcul da la durée d'imputation." });
    
    int dureeFormationImputable = 0;
    
    chronologie.iterer();
    while (chronologie.encoreSuivant())
    {
      Quantite quantiteFormationImputableSurDuree = new Quantite("0", UniteAffiliation.HEURE_TRAVAIL);
      if ((quantiteFormationImputableSurDuree == null) || (quantiteFormationImputableSurDuree.getUnite() != Unite.get("heure de travail"))) {
        throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR02_ABS_QUANTITE_HEURES_FORM", "Il n'y a pas de quantité correspondant à l'unité heure de travail.");
      }
      int nombreHeureFormationImputable = quantiteFormationImputableSurDuree.getValeurEntiere();
      
      dureeFormationImputable += formuleCalculDureeImputation(nombreHeureFormationImputable);
    }
    return dureeFormationImputable;
  }
  
  private static int determinerCodeAge(int ageDemandeurAuFg)
  {
    if (ageDemandeurAuFg < 50) {
      return 1;
    }
    if (ageDemandeurAuFg >= 57) {
      return 3;
    }
    return 2;
  }
  
  private static int determinerDureeImputationDroitCourant(Demande demande)
    throws PasAssezInformationException
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Détermination de la durée d'imputation du droit courant." });
    
    int dureeFormationImputable = 0;
    
    Damj dateDebut = demande.getFaitGenerateur().getDateFaitGenerateur();
    Damj dateFin = demande.getOdAcquise().getDateEffet();
    Periode periodeContenantFormation = new Periode(dateDebut, dateFin);
    
    Chronologie chronologieFormationImputableSurDuree = ConstructionChronologie.determinerChronoFormationAImputer(periodeContenantFormation, demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    if (chronologieFormationImputableSurDuree != null) {
      dureeFormationImputable = calculerDureeImputable(chronologieFormationImputableSurDuree);
    }
    return dureeFormationImputable;
  }
  
  public static DureeIndemnisation determinerDureeReglementaire(Demande demande)
    throws PasAssezInformationException, CoucheLogiqueException
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la détermination des durées réglementaires." });
    
    DureeIndemnisation dureeIndemnisation = new DureeIndemnisation();
    
    Quantite dureeForcee = null;
    if (demande.getDonneesTemporaires() != null) {
      dureeForcee = demande.getDonneesTemporaires().getDureeTheoriqueForcee();
    }
    if ((dureeForcee == null) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "RECHARGE"))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ASU_OBLIGATOIRE_DUREE_RECHARG", new Object[] { demande.getDossierAffectation().getProduit().getLibelleCourt() });
    }
    if ((dureeForcee != null) && (dureeForcee.getValeur() != null))
    {
      BigDecimal plafond = new BigDecimal(1277);
      BigDecimal duree = plafond.min(dureeForcee.getValeur());
      dureeIndemnisation.setDureeTheorique(new Quantite(duree, DureeReglementaire.UNITE_DEFAUT));
      dureeIndemnisation.setDureeImputation(new Quantite(0, DureeReglementaire.UNITE_DEFAUT));
    }
    else
    {
      int dureeTheoriqueDroitCourant = determinerDureeTheoriqueDroitCourant(demande);
      Quantite qteDureeTheorique = new Quantite(dureeTheoriqueDroitCourant, DureeReglementaire.UNITE_DEFAUT);
      
      int dureeImputationDroitCourant = 0;
      if (dureeTheoriqueDroitCourant >= 1095) {
        dureeImputationDroitCourant = determinerDureeImputationDroitCourant(demande);
      }
      Quantite qteDureeImputation = new Quantite(dureeImputationDroitCourant, DureeReglementaire.UNITE_DEFAUT);
      
      dureeIndemnisation.setDureeTheorique(qteDureeTheorique);
      dureeIndemnisation.setDureeImputation(qteDureeImputation);
    }
    dureeIndemnisation.setDureeEffective(ConstitutionDuree.calculerDureeEffectivePourAdmission(demande.getDemandeur(), demande.getDossierExamen().getDateAttribution(), dureeIndemnisation.getDureeTheorique(), DureeReglementaire.UNITE_DEFAUT, ConstitutionDuree.bornageALaRetraiteApplicablePourAdmission(demande)));
    
    return dureeIndemnisation;
  }
  
  private static int determinerDureeTheoriqueDroitCourant(Demande demande)
    throws CoucheLogiqueException
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Détermination de la durée théorique du droit courant." });
    
    IndividuSpec individu = demande.getDemandeur();
    FaitGenerateurSpec faitGenerateur = demande.getFaitGenerateur();
    Damj dateFG = faitGenerateur.getDateFaitGenerateur();
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    Pra pra = dossierExamen.getConstitutionQuantiteAffiliation().getJustificationAffiliation().getPeriodePraRetenue();
    
    DureeCalendaire ageFG = individu.getAgeALaDate(dateFG);
    int codeAge = determinerCodeAge(ageFG.getAnnees());
    
    int codeCentTrimestres = 0;
    if ((demande.getDemandeur().getDateCentTrimestres() != null) && 
      (demande.getDemandeur().getDateCentTrimestres().estAvantOuCoincideAvec(dateFG))) {
      codeCentTrimestres = 1;
    }
    CleAccesDureeDroit cle = new CleAccesDureeDroit(codeAge, codeCentTrimestres);
    
    DureeDroitPourPRA duree = pra.getDureeDroit(cle);
    int dureeTheorique = duree.getDuree();
    if (demande.getDonneesTemporaires().getNbJourImputer() != null) {
      dureeTheorique -= demande.getDonneesTemporaires().getNbJourImputer().intValue();
    }
    return dureeTheorique;
  }
  
  public ResultatDeterminationDuree determinerDureeReglementairePourRepriseRevision(Demande demande)
    throws ApplicativeException
  {
    ResultatDeterminationDuree resultat = new ResultatDeterminationDuree();
    
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    Quantite qteNbJourImputer = new Quantite(0, DureeReglementaire.UNITE_DEFAUT);
    Reliquat reliquat = demande.getReliquat();
    Quantite quantiteReliquat = new Quantite(reliquat.getQuantiteReliquat().getValeurEntiere(), DureeReglementaire.UNITE_DEFAUT);
    if (demande.getDonneesTemporaires().getNbJourImputer() != null)
    {
      qteNbJourImputer = new Quantite(demande.getDonneesTemporaires().getNbJourImputer().intValue(), DureeReglementaire.UNITE_DEFAUT);
      quantiteReliquat = quantiteReliquat.soustraire(qteNbJourImputer);
    }
    Quantite qteTotalJourImputation = reliquat.getQuantiteImputee().ajouter(qteNbJourImputer);
    resultat.setQuantiteJourImputationForce(qteNbJourImputer);
    resultat.setQuantiteTotalJourImputation(qteTotalJourImputation);
    resultat.setDureeTheorique(quantiteReliquat);
    resultat.setDureeImputation(qteTotalJourImputation);
    if (((demande.estUneDemandeFinDroit()) || (demande.estUneDemandeFinancement())) && (quantiteReliquat.getValeurEntiere() == 0)) {
      resultat.setDureeEffective(new Quantite(0, DureeReglementaire.UNITE_DEFAUT));
    } else {
      resultat.setDureeEffective(ConstitutionDuree.calculerDureeEffectivePourReprise(demande.getDemandeur(), dossierExamen.getDateAttribution(), quantiteReliquat, DureeReglementaire.UNITE_DEFAUT, true));
    }
    return resultat;
  }
  
  private static int formuleCalculDureeImputation(int nombreHeure)
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Application de la formule." });
    
    return (int)Math.floor(nombreHeure / 5 * 1 / 2);
  }
  
  public void mapperResultatSurDom(ResultatDeterminationDuree resultat, DureeIndemnisation dureeIndemnisation)
  {
    dureeIndemnisation.setDureeImputation(resultat.getDureeImputation());
    dureeIndemnisation.setDureeTheorique(resultat.getDureeTheorique());
    dureeIndemnisation.setDureeEffective(resultat.getDureeEffective());
    dureeIndemnisation.setDureeImputation(resultat.getDureeImputation());
  }
}

/* Location:
 * Qualified Name:     DeterminationDureeReglementaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */