package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilGestionActivitesConservees;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieActiviteConserveeConvention2014Spec;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.DeterminationSjcip;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P02;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesEntreeConstructionChronologie;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import java.util.Collection;
import java.util.Iterator;

public class ConstitutionSjc
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Sjc impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution courante est null: constitution du Sjc impossible.");
    }
    if (dossierExamenCourant.getReglementApplicable() == null) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_RA", "Le règlement applicable de l'ouverture de droits courante est null: constitution du Sjc impossible.");
    }
    if (dossierExamenCourant.getConstitutionSjr().getSjrip() == null) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_SJRIP", "Le SJRIP de l'ouverture de droits courante est null: constitution du Sjc impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (Log.isTraceActive(ConstitutionSjc.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjc.class, "demarrer", "\t\t******** Début Parcours ConstitutionSjc ********");
    }
    Resultat resultatCEPA10 = new Resultat();
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    StrategieActiviteConserveeConvention2014Spec strategieActiviteConservee = OutilGestionActivitesConservees.getInstance().recupererStrategieActiviteConserveeConvention2014(demandeCourante);
    
    Reglement reglementApplicableCourant = dossierExamenCourant.getReglementApplicable().getReglement();
    if ((!strategieActiviteConservee.constituerSalaireJournalierConserve(demandeCourante)) || (reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A4"))))
    {
      resultatCEPA10.setEtat(1);
    }
    else
    {
      fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjc constitutionSjc = new fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjc();
      
      dossierExamenCourant.setConstitutionSjc(constitutionSjc);
      Sjcip sjcipCourant = null;
      
      controlerContexte(p_contexte);
      
      Sjrip sjripOdCourante = dossierExamenCourant.getConstitutionSjr().getSjrip();
      
      sjcipCourant = DeterminationSjcip.determinerSjcip(demandeCourante, sjripOdCourante);
      
      DonneesEntreeConstructionChronologie donneesEntree = fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.mapperDemandeDonneesEntreeConstructionChronologie(demandeCourante);
      Chronologie chronoGlobaleActivitesConservees = fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionChronologie.determinerChronoActivitesConservees(donneesEntree);
      
      Quantite sjcForce = demandeCourante.getDonneesTemporaires().getSjc();
      if (sjcForce != null)
      {
        if (chronoGlobaleActivitesConservees.estVide()) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_L_CEPA10_SJCIP_FORCE_A_TORT");
        }
        sjcipCourant.setSjcInitial(new QuantiteEuro(sjcForce.getValeur()));
      }
      completerSjcipAvecActivitesConserveesNonRetenues(sjcipCourant, chronoGlobaleActivitesConservees);
      
      dossierExamenCourant.getConstitutionSjc().setSjcip(sjcipCourant);
      
      dossierExamenCourant.getConstitutionSjc().setSjcrp(DeterminationSjcip.revaloriserSjcip(dossierExamenCourant.getDateAttribution(), sjcipCourant));
      
      resultatCEPA10.setEtat(0);
    }
    if (Log.isTraceActive(ConstitutionSjc.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjc.class, "demarrer", "");
    }
    if (Log.isTraceActive(ConstitutionSjc.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjc.class, "demarrer", "\t\t******** Résultat Parcours ConstitutionSjc ********\n" + resultatCEPA10);
    }
    if (Log.isTraceActive(ConstitutionSjc.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjc.class, "demarrer", "");
    }
    if (Log.isTraceActive(ConstitutionSjc.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjc.class, "demarrer", "\t\t******** Fin Parcours ConstitutionSjc ********\n");
    }
    return resultatCEPA10;
  }
  
  private void completerSjcipAvecActivitesConserveesNonRetenues(Sjcip p_sjcipCourant, Chronologie p_chronoGlobaleActivitesConservees)
  {
    p_chronoGlobaleActivitesConservees.iterer();
    TravailSpec activiteConserveeCourante = null;
    SjrActiviteConservee sjrActiviteConserveNonRetenue = null;
    while (p_chronoGlobaleActivitesConservees.encoreSuivant())
    {
      activiteConserveeCourante = (TravailSpec)p_chronoGlobaleActivitesConservees.elementSuivant();
      if (!activiteConserveeDejaRetenueSjcip(activiteConserveeCourante, p_sjcipCourant))
      {
        sjrActiviteConserveNonRetenue = new SjrActiviteConservee(new QuantiteEuro("0"));
        sjrActiviteConserveNonRetenue.setPeriodeActiviteConservee(activiteConserveeCourante);
        p_sjcipCourant.ajouterSjrActiviteConserve(sjrActiviteConserveNonRetenue);
      }
    }
  }
  
  private boolean activiteConserveeDejaRetenueSjcip(TravailSpec p_activiteConserveeCourante, Sjcip p_sjcipCourant)
  {
    boolean activiteConserveeDejaTraitee = false;
    
    SjrActiviteConservee sjrActiviteConserveCourant = null;
    Iterator iterateur = p_sjcipCourant.getListeSjrActiviteConserve().iterator();
    while ((iterateur.hasNext()) && (!activiteConserveeDejaTraitee))
    {
      sjrActiviteConserveCourant = (SjrActiviteConservee)iterateur.next();
      if (sjrActiviteConserveCourant.getIdentifiantPeriodeActiviteConservee().equalsIgnoreCase(p_activiteConserveeCourante.getIdentifiant())) {
        activiteConserveeDejaTraitee = true;
      }
    }
    return activiteConserveeDejaTraitee;
  }
}

/* Location:
 * Qualified Name:     ConstitutionSjc
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */