package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.DeterminationSjrip;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P02;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;

public class ConstitutionSjrPourReprise
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Sjr impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution courante est null: constitution du Sjr impossible.");
    }
    if (dossierExamenCourant.getAttributionPrecedente() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "L'attribution précédente est nulle : constitution du Sjr impossible.");
    }
    if (((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionSjr().getSjrip() == null) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_SJRIP", "Le SJRIP de l'ouverture de droits courante est null: constitution du Sjc impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (Log.isTraceActive(ConstitutionSjrPourReprise.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjrPourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjrPourReprise.class, "demarrer", "\t\t******** Début Parcours ConstitutionSjrPourReprise ********");
    }
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    DossierExamen dossierExamen = (DossierExamen)demandeCourante.getDossierExamen();
    Reglement reglementApplicableCourant = dossierExamen.getReglementApplicable().getReglement();
    
    ConstitutionSjr constitutionSjr = new ConstitutionSjr();
    dossierExamen.setConstitutionSjr(constitutionSjr);
    
    Sjrip sjripCourant = DeterminationSjrip.determinerSjripPourReprise(demandeCourante);
    if (sjripCourant != null)
    {
      dossierExamen.getConstitutionSjr().setSjrip(sjripCourant);
      if (reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A2b")))
      {
        Sjr sjrA2b = new Sjr(sjripCourant.getSjrInitial().getValeur(), sjripCourant.getDateEffet(), null);
        dossierExamen.getConstitutionSjr().setSjrrp(sjrA2b);
      }
      else
      {
        dossierExamen.getConstitutionSjr().setSjrrp(DeterminationSjrip.revaloriserSjr(dossierExamen.getConstitutionSjr().getSjrip(), dossierExamen.getDateAttribution()));
      }
    }
    else
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_SJRIP_COURANT_NULL");
    }
    if (Log.isTraceActive(ConstitutionSjrPourReprise.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjrPourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjrPourReprise.class, "demarrer", "\t\t******** Fin Parcours ConstitutionSjrPourReprise ********\n");
    }
    return new Resultat();
  }
}

/* Location:
 * Qualified Name:     ConstitutionSjrPourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */