package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.mnt.dom.ConditionDecisionCPMaintien;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.DonneesForcees;
import fr.unedic.cali.asu.mnt.dom.DossierExamen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.spec.ConstantesContratTravail;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import java.math.BigDecimal;

public class DeterminationConditionDecisionCPPourMaintien
  extends ParcoursCali
  implements ParcoursAssurance
{
  static final int ACTIVITE_365_JOURS = 365;
  
  public static DemandeSpec getDemande(Contexte p_contexte)
  {
    return ((DomLiquidationDemande)p_contexte.getDonnees()).getDemandeSpec();
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    Resultat resultatCam05 = new Resultat(1);
    DemandeMaintien demandeMaintien = (DemandeMaintien)getDemande(p_contexte);
    if (Log.isTraceActive(DeterminationConditionDecisionCPPourMaintien.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionDecisionCPPourMaintien.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionDecisionCPPourMaintien.class, "demarrer", "\t\t******** Début Parcours DeterminationConditionDecisionCPPourMaintien ********\n");
    }
    ConditionDecisionCPMaintien conditionDecisionCP = new ConditionDecisionCPMaintien();
    
    conditionDecisionCP.setEtatSatisfait(true);
    conditionDecisionCP.setDecisionCPFavorable(true);
    if (demandeMaintien.getDonneesForcees().getDecisionCPFavorable() != 0)
    {
      conditionDecisionCP.setDepartVolontaire(demandeMaintien.getDonneesForcees().estMotifDepartVolontaire());
      conditionDecisionCP.setRefusFNE(demandeMaintien.getDonneesForcees().estMotifRefusFNE());
      conditionDecisionCP.setDecisionCPFavorable(demandeMaintien.getDonneesForcees().estDecisionCPFavorable());
      if (!demandeMaintien.getDonneesForcees().estDecisionCPFavorable())
      {
        conditionDecisionCP.setCodeMotifEchec(986);
        conditionDecisionCP.setEtatSatisfait(false);
      }
    }
    else
    {
      BigDecimal refusFneSurFaitGenerateur = demandeMaintien.getDemandeMaintenue().getFaitGenerateur().getRefusFne();
      String refusFneSurFonctionSigma = demandeMaintien.getDemandeMaintenue().getRefusPropositionFNE();
      if ((refusFneSurFaitGenerateur != null) && (refusFneSurFonctionSigma != null))
      {
        if ((ConstantesContratTravail.REFUS_FNE_NON_RENSEIGNE.equals(refusFneSurFaitGenerateur)) && (" ".equals(refusFneSurFonctionSigma)))
        {
          FaitGenerateurSpec faitGenerateur = demandeMaintien.getFGDDroitMaintenu();
          if ((estMotifFctValide(faitGenerateur)) && (!estEmployeurParticulier(faitGenerateur)) && (activiteEqualsOuSuperieur365Jours(faitGenerateur)))
          {
            conditionDecisionCP.setCodeMotifEchec(987);
            conditionDecisionCP.setEtatSatisfait(false);
          }
          else
          {
            conditionDecisionCP.setRefusFNE(false);
          }
        }
        else if (!ConstantesContratTravail.REFUS_FNE_NON_RENSEIGNE.equals(refusFneSurFaitGenerateur))
        {
          if (ConstantesContratTravail.FNE_REFUSE.equals(refusFneSurFaitGenerateur))
          {
            conditionDecisionCP.setRefusFNE(true);
            conditionDecisionCP.setCodeMotifEchec(986);
            conditionDecisionCP.setEtatSatisfait(false);
          }
          else if (ConstantesContratTravail.FNE_ACCEPTE.equals(refusFneSurFaitGenerateur))
          {
            conditionDecisionCP.setRefusFNE(false);
          }
        }
        else if ("O".equals(refusFneSurFonctionSigma))
        {
          conditionDecisionCP.setRefusFNE(true);
          conditionDecisionCP.setCodeMotifEchec(986);
          conditionDecisionCP.setEtatSatisfait(false);
        }
        else
        {
          conditionDecisionCP.setRefusFNE(false);
        }
      }
      else
      {
        conditionDecisionCP.setCodeMotifEchec(986);
        conditionDecisionCP.setEtatSatisfait(false);
      }
    }
    if (conditionDecisionCP.estSatisfait())
    {
      resultatCam05.setEtat(0);
    }
    else
    {
      resultatCam05.setEtat(1);
      resultatCam05.setMessageErreur(Integer.toString(conditionDecisionCP.getCodeMotifEchec()));
    }
    demandeMaintien.getDossierExamen().setConditionDecisionCP(conditionDecisionCP);
    if (Log.isTraceActive(DeterminationConditionDecisionCPPourMaintien.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionDecisionCPPourMaintien.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionDecisionCPPourMaintien.class, "demarrer", "\t\t******** Fin Parcours DeterminationConditionDecisionCPPourMaintien ********\n");
    }
    return resultatCam05;
  }
  
  private boolean estMotifFctValide(FaitGenerateurSpec p_faitGenerateur)
  {
    int motifFct = Integer.parseInt(p_faitGenerateur.getPeriodeFaitGenerateur().getMotifFin());
    return (motifFct == 6) || (motifFct == 1) || (motifFct == 2);
  }
  
  private boolean estEmployeurParticulier(FaitGenerateurSpec p_faitGenerateur)
  {
    return (p_faitGenerateur.getPeriodeFaitGenerateur().getEntreprise().getCodeNAF() == null) && (p_faitGenerateur.getPeriodeFaitGenerateur().getEntreprise().getUrssaf() != null);
  }
  
  private boolean activiteEqualsOuSuperieur365Jours(FaitGenerateurSpec p_faitGenerateur)
  {
    return p_faitGenerateur.getPeriodeFaitGenerateur().getDuree() > 365;
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionDecisionCPPourMaintien
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */