package fr.unedic.cali.asu.cge01.p03.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.calcul.FacadeCalculProduitPourLiquidationAsuAbstraite;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.OutilsAlimentationDonneesCalculMontant;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.RecuperationPensionInvaliditeAvantDate;
import fr.unedic.cali.asu.cge01.calcul.dom.FormuleMontantAREF;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cge01.p03.calcul.dom.FormuleMontantRegimeGeneral;
import fr.unedic.cali.asu.cge01.p03.calcul.outilsfonctionnels.ActiviteReduite;
import fr.unedic.cali.asu.cge01.p03.calcul.outilsfonctionnels.DeterminationReliquat;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisationAREF;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.mnt.outilsfonctionnels.OutilsMaintien;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMappingSjmSjr;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvant;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.outilsfonctionnels.OutilGestionPoursuite;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationAvantageVieillesseAvantPJI;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P03;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.AppelAvant;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.cali.parcours.DomAvantPilotage;
import fr.unedic.cali.parcours.DomCalculPilotage;
import fr.unedic.cali.parcours.ParcoursAvantPilotageElementsIndemnisation;
import fr.unedic.cali.parcours.ParcoursCalculPilotageDeterminationEtatDroit;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.cali.parcours.ResultatDeterminationEtatDroitProduit;
import fr.unedic.cali.parcours.ResultatPilotage;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.List;

public class FacadeCalculProduitPourLiquidationImpl
  extends FacadeCalculProduitPourLiquidationAsuAbstraite
{
  private static final int CINQUANTE_ANS = 50;
  private static final int DIVISEUR_COEF_AV = 10;
  
  public FormuleMontantSpec getFormuleMontant()
  {
    return new FormuleMontantRegimeGeneral();
  }
  
  public FormuleMontantSpec getFormuleMontantEnFormation()
  {
    return new FormuleMontantAREF();
  }
  
  public boolean determinerPrecompteCRC(AttributionSpec pattribution)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)pattribution;
    
    return (attribution.getCompetenceFinanciere() == 2) && ((attribution.getCompetenceAdministrative() != 1) || ((attribution.getConventionGestion() != null) && (!attribution.getConventionGestion().estPrecompteCRC())));
  }
  
  public Quantite calculerCapital(AttributionSpec attribution, MontantAsuSpec pmontant, Damj pointDeDepart, Quantite nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    IndividuSpec individu = attribution.getDemandeur();
    
    BigDecimal capital = new BigDecimal("0.00");
    
    Damj pji = pointDeDepart;
    
    boolean bornerRetraite = true;
    DonneesTemporaires donneesForcees = ((Demande)attribution.getDemande()).getDonneesTemporaires();
    if (donneesForcees != null) {
      bornerRetraite = !donneesForcees.isLeverBornageDureeEffectiveRetraite();
    }
    int dureeDroit = OutilRetraite.getInstance().bornerDureeALaRetraite(individu, pointDeDepart, nbJoursIndemnisables, bornerRetraite);
    Damj dji = pji.deplacerVersAvant(new DureeCalendaire(0, 0, dureeDroit));
    if (pji.estAvant(dji))
    {
      BigDecimal montant = pmontant.getMontantPrecompteEffectif().getValeur();
      
      capital = montant.multiply(new BigDecimal(dureeDroit));
    }
    return new QuantiteEuro(capital);
  }
  
  public Quantite calculerCapital(AttributionSpec attribution, Damj dateAttribution, Damj pointDeDepart, Quantite nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public Quantite determinerDureeEffectiveReliquat(Quantite quantiteInitiale, Quantite nbHeuresFormation)
    throws IllegalArgumentException
  {
    return DeterminationReliquat.determinerDureeEffectiveReliquat(quantiteInitiale, nbHeuresFormation);
  }
  
  public Damj determinerDateConditionNombreJoursIndemnisesNecessaireMaintien(AttributionSpec attribution)
    throws ApplicativeException
  {
    Damj pjeNcp = null;
    Damj dateConditionNombreJoursIndemnisesNecessaireMaintien = null;
    CalendrierExecutionCalculPeriodique calendrier = null;
    if (attribution == null) {
      return null;
    }
    if (dateConditionNombreJoursIndemnisesNecessaireMaintien == null)
    {
      calendrier = (CalendrierExecutionCalculPeriodique)attribution.getCalendrierExecutionCalcul();
      if (calendrier != null) {
        dateConditionNombreJoursIndemnisesNecessaireMaintien = OutilsMaintien.determinerDateConditionNombreJoursIndemnisesNecessaireMaintien(calendrier);
      }
    }
    if (dateConditionNombreJoursIndemnisesNecessaireMaintien == null)
    {
      ResultatDeterminationEtatDroitProduit resultat = null;
      
      Damj dateEtude = Damj.FIN_DES_TEMPS;
      List listeAttributions = attribution.getDemandeur().getListeAttributionsExecutablesAvant(attribution.getDateEffet());
      if (!listeAttributions.isEmpty())
      {
        AppelAvant.executerAvant(listeAttributions, dateEtude);
        pjeNcp = OutilGestionPoursuite.getInstance().recupererPremierJourExecutableNcp(attribution);
        if ((dateEtude.estApresOuCoincideAvec(pjeNcp)) && ((attribution == null) || (listeAttributions.contains(attribution))))
        {
          DomCalculPilotage domCalcul = new DomCalculPilotage();
          domCalcul.setIndividu(attribution.getDemandeur());
          domCalcul.setListeAttributions(listeAttributions);
          domCalcul.setAttributionAEtudier(attribution);
          domCalcul.setDateEtatDroit(dateEtude);
          domCalcul.setDateDebutExecution(pjeNcp);
          domCalcul.setContexteService(domCalcul.getIndividu().getContexteService());
          
          Contexte contexteCalcul = new Contexte();
          contexteCalcul.setDonnees(domCalcul);
          
          Parcours parcours = new ParcoursCalculPilotageDeterminationEtatDroit();
          ResultatPilotage resultatPilotage = (ResultatPilotage)parcours.effectuerParcours(contexteCalcul);
          
          resultat = (ResultatDeterminationEtatDroitProduit)resultatPilotage.getResultatDetaille(attribution);
        }
      }
      if (resultat != null) {
        calendrier = (CalendrierExecutionCalculPeriodique)resultat.getCalendrierExecutionCalcul();
      }
      if (calendrier != null) {
        dateConditionNombreJoursIndemnisesNecessaireMaintien = OutilsMaintien.determinerDateConditionNombreJoursIndemnisesNecessaireMaintien(calendrier);
      }
    }
    return dateConditionNombreJoursIndemnisesNecessaireMaintien;
  }
  
  public ConstituantsIndemnisation initialiserConstituantsIndemnisation(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    Damj dateCalcul = donneesEntreesRecuperationMontant.getDateCalculMontant();
    Damj dateAttribution = donneesEntreesRecuperationMontant.getDateAttribution();
    IndividuSpec individu = donneesEntreesRecuperationMontant.getIndividu();
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    ElementBaseIndemnisation elementBaseIndemnisationCourant = new ElementBaseIndemnisation();
    constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationCourant);
    
    OutilsAlimentationDonneesCalculMontant.alimenterDonneesEbiCasGeneral(donneesEntreesRecuperationMontant, elementBaseIndemnisationCourant);
    
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    
    Sjr sjr = OutilMappingSjmSjr.convertirSjr((Sjr)donneesCalculMontant.getSalaireJournalier());
    
    elementBaseIndemnisationCourant.setSjr(sjr);
    
    Sjr sjrRevalorise = RevalorisationSalaire.revaloriserSjr(elementBaseIndemnisationCourant, ProduitAsuCge01P03.getInstance(), dateCalcul);
    elementBaseIndemnisationCourant.setSjr(sjrRevalorise);
    if (donneesCalculMontant.getCoefficientSaisonnier() != null)
    {
      elementBaseIndemnisationCourant.setCoefficientSaisonnier(donneesCalculMontant.getCoefficientSaisonnier());
      if ((donneesCalculMontant.getCoefficientSaisonnier().intValue() != 1) && (individu.getAgeALaDate(dateCalcul).getAnnees() >= 50)) {
        if ((donneesCalculMontant.getTypeCaractereSaisonnierRetenu() == 1) && (donneesCalculMontant.isConditionCaractereSaisonnierParRythme())) {
          elementBaseIndemnisationCourant.setCoefficientSaisonnier(new BigDecimal("1.00"));
        }
      }
    }
    if (donneesCalculMontant.getCoefficientTempsPartiel() != null) {
      elementBaseIndemnisationCourant.setCoefficientTempsPartiel(donneesCalculMontant.getCoefficientTempsPartiel());
    }
    if (donneesCalculMontant.isPriseEnComptePensionInvalidite())
    {
      Boolean gerePensionInvalidite = donneesCalculMontant.getEstProduitGerantPensionInvalidite();
      if ((gerePensionInvalidite != null) && (gerePensionInvalidite.booleanValue()))
      {
        elementBaseIndemnisationCourant.setListePensionInvalidite(donneesCalculMontant.getListePensionInvalidite());
        elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPIChainees(elementBaseIndemnisationCourant, individu, dateCalcul, dateAttribution));
      }
      else
      {
        elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPI(individu, dateCalcul));
      }
    }
    else
    {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(new BigDecimal("0.00"));
    }
    if (donneesCalculMontant.isPriseEnCompteAvantageVieillesse())
    {
      PeriodeAvantageVieillesse periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(individu, dateCalcul);
      
      BigDecimal montantAV = BigDecimal.ZERO;
      if (periodeAvCourante != null)
      {
        montantAV = periodeAvCourante.getQuantiteEuro().getValeur();
        
        elementBaseIndemnisationCourant.setDateEffetAV(dateCalcul);
      }
      BigDecimal coeffAV = new BigDecimal("0.00");
      if ((sjrRevalorise != null) && (sjrRevalorise.getSalaire() != null) && (!sjrRevalorise.getSalaire().equals(new BigDecimal("0.00")))) {
        coeffAV = montantAV.divide(sjrRevalorise.getSalaire(), 10, 4);
      }
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(montantAV);
      elementBaseIndemnisationCourant.setCoefficientSanctionReduction(new BigDecimal("1.00"));
      
      BigDecimal tauxavantageVieillesse = parametresIndemnisation.getTauxAvantageViellesse(individu.getAgeALaDate(dateCalcul));
      if (tauxavantageVieillesse != null) {
        elementBaseIndemnisationCourant.setTauxAvantageVieillesse(tauxavantageVieillesse);
      }
    }
    else
    {
      elementBaseIndemnisationCourant.setDateEffetAV(donneesCalculMontant.getDateEffetAV());
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(donneesCalculMontant.getCoefficientAvantageVieillesse());
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(donneesCalculMontant.getMontantAvantageVieillesse());
    }
    if (donneesCalculMontant.getAvecPrecompteCRC() != null) {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(donneesCalculMontant.getAvecPrecompteCRC());
    } else if ((donneesEntreesRecuperationMontant.getCompetences().getCompetenceFinanciere() == 2) && ((donneesEntreesRecuperationMontant.getCompetences().getCompetenceAdministrative() != 1) || ((donneesEntreesRecuperationMontant.getCompetences().getConventionGestion() != null) && (!donneesEntreesRecuperationMontant.getCompetences().getConventionGestion().estPrecompteCRC())))) {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(Boolean.FALSE);
    }
    elementBaseIndemnisationCourant.setProduitMontantRetenu((ProduitAsuSpec)donneesCalculMontant.getProduit());
    if (donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie() != null)
    {
      donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie().setDateCalculMontant(donneesEntreesRecuperationMontant.getDateCalculMontant());
      
      donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie().setIndividu(donneesEntreesRecuperationMontant.getIndividu());
      
      elementBaseIndemnisationCourant.setElementBaseIndemnisationDroitAssocie((ElementBaseIndemnisation)initialiserConstituantsIndemnisation(donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie()).getElementBaseIndemnisationCourant());
    }
    if (donneesCalculMontant.isContexteFormation())
    {
      ElementBaseIndemnisationAREF ebiAREF = new ElementBaseIndemnisationAREF(elementBaseIndemnisationCourant);
      constituantsIndemnisation.setElementBaseIndemnisationCourant(ebiAREF);
    }
    return constituantsIndemnisation;
  }
  
  public Periode determinerPeriodeAvantSansCalendrier(AttributionSpec attribution)
    throws ApplicativeException
  {
    DomAvantPilotage domAvantPilotage = null;
    Contexte contexteCalcul = null;
    Parcours parcoursAvant = null;
    ResultatAvant resultat = null;
    
    domAvantPilotage = new DomAvantPilotage(attribution);
    domAvantPilotage.setAvecPriseEnCompteEvenement(true);
    contexteCalcul = new Contexte();
    contexteCalcul.setDonnees(domAvantPilotage);
    
    parcoursAvant = new ParcoursAvantPilotageElementsIndemnisation();
    
    resultat = (ResultatAvant)parcoursAvant.effectuerParcours(contexteCalcul);
    if ((((attribution instanceof RevisionSpec)) && (resultat.getPremierJourAvant() == null)) || (resultat.getDernierJourAvant().estAvant(resultat.getPremierJourAvant()))) {
      return null;
    }
    return new Periode(resultat.getPremierJourAvant(), resultat.getDernierJourAvant());
  }
  
  public BigDecimal getSeuilRenumeration(AttributionSpec pattribution, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)pattribution;
    ElementBaseIndemnisation ebi = attribution.getElementBaseIndemnisation();
    BigDecimal sjr = null;
    if (ebi.getSjr() != null) {
      sjr = RevalorisationSalaire.revaloriserSjr(ebi.getSjr(), dateCalcul).getSalaire();
    }
    boolean apprenti = ((Attribution)pattribution).isTopContratsRemuneresBaseSmic();
    Chronologie chronoPeriodesConserveesLiq = attribution.getListeActiviteConservee();
    boolean estAvecSjc = false;
    
    BigDecimal sjc = BigDecimal.ONE;
    if ((ebi.getSjc() != null) && (!chronoPeriodesConserveesLiq.estVide()))
    {
      estAvecSjc = true;
      sjc = RevalorisationSalaire.revaloriserSjc(ebi.getSjc(), dateCalcul).getSalaire();
    }
    return ActiviteReduite.calculerSeuilMensuel(dateCalcul, sjr, sjc, apprenti, estAvecSjc, BigDecimal.ONE);
  }
  
  public MontantBaseSpec determinerMontant(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    FormuleMontantSpec formuleMontant = null;
    ConstituantsIndemnisation constituantsIndemnisation = initialiserConstituantsIndemnisation(donneesEntreesRecuperationMontant);
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    if (donneesCalculMontant.getFormuleMontant() != null) {
      formuleMontant = donneesCalculMontant.getFormuleMontant();
    } else if (donneesCalculMontant.isContexteFormation()) {
      formuleMontant = getFormuleMontantEnFormation();
    } else {
      formuleMontant = getFormuleMontant();
    }
    return formuleMontant.calculer(constituantsIndemnisation, donneesEntreesRecuperationMontant.getDateCalculMontant());
  }
  
  public MontantBaseSpec determinerMontant(AttributionSpec attribution, Damj dateCalcul)
    throws ApplicativeException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
  
  public Damj recupererDateDrv(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    CalendrierExecutionAvant calAvant = (CalendrierExecutionAvant)attribution.getCalendrierExecutionAvant();
    CalendrierExecutionCalculPeriodique calPeriodique = (CalendrierExecutionCalculPeriodique)attribution.getCalendrierExecutionCalcul();
    Damj dateDrv = null;
    if ((calAvant != null) && (calAvant.getDateDrv() != null)) {
      dateDrv = calAvant.getDateDrv();
    } else if (calPeriodique != null) {
      dateDrv = calPeriodique.getDateDrv();
    }
    return dateDrv;
  }
  
  public Damj recupererDateEpuisementDuree(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    CalendrierExecutionCalculPeriodique calPeriodique = (CalendrierExecutionCalculPeriodique)attribution.getCalendrierExecutionCalcul();
    Damj dateEpuisementDuree = null;
    if (calPeriodique != null) {
      dateEpuisementDuree = calPeriodique.getDateEpuisementDuree();
    }
    return dateEpuisementDuree;
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitPourLiquidationImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */