package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.DecisionGen;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public abstract class Decision
  extends DecisionGen
  implements DecisionAssuranceSpec
{
  private static final long serialVersionUID = 1L;
  
  protected Decision() {}
  
  public Decision(DomPCSpec pc)
  {
    super(pc);
  }
  
  protected Decision(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public ConditionsAttributionSpec getConditionsAttributionActives()
  {
    ObjectifExamen objectifCourant = recupererObjectifActif();
    
    int typeObjectif = objectifCourant.getType();
    switch (typeObjectif)
    {
    case 2: 
    case 5: 
    case 6: 
      return getConditionsAttributionReprise();
    case 4: 
      return getConditionsAttributionRevision();
    }
    return getConditionsAttributionAdmission();
  }
  
  public ConstitutionElementsSpec getConstitutionElementsActifs()
  {
    ObjectifExamen objectifCourant = recupererObjectifActif();
    
    int typeObjectif = objectifCourant.getType();
    switch (typeObjectif)
    {
    case 2: 
    case 5: 
    case 6: 
      return getConstitutionElementsReprise();
    case 4: 
      return getConstitutionElementsRevision();
    }
    return getConstitutionElementsAdmission();
  }
  
  public ObjectifExamen recupererObjectifActif()
  {
    ObjectifExamen objectifCourant = ((Demande)getDemande()).getObjectifCourant();
    if (objectifCourant == null) {
      objectifCourant = ((Demande)getDemande()).getObjectifDecisionne();
    }
    return objectifCourant;
  }
  
  public boolean estValidee()
  {
    return isValidee();
  }
  
  public void copieElements(ObjetMetierSpec copieMetier)
  {
    Decision copie = (Decision)copieMetier;
    
    super.copieElements(copie);
    copie.setNatureDecision(getNatureDecision());
    copie.setValidee(estValidee());
    copie.setInvestigationFraude(isInvestigationFraude());
  }
  
  public Chronologie getListeActiviteConservee()
  {
    Chronologie chronoActiviteConservee = new ChronologiePeriodes();
    if ((getConstitutionSjc() != null) && (getConstitutionSjc().getSjcip() != null))
    {
      Collection<?> listeActiviteConservees = getConstitutionSjc().getSjcip().getCollectionSjrActiviteConservee();
      
      Iterator<?> iteratorActiviteConservee = listeActiviteConservees.iterator();
      while (iteratorActiviteConservee.hasNext())
      {
        SjrActiviteConservee activiteConserveCourante = (SjrActiviteConservee)iteratorActiviteConservee.next();
        
        TravailSpec activiteConservee = activiteConserveCourante.getPeriodeActiviteConservee();
        if (activiteConservee != null) {
          chronoActiviteConservee.ajouter(activiteConservee);
        }
      }
    }
    return chronoActiviteConservee;
  }
  
  public Chronologie getListeActiviteConserveePerdues()
  {
    Chronologie chronoActiviteConservee = new ChronologiePeriodes();
    if ((getConstitutionSjc() != null) && (getConstitutionSjc().getSjcip() != null))
    {
      Collection<?> listeActiviteConservees = getConstitutionSjc().getSjcip().getCollectionSjrActiviteConserveePerdue();
      
      Iterator<?> iteratorActiviteConservee = listeActiviteConservees.iterator();
      while (iteratorActiviteConservee.hasNext())
      {
        SjrActiviteConservee activiteConserveCourante = (SjrActiviteConservee)iteratorActiviteConservee.next();
        
        TravailSpec activiteConservee = activiteConserveCourante.getPeriodeActiviteConservee();
        if (activiteConservee != null) {
          chronoActiviteConservee.ajouter(activiteConservee);
        }
      }
    }
    return chronoActiviteConservee;
  }
  
  public int getCompetenceAdministrative()
  {
    return getCompetence().getCompetenceAdministrative();
  }
  
  public int getCompetenceFinanciere()
  {
    return getCompetence().getCompetenceFinanciere();
  }
  
  public List<TravailSpec> getListeActiviteConserveePerduesRevisees()
  {
    return new ArrayList();
  }
  
  public ConditionQuantiteAffiliationSpec getConditionAffiliation()
  {
    ConditionQuantiteAffiliationSpec condition = null;
    if (getConditionsAttributionAdmission() != null) {
      condition = getConditionsAttributionAdmission().getConditionQuantiteAffiliation();
    }
    return condition;
  }
  
  public String determinerCodeSousProduitPourSigma()
  {
    return null;
  }
}

/* Location:
 * Qualified Name:     Decision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */