package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.EchecGen;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ContributionParticuliereSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.ContributionParticuliere;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EchecSpec;
import fr.unedic.cali.dom.OdAssuranceSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class Echec
  extends EchecGen
  implements EchecSpec
{
  private static final long serialVersionUID = 1L;
  
  public Echec() {}
  
  public Echec(DomPCSpec echecPC)
  {
    super(echecPC);
  }
  
  public Echec(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public Echec(Damj dateEvenement, DossierExamen dossierExamen)
  {
    super(dateEvenement);
    copie(dossierExamen);
  }
  
  protected void copie(Attribution source)
  {
    if (source == null) {
      return;
    }
    super.copie(source);
  }
  
  public ObjetMetierSpec copie()
  {
    Echec copie = new Echec();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    Echec copie = (Echec)p_copie;
    if (getConditionsAttributionAdmission() == null) {
      setConditionsAttributionAdmission(new ConditionsAttributionAdmission());
    }
    getConditionsAttributionAdmission().copieElements(copie.getConditionsAttributionAdmission());
    if (getConstitutionElementsAdmission() == null) {
      setConstitutionElementsAdmission(new ConstitutionElementsAdmission());
    }
    getConstitutionElementsAdmission().copieElements(copie.getConstitutionElementsAdmission());
    if (getConditionsAttributionReprise() == null) {
      setConditionsAttributionReprise(new ConditionsAttributionReprise());
    }
    getConditionsAttributionReprise().copieElements(copie.getConditionsAttributionReprise());
    if (getConstitutionElementsReprise() == null) {
      setConstitutionElementsReprise(new ConstitutionElementsReprise());
    }
    getConstitutionElementsReprise().copieElements(copie.getConstitutionElementsReprise());
    if (getConditionsAttributionRevision() == null) {
      setConditionsAttributionRevision(new ConditionsAttributionRevision());
    }
    getConditionsAttributionRevision().copieElements(copie.getConditionsAttributionRevision());
    if (getConstitutionElementsRevision() == null) {
      setConstitutionElementsRevision(new ConstitutionElementsRevision());
    }
    getConstitutionElementsRevision().copieElements(copie.getConstitutionElementsRevision());
    if (getCompetence() != null) {
      copie.setCompetence((Competence)getCompetence().copie());
    }
    copie.setContexteDdeExpresse(getContexteDdeExpresse());
    if (getContributionParticuliere() != null) {
      copie.setContributionParticuliere((ContributionParticuliere)getContributionParticuliere().copie());
    }
    copie.setDateEvenement(getDateEvenement());
    copie.setNatureDecision(getNatureDecision());
    copie.setAttributionPrecedente(getAttributionPrecedente());
  }
  
  public JustificationAffiliationSpec getJustificationAffiliation()
  {
    return getConstitutionQuantiteAffiliation().getJustificationAffiliation();
  }
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete() {}
  
  public void jdoPostLoad() {}
  
  public void jdoPreStore() {}
  
  public ConstitutionSjr getConstitutionSjr()
  {
    return getConstitutionElementsRevision().getConstitutionSjr();
  }
  
  public ConstitutionSjc getConstitutionSjc()
  {
    return getConstitutionElementsRevision().getConstitutionSjc();
  }
  
  public boolean estRejetDV()
  {
    return false;
  }
  
  public ReglementApplicableSpec getConstitutionReglementApplicable()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionReglementApplicable();
    }
    if (Log.isTraceActive(Revision.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, Revision.class, "getConstitutionReglementApplicable", " Impossible de trouver l'attribution précédente");
    }
    return null;
  }
  
  public Quantite getMontantAttributionPrecedente()
    throws CoucheLogiqueException
  {
    Attribution attribution = recupererAttributionPrecedente();
    if (attribution != null)
    {
      MontantAsuSpec montantPrecedent = attribution.getMontantRecalcule(getDemande().getDateDeclenchementExamen());
      if (montantPrecedent != null) {
        return montantPrecedent.getMontantPrecompteEffectif();
      }
    }
    return null;
  }
  
  private Attribution recupererAttributionPrecedente()
  {
    if ((getAttributionPrecedente() instanceof Attribution)) {
      return (Attribution)getAttributionPrecedente();
    }
    return null;
  }
  
  public OdSpec getOuvertureDroit()
  {
    OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente == null) {
      attributionPrecedente = getDemandeAssurance().rechercherAttributionPrecedenteDuMemeType();
    }
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroit();
    }
    return ouvertureDeDroit;
  }
}

/* Location:
 * Qualified Name:     Echec
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */