package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.RepriseGen;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseActiviteReduite;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSecurisationProfessionnelleSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class Reprise
  extends RepriseGen
  implements RepriseSpec
{
  private static final long serialVersionUID = -1443284341759881602L;
  public static final String CODE_FORMULE_MONTANT = "1";
  public static final String CODE_FORMULE_MONTANT_AREF = "2";
  private boolean comptenceEnrechie = false;
  
  public Reprise() {}
  
  public Reprise(Damj dateEvenement, DossierExamenSpec dossierExamen)
  {
    super(dateEvenement);
    copie((DossierExamen)dossierExamen);
  }
  
  public Reprise(DomPCSpec reprisePC)
  {
    super(reprisePC);
  }
  
  public Reprise(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public String getRsod()
  {
    String rsod = "0";
    if (getAttributionPrecedente() != null) {
      rsod = getAttributionPrecedente().getRsod();
    }
    return rsod;
  }
  
  public String getRsrp()
  {
    return getReferenceExterne();
  }
  
  public String getSituationParticuliere()
  {
    String situationParticuliere = "";
    if (getAttributionPrecedente() != null) {
      situationParticuliere = getAttributionPrecedente().getSituationParticuliere();
    }
    return situationParticuliere;
  }
  
  public ObjetMetierSpec copie()
  {
    Reprise copie = new Reprise();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec pcopie)
  {
    Reprise copie = (Reprise)pcopie;
    super.copieElements(copie);
  }
  
  public boolean isTopContratsRemuneresBaseSmic()
  {
    boolean estApprenti = false;
    if (getAttributionPrecedente() != null) {
      estApprenti = getAttributionPrecedente().isTopContratsRemuneresBaseSmic();
    }
    return estApprenti;
  }
  
  public JustificationAffiliationSpec getJustificationAffiliation()
  {
    if ((DossierExamenAssuranceSpec)((Demande)getDossierAffecte().getDemande()).getDossierAffectationAdmission().getDossierExamen() != null) {
      return ((DossierExamenAssuranceSpec)((Demande)getDossierAffecte().getDemande()).getDossierAffectationAdmission().getDossierExamen()).getJustificationAffiliation();
    }
    return new JustificationAffiliation();
  }
  
  public boolean estDroitSaisonnier()
  {
    if ((getNatureDecision() != 14) && (getConstitutionCaractereSaisonnier() != null))
    {
      int caractereSaisonnier = getConstitutionCaractereSaisonnier().getTypeCaractereSaisonnierRetenu();
      switch (caractereSaisonnier)
      {
      case 1: 
      case 2: 
        return true;
      }
      return false;
    }
    return false;
  }
  
  public ReglementApplicableSpec getConstitutionReglementApplicable()
  {
    ReglementApplicableSpec reglement = null;
    if (getAttributionPrecedente() != null) {
      reglement = getAttributionPrecedente().getReglementApplicable();
    }
    return reglement;
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
  {
    if (getElementBaseIndemnisationPrive() == null)
    {
      ElementBaseIndemnisation ebiAttributionPrecedente = null;
      ebiAttributionPrecedente = getAttributionPrecedente().getElementBaseIndemnisation();
      
      setElementBaseIndemnisationPrive(new ElementBaseIndemnisation());
      ebiAttributionPrecedente.copieElements(getElementBaseIndemnisationPrive());
      if ((getDemande() != null) && (estDemandeEnContexteAreASP((Demande)getDemande()))) {
        getElementBaseIndemnisationPrive().setProduitAreActif(getProduit());
      } else if ((getProduit() instanceof ProduitSecurisationProfessionnelleSpec)) {
        getElementBaseIndemnisationPrive().setProduitAreActif(((ProduitSecurisationProfessionnelleSpec)getProduit()).recupererProduitAreActif(this));
      }
      Quantite dureePostPrime = getDureePostPrime();
      if ((dureePostPrime != null) && (dureePostPrime.getValeurEntiere() == 0)) {
        getElementBaseIndemnisationPrive().setEstDureePostPrimeEpuisee(true);
      }
    }
    return (ElementBaseIndemnisation)getElementBaseIndemnisationPrive().copie();
  }
  
  public ConstitutionSjr getConstitutionSjr()
  {
    ConstitutionSjr constitutionSjr = null;
    if (getAttributionPrecedente() != null)
    {
      ElementBaseIndemnisation ebiAttributionPrecedente = getElementBaseIndemnisation();
      
      constitutionSjr = getConstitutionElementsActifs().getConstitutionSjr();
      if (constitutionSjr == null) {
        constitutionSjr = getConstitutionElementsActifs().createConstitutionSjr();
      }
      Reglement reglementApplicableCourant = ebiAttributionPrecedente.getReglementApplicableMontantRetenu().getReglement();
      
      Sjr sjrAServir = ebiAttributionPrecedente.getSjr();
      Sjrip sjrip = constitutionSjr.getSjrip();
      if (sjrip == null) {
        sjrip = constitutionSjr.createSjrip();
      }
      sjrip.setDateEvenement(sjrAServir.getDateDepart());
      sjrip.setPlafondSjr(null);
      sjrip.setSjrInitial(new QuantiteEuro(sjrAServir.getSalaire()));
      
      int codeEmploiA2B = ebiAttributionPrecedente.getCodeEmploiA2B();
      constitutionSjr.setCodeEmploiA2b(codeEmploiA2B);
      if (sjrAServir != null)
      {
        Sjr sjr = null;
        if (reglementApplicableCourant.equals(getDossierAffecte().getProduit().getReglement("A2b"))) {
          sjr = new Sjr(sjrip.getSjrInitial().getValeur(), sjrip.getDateEffet(), null);
        } else {
          sjr = RevalorisationSalaire.revaloriserSjr(ebiAttributionPrecedente, getProduitMontantRetenu(), getDateAttribution());
        }
        constitutionSjr.setSjrrp(sjr);
      }
    }
    return constitutionSjr;
  }
  
  public ConstitutionSjc getConstitutionSjc()
  {
    ConstitutionSjc constitutionSjc = null;
    if (getAttributionPrecedente() != null)
    {
      ElementBaseActiviteReduite ebacAttributionPrecedente = getElementBaseActiviteReduite();
      
      Sjc sjcAttributionPrecedente = ebacAttributionPrecedente.getSjc();
      if (sjcAttributionPrecedente != null)
      {
        Damj dateEffet = sjcAttributionPrecedente.getDateDepart();
        BigDecimal sjcInitial = sjcAttributionPrecedente.getSalaire();
        constitutionSjc = getConstitutionElementsActifs().getConstitutionSjc();
        if (constitutionSjc == null) {
          constitutionSjc = getConstitutionElementsActifs().createConstitutionSjc();
        }
        Sjcip sjcipCourant = constitutionSjc.createSjcip(dateEffet, null, new QuantiteEuro(sjcInitial));
        
        Collection listeActivitesConservees = getElementBaseActiviteReduite().getListeSjrActiviteConservee();
        if (listeActivitesConservees != null)
        {
          Iterator itActiviteConservee = listeActivitesConservees.iterator();
          while (itActiviteConservee.hasNext()) {
            sjcipCourant.ajouterSjrActiviteConservee((SjrActiviteConservee)((SjrActiviteConservee)itActiviteConservee.next()).copie());
          }
        }
        Sjc sjcCourant = new Sjc(sjcipCourant.getSjcInitial().getValeur(), sjcipCourant.getDateEffet(), null);
        Sjc sjcrpCalcule = RevalorisationSalaire.revaloriserSjc(sjcCourant, getDateAttribution());
        constitutionSjc.setSjcrp(sjcrpCalcule);
      }
    }
    return constitutionSjc;
  }
  
  public ConstitutionCoefficientSaisonnier getConstitutionCoefficientSaisonnier()
  {
    ConstitutionCoefficientSaisonnier constitutionCoefficient = null;
    if (getAttributionPrecedente() != null)
    {
      BigDecimal coefficient = getElementBaseIndemnisation().getCoefficientSaisonnier();
      if (coefficient != null)
      {
        constitutionCoefficient = getConstitutionElementsActifs().createConstitutionCoefficientSaisonnier();
        constitutionCoefficient.setCoefficientSaisonnierRetenu(coefficient);
      }
    }
    return constitutionCoefficient;
  }
  
  public ConstitutionCoefficientTempsPartiel getConstitutionCoefficientTempsPartiel()
  {
    ConstitutionCoefficientTempsPartiel constitutionCoefficient = null;
    if (getAttributionPrecedente() != null)
    {
      BigDecimal coefficient = getElementBaseIndemnisation().getCoefficientTempsPartiel();
      
      constitutionCoefficient = getConstitutionElementsActifs().createConstitutionCoefficientTempsPartiel();
      constitutionCoefficient.setCoefficientTempsPartielRetenu(coefficient);
    }
    return constitutionCoefficient;
  }
  
  public ConstitutionCaractereSaisonnier getConstitutionCaractereSaisonnier()
  {
    ConstitutionCaractereSaisonnier caractereSaisonnier = null;
    if (getAttributionPrecedente() != null)
    {
      caractereSaisonnier = getConstitutionElementsActifs().createConstitutionCaractereSaisonnier();
      ElementBaseIndemnisation elementBaseIndemnisation = getElementBaseIndemnisation();
      if ((elementBaseIndemnisation.getTypeCaractereSaisonnierRetenu() == 2) || (elementBaseIndemnisation.getTypeCaractereSaisonnierRetenu() == 1)) {
        caractereSaisonnier.setCaractereSaisonnierRetenu(true);
      }
      caractereSaisonnier.setTypeCaractereSaisonnierRetenu(elementBaseIndemnisation.getTypeCaractereSaisonnierRetenu());
      caractereSaisonnier.setActivite3Sur5(elementBaseIndemnisation.isConditionCaractereSaisonnierParRythme());
    }
    return caractereSaisonnier;
  }
  
  public int getCodeEmploiA2B()
  {
    int codeEmploiA2B = -1;
    if (getConstitutionSjr() != null) {
      codeEmploiA2B = getConstitutionSjr().getCodeEmploiA2b();
    }
    return codeEmploiA2B;
  }
  
  public void jdoPostLoad() {}
  
  public void jdoPreStore() {}
  
  public void jdoPreClear() {}
  
  public ElementBaseActiviteReduite getElementBaseActiviteReduite()
  {
    return getAttributionPrecedente().getElementBaseActiviteReduite();
  }
  
  public void jdoPreDelete() {}
  
  public AttributionSpec getAttributionMaitre()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionMaitre();
    }
    return null;
  }
  
  public AttributionAssuranceSpec getAttributionOrigine()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionOrigine();
    }
    return null;
  }
  
  public boolean isInvestigationFraude()
  {
    if (getAttributionPrecedente() == null) {
      return false;
    }
    return getAttributionPrecedente().isInvestigationFraude();
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    return getAttributionPrecedente().getProduitMontantRetenu();
  }
  
  public FormuleMontantSpec getFormuleMontant(String code)
  {
    Demande demandePrecedente = (Demande)getAttributionPrecedente().getDemande();
    if ((estDemandeEnContexteAreASP((Demande)getDemande())) || ((estDemandeEnContexteAreASP(demandePrecedente)) && (!estDemandeEnContexteAreASP((Demande)getDemande())))) {
      return super.getFormuleMontant(code);
    }
    return getAttributionPrecedente().getFormuleMontant(code);
  }
  
  private boolean estDemandeEnContexteAreASP(Demande demande)
  {
    return (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "AREENTRCSP")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP"));
  }
  
  public Damj getDateFaitGenerateurDroit()
  {
    return getAttributionPrecedente().getDateFaitGenerateurDroit();
  }
  
  public MaintienEuropeen getMaintienEuropeen()
  {
    if ((getMaintienEuropeenPrive() == null) && (getAttributionPrecedente() != null)) {
      if (getAttributionPrecedente().getMaintienEuropeen() == null) {
        setMaintienEuropeenPrive(MaintienEuropeen.getInstanceMaintienEuropeen(this));
      } else {
        setMaintienEuropeenPrive(getAttributionPrecedente().getMaintienEuropeen());
      }
    }
    return getMaintienEuropeenPrive();
  }
  
  public boolean estMaintenue()
  {
    if (getOuvertureDroit().getNatureDecision() == 38) {
      return ((fr.unedic.cali.asu.dom.OdAssuranceSpec)getOuvertureDroit()).estMaintenue();
    }
    return super.estMaintenue();
  }
  
  public DemandeSpec getDemandeMontantRetenu()
  {
    return getAttributionPrecedente().getDemandeMontantRetenu();
  }
  
  public fr.unedic.cali.dom.OdAssuranceSpec getOuvertureDroit()
  {
    fr.unedic.cali.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroit();
    }
    return ouvertureDeDroit;
  }
  
  public fr.unedic.cali.asu.dom.OdAssuranceSpec getOuvertureDroitCapitalRetenu()
  {
    fr.unedic.cali.asu.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente == null) {
      attributionPrecedente = getDemandeAssurance().rechercherOuvertureDroitPrecedenteDuMemeType();
    }
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroitCapitalRetenu();
    }
    return ouvertureDeDroit;
  }
  
  public boolean estDemandeSuiteFinDeDroit()
  {
    return (getAttributionPrecedente() != null) && (getAttributionPrecedente().estDemandeSuiteFinDeDroit());
  }
  
  public CompetenceSpec getCompetence()
  {
    Competence competence = (Competence)super.getCompetence();
    if ((competence.getNumeroConventionGestion() != null) && (!comptenceEnrechie))
    {
      comptenceEnrechie = true;
      fr.unedic.cali.asu.dom.OdAssuranceSpec ouvertureDroit = (fr.unedic.cali.asu.dom.OdAssuranceSpec)getOuvertureDroit();
      if ((ouvertureDroit != null) && ("ASU_23".equals(ouvertureDroit.getDemande().getEvenementReferenceExamen().getTypeExamen())))
      {
        competence.setCodeAffectationConvention(ouvertureDroit.getConventionGestion().getCodeAffectation());
        
        competence.setBouchonnageAppelCaro(ouvertureDroit.getCompetence().getBouchonnageAppelCaro());
        competence.setDateDepotDemande(ouvertureDroit.getCompetence().getDateDepotDemande());
      }
    }
    return competence;
  }
  
  public void setCompetence(CompetenceSpec competence)
  {
    super.setCompetence(competence);
    comptenceEnrechie = false;
  }
  
  public int getTypeMontantRetenu()
  {
    return getAttributionPrecedente().getTypeMontantRetenu();
  }
  
  public int getTypeCapitalRetenu()
  {
    return getAttributionPrecedente().getTypeCapitalRetenu();
  }
  
  public SalaireJournalierSpec getSalaireJournalierInitial()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getSalaireJournalierInitial();
    }
    return null;
  }
  
  public SalaireJournalierSpec getSalaireJournalierConserve()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getSalaireJournalierConserve();
    }
    return null;
  }
  
  public Boolean estAvecPrecompteCRC()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().estAvecPrecompteCRC();
    }
    return null;
  }
  
  public BigDecimal getCoefficientSaisonnier()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getCoefficientSaisonnier();
    }
    return null;
  }
  
  public int getNatureCoefficientSaisonnier()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getNatureCoefficientSaisonnier();
    }
    return -1;
  }
  
  public boolean a3ansActiviteEn5ans()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().a3ansActiviteEn5ans();
    }
    return false;
  }
  
  public BigDecimal getCoefficientTempsPartiel()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getCoefficientTempsPartiel();
    }
    return null;
  }
  
  public boolean estSjrBaseSmic()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().estSjrBaseSmic();
    }
    return false;
  }
  
  public int getCategorieEmploiA2B()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getCategorieEmploiA2B();
    }
    return 0;
  }
  
  public ReglementApplicableSpec getReglementApplicableMontantRetenu()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getReglementApplicableMontantRetenu();
    }
    return null;
  }
  
  public ResultatAvant determinationEtatACT()
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public Damj getDateDebutDelaiDecheance()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getDateDebutDelaiDecheance();
    }
    return null;
  }
}

/* Location:
 * Qualified Name:     Reprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */