package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleDelaiReportSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieFormuleISLRSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.BaseCarence;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.BaseCarenceMontant;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.CarenceIccp;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.CarenceIslr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.EnsembleCarences;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.PreavisMesureConservatoireNonIndemnisable;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Reprise;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieISLR;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionISLR;
import fr.unedic.cali.asu.outilsfonctionnels.DeterminationCarenceAsu;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.Entretien;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.outilsfonctionnels.strategies.StrategieSpec;
import fr.unedic.cali.util.ObjetChronoPeriodeConcreteCarence;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.QuantiteJourTravailDansSemaineSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class DeterminationCarence
  implements OutilFonctionnel
{
  private static final int NOMBRE_JOUR_MAXIMUM_PMC = 999;
  private static final String JOURS = " jours).";
  
  private static CarenceIccp determinerCarenceIccpOdA4(QuantiteEuro montantCumul, ObjetChronoPeriode periodeOrigine, Sjr salaireJournalierReference)
    throws CoucheLogiqueException
  {
    CarenceIccp nouvelleCarenceIccp = null;
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Détermination de la Carence ICCP pour toutes les périodes d'activité salariée de règlement RG ou A4." });
    
    BaseCarenceMontant baseCarenceMontantTemporaire = null;
    if (((ActiviteSalarie)periodeOrigine).estContratRemunereBaseSmic()) {
      baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference, montantCumul, null, null, true);
    } else {
      baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference, montantCumul, null, null, false);
    }
    Formule formuleCarenceIccp = new FormuleCarenceIccpMontant();
    QuantiteJour resultatFormuleIccp = (QuantiteJour)formuleCarenceIccp.appliquerFormule(baseCarenceMontantTemporaire);
    if ((resultatFormuleIccp != null) && (resultatFormuleIccp.getNombreJours() > 0))
    {
      OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Création de la Carence ICCP (", Integer.valueOf(resultatFormuleIccp.getNombreJours()), " jours)." });
      
      nouvelleCarenceIccp = new CarenceIccp(periodeOrigine, resultatFormuleIccp.getNombreJours());
    }
    return nouvelleCarenceIccp;
  }
  
  private static void determinerCarenceIslrOdA4(ActiviteSalarie periodeFg, Sjr salaireJournalierReference, EnsembleCarences ensembleCarencesPeriodeFg, Damj dateFaitGenerateurOuDernierSinistre)
    throws PasAssezInformationException, CoucheLogiqueException
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Détermination de la Carence ISLR pour la période d'activité salariée qui porte le Fait Générateur." });
    
    determinerMontantIslr(periodeFg, ensembleCarencesPeriodeFg, dateFaitGenerateurOuDernierSinistre);
    
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(dateFaitGenerateurOuDernierSinistre);
    StrategieSpec strategie = FabriqueStrategieISLR.getInstance().getStrategie(critere);
    FormuleDelaiReportSpec formuleCarenceIslr = ((StrategieFormuleISLRSpec)strategie).getFormuleISLR();
    
    boolean isTransactionEnCours = periodeFg.getContrat().isTransactionEnCours();
    if (isTransactionEnCours)
    {
      BaseCarenceMontant baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference);
      if (periodeFg.getContrat() != null) {
        baseCarenceMontantTemporaire.setMotifRupture(periodeFg.getContrat().getCodeMotifFin());
      }
      CarenceIslr nouvelleCarenceIslr = new CarenceIslr(periodeFg, formuleCarenceIslr.recupererPlafondISLR(baseCarenceMontantTemporaire));
      
      ensembleCarencesPeriodeFg.setCarenceIslr(nouvelleCarenceIslr);
      ensembleCarencesPeriodeFg.setPresenceTransaction(true);
    }
    else
    {
      QuantiteEuro quantiteEuroIslr = periodeFg.getQuantiteEuroIslr();
      if ((quantiteEuroIslr != null) && (quantiteEuroIslr.getValeurMontant().compareTo(BigDecimal.ZERO) > 0))
      {
        BaseCarenceMontant baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference, null, quantiteEuroIslr, periodeFg.getDateFin());
        if (periodeFg.getContrat() != null) {
          baseCarenceMontantTemporaire.setMotifRupture(periodeFg.getContrat().getCodeMotifFin());
        }
        QuantiteJour resultatFormuleIslr = (QuantiteJour)formuleCarenceIslr.appliquerFormule(baseCarenceMontantTemporaire);
        if ((resultatFormuleIslr != null) && (resultatFormuleIslr.getNombreJours() > 0))
        {
          OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Création de la Carence ISLR (", Integer.valueOf(resultatFormuleIslr.getNombreJours()), " jours)." });
          
          CarenceIslr nouvelleCarenceIslr = new CarenceIslr(periodeFg, resultatFormuleIslr.getNombreJours());
          ensembleCarencesPeriodeFg.setCarenceIslr(nouvelleCarenceIslr);
        }
      }
    }
  }
  
  private static void determinerMontantIslr(ActiviteSalarie periode, EnsembleCarences ensembleCarences, Damj dateFaitGenerateurOuDernierSinistre)
    throws CoucheLogiqueException
  {
    try
    {
      periode.setQuantiteEuroIslr(ConstitutionISLR.getInstance().calculeISLR(periode.getListeIndemnites(), periode.getCodeMotifFin(), periode.getCategorieEmploiParticulier(), dateFaitGenerateurOuDernierSinistre));
    }
    catch (CoucheLogiqueException clex)
    {
      if (clex.getMessage().equals("ASU_PR_CALI_L_CEPA05_AUTRES_INDEMNITES_LEGALES")) {
        ensembleCarences.setAutresIndemnitesLegales(true);
      } else {
        throw clex;
      }
    }
  }
  
  public static List<EnsembleCarences> determinerCarences(Chronologie chronologie, Demande demande, Chronologie chronologiePMC)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    Attribution attributionCourante = (Attribution)demande.getAttribution();
    
    Sjr salaireJournalierReference = recupererSjr(attributionCourante);
    
    return determinerCarences(chronologie, demande, salaireJournalierReference, chronologiePMC);
  }
  
  public static List<EnsembleCarences> determinerCarences(Chronologie chronologie, Demande demande, Sjr sjrrp, Chronologie chronologiePMC)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    Reglement reglementApplicableCourant = null;
    
    Attribution attributionCourante = (Attribution)demande.getAttribution();
    
    List<EnsembleCarences> listeEnsembleCarencesRetournee = new ArrayList();
    
    chronologie.setComparateur(new ComparateurTemporelsSurDateFin());
    
    ActiviteSalarie periodeFg = null;
    if (attributionCourante.getFaitGenerateur() != null)
    {
      periodeFg = attributionCourante.getFaitGenerateur().getPeriodeFaitGenerateur();
    }
    else
    {
      Chronologie passeProfessionnel = new ChronologiePeriodes();
      passeProfessionnel.ajouter(chronologie);
      passeProfessionnel.ajouter(chronologiePMC);
      
      periodeFg = (ActiviteSalarie)RechercherDernierSinistre.rechercherDernierSinistre(demande.getDateExamen(), passeProfessionnel);
    }
    reglementApplicableCourant = attributionCourante.getReglementApplicable().getReglement();
    
    ProduitSpec produit = ((DossierAffectation)demande.getDossierAffectation()).getProduit();
    if ((reglementApplicableCourant.equals(produit.getReglement("RG"))) || (reglementApplicableCourant.equals(produit.getReglement("OP"))) || (reglementApplicableCourant.equals(produit.getReglement("A1"))) || (reglementApplicableCourant.equals(produit.getReglement("A2a"))) || (reglementApplicableCourant.equals(produit.getReglement("A2b"))) || (reglementApplicableCourant.equals(produit.getReglement("A3"))) || (reglementApplicableCourant.equals(produit.getReglement("A5"))) || (reglementApplicableCourant.equals(produit.getReglement("A6")))) {
      determinerCarencesOdRg(chronologie, chronologiePMC, demande, periodeFg, sjrrp, listeEnsembleCarencesRetournee);
    } else if (reglementApplicableCourant.equals(produit.getReglement("A4"))) {
      determinerCarencesOdA4(chronologie, chronologiePMC, demande, periodeFg, sjrrp, listeEnsembleCarencesRetournee);
    } else if ((reglementApplicableCourant.equals(produit.getReglement("A9A"))) || (reglementApplicableCourant.equals(produit.getReglement("A9B")))) {
      determinerCarencesOdA9(chronologie, chronologiePMC, demande, listeEnsembleCarencesRetournee);
    }
    return listeEnsembleCarencesRetournee;
  }
  
  private static EnsembleCarences determinerCarencesPmcOdA4(Demande demande, Chronologie chronologie, Chronologie chronologiePMC, ActiviteSalarie periodeFg, List listeEnsembleCarencesRetournee)
    throws CoucheLogiqueException
  {
    EnsembleCarences ensembleCarencesPeriodeFg = null;
    boolean ensembleCarencesPeriodeFgTrouve = false;
    
    ActiviteSalarie periodeTraitee = null;
    EnsembleCarences ensembleCarencesPeriodeTraitee = null;
    
    chronologie.iterer();
    while (chronologie.encoreSuivant())
    {
      periodeTraitee = (ActiviteSalarie)chronologie.elementSuivant();
      
      ensembleCarencesPeriodeTraitee = new EnsembleCarences();
      
      determinerCarencePmc(demande, periodeTraitee, ensembleCarencesPeriodeTraitee);
      
      listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeTraitee);
      if (!ensembleCarencesPeriodeFgTrouve)
      {
        ensembleCarencesPeriodeFgTrouve = periodeTraitee.getIdentifiant().equals(periodeFg.getIdentifiant());
        if (ensembleCarencesPeriodeFgTrouve) {
          ensembleCarencesPeriodeFg = ensembleCarencesPeriodeTraitee;
        }
      }
    }
    chronologiePMC.iterer();
    while (chronologiePMC.encoreSuivant())
    {
      periodeTraitee = (ActiviteSalarie)chronologiePMC.elementSuivant();
      
      ensembleCarencesPeriodeTraitee = new EnsembleCarences();
      
      determinerCarencePmc(demande, periodeTraitee, ensembleCarencesPeriodeTraitee);
      
      listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeTraitee);
      if (!ensembleCarencesPeriodeFgTrouve)
      {
        ensembleCarencesPeriodeFgTrouve = periodeTraitee.getIdentifiant().equals(periodeFg.getIdentifiant());
        if (ensembleCarencesPeriodeFgTrouve) {
          ensembleCarencesPeriodeFg = ensembleCarencesPeriodeTraitee;
        }
      }
    }
    return ensembleCarencesPeriodeFg;
  }
  
  private static void determinerCarenceIccp(ActiviteSalarie periodeActiviteSalarie, Sjr salaireJournalierReference, Damj dateFg, EnsembleCarences ensembleCarences, boolean bEstApprenti)
    throws CoucheLogiqueException
  {
    CarenceIccp nouvelleCarenceIccp = null;
    Formule formuleCarenceIccp = null;
    QuantiteJour resultatFormuleIccp = null;
    BaseCarenceMontant baseCarenceMontantTemporaire = null;
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Détermination de la Carence ICCP sur la période d'activité salariée: ", periodeActiviteSalarie });
    
    BaseCarence baseCarencePeriodeActiviteCourante = ConstructionBaseCarence.getInstance().determinerBaseCarence(periodeActiviteSalarie, dateFg);
    
    QuantiteEuro quantiteEuroIccp = baseCarencePeriodeActiviteCourante.getQuantiteEuroIccp();
    if ((quantiteEuroIccp != null) && (quantiteEuroIccp.getValeurMontant().compareTo(BigDecimal.ZERO) > 0))
    {
      if (bEstApprenti) {
        baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference, quantiteEuroIccp, null, null, true);
      } else {
        baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference, quantiteEuroIccp, null, null, false);
      }
      formuleCarenceIccp = new FormuleCarenceIccpMontant();
      resultatFormuleIccp = (QuantiteJour)formuleCarenceIccp.appliquerFormule(baseCarenceMontantTemporaire);
      
      Reglement reglementAppartenance = periodeActiviteSalarie.getReglement();
      ProduitSpec produit = reglementAppartenance.getProduit();
      if (reglementAppartenance.equals(produit.getReglement("A5")))
      {
        int nbJoursIccp = resultatFormuleIccp.getNombreJours();
        if (periodeActiviteSalarie.getContrat().getNbreJoursCongesPris() > 0) {
          resultatFormuleIccp = new QuantiteJour(BigDecimal.ZERO.max(new BigDecimal(nbJoursIccp - periodeActiviteSalarie.getContrat().getNbreJoursCongesPris())));
        }
      }
    }
    else
    {
      QuantiteJourTravailDansSemaineSpec quantiteJourIccp = baseCarencePeriodeActiviteCourante.getQuantiteJourIccp();
      if ((quantiteJourIccp != null) && (quantiteJourIccp.getNombreJours() > 0))
      {
        formuleCarenceIccp = new FormuleCarenceIccpTemps();
        resultatFormuleIccp = (QuantiteJour)formuleCarenceIccp.appliquerFormule(baseCarencePeriodeActiviteCourante);
      }
    }
    if ((resultatFormuleIccp != null) && (resultatFormuleIccp.getNombreJours() > 0))
    {
      OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Création de la Carence ICCP (", Integer.valueOf(resultatFormuleIccp.getNombreJours()), " jours)." });
      nouvelleCarenceIccp = new CarenceIccp(periodeActiviteSalarie, resultatFormuleIccp.getNombreJours());
      
      ensembleCarences.setCarenceIccp(nouvelleCarenceIccp);
    }
  }
  
  private static void determinerCarenceIslr(ActiviteSalarie periodeActiviteSalarie, Sjr salaireJournalierReference, Damj dateFg, EnsembleCarences ensembleCarences)
    throws CoucheLogiqueException
  {
    BaseCarenceMontant baseCarenceMontantTemporaire = null;
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Détermination de la Carence ISLR sur la période d'activité salariée: ", periodeActiviteSalarie });
    
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(dateFg);
    StrategieSpec strategie = FabriqueStrategieISLR.getInstance().getStrategie(critere);
    FormuleDelaiReportSpec formuleCarenceIslr = ((StrategieFormuleISLRSpec)strategie).getFormuleISLR();
    
    boolean isTransactionEnCours = periodeActiviteSalarie.getContrat().isTransactionEnCours();
    if (isTransactionEnCours)
    {
      baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference);
      if (periodeActiviteSalarie.getContrat() != null) {
        baseCarenceMontantTemporaire.setMotifRupture(periodeActiviteSalarie.getContrat().getCodeMotifFin());
      }
      CarenceIslr nouvelleCarenceIslr = new CarenceIslr(periodeActiviteSalarie, formuleCarenceIslr.recupererPlafondISLR(baseCarenceMontantTemporaire));
      
      ensembleCarences.setCarenceIslr(nouvelleCarenceIslr);
      ensembleCarences.setPresenceTransaction(true);
    }
    else
    {
      BaseCarence baseCarencePeriodeActiviteCourante = ConstructionBaseCarence.getInstance().determinerBaseCarence(periodeActiviteSalarie, dateFg);
      
      QuantiteEuro quantiteEuroIslr = baseCarencePeriodeActiviteCourante.getQuantiteEuroIslr();
      if ((quantiteEuroIslr != null) && (quantiteEuroIslr.getValeurMontant().compareTo(BigDecimal.ZERO) > 0))
      {
        baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference, null, quantiteEuroIslr, dateFg);
        if (periodeActiviteSalarie.getContrat() != null) {
          baseCarenceMontantTemporaire.setMotifRupture(periodeActiviteSalarie.getContrat().getCodeMotifFin());
        }
        QuantiteJour resultatFormuleIslr = (QuantiteJour)formuleCarenceIslr.appliquerFormule(baseCarenceMontantTemporaire);
        if ((resultatFormuleIslr != null) && (resultatFormuleIslr.getNombreJours() > 0))
        {
          OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Création de la Carence ISLR (", Integer.valueOf(resultatFormuleIslr.getNombreJours()), " jours)." });
          
          CarenceIslr nouvelleCarenceIslr = new CarenceIslr(periodeActiviteSalarie, resultatFormuleIslr.getNombreJours());
          
          ensembleCarences.setCarenceIslr(nouvelleCarenceIslr);
        }
      }
    }
  }
  
  private static CarenceIccp determinerCarenceIccpForcee(Demande demande)
    throws CoucheLogiqueException
  {
    CarenceIccp carenceIccp = null;
    if (demande.getDonneesTemporaires().getQuantiteJoursDiffereIccpConservatoire().getValeur().intValue() > 0)
    {
      QuantiteJourTravailDansSemaineSpec qteJourIccp = (QuantiteJourTravailDansSemaineSpec)demande.getDonneesTemporaires().getQuantiteJoursDiffereIccpConservatoire();
      
      int nombreJoursSemaine = qteJourIccp.getNombreJoursSemaine();
      BigDecimal nominateur1 = demande.getDonneesTemporaires().getQuantiteJoursDiffereIccpConservatoire().getValeur().setScale(0, 0);
      
      BigDecimal nominateur2 = new BigDecimal("7");
      BigDecimal denominateur = new BigDecimal(String.valueOf(nombreJoursSemaine));
      BigDecimal resultatFormule = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
      QuantiteJour quantiteJourCalculee = new QuantiteJour(Mathematiques.tronque(resultatFormule, 0).toString());
      
      Damj pointDepartCarenceIccp = demande.getAttribution().getDateAttribution().veille();
      if (demande.getDonneesTemporaires().getDateDepartICCP() != null) {
        pointDepartCarenceIccp = demande.getDonneesTemporaires().getDateDepartICCP().veille();
      } else if ((demande.getModeLiquidation() != null) && ((demande.getModeLiquidation().equals("S")) || (demande.getModeLiquidation().equals("C")))) {
        if ((demande.getEntretien() != null) && (demande.getEntretien().isAExerceActiviteSalarie()))
        {
          pointDepartCarenceIccp = demande.getEntretien().getDateFinContrat();
          if (pointDepartCarenceIccp.lendemain().estApres(demande.getAttribution().getDateAttribution())) {
            fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_LS_POINT_DEPART_ICCP_CONSERVATOIRE", new String[] { pointDepartCarenceIccp.toString() });
          }
        }
      }
      carenceIccp = new CarenceIccp(new ObjetChronoPeriodeConcreteCarence(pointDepartCarenceIccp, pointDepartCarenceIccp), quantiteJourCalculee.getNombreJours());
      
      carenceIccp.setDateFinPeriodeOrigine(pointDepartCarenceIccp);
    }
    return carenceIccp;
  }
  
  private static void ajouterCarencePmcForcee(Demande demande, EnsembleCarences ensembleCarences)
  {
    ActiviteSalarie periodeFct = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(demande.getDonneesTemporaires().getIndentifiantFctPMC());
    if (periodeFct != null) {
      ConstitutionPMC.ajouterPmcForcee(periodeFct, demande.getDonneesTemporaires().isPmcIndemnisable(), demande.getDonneesTemporaires().getFinPmc(), ensembleCarences);
    }
  }
  
  private static void determinerCarencesOdRg(Chronologie chronologie, Chronologie chronologiePMC, Demande demande, ActiviteSalarie periodeFg, Sjr salaireJournalierReference, List<EnsembleCarences> listeEnsembleCarencesRetournee)
    throws PasAssezInformationException, CoucheLogiqueException
  {
    ActiviteSalarie periodeTraitee = null;
    EnsembleCarences ensembleCarencesPeriodeTraitee = null;
    
    traiterCarenceIccpConservatoireForcee(demande, listeEnsembleCarencesRetournee);
    
    boolean bEstEnContexteApprentissage = false;
    
    Attribution attributionConcerne = (Attribution)demande.getAttribution();
    if (attributionConcerne.isTopContratsRemuneresBaseSmic()) {
      bEstEnContexteApprentissage = true;
    }
    if (!chronologie.estVide())
    {
      chronologie.iterer();
      while (chronologie.encoreSuivant())
      {
        periodeTraitee = (ActiviteSalarie)chronologie.elementSuivant();
        
        ensembleCarencesPeriodeTraitee = new EnsembleCarences();
        
        determinerCarencePmc(demande, periodeTraitee, ensembleCarencesPeriodeTraitee);
        
        determinerCarenceIccp(periodeTraitee, salaireJournalierReference, periodeFg.getDateFin(), ensembleCarencesPeriodeTraitee, bEstEnContexteApprentissage);
        
        determinerMontantIslr(periodeTraitee, ensembleCarencesPeriodeTraitee, demande.getDateFaitGenerateurOuDernierSinistre());
        determinerCarenceIslr(periodeTraitee, salaireJournalierReference, periodeFg.getDateFin(), ensembleCarencesPeriodeTraitee);
        
        listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeTraitee);
      }
      chronologiePMC.iterer();
      while (chronologiePMC.encoreSuivant())
      {
        periodeTraitee = (ActiviteSalarie)chronologiePMC.elementSuivant();
        
        ensembleCarencesPeriodeTraitee = new EnsembleCarences();
        
        determinerCarencePmc(demande, periodeTraitee, ensembleCarencesPeriodeTraitee);
        
        listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeTraitee);
      }
    }
    boolean presencePmcForcee = (demande.getDonneesTemporaires().getIndentifiantFctPMC() != null) && (demande.getDonneesTemporaires().getFinPmc() != null);
    if (presencePmcForcee)
    {
      EnsembleCarences ensembleCarencesForcee = new EnsembleCarences();
      ajouterCarencePmcForcee(demande, ensembleCarencesForcee);
      listeEnsembleCarencesRetournee.add(ensembleCarencesForcee);
    }
  }
  
  private static void ajouterCarenceALaListe(List<EnsembleCarences> listeEnsembleCarencesRetournee, EnsembleCarences ensembleCarencesPeriodeTraitee)
  {
    if ((ensembleCarencesPeriodeTraitee.getCarenceIccp() != null) || (ensembleCarencesPeriodeTraitee.getCarenceIslr() != null) || (ensembleCarencesPeriodeTraitee.getCarencePmcIndemnisable() != null) || (ensembleCarencesPeriodeTraitee.getCarencePmcNonIndemnisable() != null)) {
      listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeTraitee);
    }
  }
  
  private static void determinerCarencesOdA9(Chronologie chronologie, Chronologie chronologiePMC, Demande demande, List<EnsembleCarences> listeEnsembleCarencesRetournee)
    throws CoucheLogiqueException
  {
    ActiviteSalarie periodeTraitee = null;
    EnsembleCarences ensembleCarencesPeriodeTraitee = null;
    
    CarenceIccp carenceICCP = null;
    CarenceIslr carenceISLR = null;
    ActiviteSalarie periodeCarenceExpatrie = (ActiviteSalarie)demande.getDonneesTemporaires().getPeriodeCarenceExpatrie();
    if (demande.getDonneesTemporaires().getQuantiteJourICCP() != null)
    {
      int nbJourCarenceICCP = demande.getDonneesTemporaires().getQuantiteJourICCP().getValeurEntiere();
      if (nbJourCarenceICCP > 0) {
        carenceICCP = new CarenceIccp(periodeCarenceExpatrie, nbJourCarenceICCP);
      }
    }
    if (demande.getDonneesTemporaires().getQuantiteJourISLR() != null)
    {
      int nbJourCarenceISLR = demande.getDonneesTemporaires().getQuantiteJourISLR().getValeurEntiere();
      if (nbJourCarenceISLR > 0) {
        carenceISLR = new CarenceIslr(periodeCarenceExpatrie, nbJourCarenceISLR);
      }
    }
    chronologie.iterer();
    while (chronologie.encoreSuivant())
    {
      periodeTraitee = (ActiviteSalarie)chronologie.elementSuivant();
      
      ensembleCarencesPeriodeTraitee = new EnsembleCarences();
      
      determinerCarencePmc(demande, periodeTraitee, ensembleCarencesPeriodeTraitee);
      
      ensembleCarencesPeriodeTraitee.setCarenceIccp(carenceICCP);
      
      ensembleCarencesPeriodeTraitee.setCarenceIslr(carenceISLR);
      
      ajouterCarenceALaListe(listeEnsembleCarencesRetournee, ensembleCarencesPeriodeTraitee);
    }
    chronologiePMC.iterer();
    while (chronologiePMC.encoreSuivant())
    {
      periodeTraitee = (ActiviteSalarie)chronologiePMC.elementSuivant();
      
      ensembleCarencesPeriodeTraitee = new EnsembleCarences();
      
      determinerCarencePmc(demande, periodeTraitee, ensembleCarencesPeriodeTraitee);
      
      ensembleCarencesPeriodeTraitee.setCarenceIccp(carenceICCP);
      
      ensembleCarencesPeriodeTraitee.setCarenceIslr(carenceISLR);
      
      ajouterCarenceALaListe(listeEnsembleCarencesRetournee, ensembleCarencesPeriodeTraitee);
    }
  }
  
  private static void determinerCarencesOdA4(Chronologie chronologie, Chronologie chronologiePMC, Demande demande, ActiviteSalarie periodeFg, Sjr salaireJournalierReference, List<EnsembleCarences> listeEnsembleCarencesRetournee)
    throws CoucheLogiqueException, PasAssezInformationException, ApplicativeException
  {
    EnsembleCarences ensembleCarencesPeriodeFg = null;
    
    ensembleCarencesPeriodeFg = determinerCarencesPmcOdA4(demande, chronologie, chronologiePMC, periodeFg, listeEnsembleCarencesRetournee);
    
    traiterCarenceIccpConservatoireForcee(demande, listeEnsembleCarencesRetournee);
    
    Chronologie chronologieHorsAttributions = chronologie;
    
    Chronologie chronologiePendantAttributionsAvecIccpRupture = new ChronologiePeriodes();
    
    Periode periodeAttributionAsuPrecedente = DeterminationCarenceAsu.determinerPeriodePriseEnCompteActiviteReduiteAsuPrecedente(demande);
    Damj finPeriodeAttributionAsuPrecedente = null;
    if (periodeAttributionAsuPrecedente != null)
    {
      chronologieHorsAttributions = DeterminationCarenceAsu.determinerChronoHorsPeriodePriseEnCompteActiviteReduite(chronologieHorsAttributions, periodeAttributionAsuPrecedente);
      
      chronologiePendantAttributionsAvecIccpRupture.ajouter(DeterminationCarenceAsu.determinerChronoPendantPeriodePriseEnCompteActiviteReduite(chronologie, periodeAttributionAsuPrecedente));
      
      finPeriodeAttributionAsuPrecedente = periodeAttributionAsuPrecedente.getFin();
    }
    Periode periodeAttributionAssPrecedente = DeterminationCarenceAsu.determinerPeriodePriseEnCompteActiviteReduiteAssPrecedente(demande);
    Damj finPeriodeAttributionAssPrecedente = null;
    if (periodeAttributionAssPrecedente != null)
    {
      chronologieHorsAttributions = DeterminationCarenceAsu.determinerChronoHorsPeriodePriseEnCompteActiviteReduite(chronologieHorsAttributions, periodeAttributionAssPrecedente);
      
      chronologiePendantAttributionsAvecIccpRupture.ajouter(DeterminationCarenceAsu.determinerChronoPendantPeriodePriseEnCompteActiviteReduite(chronologie, periodeAttributionAssPrecedente));
      
      finPeriodeAttributionAssPrecedente = periodeAttributionAssPrecedente.getFin();
    }
    if (periodeFg != null)
    {
      Periode periodeDelaiRechercheCarences = ((DossierExamen)demande.getDossierExamen()).getConstitutionDelais().getPeriodeReference91jours();
      
      BaseCarence baseCarencePeriodeFaitGenerateur = ConstructionBaseCarence.getInstance().determinerBaseCarenceOdA4(periodeFg, chronologiePendantAttributionsAvecIccpRupture, chronologieHorsAttributions, periodeDelaiRechercheCarences, finPeriodeAttributionAsuPrecedente, finPeriodeAttributionAssPrecedente);
      
      QuantiteEuro montantCumulIccp = baseCarencePeriodeFaitGenerateur.getQuantiteEuroIccp();
      
      ((DossierExamen)demande.getDossierExamen()).getConstitutionDelais().setCumulMontantICCPA4Origine(montantCumulIccp);
      
      CarenceIccp nouvelleCarenceIccp = null;
      if ((montantCumulIccp != null) && (montantCumulIccp.getValeurMontant().compareTo(BigDecimal.ZERO) > 0)) {
        nouvelleCarenceIccp = determinerCarenceIccpOdA4(montantCumulIccp, periodeFg, salaireJournalierReference);
      }
      if (ensembleCarencesPeriodeFg == null) {
        ensembleCarencesPeriodeFg = new EnsembleCarences();
      }
      ensembleCarencesPeriodeFg.setCarenceIccp(nouvelleCarenceIccp);
      
      determinerCarenceIslrOdA4(periodeFg, salaireJournalierReference, ensembleCarencesPeriodeFg, demande.getDateFaitGenerateurOuDernierSinistre());
      
      listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeFg);
    }
  }
  
  public static Sjr recupererSjr(DossierExamen dossierExamen)
  {
    Sjr salaireJournalierReference = null;
    
    boolean readmissionAvecMontantPrecedent = (dossierExamen.getConstitutionProduitResultant() != null) && (dossierExamen.getConstitutionProduitResultant().getMontantRetenu() == 2);
    if (readmissionAvecMontantPrecedent) {
      salaireJournalierReference = dossierExamen.getConstitutionProduitResultant().getSjrrpProduitPrecedent();
    } else {
      salaireJournalierReference = dossierExamen.getConstitutionSjr().getSjrrp();
    }
    return salaireJournalierReference;
  }
  
  private static void determinerCarencePmc(Demande demande, ActiviteSalarie periodeActiviteSalarie, EnsembleCarences ensembleCarences)
    throws CoucheLogiqueException
  {
    boolean presencePmcForcee = (demande.getDonneesTemporaires().getIndentifiantFctPMC() != null) && (demande.getDonneesTemporaires().getFinPmc() != null);
    
    boolean levagePmc = demande.getDonneesTemporaires().isLeveePmc();
    if (presencePmcForcee)
    {
      if (periodeActiviteSalarie.getIdentifiant().equalsIgnoreCase(demande.getDonneesTemporaires().getIndentifiantFctPMC())) {
        ajouterCarencePmcForcee(demande, ensembleCarences);
      }
    }
    else if (!levagePmc) {
      ConstitutionPMC.determinerPMC(periodeActiviteSalarie, ensembleCarences);
    }
    if ((ensembleCarences.getCarencePmc() != null) && (ensembleCarences.getCarencePmc().getQuantiteInitialJour() > 999))
    {
      Damj dateFCTDamj = ensembleCarences.getCarencePmc().getOrigine().getDateFin();
      String dateFCTString = dateFCTDamj.formater();
      
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB17", new String[] { dateFCTString });
    }
  }
  
  private static void traiterCarenceIccpConservatoireForcee(Demande demande, List<EnsembleCarences> listeEnsembleCarencesRetournee)
    throws CoucheLogiqueException
  {
    EnsembleCarences ensembleCarencesForcee = null;
    CarenceIccp carenceIccpForcee = null;
    if (((demande.getDossierExamen() instanceof Reprise)) && (demande.getDonneesTemporaires().getQuantiteJoursDiffereIccpConservatoire() != null))
    {
      carenceIccpForcee = determinerCarenceIccpForcee(demande);
      if (carenceIccpForcee != null)
      {
        ensembleCarencesForcee = new EnsembleCarences();
        ensembleCarencesForcee.setCarenceIccp(carenceIccpForcee);
        listeEnsembleCarencesRetournee.add(ensembleCarencesForcee);
      }
    }
  }
  
  public static boolean estPrecedeParUneAttributionChomageSansRCT(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    OdSpec odPrecedente = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
    if (odPrecedente != null)
    {
      DemandeAssuranceSpec demandePrec = (DemandeAssuranceSpec)odPrecedente.getDemande();
      return OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demandePrec);
    }
    return false;
  }
}

/* Location:
 * Qualified Name:     DeterminationCarence
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */