package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.CarenceIslr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Differe;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.EnsembleCarences;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.PreavisMesureConservatoireNonIndemnisableSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Preavis;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieRuptureContratSuiteChomageSansRupture;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSurMemeContratGAEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSuspensionChomageSansRCT;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.FiltreDebutApresDate;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;

public class DeterminationCarenceRCT
{
  public static EnsembleCarences definirCarenceSupSiContexteChomageSansRCT(DemandeAssuranceSpec p_demande)
    throws CoucheLogiqueException
  {
    EnsembleCarences ensembleCarences = null;
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(p_demande)) {
      if ((p_demande.getDonneesTemporaires().getPeriodeFctARetenirRuptureContratTravail() != null) && (OutilsChomageSansRCT.estUnContexteRuptureContratPendantSuspension(p_demande)))
      {
        TravailSpec periodeDebutCarence = trouverPeriodeActiviteTerminantLeContrat(p_demande.getDemandeur(), p_demande.getDonneesTemporaires().getPeriodeFctARetenirRuptureContratTravail());
        
        ensembleCarences = definirEnsembleCarence(periodeDebutCarence, getNbJoursCarence(p_demande));
        
        Preavis preavis = definirPreavis(p_demande);
        if ((preavis != null) && (preavis.getPeriodeNonEffectueeNonPayee() != null))
        {
          if (ensembleCarences == null) {
            ensembleCarences = new EnsembleCarences();
          }
          PreavisMesureConservatoireNonIndemnisableSpec pmc = ensembleCarences.creerPMCNonIndemnisable((ActiviteSalarie)periodeDebutCarence, new Periode(preavis.getPeriodeNonEffectueeNonPayee().getDebut(), preavis.getPeriodeNonEffectueeNonPayee().getFin()));
          
          ensembleCarences.setCarencePmc(pmc);
        }
      }
    }
    return ensembleCarences;
  }
  
  private static Preavis definirPreavis(DemandeAssuranceSpec p_demande)
  {
    Preavis preavis = null;
    
    ActiviteSalarie periodeValidationProduit = OutilsChomageSansRCT.trouverDernierSinistre(p_demande);
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieSurMemeContratGAEC(periodeValidationProduit));
    filtres.ajouterFiltre(new FiltreDebutApresDate(periodeValidationProduit.getDateFin()));
    
    Chronologie chronoMemeActiviteGaecApresDate = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    
    filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieRuptureContratSuiteChomageSansRupture());
    Chronologie chronoPeriodesRuptureContrat = chronoMemeActiviteGaecApresDate.copier(filtres);
    if (!chronoPeriodesRuptureContrat.estVide())
    {
      ActiviteSalarie activiteSalarie = (ActiviteSalarie)chronoPeriodesRuptureContrat.premierElement();
      if (activiteSalarie.getContrat().getPreavis() != null) {
        preavis = activiteSalarie.getContrat().getPreavis();
      }
    }
    return preavis;
  }
  
  public static Differe definirDiffereContexteChomageSansRCT(DemandeAssuranceSpec p_demande)
    throws CoucheLogiqueException
  {
    boolean creerDiffere = false;
    if ((DeterminationCarence.estPrecedeParUneAttributionChomageSansRCT(p_demande)) && (OutilsChomageSansRCT.estPremiereRepriseApresSuspension((DossierExamenAssuranceSpec)p_demande.getDossierExamen()))) {
      creerDiffere = true;
    } else if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(p_demande)) {
      if (OutilsChomageSansRCT.estUnContexteRuptureContratPendantSuspension(p_demande)) {
        creerDiffere = true;
      }
    }
    if (creerDiffere) {
      return new Differe(7);
    }
    return null;
  }
  
  private static int getNbJoursCarence(DemandeAssuranceSpec p_demande)
  {
    if (p_demande.getDonneesTemporaires().getQuantiteJoursDiffereChomageTotalSansRupture() != null) {
      return p_demande.getDonneesTemporaires().getQuantiteJoursDiffereChomageTotalSansRupture().getNombreJours();
    }
    return 0;
  }
  
  private static EnsembleCarences definirEnsembleCarence(TravailSpec p_periode, int p_nbJourCarence)
  {
    if (p_nbJourCarence != 0)
    {
      EnsembleCarences ensembleCarencesChomagSansRCT = new EnsembleCarences();
      CarenceIslr carenceIslr = new CarenceIslr((ObjetChronoPeriode)p_periode, p_nbJourCarence);
      ensembleCarencesChomagSansRCT.setCarenceIslr(carenceIslr);
      return ensembleCarencesChomagSansRCT;
    }
    return null;
  }
  
  private static TravailSpec trouverPeriodeActiviteTerminantLeContrat(IndividuSpec p_demandeur, TravailSpec p_periodeActivite)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieSurMemeContratGAEC(p_periodeActivite));
    filtres.ajouterFiltre(new FiltreDebutApresDate(p_periodeActivite.getDateFin()));
    
    Chronologie chronoPeriodesTerminantASChomageSansRCT = p_demandeur.getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    if (chronoPeriodesTerminantASChomageSansRCT.estVide()) {
      return p_periodeActivite;
    }
    return (TravailSpec)chronoPeriodesTerminantASChomageSansRCT.dernierElement();
  }
  
  public static boolean presencePeriodeActiviteTravailleApresSuspension(IndividuSpec p_demandeur, TravailSpec p_periodeActivite)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieSurMemeContratGAEC(p_periodeActivite));
    filtres.ajouterFiltre(new FiltreDebutApresDate(p_periodeActivite.getDateFin()));
    FiltreNegation filtreNegation = new FiltreNegation(new FiltreActiviteSalarieSuspensionChomageSansRCT());
    filtres.ajouterFiltre(filtreNegation);
    Chronologie chronoPeriodes = p_demandeur.getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    return !chronoPeriodes.estVide();
  }
}

/* Location:
 * Qualified Name:     DeterminationCarenceRCT
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */