package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Competence;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.EnsembleCarences;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Od;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Readmission;
import fr.unedic.cali.asu.dom.AccesseurDroitsSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.OutilConstructionDonneesEntreesRecuperationMontant;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.avant.ExecutionAvantImpossibleException;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ReadmissionSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.outilsfonctionnels.AppelAvant;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class DeterminationProduitResultant
  implements OutilFonctionnel
{
  private static DeterminationProduitResultant instance = null;
  
  public Quantite determinationDureeProduitResultant(Od read, MontantAsuSpec montantResultant, Damj pointDepartUnique, Quantite capitalProduitResultant)
    throws CoucheLogiqueException
  {
    Quantite montant = null;
    QuantiteJour duree = null;
    
    montant = montantResultant.getMontantPrecompteEffectif();
    if (montant.getValeur().doubleValue() == 0.0D)
    {
      duree = new QuantiteJour("0");
    }
    else
    {
      BigDecimal dureeTemp = Mathematiques.diviseParDefaut(capitalProduitResultant.getValeur(), montant.getValeur());
      dureeTemp = dureeTemp.setScale(0, 0);
      duree = new QuantiteJour(dureeTemp);
    }
    return determinerDuree(duree.getNombreJours(), pointDepartUnique, read);
  }
  
  public void constitutionMontantCepa15(MontantAsuSpec montantRetenu, Readmission attributionCourante)
    throws CoucheLogiqueException
  {
    ConstitutionProduitResultant cepa15 = attributionCourante.getConstitutionProduitResultant();
    
    cepa15.createConstitutionMontantsBruts();
    if (montantRetenu != null)
    {
      cepa15.getConstitutionMontantsBruts().setMontantJournalierBrut(montantRetenu.getMontantPrecompteEffectif());
      cepa15.getConstitutionMontantsBruts().setMontantBrutSansDeduction(montantRetenu.getMontantBrut());
      cepa15.getConstitutionMontantsBruts().setMontantBase(montantRetenu.getBase());
      cepa15.getConstitutionMontantsBruts().setMontantMini(montantRetenu.getMini());
      cepa15.getConstitutionMontantsBruts().setMontantPlafond(montantRetenu.getPlafond());
      cepa15.getConstitutionMontantsBruts().setMontantPlancher(montantRetenu.getPlancher());
      cepa15.getConstitutionMontantsBruts().setMontantBrutSansPensionInvaliditeADeduire(montantRetenu.getMontantBrutSansPensionInvaliditeADeduire());
      
      cepa15.getConstitutionMontantsBruts().setPensionInvaliditeADeduirePriseEnCompte(montantRetenu.getPensionInvaliditeADeduirePriseEnCompte());
      
      cepa15.getConstitutionMontantsBruts().setMontantJournalierAvantageVieillesse(montantRetenu.getMontantJournalierAvantageVieillesse());
      cepa15.getConstitutionMontantsBruts().setMontantJournalierAvantageVieillesseDeduit(montantRetenu.getMontantJournalierAvantageVieillesseDeduit());
      
      cepa15.getConstitutionMontantsBruts().setCrc(montantRetenu.getCrc());
    }
  }
  
  public Damj determinerPointDepartUnique(Demande demandeCourante, MontantAsuSpec montantCourant, MontantAsuSpec montantPrecedant)
    throws CoucheLogiqueException, ApplicativeException
  {
    DossierExamen dossierExamen = (DossierExamen)demandeCourante.getDossierExamen();
    AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)dossierExamen;
    AttributionAssuranceSpec attributionPrecedente = dossierExamen.getAttributionPrecedente();
    
    Sjr sjrMontantMax = obtenirSjrDuMontantMax(attributionCourante, attributionPrecedente, montantCourant, montantPrecedant);
    
    return determinerPointDepart(attributionCourante, sjrMontantMax);
  }
  
  private Sjr obtenirSjrDuMontantMax(AttributionAssuranceSpec attributionCourante, AttributionAssuranceSpec attributionPrecedente, MontantAsuSpec p_montantCourant, MontantAsuSpec p_montantPrecedent)
    throws CoucheLogiqueException
  {
    Sjr sjrMontantMax = null;
    CompetenceSpec competenceDroitPrecedent = null;
    CompetenceSpec competenceDroitCourant = attributionCourante.getCompetence();
    if (attributionPrecedente != null) {
      competenceDroitPrecedent = attributionPrecedente.getCompetence();
    }
    if ((attributionPrecedente == null) || (((Demande)attributionCourante.getDemande()).getDonneesTemporaires().getSjrSP() != null))
    {
      if (p_montantCourant.getMontantBrut().compareTo(p_montantPrecedent.getMontantBrut()) >= 0)
      {
        sjrMontantMax = attributionCourante.getElementBaseIndemnisation().getSjr();
      }
      else
      {
        Sjr sjrDonnesForcees = new Sjr(((Demande)attributionCourante.getDemande()).getDonneesTemporaires().getSjrSP().getValeur(), ((Demande)attributionCourante.getDemande()).getDonneesTemporaires().getTermePrcSp(), null);
        
        sjrMontantMax = sjrDonnesForcees;
      }
    }
    else if (((competenceDroitCourant.getCompetenceFinanciere() == 1) && (competenceDroitPrecedent.getCompetenceFinanciere() == 1)) || ((competenceDroitCourant.getCompetenceFinanciere() == 2) && (competenceDroitPrecedent.getCompetenceFinanciere() == 2) && (competenceDroitCourant.getNumeroConventionGestion() != null) && (competenceDroitPrecedent.getNumeroConventionGestion() != null) && (competenceDroitCourant.getNumeroConventionGestion().equalsIgnoreCase(competenceDroitPrecedent.getNumeroConventionGestion())) && (!competenceDroitCourant.getNumeroConventionGestion().equalsIgnoreCase("555"))))
    {
      if (p_montantCourant.getMontantPrecompte().compareTo(p_montantPrecedent.getMontantPrecompte()) >= 0) {
        sjrMontantMax = RevalorisationSalaire.revaloriserSjr(attributionCourante.getElementBaseIndemnisation(), attributionCourante.getProduitMontantRetenu(), attributionCourante.getDateAttribution());
      } else {
        sjrMontantMax = RevalorisationSalaire.revaloriserSjr(attributionPrecedente.getElementBaseIndemnisation(), attributionPrecedente.getProduitMontantRetenu(), attributionCourante.getDateAttribution());
      }
    }
    else if (p_montantCourant.getMontantBrut().compareTo(p_montantPrecedent.getMontantBrut()) >= 0) {
      sjrMontantMax = RevalorisationSalaire.revaloriserSjr(attributionCourante.getElementBaseIndemnisation(), attributionCourante.getProduitMontantRetenu(), attributionCourante.getDateAttribution());
    } else {
      sjrMontantMax = RevalorisationSalaire.revaloriserSjr(attributionPrecedente.getElementBaseIndemnisation(), attributionPrecedente.getProduitMontantRetenu(), attributionCourante.getDateAttribution());
    }
    return sjrMontantMax;
  }
  
  public MontantAsuSpec obtenirMontantDroitPrecedent(DossierExamen dossierExamen, Demande demande)
    throws CoucheLogiqueException
  {
    MontantAsuSpec montant = null;
    AttributionAssuranceSpec attributionPrecedente = dossierExamen.getAttributionPrecedente();
    Individu individu = (Individu)demande.getDemandeur();
    if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      montant = obtenirMontantDroitPrecedentSecteurPublic(demande, dossierExamen, individu, null);
    } else {
      montant = obtenirMontant(dossierExamen, attributionPrecedente);
    }
    return montant;
  }
  
  public MontantAsuSpec obtenirMontantDroitPrecedentAvecCompetenceAServir(DossierExamen dossierExamenCourant, Demande demande)
    throws CoucheLogiqueException
  {
    MontantAsuSpec montant = null;
    AttributionAssuranceSpec attributionPrecedente = dossierExamenCourant.getAttributionPrecedente();
    Competences competencesAServir = getConteneurCompetence((Competence)dossierExamenCourant.getCompetence());
    Individu individu = (Individu)demande.getDemandeur();
    if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      montant = obtenirMontantDroitPrecedentSecteurPublic(demande, dossierExamenCourant, individu, competencesAServir);
    } else {
      montant = obtenirMontant(dossierExamenCourant, attributionPrecedente, competencesAServir);
    }
    return montant;
  }
  
  public MontantAsuSpec obtenirMontantDroitCourant(DossierExamen dossierExamen)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)dossierExamen;
    
    return obtenirMontant(dossierExamen, attributionCourante);
  }
  
  public MontantAsuSpec obtenirMontantDroitCourantAvecCompetenceAServir(DossierExamen dossierExamenCourant)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)dossierExamenCourant;
    Competences competencesAServir = getConteneurCompetence((Competence)dossierExamenCourant.getCompetence());
    
    MontantAsuSpec montant = obtenirMontant(dossierExamenCourant, attributionCourante, competencesAServir);
    
    return montant;
  }
  
  public MontantAsuSpec obtenirMontantDroitPrecedentSecteurPublic(Demande demande, DossierExamen dossierExamen, IndividuSpec individu, Competences competences)
    throws CoucheLogiqueException
  {
    ElementBaseIndemnisation ebi = null;
    
    ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
    conteneur.setDemande(demande);
    conteneur.setDateRecherche(dossierExamen.getDateAttribution());
    conteneur.setDateFinContrat(dossierExamen.getDateAttribution());
    
    conteneur.setBesoinCritereQualif(false);
    DecorReglementaire decorReglementaireDateExamen = ConstitutionDecorReglementaire.recupererDecor(conteneur);
    
    ProduitAsuSpec produitPrecedent = (ProduitAsuSpec)decorReglementaireDateExamen.determinerProduitEffectifDeLaLigne(LigneAsuCge01.getInstance());
    
    ebi = new ElementBaseIndemnisation();
    ebi.setSjc(null);
    ebi.setSjr(new Sjr(demande.getDonneesTemporaires().getSjrSP().getValeur(), demande.getDonneesTemporaires().getTermePrcSp(), null));
    
    ebi.setCoefficientSaisonnier(demande.getDonneesTemporaires().getCoefficientSaisonnierSp());
    ebi.setCoefficientTempsPartiel(demande.getDonneesTemporaires().getCoefficientTempsPartielSp());
    
    ebi.setIsConditionCaractereSaisonnierParRythme(false);
    ebi.setTypeCaractereSaisonnierRetenu(-1);
    
    ebi.setIsSjrBaseSurPourcentageSMIC(false);
    
    ebi.setReglementApplicableMontantRetenu(dossierExamen.getReglementApplicable());
    if (competences == null)
    {
      competences = new Competences();
      competences.setCompetenceAdministrative(2);
      competences.setCompetenceFinanciere(2);
    }
    Damj dateAttrib = dossierExamen.getDateAttribution();
    FormuleMontantSpec formule = produitPrecedent.getFormuleMontant("1");
    
    return obtenirMontant(produitPrecedent, individu, ebi, competences, formule, dateAttrib);
  }
  
  public MontantAsuSpec obtenirMontant(DossierExamen dossierExamen, AttributionAssuranceSpec attribution)
    throws CoucheLogiqueException
  {
    ProduitSpec produit = attribution.getProduitMontantRetenu();
    IndividuSpec demandeur = attribution.getDemande().getDemandeur();
    ElementBaseIndemnisation ebi = attribution.getElementBaseIndemnisation();
    Competences competences = getConteneurCompetence(attribution);
    FormuleMontantSpec formule = attribution.getFormuleMontant("1");
    Damj dateAttrib = dossierExamen.getDateAttribution();
    
    return obtenirMontant(produit, demandeur, ebi, competences, formule, dateAttrib);
  }
  
  public MontantAsuSpec obtenirMontant(DossierExamen dossierExamen, AttributionAssuranceSpec attribution, Competences competence)
    throws CoucheLogiqueException
  {
    ProduitSpec produit = attribution.getProduitMontantRetenu();
    IndividuSpec demandeur = attribution.getDemande().getDemandeur();
    ElementBaseIndemnisation ebi = attribution.getElementBaseIndemnisation();
    FormuleMontantSpec formule = attribution.getFormuleMontant("1");
    Damj dateAttrib = dossierExamen.getDateAttribution();
    
    return obtenirMontant(produit, demandeur, ebi, competence, formule, dateAttrib);
  }
  
  public MontantAsuSpec obtenirMontant(ProduitSpec produit, IndividuSpec demandeur, ElementBaseIndemnisation ebi, Competences competence, FormuleMontantSpec formule, Damj dateAttrib)
    throws CoucheLogiqueException
  {
    OutilConstructionDonneesEntreesRecuperationMontant outil = new OutilConstructionDonneesEntreesRecuperationMontant();
    DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant = outil.creerDonneesEntreesRecuperationMontant(ebi);
    donneesEntreesRecuperationMontant.setDateCalculMontant(dateAttrib);
    donneesEntreesRecuperationMontant.setIndividu(demandeur);
    donneesEntreesRecuperationMontant.getDonneesCalculMontant().setFormuleMontant(formule);
    donneesEntreesRecuperationMontant.getDonneesCalculMontant().setProduit(produit);
    donneesEntreesRecuperationMontant.setCompetences(competence);
    return DeterminationMontant.determinerMontant(donneesEntreesRecuperationMontant);
  }
  
  private Competences getConteneurCompetence(AttributionAssuranceSpec attribution)
  {
    Competences conteneurCompetences = new Competences();
    
    conteneurCompetences.setCompetenceAdministrative(attribution.getCompetenceAdministrative());
    conteneurCompetences.setCompetenceFinanciere(attribution.getCompetenceFinanciere());
    conteneurCompetences.setConventionGestion(attribution.getConventionGestion());
    
    return conteneurCompetences;
  }
  
  private Competences getConteneurCompetence(Competence competence)
  {
    Competences conteneurCompetences = new Competences();
    
    conteneurCompetences.setCompetenceAdministrative(competence.getCompetenceAdministrative());
    conteneurCompetences.setCompetenceFinanciere(competence.getCompetenceFinanciere());
    conteneurCompetences.setConventionGestion(competence.getConventionGestion());
    
    return conteneurCompetences;
  }
  
  private void reportElementsDroits(Readmission attributionCourante)
    throws CoucheLogiqueException
  {
    ConstitutionProduitResultant cepa15 = attributionCourante.getConstitutionProduitResultant();
    DossierExamenAssuranceSpec attributionSourceMontant = null;
    if (attributionCourante.getConstitutionProduitResultant().getMontantRetenu() == 2) {
      attributionSourceMontant = attributionCourante.getAttributionPrecedente();
    } else {
      attributionSourceMontant = attributionCourante;
    }
    Sjr sjriProduitPrecedent = new Sjr(attributionSourceMontant.getAccesseurDroits().getSjrInitial().getValeur(), attributionSourceMontant.getAccesseurDroits().getDateEffetSjr(), null);
    
    ProduitSpec produit = ((DossierAffectation)attributionCourante.getDemande().getDossierAffectation()).getProduit();
    
    Reglement reglementApplicableCourant = attributionCourante.getReglementApplicable().getReglement();
    if (reglementApplicableCourant.equals(produit.getReglement("A2b")))
    {
      EvenementParametre evtParam = ParametresIndemnisation.getParametresIndemnisation().getElementActif(attributionCourante.getDateAttribution());
      
      BigDecimal plafond = evtParam.getPlafond().multiply(new BigDecimal("12")).divide(new BigDecimal("365"), 2, 1);
      
      Sjr sjripProduitPrecedent = new Sjr(sjriProduitPrecedent.getSalaire().min(plafond), sjriProduitPrecedent.getDateDepart(), null);
      cepa15.setSjrrpProduitPrecedent(sjripProduitPrecedent);
    }
    else
    {
      cepa15.setSjrrpProduitPrecedent(RevalorisationSalaire.revaloriserSjr(((AttributionAssuranceSpec)attributionSourceMontant).getElementBaseIndemnisation(), ((AttributionAssuranceSpec)attributionSourceMontant).getProduitMontantRetenu(), attributionCourante.getDateAttribution()));
    }
  }
  
  private void reportElementsDroitsSP(Readmission attributionCourante)
    throws CoucheLogiqueException
  {
    ConstitutionProduitResultant cepa15 = attributionCourante.getConstitutionProduitResultant();
    Demande demandeCourante = (Demande)attributionCourante.getDemande();
    
    QuantiteEuro sjrDroitPrecedentSP = new QuantiteEuro(demandeCourante.getDonneesTemporaires().getSjrSP().getValeur());
    Damj dateAttributionDroitAnterieur = demandeCourante.getDonneesTemporaires().getDateAttributionDroitAnterieurSp();
    Damj dateTermePRC = demandeCourante.getDonneesTemporaires().getTermePrcSp();
    if (attributionCourante.getConstitutionProduitResultant().getMontantRetenu() == 2)
    {
      Sjr sjriProduitPrecedent = new Sjr(sjrDroitPrecedentSP.getValeur(), dateTermePRC, null);
      
      ProduitSpec produit = ((DossierAffectation)attributionCourante.getDemande().getDossierAffectation()).getProduit();
      
      Reglement reglementApplicableCourant = attributionCourante.getReglementApplicable().getReglement();
      if (reglementApplicableCourant.equals(produit.getReglement("A2b")))
      {
        EvenementParametre evtParam = ParametresIndemnisation.getParametresIndemnisation().getElementActif(dateAttributionDroitAnterieur);
        BigDecimal plafond = evtParam.getPlafond().multiply(new BigDecimal("12")).divide(new BigDecimal("365"), 2, 1);
        
        Sjr sjripProduitPrecedent = new Sjr(sjriProduitPrecedent.getSalaire().min(plafond), sjriProduitPrecedent.getDateDepart(), null);
        cepa15.setSjrrpProduitPrecedent(sjripProduitPrecedent);
      }
      else
      {
        cepa15.setSjrrpProduitPrecedent(RevalorisationSalaire.revaloriserSjr(attributionCourante.getElementBaseIndemnisation(), attributionCourante.getProduitMontantRetenu(), attributionCourante.getDateAttribution()));
      }
    }
    else
    {
      reportElementsDroits(attributionCourante);
    }
  }
  
  public void reportElementsDroits(Readmission attributionCourante, Demande demandeCourante)
    throws CoucheLogiqueException
  {
    if (demandeCourante.estEnContexteDroitAnterieurSecteurPublicValide()) {
      reportElementsDroitsSP(attributionCourante);
    } else {
      reportElementsDroits(attributionCourante);
    }
  }
  
  public int determinerTypeReadmission(ConstitutionProduitResultant cepa, MontantAsuSpec montantProduitResultant, Quantite capitalProduitResultant, MontantAsuSpec montantPrecedentAvecCompetenceDuDroitAServir, MontantAsuSpec montantCourantAvecCompetenceDuDroitAServir, Quantite capitalComparatifDroitPrecedent, Quantite capitalComparatifDroitCourant)
  {
    cepa.setCapitalMax(capitalProduitResultant);
    if ((montantProduitResultant.getMontantPrecompteEffectif().equals(montantCourantAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif())) && (capitalProduitResultant.equals(capitalComparatifDroitCourant)))
    {
      cepa.setCapitalRetenu(1);
      cepa.setMontantRetenu(1);
      return 12;
    }
    if ((montantProduitResultant.getMontantPrecompteEffectif().equals(montantPrecedentAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif())) && (montantProduitResultant.getSjrNonReduit().equals(montantPrecedentAvecCompetenceDuDroitAServir.getSjrNonReduit())) && (capitalProduitResultant.equals(capitalComparatifDroitCourant)))
    {
      cepa.setCapitalRetenu(1);
      cepa.setMontantRetenu(2);
      return 26;
    }
    if ((montantProduitResultant.getMontantPrecompteEffectif().equals(montantCourantAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif())) && (montantProduitResultant.getSjrNonReduit().equals(montantCourantAvecCompetenceDuDroitAServir.getSjrNonReduit())) && (capitalProduitResultant.equals(capitalComparatifDroitPrecedent)))
    {
      cepa.setCapitalRetenu(2);
      cepa.setMontantRetenu(1);
      return 26;
    }
    if ((montantProduitResultant.getMontantPrecompteEffectif().equals(montantPrecedentAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif())) && (capitalProduitResultant.equals(capitalComparatifDroitPrecedent)))
    {
      cepa.setCapitalRetenu(2);
      cepa.setMontantRetenu(2);
      return 11;
    }
    return -1;
  }
  
  public void affecterDureeDroitCourant(Demande demandeCourante, Quantite dureeDroitCourant)
    throws CoucheLogiqueException
  {
    ((DossierExamen)demandeCourante.getDossierExamen()).getConstitutionDurees().getDureeIndemnisation().setDureeEffective(dureeDroitCourant);
  }
  
  public Quantite obtenirCapitalPourComparaison(Quantite duree, MontantAsuSpec montant, DossierExamen dossierExamen, Demande demandeCourante, boolean capitalCourant)
    throws CoucheLogiqueException
  {
    Quantite capitalProduitEffectif = null;
    if ((!capitalCourant) && (demandeCourante.estEnContexteDroitAnterieurSecteurPublicValide()))
    {
      capitalProduitEffectif = demandeCourante.getDonneesTemporaires().getCapitalReliquatSecteurPublic();
    }
    else
    {
      AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)dossierExamen;
      
      capitalProduitEffectif = AppelCalculParLiquidationAsu.calculerCapital(attributionCourante, montant, attributionCourante.getDateAttribution(), duree);
    }
    return new QuantiteEuro(capitalProduitEffectif.getValeur());
  }
  
  public Damj determinerPointDepart(AttributionAssuranceSpec attribution, Sjr sjr)
    throws CoucheLogiqueException, ApplicativeException
  {
    ResultatAvant resultatAvant = null;
    try
    {
      List<EnsembleCarences> listeEnsembleCarences = new ArrayList();
      ArrayList listeCarences = new ArrayList();
      ArrayList listeDelaisReports = new ArrayList();
      Chronologie chronologieActiviteSalarie = new ChronologiePeriodes();
      Chronologie chronologieActiviteSalariePMC = new ChronologiePeriodes();
      Demande demande = (Demande)attribution.getDemande();
      
      listeDelaisReports = DeterminationDiffere.determinerDiffere(demande);
      
      Periode periodeReference = ((DelaiRecherche)DelaiRecherche.getInstance()).determinerDelaiRechercheCarences(demande);
      
      Periode periodeReferencePMC = ((DelaiRecherche)DelaiRecherche.getInstance()).determinerDelaiRechercheComplementairePMC(demande);
      if (periodeReference != null) {
        chronologieActiviteSalarie = ConstructionChronologie.determinerChronoActivitesParticipantCarences(periodeReference, demande);
      }
      if (periodeReferencePMC != null) {
        chronologieActiviteSalariePMC = ConstructionChronologie.determinerChronoActivitesParticipantPMC(periodeReferencePMC, demande, chronologieActiviteSalarie);
      }
      DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
      
      ConstitutionDelais constitutionDelais = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionDelais();
      
      constitutionDelais.setPeriodeReference91jours(periodeReference);
      
      listeEnsembleCarences = DeterminationCarence.determinerCarences(chronologieActiviteSalarie, demande, sjr, chronologieActiviteSalariePMC);
      
      Iterator it = listeEnsembleCarences.iterator();
      while (it.hasNext())
      {
        EnsembleCarences listeCarencesTemp = (EnsembleCarences)it.next();
        if (listeCarencesTemp != null) {
          listeCarences.addAll(listeCarencesTemp.getListeCarences());
        }
      }
      resultatAvant = AppelAvant.executerAvant(attribution.getDemande().getDemandeur(), attribution.getDateEffet(), attribution.getProduit(), listeDelaisReports, listeCarences);
    }
    catch (ExecutionAvantImpossibleException e)
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CESSATION_PENDANT_AVANT");
    }
    return resultatAvant.getPji();
  }
  
  public void affecterDureeDroitPrecedent(DossierExamen readmission, Quantite duree)
  {
    readmission.getConstitutionProduitResultant().setDureeDroitPrecedent(duree);
  }
  
  public Quantite determinerDureeDroitPrecedentPourCalculCapital(Demande demandeCourante, Damj pointDepartUnique, MontantAsuSpec montantDroitPrecedent)
    throws CoucheLogiqueException
  {
    Quantite quantiteReliquat = null;
    int nombreJours = 0;
    DossierExamen dossierExamen = (DossierExamen)demandeCourante.getDossierExamen();
    if (demandeCourante.estEnContexteDroitAnterieurSecteurPublicValide())
    {
      quantiteReliquat = demandeCourante.getDonneesTemporaires().getCapitalReliquatSecteurPublic();
      BigDecimal montantPrecompte = montantDroitPrecedent.getMontantPrecompteEffectif().getValeur();
      QuantiteJour duree = new QuantiteJour("0");
      if (montantPrecompte.compareTo(BigDecimal.ZERO) > 0)
      {
        duree = new QuantiteJour(Mathematiques.diviseASup(quantiteReliquat.getValeur(), montantPrecompte, 0));
        
        nombreJours = duree.getNombreJours();
      }
    }
    else
    {
      quantiteReliquat = demandeCourante.getReliquat().getQuantiteReliquat();
      nombreJours = quantiteReliquat.getValeurEntiere();
    }
    return determinerDuree(nombreJours, pointDepartUnique, dossierExamen);
  }
  
  private Quantite determinerDuree(int qNombreJours, Damj pointDepartUnique, DossierExamen dossierExamen)
    throws CoucheLogiqueException
  {
    IndividuSpec individu = dossierExamen.getDemande().getDemandeur();
    Quantite nombreJours = new Quantite(qNombreJours, DureeReglementaire.UNITE_DEFAUT);
    
    boolean bornerRetraite = true;
    DonneesTemporaires donneesForcees = ((Demande)dossierExamen.getDemande()).getDonneesTemporaires();
    if (donneesForcees != null) {
      bornerRetraite = !donneesForcees.isLeverBornageDureeEffectiveRetraite();
    }
    int duree = OutilRetraite.getInstance().bornerDureeALaRetraite(individu, pointDepartUnique, nombreJours, bornerRetraite);
    return new Quantite(duree, DureeReglementaire.UNITE_DEFAUT);
  }
  
  public ReadmissionSpec miseAJourReadmissionEnFonctionType(int typeReadmission, Demande demandeCourante)
    throws CoucheLogiqueException
  {
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    ReadmissionSpec readmission = (Readmission)dossierExamenCourant.changerEtat(typeReadmission);
    readmission.setNatureDecision(typeReadmission);
    demandeCourante.getObjectifCourant().setSousType(typeReadmission);
    
    return readmission;
  }
  
  public void miseAJourCapitauxSurCepa15(DossierExamen readmission, Quantite capitalComparatifDroitPrecedent, Quantite capitalComparatifDroitCourant)
    throws CoucheLogiqueException
  {
    readmission.getConstitutionProduitResultant().setCapitalDroitPrecedent(capitalComparatifDroitPrecedent);
    if (readmission.getConstitutionProduitResultant().getConstitutionMontantsBruts() == null) {
      readmission.getConstitutionProduitResultant().createConstitutionMontantsBruts();
    }
    readmission.getConstitutionProduitResultant().getConstitutionMontantsBruts().setCapitalInitialBrut(capitalComparatifDroitCourant);
  }
  
  public void constitutionDureeDroitPrecedentCepa15(Demande demandeCourante)
  {
    ((Od)demandeCourante.getAttribution()).getConstitutionProduitResultant().setDureeDroitPrecedent(demandeCourante.getReliquat().getQuantiteReliquat());
  }
  
  public void affecterMontantPrecedentAvecCompetenceAServir(DossierExamen readmission, MontantAsuSpec montantPrecedent)
  {
    readmission.getConstitutionProduitResultant().setMontantDroitPrecedent(new QuantiteEuro(montantPrecedent.getMontantPrecompteEffectif().getValeur()));
  }
  
  public void affecterDureeDroitResultant(Quantite dureeDroitResultant, DossierExamen readmission)
  {
    ConstitutionProduitResultant constitutionProduitResultant = readmission.getConstitutionProduitResultant();
    
    constitutionProduitResultant.createConstitutionDurees();
    constitutionProduitResultant.getConstitutionDurees().createDureeIndemnisation();
    constitutionProduitResultant.getConstitutionDurees().getDureeIndemnisation().setDureeEffective(dureeDroitResultant);
    constitutionProduitResultant.getConstitutionDurees().getDureeIndemnisation().setDureeTheorique(dureeDroitResultant);
  }
  
  public static DeterminationProduitResultant getInstance()
  {
    if (instance == null) {
      instance = new DeterminationProduitResultant();
    }
    return instance;
  }
}

/* Location:
 * Qualified Name:     DeterminationProduitResultant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */