package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionCoefficientTempsPartiel;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Prc;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Revision;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DeterminationCoefficientTempsPartiel;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class ConstitutionCoefficientTempsPartielPourRevision
  extends ParcoursCali
  implements ParcoursAssurance
{
  private BigDecimal m_coefficientTempsPartiel = new BigDecimal("1");
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null pour la constitution du coefficient Temps Partiel");
    }
    if (((DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen()).getAttributionPrecedente() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution est null pour la constitution du coefficient Temps Partiel.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution courante est null: constitution du coefficient Temps Partiel impossible.");
    }
    if (dossierExamenCourant.getReglementApplicable() == null) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_RA", "Le règlement applicable de l'ouverture de droits courante est null: constitution du coefficient Temps Partiel impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours(Niveau.DEBUG);
    
    Resultat resultat = new Resultat(0);
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    Revision dossierExamenCourant = (Revision)demande.getDossierExamen();
    
    Reglement reglementApplicable = dossierExamenCourant.getReglementApplicable().getReglement();
    
    ConstitutionCoefficientTempsPartiel cepa11 = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionCoefficientTempsPartiel();
    if (demande.getDonneesTemporaires().getCoefficientTempsPartielActConservee() != null)
    {
      m_coefficientTempsPartiel = demande.getDonneesTemporaires().getCoefficientTempsPartielActConservee();
    }
    else if ((reglementApplicable.estNomReglementIdentique("RG")) || (reglementApplicable.estNomReglementIdentique("OP")) || (reglementApplicable.estNomReglementIdentique("A2a")) || (reglementApplicable.estNomReglementIdentique("A6")))
    {
      AttributionAssuranceSpec attributionOrigine = (AttributionAssuranceSpec)dossierExamenCourant.getOuvertureDroit();
      
      Periode prtp = ((DossierExamen)attributionOrigine).getConstitutionSjr().getSjrip().getPrc().getPeriode();
      
      Chronologie chronologiePrs = ConstructionChronologie.determinerChronoActivitesPrcPourRevision(demande, prtp);
      if (!chronologiePrs.estVide())
      {
        Chronologie chronologiePeriodeHoraireStable = DeterminationCoefficientTempsPartiel.determinerChronoPeriodesIntensiteADate(prtp, chronologiePrs);
        
        m_coefficientTempsPartiel = DeterminationCoefficientTempsPartiel.determinerCoefficientTempsPartiel(chronologiePeriodeHoraireStable);
      }
    }
    cepa11.setCoefficientTempsPartielRetenu(m_coefficientTempsPartiel);
    
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\t\t******** Résultat Parcours ConstitutionCoefficientTempsPartielPourRevision ********\n", resultat });
    
    OutilTrace.tracerFinParcours(Niveau.DEBUG);
    
    return resultat;
  }
  
  private DemandeSpec getDemande(Contexte p_contexte)
  {
    return ((DomLiquidationDemande)p_contexte.getDonnees()).getDemandeSpec();
  }
}

/* Location:
 * Qualified Name:     ConstitutionCoefficientTempsPartielPourRevision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */