package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.CarenceIccp;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.CarenceIslr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Differe;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.EnsembleCarences;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.PreavisMesureConservatoireIndemnisable;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.PreavisMesureConservatoireNonIndemnisable;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DelaiRecherche;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DeterminationCarence;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DeterminationCarenceRCT;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CarenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.outilsfonctionnels.OutilCarence;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;

public class ConstitutionDelaiReportPourReprise
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null pour la constitution des carences.");
    }
    if (getEtatDroitPrecedent(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "L'état de droit précèdent est vide pour la constitution des carences .");
    }
  }
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    
    ConstitutionDelais constitutionDelais = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionDelais();
    
    DossierExamen attributionPrecedente = (DossierExamen)dossierExamenCourant.getAttributionPrecedente();
    
    Periode periodeReference = ((DelaiRecherche)DelaiRecherche.getInstance()).determinerDelaiRechercheCarences(demande);
    constitutionDelais.setPeriodeReference91jours(periodeReference);
    
    Periode periodeReferencePMC = ((DelaiRecherche)DelaiRecherche.getInstance()).determinerDelaiRechercheComplementairePMC(demande);
    
    Chronologie chronologieActiviteSalarie = new ChronologiePeriodes();
    Chronologie chronologieActiviteSalariePMC = new ChronologiePeriodes();
    if (periodeReference != null) {
      chronologieActiviteSalarie = ConstructionChronologie.determinerChronoActivitesParticipantCarences(periodeReference, demande);
    }
    if (periodeReferencePMC != null) {
      chronologieActiviteSalariePMC = ConstructionChronologie.determinerChronoActivitesParticipantPMC(periodeReferencePMC, demande, chronologieActiviteSalarie);
    }
    if (Log.isTraceActive(ConstitutionDelaiReportPourReprise.class, Niveau.INFO)) {
      Log.ecritTrace(Niveau.INFO, ConstitutionDelaiReportPourReprise.class, "demarrer", "Chronologie des ActiviteSalarie participant aux délais reports : " + chronologieActiviteSalarie);
    }
    List<EnsembleCarences> listeEnsembleCarences = new ArrayList();
    if (estDemandeEligibleCarences(demande)) {
      listeEnsembleCarences = DeterminationCarence.determinerCarences(chronologieActiviteSalarie, demande, chronologieActiviteSalariePMC);
    }
    Iterator iterListeEnsembleCarences = listeEnsembleCarences.iterator();
    while (iterListeEnsembleCarences.hasNext()) {
      dossierExamenCourant.getConstitutionDelais().ajouterEnsembleCarences((EnsembleCarences)iterListeEnsembleCarences.next());
    }
    Boolean forcageDelai = null;
    if (demande.getDonneesTemporaires() != null) {
      forcageDelai = demande.getDonneesTemporaires().isDelaiAttenteForce();
    }
    if ((forcageDelai != null) && (forcageDelai.booleanValue()))
    {
      dossierExamenCourant.getConstitutionDelais().ajouterDelaisReports(new Differe(7));
    }
    else if (forcageDelai == null)
    {
      ArrayList listeEnsembleCarencesPrecedent = new ArrayList();
      if ((!dossierExamenCourant.getAttributionPrecedente().isUnJourDiffereConsomme()) && (((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionDelais() != null))
      {
        Collection listeDelaiReportAttributionPrecedente = ((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionDelais().getListeDelaisReports();
        Iterator itDelaiReport = listeDelaiReportAttributionPrecedente.iterator();
        if (itDelaiReport.hasNext())
        {
          Differe delaiAttenteAttributionPrecedente = (Differe)itDelaiReport.next();
          if (delaiAttenteAttributionPrecedente.getQuantiteInitialJour() > 0) {
            listeEnsembleCarencesPrecedent.addAll(attributionPrecedente.getConstitutionDelais().getListeEnsembleCarences());
          }
        }
      }
      Iterator iterListeEnsembleCarencesPrecedente = listeEnsembleCarencesPrecedent.iterator();
      while (iterListeEnsembleCarencesPrecedente.hasNext())
      {
        EnsembleCarences element = (EnsembleCarences)iterListeEnsembleCarencesPrecedente.next();
        if (element != null) {
          dossierExamenCourant.getConstitutionDelais().ajouterEnsembleCarences((EnsembleCarences)element.copie());
        }
      }
    }
    EnsembleCarences ensembleCarencesChomageSansRCT = DeterminationCarenceRCT.definirCarenceSupSiContexteChomageSansRCT(demande);
    if (ensembleCarencesChomageSansRCT != null) {
      dossierExamenCourant.getConstitutionDelais().ajouterEnsembleCarences(ensembleCarencesChomageSansRCT);
    }
    Collection listeDelaisReports = getDelaiReport(dossierExamenCourant);
    
    Iterator iter = listeDelaisReports.iterator();
    while (iter.hasNext())
    {
      Differe element = (Differe)iter.next();
      if (element != null) {
        dossierExamenCourant.getConstitutionDelais().ajouterDelaisReports((Differe)element.copie());
      }
    }
    ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit((Attribution)dossierExamenCourant, null, false);
    
    alimenterResultatCepaDepuisAvant(resultatCalcul, constitutionDelais, demande);
    
    OutilTrace.tracerFinParcours();
    return new Resultat();
  }
  
  private boolean estDemandeEligibleCarences(Demande demande)
  {
    return ((!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "AREENTRCSP")) && (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP"))) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 10));
  }
  
  private ResultatExecutionCalculSpec getEtatDroitPrecedent(Contexte contexte)
  {
    return ((DomLiquidationAssurance)contexte.getDonnees()).getResultatExecutionCalculDroitPrecedent();
  }
  
  protected Collection getDelaiReport(DossierExamen dossierExamenCourant)
    throws CoucheLogiqueException
  {
    Collection listeDelaiReport = new ArrayList();
    if ((DeterminationCarence.estPrecedeParUneAttributionChomageSansRCT((DemandeAssuranceSpec)dossierExamenCourant.getDemande())) && (OutilsChomageSansRCT.estPremiereRepriseApresSuspension(dossierExamenCourant)))
    {
      Differe differeJours = new Differe(7);
      listeDelaiReport.add(differeJours);
    }
    else if (!dossierExamenCourant.getAttributionPrecedente().isUnJourDiffereConsomme())
    {
      if (((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionDelais() != null) {
        listeDelaiReport = ((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionDelais().getListeDelaisReports();
      }
    }
    else
    {
      Damj dateAttributionReprise = dossierExamenCourant.getDateAttribution();
      Damj debutProchaineCarence = dateAttributionReprise;
      Damj pjiAttributionPrecedente = ((Attribution)dossierExamenCourant.getAttributionPrecedente()).getConstitutionPointDepartIndemnisation().getPji();
      if (dateAttributionReprise.estAvant(pjiAttributionPrecedente))
      {
        Collection listeEnsembleCarence = null;
        if (((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionDelais() != null) {
          listeEnsembleCarence = ((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionDelais().getListeEnsembleCarences();
        } else {
          listeEnsembleCarence = new ArrayList();
        }
        Iterator it = listeEnsembleCarence.iterator();
        while (it.hasNext())
        {
          EnsembleCarences ensembleCarence = (EnsembleCarences)it.next();
          EnsembleCarences nouvelEnsembleCarence = new EnsembleCarences();
          
          debutProchaineCarence = dateAttributionReprise;
          
          nouvelEnsembleCarence.setCarencePmc(definirCarencePMC(ensembleCarence, dateAttributionReprise, debutProchaineCarence));
          debutProchaineCarence = definirProchainDebutCarence(nouvelEnsembleCarence.getCarencePmc(), debutProchaineCarence);
          
          nouvelEnsembleCarence.setCarenceIccp(definirCarenceIccp(ensembleCarence, dateAttributionReprise, debutProchaineCarence));
          debutProchaineCarence = definirProchainDebutCarence(nouvelEnsembleCarence.getCarenceIccp(), debutProchaineCarence);
          
          nouvelEnsembleCarence.setCarenceIslr(definirCarenceIslr(ensembleCarence, dateAttributionReprise, debutProchaineCarence));
          debutProchaineCarence = definirProchainDebutCarence(nouvelEnsembleCarence.getCarenceIslr(), debutProchaineCarence);
          
          dossierExamenCourant.getConstitutionDelais().ajouterEnsembleCarences(nouvelEnsembleCarence);
        }
        Collection listeDelaiReportAttributionPrecedente = null;
        if (((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionDelais() != null) {
          listeDelaiReportAttributionPrecedente = ((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionDelais().getListeDelaisReports();
        } else {
          listeDelaiReportAttributionPrecedente = new ArrayList();
        }
        Differe differe = definirDiffere(listeDelaiReportAttributionPrecedente, debutProchaineCarence);
        if (differe != null) {
          listeDelaiReport.add(differe);
        }
      }
    }
    return listeDelaiReport;
  }
  
  private Damj definirProchainDebutCarence(CarencePrefixeAFixer carence, Damj dateDebutProchaineCarence)
  {
    if (carence != null) {
      return carence.getPeriodeApplicationCarence().getFin().lendemain();
    }
    return dateDebutProchaineCarence;
  }
  
  private Differe definirDiffere(Collection listeDelaiReport, Damj debutProchaineCarence)
  {
    Iterator itDelaiReport = listeDelaiReport.iterator();
    if (itDelaiReport.hasNext())
    {
      Differe differeReference = (Differe)itDelaiReport.next();
      boolean ajouterReport = false;
      Damj dateDebutPeriodeEffet = debutProchaineCarence;
      Damj dateFinPeriodeEffet = null;
      int nbrJours = 0;
      if (debutProchaineCarence.estContenueDans(differeReference.getPeriodeEffet()))
      {
        nbrJours = debutProchaineCarence.veille().joursEntre(differeReference.getPeriodeEffet().getFin());
        dateFinPeriodeEffet = debutProchaineCarence.deplacerVersAvant(new DureeCalendaire(0, 0, nbrJours));
        ajouterReport = true;
      }
      else if (debutProchaineCarence.estAvant(differeReference.getPeriodeEffet().getDebut()))
      {
        nbrJours = differeReference.getQuantiteInitialJour();
        dateFinPeriodeEffet = debutProchaineCarence.deplacerVersAvant(new DureeCalendaire(0, 0, nbrJours));
        ajouterReport = true;
      }
      if (ajouterReport)
      {
        Differe differe = new Differe();
        differe.setPeriodeEffet(new Periode(dateDebutPeriodeEffet, dateFinPeriodeEffet));
        differe.setQuantiteInitialJour(nbrJours);
        return differe;
      }
    }
    return null;
  }
  
  private PreavisMesureConservatoireNonIndemnisable definirCarencePMC(EnsembleCarences ensembleCarence, Damj dateAttributionReprise, Damj debutPochaineCarence)
  {
    PreavisMesureConservatoireNonIndemnisable pmc = null;
    if (ensembleCarence.getCarencePmc() != null)
    {
      Periode periodePMCOrigine = ensembleCarence.getCarencePmc().getPeriodeApplicationCarence();
      if (dateAttributionReprise.estContenueDans(periodePMCOrigine))
      {
        int nbrJours = dateAttributionReprise.veille().joursEntre(periodePMCOrigine.getFin());
        Damj dateFinNouvelleCarence = debutPochaineCarence.deplacerVersAvant(new DureeCalendaire(0, 0, nbrJours)).veille();
        Periode periodeCarencePMC = new Periode(debutPochaineCarence, dateFinNouvelleCarence);
        pmc = new PreavisMesureConservatoireNonIndemnisable(ensembleCarence.getCarencePmc().getOrigine(), periodeCarencePMC);
      }
      else if (dateAttributionReprise.estAvant(periodePMCOrigine.getDebut()))
      {
        Periode periodeCarencePMC = new Periode(periodePMCOrigine.getDebut(), periodePMCOrigine.getFin());
        pmc = new PreavisMesureConservatoireNonIndemnisable(ensembleCarence.getCarencePmc().getOrigine(), periodeCarencePMC);
      }
    }
    if (pmc != null)
    {
      Damj finProchainePeriode = debutPochaineCarence.deplacerVersAvant(new DureeCalendaire(0, 0, pmc.getQuantiteInitialJour())).veille();
      Periode periodeApplicationCarence = new Periode(debutPochaineCarence, finProchainePeriode);
      pmc.setPeriodeApplicationCarence(periodeApplicationCarence);
    }
    return pmc;
  }
  
  private CarenceIslr definirCarenceIslr(EnsembleCarences ensembleCarence, Damj dateAttributionReprise, Damj debutPochaineCarence)
  {
    CarenceIslr carence = null;
    if (ensembleCarence.getCarenceIslr() != null)
    {
      Periode periodeISLROrigine = ensembleCarence.getCarenceIslr().getPeriodeApplicationCarence();
      if (dateAttributionReprise.estContenueDans(periodeISLROrigine))
      {
        int nbrJours = dateAttributionReprise.veille().joursEntre(periodeISLROrigine.getFin());
        carence = new CarenceIslr(ensembleCarence.getCarenceIslr().getOrigine(), nbrJours);
      }
      else if (dateAttributionReprise.estAvant(periodeISLROrigine.getDebut()))
      {
        int nbrJours = periodeISLROrigine.getDuree();
        carence = new CarenceIslr(ensembleCarence.getCarenceIslr().getOrigine(), nbrJours);
      }
    }
    if (carence != null)
    {
      Damj finProchainePeriode = debutPochaineCarence.deplacerVersAvant(new DureeCalendaire(0, 0, carence.getQuantiteInitialJour())).veille();
      Periode periodeApplicationCarence = new Periode(debutPochaineCarence, finProchainePeriode);
      carence.setPeriodeApplicationCarence(periodeApplicationCarence);
    }
    return carence;
  }
  
  private CarenceIccp definirCarenceIccp(EnsembleCarences ensembleCarence, Damj dateAttributionReprise, Damj debutPochaineCarence)
  {
    CarenceIccp carence = null;
    if (ensembleCarence.getCarenceIccp() != null)
    {
      Periode periodeICCPOrigine = ensembleCarence.getCarenceIccp().getPeriodeApplicationCarence();
      if (dateAttributionReprise.estContenueDans(periodeICCPOrigine))
      {
        int nbrJours = dateAttributionReprise.veille().joursEntre(periodeICCPOrigine.getFin());
        carence = new CarenceIccp(ensembleCarence.getCarenceIccp().getOrigine(), nbrJours);
      }
      else if (dateAttributionReprise.estAvant(periodeICCPOrigine.getDebut()))
      {
        int nbrJours = periodeICCPOrigine.getDuree();
        carence = new CarenceIccp(ensembleCarence.getCarenceIccp().getOrigine(), nbrJours);
      }
    }
    if (carence != null)
    {
      Damj finProchainePeriode = debutPochaineCarence.deplacerVersAvant(new DureeCalendaire(0, 0, carence.getQuantiteInitialJour())).veille();
      Periode periodeApplicationCarence = new Periode(debutPochaineCarence, finProchainePeriode);
      carence.setPeriodeApplicationCarence(periodeApplicationCarence);
    }
    return carence;
  }
  
  private static void alimenterResultatCepaDepuisAvant(ResultatExecutionCalculSpec resultat, ConstitutionDelais cepa, Demande demande)
    throws CoucheLogiqueException
  {
    for (ListIterator iter = resultat.getListeCarencesEffectives().listIterator(); iter.hasNext();)
    {
      CarenceSpec carenceCourante = (CarenceSpec)iter.next();
      if (!OutilCarence.estCarenceDeType(carenceCourante, "Différé"))
      {
        CarencePrefixeAFixer carence = (CarencePrefixeAFixer)carenceCourante;
        if ((carence instanceof CarenceIccp))
        {
          CarenceIccp carenceIccp = (CarenceIccp)carence;
          if (carenceIccp.getPeriodeApplicationCarence() != null)
          {
            cepa.setDebutCarenceICCP(carenceIccp.getPeriodeApplicationCarence().getDebut());
            cepa.setTermeCarenceICCP(carenceIccp.getPeriodeApplicationCarence().getFin());
            cepa.setNbJoursCarenceICCP(carenceIccp.getPeriodeApplicationCarence().getDuree());
          }
          if (cepa.getDebutPmcIndemnisable() == null)
          {
            PreavisMesureConservatoireIndemnisable pmci = carenceIccp.getEnsembleCarences().getPmcIndemnisable();
            if (pmci != null)
            {
              cepa.setDebutPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDebut());
              cepa.setTermePmcIndemnisable(pmci.getPeriodeApplicationPMC().getFin());
              cepa.setNbJoursPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDuree());
            }
          }
        }
        else if ((carence instanceof CarenceIslr))
        {
          CarenceIslr carenceIslr = (CarenceIslr)carence;
          if (carenceIslr.getPeriodeApplicationCarence() != null)
          {
            cepa.setDebutCarenceISLR(carenceIslr.getPeriodeApplicationCarence().getDebut());
            cepa.setTermeCarenceISLR(carenceIslr.getPeriodeApplicationCarence().getFin());
            cepa.setNbJoursCarenceISLR(carenceIslr.getPeriodeApplicationCarence().getDuree());
            if (carenceIslr.getEnsembleCarences().isPresenceTransaction()) {
              leverAlerteA11MNB4SurCarenceIslr(demande, (ActiviteSalarie)carenceIslr.getOrigine());
            }
          }
          if (cepa.getDebutPmcIndemnisable() == null)
          {
            PreavisMesureConservatoireIndemnisable pmci = carenceIslr.getEnsembleCarences().getPmcIndemnisable();
            if (pmci != null)
            {
              cepa.setDebutPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDebut());
              cepa.setTermePmcIndemnisable(pmci.getPeriodeApplicationPMC().getFin());
              cepa.setNbJoursPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDuree());
            }
          }
        }
        else if ((carence instanceof PreavisMesureConservatoireNonIndemnisable))
        {
          PreavisMesureConservatoireNonIndemnisable carencePmc = (PreavisMesureConservatoireNonIndemnisable)carence;
          if (carencePmc.getPeriodeApplicationCarence() != null)
          {
            cepa.setDebutCarencePMC(carencePmc.getPeriodeApplicationCarence().getDebut());
            cepa.setTermeCarencePMC(carencePmc.getPeriodeApplicationCarence().getFin());
            cepa.setNbJoursCarencePMC(carencePmc.getPeriodeApplicationCarence().getDuree());
          }
        }
      }
    }
    Differe differe = (Differe)OutilCarence.trouverCarence(resultat.getListeCarencesEffectives(), "Différé");
    if (differe != null)
    {
      cepa.setDebutCarenceDiffere(differe.getPeriodeEffet().getDebut());
      cepa.setTermeCarenceDiffere(differe.getPeriodeEffet().getFin());
      cepa.setNbJoursCarenceDiffere(differe.getQuantiteInitialJour());
    }
  }
  
  private static void leverAlerteA11MNB4SurCarenceIslr(Demande demande, ActiviteSalarie periodeActiviteSalarieCourante)
  {
    Collection listeActivitesSalariees = null;
    
    String codeAlerteNonBloquante = "A11MNB4";
    if (demande.getAlertesNonBloquantes().containsKey(codeAlerteNonBloquante))
    {
      listeActivitesSalariees = (Collection)demande.getAlertesNonBloquantes().get(codeAlerteNonBloquante);
      
      ObjetAlertesNonBloquantes objetAlertesNonBloquantes = new ObjetAlertesNonBloquantes(periodeActiviteSalarieCourante);
      if (!listeActivitesSalariees.contains(objetAlertesNonBloquantes)) {
        listeActivitesSalariees.add(objetAlertesNonBloquantes);
      }
    }
    else
    {
      listeActivitesSalariees = new ArrayList();
      
      listeActivitesSalariees.add(new ObjetAlertesNonBloquantes(periodeActiviteSalarieCourante));
      demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listeActivitesSalariees);
    }
  }
}

/* Location:
 * Qualified Name:     ConstitutionDelaiReportPourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */