package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DeterminationSjcip;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesEntreeConstructionChronologie;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class ConstitutionSjcPourRevision
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Sjc impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution courante est null: constitution du Sjc impossible.");
    }
    if (dossierExamenCourant.getAttributionPrecedente() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "L'attribution précédente est nulle : constitution du Sjc impossible.");
    }
    if (dossierExamenCourant.getReglementApplicable() == null) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_RA", "Le règlement applicable de l'ouverture de droits courante est null: constitution du Sjc impossible.");
    }
    if (dossierExamenCourant.getConstitutionSjr().getSjrip() == null) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_SJRIP", "Le SJRIP de l'ouverture de droits courante est null: constitution du Sjc impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours(Niveau.DEBUG);
    
    Resultat resultat = new Resultat();
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    ProduitSpec produit = ((DossierAffectation)demandeCourante.getDossierAffectation()).getProduit();
    
    Reglement reglementApplicableCourant = dossierExamenCourant.getReglementApplicable().getReglement();
    if (reglementApplicableCourant.equals(produit.getReglement("A4")))
    {
      resultat.setEtat(1);
    }
    else
    {
      ConstitutionSjc constitutionSjc = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionSjc();
      
      DonneesEntreeConstructionChronologie donneesEntree = fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.mapperDemandeDonneesEntreeConstructionChronologie(demandeCourante);
      Chronologie chronoGlobaleActivitesConservees = fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionChronologie.determinerChronoActivitesConservees(donneesEntree);
      
      Sjrip sjripOdCourante = dossierExamenCourant.getConstitutionSjr().getSjrip();
      Periode prc = DeterminationSjcip.determinerPeriodePrcSjcCourante(demandeCourante, sjripOdCourante);
      QuantiteEuro plafond = DeterminationSjcip.getPlafondSJCip(demandeCourante, sjripOdCourante);
      
      Sjcip sjcipCourant = ((DossierExamen)demandeCourante.getDossierExamen()).getConstitutionSjc().createSjcip(prc.getFin(), plafond, new QuantiteEuro(new BigDecimal(0)));
      
      Quantite sjcForce = demandeCourante.getDonneesTemporaires().getSjcPerteActConservee();
      if (sjcForce != null)
      {
        Damj termePrc = ((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionSjc().getSjcip().getDateEffet();
        
        plafond = ((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionSjc().getSjcip().getPlafond();
        
        sjcipCourant.setSjcInitial(new QuantiteEuro(sjcForce.getValeur()));
        sjcipCourant.setPlafond(plafond);
        sjcipCourant.setDateEvenement(termePrc);
        
        DeterminationSjcip.initialiserSjcipAvecActivitesConserveesNonRetenues(sjcipCourant, chronoGlobaleActivitesConservees);
      }
      else
      {
        Chronologie chronoRetenue = DeterminationSjcip.determinerChronoASConserveesRetenuesPourSjcip(chronoGlobaleActivitesConservees, prc.getFin());
        
        DeterminationSjcip.determinerSjcip(demandeCourante, chronoRetenue, prc, sjcipCourant);
        
        completerSjcipAvecActivitesConserveesNonRetenues(sjcipCourant, chronoGlobaleActivitesConservees);
      }
      DeterminationSjcip.mettreAJourTypeActivitesConservees(sjcipCourant);
      
      constitutionSjc.setSjcrp(DeterminationSjcip.revaloriserSjcip(dossierExamenCourant.getDateAttribution(), sjcipCourant));
      
      resultat.setEtat(0);
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\t\t******** Résultat Parcours ConstitutionSjcPourRevision ********\n", resultat });
    
    OutilTrace.tracerFinParcours(Niveau.DEBUG);
    
    return resultat;
  }
  
  private void completerSjcipAvecActivitesConserveesNonRetenues(Sjcip p_sjcipCourant, Chronologie p_chronoGlobaleActivitesConservees)
  {
    p_chronoGlobaleActivitesConservees.iterer();
    TravailSpec activiteConserveeCourante = null;
    SjrActiviteConservee sjrActiviteConserveNonRetenue = null;
    while (p_chronoGlobaleActivitesConservees.encoreSuivant())
    {
      activiteConserveeCourante = (TravailSpec)p_chronoGlobaleActivitesConservees.elementSuivant();
      if (!activiteConserveeDejaRetenueSjcip(activiteConserveeCourante, p_sjcipCourant))
      {
        sjrActiviteConserveNonRetenue = new SjrActiviteConservee(new QuantiteEuro("0"));
        sjrActiviteConserveNonRetenue.setPeriodeActiviteConservee(activiteConserveeCourante);
        p_sjcipCourant.ajouterSjrActiviteConservee(sjrActiviteConserveNonRetenue);
      }
    }
  }
  
  private boolean activiteConserveeDejaRetenueSjcip(TravailSpec p_activiteConserveeCourante, Sjcip p_sjcipCourant)
  {
    boolean activiteConserveeDejaTraitee = false;
    
    SjrActiviteConservee sjrActiviteConserveCourant = null;
    Iterator iterateur = p_sjcipCourant.getCollectionSjrActiviteConservee().iterator();
    while ((iterateur.hasNext()) && (!activiteConserveeDejaTraitee))
    {
      sjrActiviteConserveCourant = (SjrActiviteConservee)iterateur.next();
      if (sjrActiviteConserveCourant.getIdentifiantPeriodeActiviteConservee().equalsIgnoreCase(p_activiteConserveeCourante.getIdentifiant())) {
        activiteConserveeDejaTraitee = true;
      }
    }
    return activiteConserveeDejaTraitee;
  }
}

/* Location:
 * Qualified Name:     ConstitutionSjcPourRevision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */