package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatRechercheConditionChomageInvolontaire;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.strategies.spec.StrategieConditionChomageInvolontaireAre14Spec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieConditionChomageInvolontaire;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConditionChomageInvolontaire;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConditionsAttributionSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;

public class DeterminationConditionChomageInvolontaire
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance est null pour une détermination condition chômage involontaire.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    if (Log.isTraceActive(DeterminationConditionChomageInvolontaire.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageInvolontaire.class, "demarrer", "\t\t******** Début Parcours DeterminationConditionChomageInvolontaire ********\n");
    }
    Resultat resultatCapa09 = new Resultat(1);
    
    Demande demandeAssurance = DomLiquidationAssurance.getDemande(p_contexte);
    
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(demandeAssurance.getDateExamen());
    critereStrategie.setDemande(demandeAssurance);
    StrategieConditionChomageInvolontaireAre14Spec strategieConditionChomageInvolontaire = (StrategieConditionChomageInvolontaireAre14Spec)FabriqueStrategieConditionChomageInvolontaire.getInstance().getStrategie(critereStrategie);
    
    ResultatRechercheConditionChomageInvolontaire resultat = strategieConditionChomageInvolontaire.rechercheConditionChomageInvolontairePourOd(demandeAssurance);
    ConditionChomageInvolontaire conditionChomageInvolontaire = ((DossierExamen)demandeAssurance.getDossierExamen()).getConditionsAttributionActives().createConditionChomageInvolontaire();
    alimenterCap(resultat, conditionChomageInvolontaire);
    if (conditionChomageInvolontaire.estSatisfait())
    {
      resultatCapa09.setEtat(0);
    }
    else
    {
      resultatCapa09.setEtat(1);
      resultatCapa09.setMessageErreur(Integer.toString(conditionChomageInvolontaire.getCodeMotifEchec()));
    }
    if (Log.isTraceActive(DeterminationConditionChomageInvolontaire.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageInvolontaire.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageInvolontaire.class, "demarrer", "\t\t******** Résultat Parcours DeterminationConditionChomageInvolontaire ********\n" + resultatCapa09);
      
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageInvolontaire.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageInvolontaire.class, "demarrer", "\t\t******** Fin Parcours DeterminationConditionChomageInvolontaire ********\n");
    }
    return resultatCapa09;
  }
  
  private static void alimenterCap(ResultatRechercheConditionChomageInvolontaire resultat, ConditionChomageInvolontaire conditionChomageInvolontaire)
  {
    conditionChomageInvolontaire.setCodeMotifEchec(resultat.getResultatElementDroit().getCodeMotifEchec());
    conditionChomageInvolontaire.setEtatSatisfait(resultat.getResultatElementDroit().estSatisfait());
    conditionChomageInvolontaire.setSituationConditionChomageInvolontaire(resultat.getSituationConditionChomageInvolontaire());
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionChomageInvolontaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */