package fr.unedic.cali.asu.cge01.p05.parametres;

import fr.unedic.cali.asu.cge01.parametres.ParametrageListePRASpec;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesPRA;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class ParametrageListePRARechargement
  implements ParametrageListePRASpec
{
  public static final int PRA_72_MOIS = 72;
  public static final int PRA_48_MOIS = 48;
  public static final int PRA_36_MOIS = 36;
  public static final int PRA_28_MOIS = 28;
  public static final int PRA_26_MOIS = 26;
  public static final int PRA_24_MOIS = 24;
  public static final int PRA_22_MOIS = 22;
  public static final int PRA_20_MOIS = 20;
  public static final int INF_50ANS = 1;
  public static final int SUP_EGAL_50ANS = 2;
  public static final int SUP_EGAL_57ANS = 3;
  public static final int AGE_50_ANS = 50;
  public static final int AGE_57_ANS = 57;
  public static final int DUREE_DROIT_1277 = 1277;
  public static final int CENT_TRIMESTRES_ACQUIS = 1;
  private Collection<Pra> m_listePRA;
  private static ParametrageListePRARechargement s_instance;
  private static final int UN = 1;
  private static final int DEUX = 2;
  private static final int TROIS = 3;
  private static final int QUATRE = 4;
  public static final int DONNEE_SANS_OBJET = -1;
  
  public static ParametrageListePRARechargement getInstance()
  {
    if (s_instance == null) {
      s_instance = new ParametrageListePRARechargement();
    }
    return s_instance;
  }
  
  public ParametrageListePRARechargement()
  {
    initInstance();
  }
  
  private void initInstance()
  {
    m_listePRA = new ArrayList();
    
    initInstanceRG();
    
    initInstanceRGParticulier();
    
    initInstanceA1();
    
    initInstanceA2A();
    
    initInstanceA2B();
    
    initInstanceA3();
    
    initInstanceA4();
    
    initInstanceA5();
    
    initInstanceA9A();
  }
  
  public List<Pra> getListePra(CleAccesPRA p_cle)
    throws CoucheLogiqueException
  {
    List<Pra> resultatListePRA = new ArrayList();
    if ("OP".equals(p_cle.getNomReglement())) {
      throw new CoucheLogiqueException("Le règlement RG_OP n'est pas géré pour le produit ARE09");
    }
    Iterator<Pra> it = m_listePRA.iterator();
    while (it.hasNext())
    {
      Pra pra = (Pra)it.next();
      if (pra.estApplicable(p_cle)) {
        resultatListePRA.add((Pra)pra.copie());
      }
    }
    return resultatListePRA;
  }
  
  private void initInstanceRG()
  {
    Pra pra = new Pra("RG", new int[] { 2, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RG", new int[] { 1 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceRGParticulier()
  {
    Pra pra = new Pra("RGP", new int[] { 2, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RGP", new int[] { 1 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA1()
  {
    Pra pra = new Pra("A1", new int[] { 2, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 30, "jour d'affiliation");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A1", new int[] { 1 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 30, "jour d'affiliation");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA2A()
  {
    Pra pra = new Pra("A2a", new int[] { 2, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2a", new int[] { 1 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA2B()
  {
    Pra pra = new Pra("A2b", new int[] { 2, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 30, "embarquement administratif");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2b", new int[] { 1 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 30, "embarquement administratif");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA3()
  {
    Pra pra = new Pra("A3", new int[] { 2, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 43, "vacation");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A3", new int[] { 1 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 43, "vacation");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA4()
  {
    Pra pra = new Pra("A4", new int[] { 2, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A4", new int[] { 1 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA5()
  {
    Pra pra = new Pra("A5", new int[] { 2, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A5", new int[] { 1 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA9A()
  {
    Pra pra = new Pra("A9A", new int[] { 2, 3 }, 36, 4, 1);
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A9A", 28, 2, 3);
    positionnerQuantiteAffiliationRequise(pra, 150, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void ajouterPRASurCollection(Pra p_pra)
  {
    m_listePRA.add(p_pra);
  }
  
  private void positionnerQuantiteAffiliationRequise(Pra p_pra, int p_quantite, String p_uniteAffiliation)
  {
    Unite unite = Unite.get(p_uniteAffiliation);
    Quantite quantite = new Quantite(p_quantite, unite);
    p_pra.getListeQuantitesAffiliationRequises().put(unite, quantite);
  }
}

/* Location:
 * Qualified Name:     ParametrageListePRARechargement
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */