package fr.unedic.cali.asu.cge01.p07.calcul;

import fr.unedic.cali.asu.calcul.dom.DureeProlongation;
import fr.unedic.cali.asu.cge01.calcul.FacadeCalculLigneImpl;
import fr.unedic.cali.asu.cge01.p6b.calcul.outilsfonctionnels.Qualification;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.EtatAuDji;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.periode.ActionFormation;
import fr.unedic.cali.calcul.dom.periode.DebutActionFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodeFormation;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.GestionSuivi;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ContexteUT;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyse;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DureeProlongationAbstraite;
import fr.unedic.cali.dom.QuantiteDroit;
import fr.unedic.cali.dom.QuantiteDroitSpec;
import fr.unedic.cali.dom.QuantiteIndemnisationSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class FacadeCalculProduitImpl
  extends FacadeCalculLigneImpl
{
  public QualificationPeriodes qualificationPeriodes(ChronologiePeriodes p_chronologiePeriodes, AttributionSpec p_attribution, ContexteUT p_contexteUT)
    throws CoucheLogiqueException
  {
    return new Qualification().qualificationPeriodes(p_chronologiePeriodes, p_attribution);
  }
  
  public Quantite determinerQteContexteFormation(AttributionSpec attribution, Quantite quantiteAImputer, String contexteIndemnisation, QuantiteDroitSpec quantiteDroitAImputer, List<QuantiteDroitSpec> listeQuantiteDroit)
    throws CoucheLogiqueException
  {
    Quantite qteAImputer = quantiteAImputer;
    if (estUnContexteAllongementAREF(attribution))
    {
      if ((quantiteDroitAImputer instanceof DureeProlongationAbstraite)) {
        ((DureeProlongationAbstraite)quantiteDroitAImputer).setContexteAllongementAref(true);
      }
      if ((contexteIndemnisation.compareTo("1") == 0) && ((quantiteDroitAImputer instanceof DureeProlongationAbstraite))) {
        qteAImputer = new QuantiteJour(BigDecimal.ZERO);
      } else if ((contexteIndemnisation.compareTo("2") == 0) && 
        ((quantiteDroitAImputer instanceof QuantiteIndemnisationSpec)) && (recupererQteDureeProlongationCourante(listeQuantiteDroit) != null) && (recupererQteDureeProlongationCourante(listeQuantiteDroit).compareTo(BigDecimal.ZERO) > 0)) {
        qteAImputer = new QuantiteJour(BigDecimal.ZERO);
      }
    }
    return qteAImputer;
  }
  
  private BigDecimal recupererQteDureeProlongationCourante(List<QuantiteDroitSpec> listeQuantiteDroit)
  {
    BigDecimal qteProlongation = null;
    Iterator<QuantiteDroitSpec> ite = listeQuantiteDroit.iterator();
    while (ite.hasNext())
    {
      QuantiteDroitSpec duree = (QuantiteDroitSpec)ite.next();
      if ((duree instanceof DureeProlongationAbstraite)) {
        qteProlongation = duree.getQuantiteCourante().getValeur();
      }
    }
    return qteProlongation;
  }
  
  public EtatAuDji renseignerEtatAuDji(UniteTraitement derniereUT, CalendrierExecutionCalculPeriodique calendrier, AttributionSpec attribution, EtatAuDji etatAuDji)
    throws CoucheLogiqueException
  {
    EtatAuDji etatAuDjiM = super.renseignerEtatAuDji(derniereUT, calendrier, attribution, etatAuDji);
    if (estUnContexteAllongementAREF(attribution))
    {
      QuantiteDroitSpec reliquat = derniereUT.getConstituantsIndemnisationEnFinUT().getDureeProlongation();
      if (reliquat != null) {
        etatAuDjiM.setReliquatDureeProlongation(((QuantiteDroit)reliquat).getQuantiteCourante());
      } else {
        etatAuDjiM.setReliquatDureeProlongation(new Quantite("0", DureeProlongation.UNITE_DEFAUT));
      }
    }
    return etatAuDjiM;
  }
  
  private boolean estUnContexteAllongementAREF(AttributionSpec attribution)
  {
    boolean estElligibleAllongementAREF = false;
    TrancheExecutable tranche = OutilsTrancheCalcul.recupererTrancheInitiale(attribution);
    if (tranche.isEligibleAllongementAREF()) {
      estElligibleAllongementAREF = true;
    }
    return estElligibleAllongementAREF;
  }
  
  public void miseAjourCumulAllongementAREF(UniteTraitement ut, ConstituantsIndemnisation constituantsIndemnisation, AttributionSpec attribution)
  {
    ChronologiePeriodes periodeSegmentantes = ut.getQualificationPeriodes().getPeriodesSegmentantes();
    Iterator<ObjetChronoPeriodeCalcul> ite = periodeSegmentantes.iterer();
    ArrayList<Damj> chronoDateDebutAF = new ArrayList();
    int cumulAREF = ut.getConstituantsIndemnisationEnDebutUT().getCumulTotalAllongementAREF();
    while (ite.hasNext())
    {
      ObjetChronoPeriodeCalcul periode = (ObjetChronoPeriodeCalcul)ite.next();
      if ((periode instanceof DebutActionFormation)) {
        chronoDateDebutAF.add(periode.getDateDebut());
      }
      if (((periode instanceof PeriodeFormation)) && 
        (periode.getDateFin().coincideAvec(((PeriodeFormation)periode).getActionFormation().getDateFin())))
      {
        int rangEnquete = ((PeriodeFormation)periode).getActionFormation().getIdentifiantActionFormation();
        GestionSuivi.enregistrerEnquetePbjcNcp(attribution, periode.getDateFin(), 44, rangEnquete, true, null, this, null);
      }
    }
    Iterator<ObjetChronoPeriodeCalcul> iteratorPa = ut.getListePeriodesAnalyse().iterer();
    while (iteratorPa.hasNext())
    {
      PeriodeAnalyse pa = (PeriodeAnalyse)iteratorPa.next();
      if ((!chronoDateDebutAF.isEmpty()) && (chronoDateDebutAF.contains(pa.getDateDebut()))) {
        cumulAREF = 0;
      }
      cumulAREF += pa.getNbJoursAllongementAREF();
    }
    ut.getConstituantsIndemnisationEnFinUT().setCumulTotalAllongementAREF(cumulAREF);
  }
  
  public QuantiteDroitSpec determinerDureeProlongationprioritaire(AttributionSpec attribution, List<QuantiteDroitSpec> listeQuantiteDroitActives, Quantite quantiteAImputer)
  {
    QuantiteDroitSpec quantiteDroitAImputer = null;
    DureeProlongationAbstraite dureeProlongationAbstraite = recupererDureeProlongationCourante(listeQuantiteDroitActives);
    if ((dureeProlongationAbstraite != null) && (estUnContexteAllongementAREF(attribution)) && (dureeProlongationAbstraite.getQuantiteCourante().getValeurEntiere() > 0))
    {
      Iterator<QuantiteDroitSpec> ite = listeQuantiteDroitActives.iterator();
      while (ite.hasNext())
      {
        QuantiteDroitSpec duree = (QuantiteDroitSpec)ite.next();
        if (((duree instanceof QuantiteIndemnisationSpec)) && (((QuantiteIndemnisationSpec)duree).getCodeFormuleMontant().equals("2"))) {
          quantiteDroitAImputer = dureeProlongationAbstraite;
        }
      }
    }
    return quantiteDroitAImputer;
  }
  
  private static DureeProlongationAbstraite recupererDureeProlongationCourante(List<QuantiteDroitSpec> listeQuantiteDroit)
  {
    QuantiteDroitSpec qte = null;
    Iterator<QuantiteDroitSpec> ite = listeQuantiteDroit.iterator();
    while (ite.hasNext())
    {
      QuantiteDroitSpec duree = (QuantiteDroitSpec)ite.next();
      if ((duree instanceof DureeProlongationAbstraite)) {
        qte = duree;
      }
    }
    return (DureeProlongationAbstraite)qte;
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */