package fr.unedic.cali.asu.cge01.p07.liquidation.dom;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.ObjectMapper;
import fr.pe.cali.reglementaire.regles.assurance.affiliation.dom.PeriodeAssimilee;
import fr.pe.cali.reglementaire.regles.assurance.affiliation.dom.SemaineCivile;
import fr.unedic.cali.asu.dom.AffiliationSupplementaire;
import fr.unedic.cali.asu.dom.PeriodeElementaire;
import fr.unedic.cali.asu.dom.PlafonnementAffiliation;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.io.StringWriter;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@JsonIgnoreProperties({"uniteJustification", "chronoZmes", "typeJustificationAffiliation", "periodeRechercheAffiliation", "quantiteAffiliation", "quantiteAssimilation", "justificationRepartitionJoursTravailles", "isPresencePNDS", "estAffiliationPlafonne", "listePlafonnementAffiliation", "listePeriodeElementaires", "listeAffiliationSupplementaire"})
public class JustificationAffiliationJoursTravailles
  implements fr.unedic.cali.dom.spec.JustificationAffiliationSpec, fr.unedic.cali.asu.dom.JustificationAffiliationSpec
{
  private static final long serialVersionUID = 1L;
  private int nombreJoursAppartenance = 0;
  private int nombreJoursAffiliation = 0;
  private int nombreJoursAssimilation = 0;
  private transient List<SemaineCivile> justificationSemaineCivile;
  private Map<String, List<Damj>> justificationRepartitionJoursTravailles;
  private Periode periodeRechercheAffiliation = null;
  private int plafondAssimilation = 0;
  private List<PeriodeAssimilee> periodesAssimilees;
  private List<PlafonnementAffiliation> listePlafonnementAffiliation;
  private List<PeriodeElementaire> listePeriodeElementaires;
  private List<AffiliationSupplementaire> listeAffiliationSupplementaire;
  private boolean estAffiliationPlafonne;
  
  public ObjetMetierSpec copie()
  {
    JustificationAffiliationJoursTravailles justif = new JustificationAffiliationJoursTravailles();
    copieElements(justif);
    return justif;
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    JustificationAffiliationJoursTravailles justifCopie = (JustificationAffiliationJoursTravailles)copie;
    justifCopie.setNombreJoursAffiliation(getNombreJoursAffiliation());
    justifCopie.setNombreJoursAppartenance(getNombreJoursAppartenance());
    justifCopie.setNombreJoursAssimilation(getNombreJoursAssimilation());
    justifCopie.setPeriodeRechercheAffiliation((Periode)getPeriodeRechercheAffiliation().copie());
    justifCopie.setJustificationRepartitionJoursTravailles(new HashMap());
    for (String cleCourante : justificationRepartitionJoursTravailles.keySet())
    {
      List<Damj> listeCourante = new ArrayList();
      listeCourante.addAll((Collection)justificationRepartitionJoursTravailles.get(cleCourante));
      justifCopie.getJustificationRepartitionJoursTravailles().put(cleCourante, listeCourante);
    }
    justifCopie.setJustificationSemaineCivile(new ArrayList());
    for (SemaineCivile semaine : justificationSemaineCivile) {
      justifCopie.getJustificationSemaineCivile().add(semaine.copie());
    }
    justifCopie.setListePeriodeElementaires(new ArrayList());
    for (PeriodeElementaire periode : listePeriodeElementaires) {
      justifCopie.getListePeriodeElementaires().add((PeriodeElementaire)periode.copie());
    }
    justifCopie.setListeAffiliationSupplementaire(new ArrayList());
    for (AffiliationSupplementaire affiliation : listeAffiliationSupplementaire) {
      justifCopie.getListeAffiliationSupplementaire().add((AffiliationSupplementaire)affiliation.copie());
    }
  }
  
  public UniteAffiliation getUniteJustification()
  {
    return UniteAffiliation.JOUR_TRAVAILLE;
  }
  
  public Chronologie getChronoZmes()
  {
    return null;
  }
  
  public String getTypeJustificationAffiliation()
  {
    return "justifJoursTravailles";
  }
  
  public Periode getPeriodeRechercheAffiliation()
  {
    return periodeRechercheAffiliation;
  }
  
  public Quantite getQuantiteAffiliation()
  {
    return new Quantite(BigDecimal.valueOf(nombreJoursAffiliation), Unite.get("jour travaillés"));
  }
  
  public Quantite getQuantiteAssimilation()
  {
    return new Quantite(BigDecimal.valueOf(nombreJoursAssimilation), Unite.get("jour travaillés"));
  }
  
  public int getNombreJoursAppartenance()
  {
    return nombreJoursAppartenance;
  }
  
  public void setNombreJoursAppartenance(int nombreJoursAppartenance)
  {
    this.nombreJoursAppartenance = nombreJoursAppartenance;
  }
  
  public int getNombreJoursAffiliation()
  {
    return nombreJoursAffiliation;
  }
  
  public void setNombreJoursAffiliation(int nombreJoursAffiliation)
  {
    this.nombreJoursAffiliation = nombreJoursAffiliation;
  }
  
  public int getNombreJoursAssimilation()
  {
    return nombreJoursAssimilation;
  }
  
  public void setNombreJoursAssimilation(int nombreJoursAssimilation)
  {
    this.nombreJoursAssimilation = nombreJoursAssimilation;
  }
  
  @JsonProperty("semaine")
  public List<SemaineCivile> getJustificationSemaineCivile()
  {
    return justificationSemaineCivile;
  }
  
  public void setJustificationSemaineCivile(List<SemaineCivile> justificationSemaineCivile)
  {
    this.justificationSemaineCivile = justificationSemaineCivile;
  }
  
  public Map<String, List<Damj>> getJustificationRepartitionJoursTravailles()
  {
    return justificationRepartitionJoursTravailles;
  }
  
  public void setJustificationRepartitionJoursTravailles(Map<String, List<Damj>> justificationRepartitionJoursTravailles)
  {
    this.justificationRepartitionJoursTravailles = justificationRepartitionJoursTravailles;
  }
  
  public void setPeriodeRechercheAffiliation(Periode periodeRechercheAffiliation)
  {
    this.periodeRechercheAffiliation = periodeRechercheAffiliation;
  }
  
  public boolean isPresencePNDS()
  {
    boolean presencePNDS = false;
    for (SemaineCivile semaineCourante : justificationSemaineCivile) {
      if (semaineCourante.isEstSanctionne())
      {
        presencePNDS = true;
        break;
      }
    }
    return presencePNDS;
  }
  
  public String genererJson()
  {
    String json = null;
    try
    {
      ObjectMapper mapper = new ObjectMapper();
      StringWriter writer = new StringWriter();
      mapper.writeValue(writer, this);
      json = writer.toString();
    }
    catch (Exception ex)
    {
      json = "";
    }
    return json;
  }
  
  public int getPlafondAssimilation()
  {
    return plafondAssimilation;
  }
  
  public void setPlafondAssimilation(int plafondAssimilation)
  {
    this.plafondAssimilation = plafondAssimilation;
  }
  
  @JsonProperty("assimilations")
  public List<PeriodeAssimilee> getPeriodesAssimilees()
  {
    return periodesAssimilees;
  }
  
  public void setPeriodesAssimilees(List<PeriodeAssimilee> periodesAssimilees)
  {
    this.periodesAssimilees = periodesAssimilees;
  }
  
  public List<PlafonnementAffiliation> getListePlafonnementAffiliation()
  {
    return listePlafonnementAffiliation;
  }
  
  public void setListePlafonnementAffiliation(List<PlafonnementAffiliation> listePlafonnementAffiliation)
  {
    this.listePlafonnementAffiliation = listePlafonnementAffiliation;
  }
  
  public boolean isEstAffiliationPlafonne()
  {
    return estAffiliationPlafonne;
  }
  
  public void setEstAffiliationPlafonne(boolean estAffiliationPlafonne)
  {
    this.estAffiliationPlafonne = estAffiliationPlafonne;
  }
  
  public List<PeriodeElementaire> getListePeriodeElementaires()
  {
    return listePeriodeElementaires;
  }
  
  public void setListePeriodeElementaires(List<PeriodeElementaire> listePeriodeElementaires)
  {
    this.listePeriodeElementaires = listePeriodeElementaires;
  }
  
  public List<AffiliationSupplementaire> getListeAffiliationSupplementaire()
  {
    return listeAffiliationSupplementaire;
  }
  
  public void setListeAffiliationSupplementaire(List<AffiliationSupplementaire> listeAffiliationSupplementaire)
  {
    this.listeAffiliationSupplementaire = listeAffiliationSupplementaire;
  }
}

/* Location:
 * Qualified Name:     JustificationAffiliationJoursTravailles
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */