package fr.unedic.cali.asu.cge01.revision.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsRevisions;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientTempsPartiel;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Mathematiques;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class DeterminationCoefficientTempsPartiel
{
  private static final BigDecimal COEFFICIENT_TP_1 = BigDecimal.ONE;
  private static final int NB_DECIMAL = 4;
  
  public static BigDecimal determinerCoefficientTempsPartiel(Demande demandeRevision)
  {
    BigDecimal coefficientTpRetour = BigDecimal.ZERO;
    
    AttributionAssuranceSpec attributionRevision = (AttributionAssuranceSpec)demandeRevision.getDossierExamen();
    AttributionAssuranceSpec odRevisee = (AttributionAssuranceSpec)attributionRevision.getOuvertureDroit();
    
    Reglement reglementOdRevisee = odRevisee.getReglementApplicable().getReglement();
    boolean estReglementOdReviseEntrainantCoeff1 = estReglementOdPourCoefTP1(reglementOdRevisee.getNomReglement());
    if (estReglementOdReviseEntrainantCoeff1) {
      return COEFFICIENT_TP_1;
    }
    DossierExamen dossierExamen = (DossierExamen)odRevisee;
    coefficientTpRetour = coefficientTpRetour.add(dossierExamen.getConstitutionCoefficientTempsPartiel().getCoefficientTempsPartielRetenu());
    
    List<DemandeAssuranceSpec> listeDemandeAssocieesAdmission = OutilsRevisions.getListeDemandesAssocieesAdmission(demandeRevision);
    
    Iterator<DemandeAssuranceSpec> iterateur = listeDemandeAssocieesAdmission.iterator();
    while (iterateur.hasNext())
    {
      DemandeAssuranceSpec demandeAssurance = (DemandeAssuranceSpec)iterateur.next();
      
      DossierExamenAssuranceSpec dossierExamenSousJacente = (DossierExamenAssuranceSpec)demandeAssurance.getDossierExamen();
      Reglement reglementAttributionSousJacente = dossierExamenSousJacente.getReglementApplicable().getReglement();
      boolean estReglementDemandeSoujacenteEntrainantCoef1 = estReglementDemandeSousJacentePourCoefTP1(reglementAttributionSousJacente.getNomReglement());
      if (estReglementDemandeSoujacenteEntrainantCoef1) {
        return COEFFICIENT_TP_1;
      }
      coefficientTpRetour = coefficientTpRetour.add(((DossierExamen)dossierExamenSousJacente).getConstitutionCoefficientTempsPartiel().getCoefficientTempsPartielRetenu());
    }
    coefficientTpRetour = bornerFormaterCoefficientTp(coefficientTpRetour);
    
    return coefficientTpRetour;
  }
  
  private static boolean estReglementDemandeSousJacentePourCoefTP1(String reglement)
  {
    Collection<String> listeReglements = new ArrayList();
    
    listeReglements.add("A1");
    listeReglements.add("A2b");
    listeReglements.add("A3");
    listeReglements.add("A4");
    listeReglements.add("A5");
    listeReglements.add("A8");
    listeReglements.add("A9B");
    listeReglements.add("A10");
    
    return listeReglements.contains(reglement);
  }
  
  private static boolean estReglementOdPourCoefTP1(String reglement)
  {
    Collection<String> listeReglements = new ArrayList();
    
    listeReglements.add("A1");
    listeReglements.add("A2b");
    listeReglements.add("A3");
    listeReglements.add("A4");
    listeReglements.add("A5");
    
    return listeReglements.contains(reglement);
  }
  
  private static BigDecimal bornerFormaterCoefficientTp(BigDecimal pCoefficientTp)
  {
    BigDecimal coefficientTp = pCoefficientTp.min(COEFFICIENT_TP_1);
    return Mathematiques.tronque(coefficientTp, 4);
  }
}

/* Location:
 * Qualified Name:     DeterminationCoefficientTempsPartiel
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */