package fr.unedic.cali.asu.cge01.revision.outilsfonctionnels.sjr;

import fr.unedic.cali.asu.cge01.calcul.dom.FormuleMontantRegimeGeneral;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.crc.DonneesEntreesOutilPcrc;
import fr.unedic.cali.asu.outilsfonctionnels.crc.OutilConstructionDonneesEntreesPcrc;
import fr.unedic.cali.asu.outilsfonctionnels.crc.OutilPcrc;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodePensionInvaliditeChaineeSpec;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationAvantageVieillesseAvantPJI;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSecurisationProfessionnelleSpec;
import fr.unedic.cali.parametres.AccesFacteurPlancher;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;

public final class OutilConstructionDonneesEntreesReconstructionSjr
  implements OutilFonctionnel
{
  public static DonneesEntreesOutilReconstructionSjr construireDonneesEntreeesOutilReconstructionSjr(DemandeSpec pDemande)
    throws CoucheLogiqueException
  {
    DonneesEntreesOutilReconstructionSjr donneesEntreesOutilReconstructionSjr = new DonneesEntreesOutilReconstructionSjr();
    Demande demande = (Demande)pDemande;
    Attribution attributionRevision = (Attribution)demande.getAttribution();
    IndividuSpec individu = demande.getDemandeur();
    
    Damj dateCalcul = demande.getDateFaitGenerateurOuDernierSinistre().lendemain();
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "REVAUTO")) {
      dateCalcul = demande.getDateExamen();
    }
    donneesEntreesOutilReconstructionSjr.setDateCalcul(dateCalcul);
    
    ProduitAsuSpec produit = (ProduitAsuSpec)attributionRevision.getProduit();
    if ((produit instanceof ProduitSecurisationProfessionnelleSpec)) {
      produit = ((ProduitSecurisationProfessionnelleSpec)produit).recupererProduitAreActif(attributionRevision);
    }
    donneesEntreesOutilReconstructionSjr.setProduit(produit);
    
    BigDecimal montantAvantageVieillesse = determinerMontantAvantageVieillesse(attributionRevision.getDemandeur(), dateCalcul);
    donneesEntreesOutilReconstructionSjr.setMontantAvantageVieillesse(montantAvantageVieillesse);
    donneesEntreesOutilReconstructionSjr.setTauxAvantageVieillesse(determinerTauxAvantageVieillesse(individu, dateCalcul));
    
    ConstitutionMontantsBruts cepaMontant = attributionRevision.getConstitutionMontantsBruts();
    BigDecimal montant = cepaMontant.getMontantJournalierBrut().getValeur();
    donneesEntreesOutilReconstructionSjr.setMontant(montant);
    
    Collection<PeriodePensionInvaliditeChaineeSpec> listePi = cepaMontant.getListePensionInvalidite();
    donneesEntreesOutilReconstructionSjr.setMontantPi(OutilDeterminationMontantPi.determinerMontantPensionInvalidite(dateCalcul, listePi));
    
    donneesEntreesOutilReconstructionSjr.setCoefficientBase(FormuleMontantRegimeGeneral.FACTEUR_BASE);
    donneesEntreesOutilReconstructionSjr.setCoefficientPlafond(FormuleMontantRegimeGeneral.FACTEUR_PLAFOND);
    
    BigDecimal valeurPlancher = AccesFacteurPlancher.getInstance().getValeurPlancher(produit.getNomUnique());
    donneesEntreesOutilReconstructionSjr.setCoefficientPlancher(valeurPlancher);
    
    BigDecimal coefficientTempPartiel = attributionRevision.getCoefficientTempsPartiel();
    donneesEntreesOutilReconstructionSjr.setCoefficientSurParametre(determinerCoefficientSurParametre(coefficientTempPartiel));
    donneesEntreesOutilReconstructionSjr.setCoefficientTp(coefficientTempPartiel);
    
    EvenementParametre parametres = ParametresIndemnisation.getParametresIndemnisation().getElementActif(dateCalcul);
    donneesEntreesOutilReconstructionSjr.setPartieFixe(parametres.getPartieFixe());
    
    DonneesEntreesOutilPcrc donneesEntreesOutilPrc = OutilConstructionDonneesEntreesPcrc.contruireDonneesEntreesOutilPcrc(attributionRevision.getCompetence());
    
    donneesEntreesOutilReconstructionSjr.setEstMontantSoumisAPcrc(OutilPcrc.estSoumisACrc(donneesEntreesOutilPrc));
    
    donneesEntreesOutilReconstructionSjr.setParametreParticipationRetraiteComplementaire(parametres.getCotisationRetraiteComplementaire());
    
    BigDecimal miniAre = parametres.getAllocationMinimale();
    donneesEntreesOutilReconstructionSjr.setMiniAre(miniAre);
    
    return donneesEntreesOutilReconstructionSjr;
  }
  
  public static BigDecimal determinerCoefficientSurParametre(BigDecimal p_coefficientTp)
  {
    return p_coefficientTp;
  }
  
  public static BigDecimal determinerTauxAvantageVieillesse(IndividuSpec pIndividu, Damj pDateEffetParametre)
    throws CoucheLogiqueException
  {
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    
    BigDecimal retour = parametresIndemnisation.getTauxAvantageViellesse(pIndividu.getAgeALaDate(pDateEffetParametre));
    if (retour == null) {
      retour = BigDecimal.ZERO;
    }
    return retour;
  }
  
  public static BigDecimal determinerMontantAvantageVieillesse(IndividuSpec pIndividu, Damj pDateEffetParametre)
    throws CoucheLogiqueException
  {
    PeriodeAvantageVieillesse periodeAvantageVieillesse = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(pIndividu, pDateEffetParametre);
    
    BigDecimal montantAV = new BigDecimal(0);
    if (periodeAvantageVieillesse != null) {
      montantAV = periodeAvantageVieillesse.getQuantiteEuro().getValeur();
    }
    return montantAV;
  }
}

/* Location:
 * Qualified Name:     OutilConstructionDonneesEntreesReconstructionSjr
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */