package fr.unedic.cali.asu.cge01.revision.outilsfonctionnels.strategies;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.parcours.conteneurs.ConteneurParcoursRevisionAutomatique;
import fr.unedic.cali.asu.cge01.revision.outilsfonctionnels.strategies.spec.StrategieRevisionAutomatiqueSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.EreRevisionConvention2014;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.SjrActiviteConserveeSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsRevisions;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientTempsPartiel;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionElementsAdmission;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionElementsReprise;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.produits.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class StrategieRevisionAutomatiqueApresARE2014
  implements StrategieRevisionAutomatiqueSpec
{
  public void alimenterDonneesForceesDemandeAReviser(ConteneurParcoursRevisionAutomatique conteneur)
  {
    DonneesTemporaires donneesForceesDemandeAReviserTemporaire = conteneur.getDemandeRevision().getDonneesTemporaires();
    donneesForceesDemandeAReviserTemporaire.setIdentifiantPeriodeActiviteConserveePerdue(conteneur.getActiviteConserveeAReviser().getIdentifiant());
    donneesForceesDemandeAReviserTemporaire.setTypeContexteDemandeDonneesTemporaires("REVAUTO");
  }
  
  public Contexte creerContextePourRevision(ConteneurParcoursRevisionAutomatique conteneur)
  {
    Contexte contexteAReviser = new Contexte();
    DomLiquidationAssurance domLiquidationAssuranceAReviser = new DomLiquidationAssurance();
    domLiquidationAssuranceAReviser.setDemande(conteneur.getDemandeRevision());
    domLiquidationAssuranceAReviser.setIndividu(conteneur.getDemandeRevision().getDemandeur());
    conteneur.getDemandeRevision().setDemandeLiquidee(true);
    contexteAReviser.setDonnees(domLiquidationAssuranceAReviser);
    domLiquidationAssuranceAReviser.setContexteService(conteneur.getDemandeRevision().getDemandeur().getContexteService());
    return contexteAReviser;
  }
  
  public Demande creerDemandeAReviser(ConteneurParcoursRevisionAutomatique conteneur)
    throws CoucheLogiqueException
  {
    Demande revision = new Demande();
    revision.setEvenementReferenceExamen(new EreRevisionConvention2014());
    FormulaireAsu formulaireAsu = revision.createFormulaireAsu();
    formulaireAsu.setDateDepot(conteneur.getActiviteConserveeAReviser().getDateFin().lendemain());
    formulaireAsu.setMotifEnvoi("ASU_28");
    formulaireAsu.setReferenceExterne("REV_001");
    revision.setEstFormulaireCharge(true);
    revision.setDemandeur(conteneur.getDemandeCourante().getDemandeur());
    return revision;
  }
  
  public void mettreAJourDemandeRevision(ConteneurParcoursRevisionAutomatique conteneur)
    throws ApplicativeException
  {
    Demande revision = conteneur.getDemandeRevision();
    EreRevisionConvention2014 ere = (EreRevisionConvention2014)revision.getEvenementReferenceExamen();
    ere.setContexteDemande("REVAUTO");
    ere.setDateExamenForcee(conteneur.getDemandeCourante().getDateAttribution());
    Attribution attribution = conteneur.getAttributionAReviser();
    revision.setAttributionPrecedenteDuMemeType(attribution);
    
    conteneur.getAttributionAReviser().setElementBaseIndemnisation(null);
    if (attribution.getProduit() != null)
    {
      ProduitAsuSpec produit = (ProduitAsuSpec)attribution.getProduit();
      Contexte contexte = getContexteTranche(conteneur);
      produit.constituerTranchesExecutables(contexte);
    }
  }
  
  private Contexte getContexteTranche(ConteneurParcoursRevisionAutomatique conteneur)
  {
    Contexte contexte = new Contexte();
    Attribution attribution = conteneur.getAttributionAReviser();
    DomLiquidationAssurance dom = new DomLiquidationAssurance();
    dom.setDemande(attribution.getDemande());
    dom.setIndividu(attribution.getDemandeur());
    conteneur.getDemandeRevision().setDemandeLiquidee(true);
    contexte.setDonnees(dom);
    dom.setContexteService(conteneur.getDemandeRevision().getDemandeur().getContexteService());
    return contexte;
  }
  
  public void reviserActiviteConservee(ConteneurParcoursRevisionAutomatique conteneur)
    throws ApplicativeException
  {
    Parcours parcoursLiquidation = GammeAsu.getInstance().getParcoursLiquidation(conteneur.getDemandeRevision());
    parcoursLiquidation.demarrer(conteneur.getContexteRevision());
    
    conteneur.getAttributionAReviser().setListeTranchesExecutables(new ArrayList());
    mettreAjourDonnees(conteneur);
  }
  
  public boolean estFCTATraiter(ConteneurParcoursRevisionAutomatique conteneur)
  {
    return (conteneur.isNouvelleRevisionDroit()) && (!estFCTConcomittante(conteneur));
  }
  
  private boolean estFCTConcomittante(ConteneurParcoursRevisionAutomatique conteneur)
  {
    if (conteneur.getActiviteConserveeAReviserPrecedente() != null) {
      return conteneur.getActiviteConserveeAReviserPrecedente().getDateFin().coincideAvec(conteneur.getActiviteConserveeAReviser().getDateFin());
    }
    return false;
  }
  
  private void mettreAjourDonnees(ConteneurParcoursRevisionAutomatique conteneur)
    throws ApplicativeException
  {
    Demande revision = conteneur.getDemandeRevision();
    if (revision.getAttribution() != null)
    {
      mettreAjourDemande(conteneur.getDemandeCourante());
      
      mettreAjourCepa((Attribution)conteneur.getDemandeCourante().getAttribution(), (Attribution)revision.getAttribution());
      
      mettreAJourOdOrigine(conteneur);
      mettreAJourActivitesSurCepa(conteneur);
      
      mettreAjourConteneur(conteneur);
    }
    else
    {
      mettreAJourOdOrigine(conteneur);
    }
  }
  
  private void mettreAjourDemande(Demande demandeCourante)
    throws ApplicativeException
  {
    Attribution attributionCourante = (Attribution)demandeCourante.getDossierExamen();
    
    int sousTypeObjectif = demandeCourante.getObjectifCourant().getSousType();
    if ((sousTypeObjectif != 10) && (sousTypeObjectif != 15))
    {
      String rsod = attributionCourante.getReferenceExterne();
      
      Attribution readmission = (Attribution)attributionCourante.changerEtat(10);
      readmission.setNatureDecision(12);
      
      demandeCourante.getObjectifCourant().setSousType(12);
      readmission.setReferenceExterne(rsod);
    }
    if (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "REVAUTO"))
    {
      ContexteDemande contexteDemande = new ContexteDemande();
      contexteDemande.setTypeContexteDemande("REVAUTO");
      demandeCourante.ajouterContexteDemande(contexteDemande);
    }
  }
  
  private void mettreAjourCepa(Attribution attributionARevise, Attribution attributionRevision)
  {
    int sousTypeObjectif = ((Demande)attributionARevise.getDemande()).getObjectifCourant().getSousType();
    if (sousTypeObjectif == 15)
    {
      attributionRevision.getConstitutionElementsAdmission().getConstitutionDurees().copieElements(attributionARevise.getConstitutionElementsReprise().createConstitutionDurees());
      
      attributionRevision.getConstitutionElementsAdmission().getConstitutionSjr().copieElements(attributionARevise.getConstitutionElementsReprise().createConstitutionSjr());
      
      attributionARevise.getConstitutionElementsAdmission().getConstitutionSjr().setSjrRevise(Boolean.TRUE);
      attributionRevision.getConstitutionElementsAdmission().getConstitutionCoefficientTempsPartiel().copieElements(attributionARevise.getConstitutionElementsReprise().createConstitutionCoefficientTempsPartiel());
      
      attributionRevision.getConstitutionElementsAdmission().getConstitutionMontantsBruts().copieElements(attributionARevise.getConstitutionElementsReprise().createConstitutionMontantsBruts());
    }
    else
    {
      attributionRevision.getConstitutionElementsAdmission().getConstitutionDurees().copieElements(attributionARevise.getConstitutionElementsAdmission().createConstitutionDurees());
      
      attributionRevision.getConstitutionElementsAdmission().getConstitutionSjr().copieElements(attributionARevise.getConstitutionElementsAdmission().createConstitutionSjr());
      
      attributionARevise.getConstitutionElementsAdmission().getConstitutionSjr().setSjrRevise(Boolean.TRUE);
      attributionRevision.getConstitutionElementsAdmission().getConstitutionCoefficientTempsPartiel().copieElements(attributionARevise.getConstitutionElementsAdmission().createConstitutionCoefficientTempsPartiel());
      
      attributionRevision.getConstitutionElementsAdmission().getConstitutionMontantsBruts().copieElements(attributionARevise.getConstitutionElementsAdmission().createConstitutionMontantsBruts());
    }
  }
  
  private void mettreAjourConteneur(ConteneurParcoursRevisionAutomatique conteneur)
  {
    conteneur.setAttributionAReviser((Attribution)conteneur.getDemandeCourante().getAttribution());
    conteneur.setDemandeRevision(null);
  }
  
  private void mettreAJourOdOrigine(ConteneurParcoursRevisionAutomatique conteneur)
  {
    Attribution odOrigine = (Attribution)conteneur.getDemandeOrigine().getAttribution().getOuvertureDroit();
    Collection<SjrActiviteConservee> listeActiviteConserveePerdue = odOrigine.getCollectionSjrActiviteConserveePerdue();
    mettreAJourSjrActiviteConservee(listeActiviteConserveePerdue, conteneur.getDemandeRevision());
    
    Attribution attributionAReviser = (Attribution)conteneur.getDemandeCourante().getAttribution();
    mettreAJourSjrActiviteConservee(attributionAReviser.getCollectionSjrActiviteConserveePerdue(), conteneur.getDemandeRevision());
  }
  
  private void mettreAJourActivitesSurCepa(ConteneurParcoursRevisionAutomatique conteneur)
  {
    Attribution attributionAReviser = (Attribution)conteneur.getDemandeCourante().getAttribution();
    TravailSpec periode = conteneur.getActiviteConserveeAReviser();
    
    ConstitutionSjc cepaSjc = attributionAReviser.getConstitutionElementsAdmission().getConstitutionSjc();
    if (cepaSjc != null)
    {
      cepaSjc.getSjcip().setSjcInitial(new QuantiteEuro(BigDecimal.ZERO));
      cepaSjc.getSjcip().setPlafond(new QuantiteEuro(BigDecimal.ZERO));
      cepaSjc.getSjcrp().setSalaire(BigDecimal.ZERO);
      
      SjrActiviteConserveeSpec sjrActivite = trouverSjrActiviteConservee(cepaSjc.getSjcip().getListSjrActiviteConservee(), periode);
      if (sjrActivite != null) {
        sjrActivite.setTypeActiviteConservee("R");
      }
    }
    ConditionActiviteConservee capaCumul = attributionAReviser.getConditionsAttributionAdmission().getConditionActiviteConservee();
    if (capaCumul != null)
    {
      SjrActiviteConserveeSpec sjrActivite = trouverSjrActiviteConservee(capaCumul.getListSjrActiviteConservee(), periode);
      if (sjrActivite != null) {
        sjrActivite.setTypeActiviteConservee("R");
      }
    }
  }
  
  private SjrActiviteConserveeSpec trouverSjrActiviteConservee(List<SjrActiviteConserveeSpec> liste, TravailSpec periode)
  {
    Iterator<SjrActiviteConserveeSpec> it = liste.iterator();
    SjrActiviteConserveeSpec sjrActivite = null;
    while (it.hasNext())
    {
      SjrActiviteConserveeSpec sjrCourant = (SjrActiviteConserveeSpec)it.next();
      if (sjrCourant.getIdentifiantPeriodeActiviteConservee().equals(periode.getIdentifiant()))
      {
        sjrActivite = sjrCourant;
        break;
      }
    }
    return sjrActivite;
  }
  
  private void mettreAJourSjrActiviteConservee(Collection<SjrActiviteConservee> collectionSjrActiviteConservee, Demande demandeRevision)
  {
    List<TravailSpec> listeFctRevisees = OutilsRevisions.getListeFctsAssociees(demandeRevision);
    Iterator<TravailSpec> it = listeFctRevisees.iterator();
    while (it.hasNext()) {
      mettreAJourSjrActiviteConservee(collectionSjrActiviteConservee, (TravailSpec)it.next());
    }
  }
  
  private void mettreAJourSjrActiviteConservee(Collection<SjrActiviteConservee> collectionSjrActiviteConservee, TravailSpec activiteConservee)
  {
    Iterator<SjrActiviteConservee> it = collectionSjrActiviteConservee.iterator();
    while (it.hasNext())
    {
      SjrActiviteConservee sjrActiviteConservee = (SjrActiviteConservee)it.next();
      if (sjrActiviteConservee.getPeriodeActiviteConservee().getIdentifiant().equals(activiteConservee.getIdentifiant()))
      {
        sjrActiviteConservee.setTypeActiviteConservee("R");
        break;
      }
    }
  }
}

/* Location:
 * Qualified Name:     StrategieRevisionAutomatiqueApresARE2014
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */