package fr.unedic.cali.asu.csa06.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.dom.ParametresCalculAppartenance;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.OutilMappingJustificationAffiliation;
import fr.unedic.cali.asu.csa06.liquidation.outilsfonctionnels.ConstructionPra;
import fr.unedic.cali.asu.csa06.parametres.FabriqueParametres;
import fr.unedic.cali.asu.csa06.parametres.spec.ParametresSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.JustificationAffiliationJoursTravailles;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.parametres.OutilAccesListeUnitesReglement;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.CalculAppartenanceSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.List;

public class ConstitutionQuantiteAffiliation
  extends ParcoursCali
  implements ParcoursAssurance
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCEPA09 = new Resultat(0);
    
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    DossierAffectation dossierAffecte = (DossierAffectation)dossierExamenCourant.getDossierAffecte();
    
    ActiviteSalarie dernierSinistre = (ActiviteSalarie)dossierAffecte.getSinistre();
    
    ParametresSpec parametres = FabriqueParametres.getParametres(demande);
    
    Pra pra = ConstructionPra.getPra(dernierSinistre, demande, parametres);
    
    Chronologie passeProfessionnel = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    
    Chronologie chronoPeriodesParticipantes = ConstructionChronologie.determinerPeriodesParticipantesAffiliationRegle13Mois(demande.getListContexteDemande(), pra, passeProfessionnel, false);
    
    fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionQuantiteAffiliation constitutionQuantiteAppartenance = dossierExamenCourant.createConstitutionQuantiteAffiliation();
    
    Quantite quantiteAffiliation = dossierAffecte.getValidationProduit().getQuantiteAcquise();
    Quantite quantiteAffiliationSecondaire = dossierAffecte.getValidationProduit().getQuantiteAcquiseSecondaire();
    
    CalculAppartenanceSpec outilCalculAppartenance = ((ProduitAsuSpec)dossierAffecte.getProduit()).getOutilCalculAppartenance(demande, false);
    
    ParametresCalculAppartenance parametresAppartenance = new ParametresCalculAppartenance();
    parametresAppartenance.setEffectuerImputationAffiliationPmvs(true);
    parametresAppartenance.setPrendreEnCompteDernierJourFevrier(true);
    parametresAppartenance.setPrendreEnCompteDonneesForcees(true);
    parametresAppartenance.setActiverSpecificitesRechargement(false);
    parametresAppartenance.setComptabiliserAssimilation(true);
    parametresAppartenance.setContexteAppel("cepAffi");
    if (estApplicableNonPriseEnCompteAssimilationEtDerniersJoursFevrier(demande.getDateExamen()))
    {
      parametresAppartenance.setPrendreEnCompteDernierJourFevrier(false);
      parametresAppartenance.setComptabiliserAssimilation(false);
    }
    List<Unite> listeUniteReglement = OutilAccesListeUnitesReglement.getInstance().recupererListeUniteConstitutionQuantiteAffiliation(dossierExamenCourant.getReglementApplicable().getReglement().getNomReglement(), dossierAffecte.getProduit());
    
    parametresAppartenance.setListeUnitesReglement(listeUniteReglement);
    
    QuantitesAppartenance quantitesAppartenance = (QuantitesAppartenance)outilCalculAppartenance.calculer(demande, pra, chronoPeriodesParticipantes, dossierExamenCourant.getReglementApplicable().getReglement(), parametresAppartenance);
    
    constitutionQuantiteAppartenance.setArticle3("1");
    constitutionQuantiteAppartenance.setQuantiteAffiliationAcquise(quantiteAffiliation);
    constitutionQuantiteAppartenance.setQuantiteAffiliationAcquiseSecondaire(quantiteAffiliationSecondaire);
    constitutionQuantiteAppartenance.setDureeInitiale(parametres.getDureePraEnMois());
    
    constitutionQuantiteAppartenance.setPeriodePRA(new Periode(pra.getDebut(), pra.getFin()));
    constitutionQuantiteAppartenance.setQuantiteAssimilationAcquise(new Quantite(0, quantiteAffiliation.getUnite()));
    if (quantiteAffiliationSecondaire != null) {
      constitutionQuantiteAppartenance.setQuantiteAssimilationAcquiseSecondaire(new Quantite(0, quantiteAffiliationSecondaire.getUnite()));
    }
    JustificationAffiliationSpec justificationAffiliation = quantitesAppartenance.getJustificationAffiliation(quantiteAffiliation.getUnite());
    boolean estAffiliationPlafonnee;
    if ("justifCGENouveauModele".equals(justificationAffiliation.getTypeJustificationAffiliation()))
    {
      fr.unedic.cali.asu.dom.JustificationAffiliation justif = (fr.unedic.cali.asu.dom.JustificationAffiliation)justificationAffiliation;
      
      boolean estAffiliationPlafonnee = justif.isEstAffiliationPlafonnee();
      
      dossierAffecte.getValidationProduit().setJustificationCalculAffiliation(justif);
    }
    else
    {
      boolean estAffiliationPlafonnee;
      if ("justifJoursTravailles".equals(justificationAffiliation.getTypeJustificationAffiliation()))
      {
        JustificationAffiliationJoursTravailles justificationJTPersiste = new JustificationAffiliationJoursTravailles();
        OutilMappingJustificationAffiliation.getInstance().mapperJustificationJoursTravaillesNonPersistantVersPersistant(justificationAffiliation, justificationJTPersiste);
        
        ((DossierAffecte)demande.getDossierAffectation()).getValidationProduit().setJustificationAffiliationJoursTravailles(justificationJTPersiste);
        estAffiliationPlafonnee = false;
      }
      else
      {
        fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation justif = (fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation)justificationAffiliation;
        
        justif.setAppartenanceCalculee(quantiteAffiliation);
        justif.setPeriodePraRetenue(pra);
        
        estAffiliationPlafonnee = justif.estAffiliationPlafonnee();
        
        constitutionQuantiteAppartenance.ajouterJustificationAffiliation(justif, quantiteAffiliation.getUnite());
      }
    }
    constitutionQuantiteAppartenance.setEstAffiliationPlafonnee(estAffiliationPlafonnee);
    
    OutilTrace.tracerFinParcours();
    return resultatCEPA09;
  }
  
  protected boolean estApplicableNonPriseEnCompteAssimilationEtDerniersJoursFevrier(Damj dateExamen)
    throws CoucheLogiqueException
  {
    Damj dateApplication = GestionnaireDateApplication.getInstance().recupererDateApplication("Activation de la non prise en compte de l'assimilation pour la ligne CSA");
    return dateExamen.estApresOuCoincideAvec(dateApplication);
  }
}

/* Location:
 * Qualified Name:     ConstitutionQuantiteAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */