package fr.unedic.cali.asu.csa06.p01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parametres.AccesListeUnitesReglement;
import fr.unedic.cali.asu.parametres.ValeurListeUnitesReglement;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCsa06P01;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.affectation.ValidationProduitSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesQualifiables;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltreTemporel;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.List;

public class RechercheValiditeProduit
  extends fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.RechercheValiditeProduit
{
  private static final int NB_CHIFFRE_APRES_VIRGULE = 10;
  
  public static ValidationProduitSpec validerProduit(ActiviteSalarie p_activiteSalarie, IndividuSpec p_individu, DemandeAssuranceSpec p_demandeAssurance, boolean p_avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    ValidationProduit validationProduit = null;
    if (Log.isTraceActive(RechercheValiditeProduit.class, Niveau.INFO)) {
      Log.ecritTrace(Niveau.INFO, RechercheValiditeProduit.class, "validerProduit", "Validation du produit pour l'activité : " + p_activiteSalarie);
    }
    if (p_activiteSalarie.estQualifiable())
    {
      Pra pra = ConstructionPra.getPra(p_activiteSalarie, p_demandeAssurance);
      
      boolean presenceReglementAppartenanceDifferent = verifierReglementAppartenanceDifferent(p_demandeAssurance, pra);
      if (presenceReglementAppartenanceDifferent) {
        validationProduit = verifierConditionAffiliation(p_demandeAssurance, pra, p_avecPeriodeNonAttestee);
      }
      if (validationProduit != null)
      {
        validationProduit.setPeriodeValidationProduit(p_activiteSalarie);
        validationProduit.setPeriodePra(pra);
      }
    }
    return validationProduit;
  }
  
  private static ValidationProduit verifierConditionAffiliation(DemandeAssuranceSpec p_demande, Pra p_pra, boolean p_avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    Chronologie passeProfessionnel = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    
    Chronologie chronoPeriodesParticipantes = ConstructionChronologie.determinerPeriodesParticipantesAffiliationRegle13Mois(null, p_pra, passeProfessionnel, p_avecPeriodeNonAttestee);
    
    Reglement reglementAppartenance = Reglement.getInstance("RG", ProduitAsuCsa06P01.getInstance());
    
    JustificationAffiliation justif = new JustificationAffiliation();
    
    QuantitesAppartenance quantitesAppartenance = fr.unedic.cali.asu.cge01.p02.liquidation.outilsaffiliation.CalculAppartenance.getInstance().calculer(p_demande, justif, p_pra, chronoPeriodesParticipantes, reglementAppartenance);
    
    boolean affiliationSuffisante = false;
    Quantite qteAffiliation = null;
    Quantite qteAssimilation = null;
    
    String contexteReglement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)p_demande, "RECHARGE") ? "RECHARGE" : null;
    
    List listeUnites = AccesListeUnitesReglement.get(reglementAppartenance, contexteReglement).getListeUnites();
    Iterator iter = listeUnites.iterator();
    ValidationProduit validationCsa = null;
    while ((!affiliationSuffisante) && (iter.hasNext()))
    {
      Unite unite = (Unite)iter.next();
      qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
      if (qteAffiliation == null) {
        qteAffiliation = new Quantite("0", unite);
      }
      qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
      if (qteAssimilation == null) {
        qteAssimilation = new Quantite("0", unite);
      }
      BigDecimal valAcquise = qteAffiliation.getValeur().add(qteAssimilation.getValeur());
      BigDecimal valRequise = fr.unedic.cali.asu.csa06.p01.parametres.Parametres.getQuantiteAffiliationRequise(unite).getValeur();
      if (valAcquise.compareTo(valRequise) >= 0)
      {
        affiliationSuffisante = true;
        validationCsa = new ValidationProduit();
        
        validationCsa.setQuantiteAcquise(new Quantite(valAcquise.setScale(10, 1), unite));
        validationCsa.setReglementApplicable(fr.unedic.cali.dom.affectation.Parametres.getReglement(reglementAppartenance.getNomReglement(), ProduitAsuCsa06P01.getInstance()));
      }
    }
    if (validationCsa != null)
    {
      iter = listeUnites.iterator();
      while (iter.hasNext())
      {
        Unite unite = (Unite)iter.next();
        if (!unite.equals(qteAffiliation.getUnite()))
        {
          qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
          if (qteAffiliation == null) {
            qteAffiliation = new Quantite("0", unite);
          }
          qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
          if (qteAssimilation == null) {
            qteAssimilation = new Quantite("0", unite);
          }
          validationCsa.setQuantiteAcquiseSecondaire(new Quantite(qteAffiliation.ajouter(qteAssimilation).getValeur().setScale(10, 1), qteAffiliation.getUnite()));
        }
      }
    }
    if (quantitesAppartenance.estEnConflit()) {
      p_demande.setLiquideeAvecConflits(true);
    }
    return validationCsa;
  }
  
  private static boolean verifierReglementAppartenanceDifferent(DemandeAssuranceSpec p_demande, Pra p_pra)
  {
    Chronologie passeProfessionnel = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    
    FiltreTemporel filtre = new FiltreChevauchePeriode(p_pra);
    passeProfessionnel = passeProfessionnel.copier(filtre);
    
    filtre = new FiltreActiviteSalarie();
    Chronologie listeActivitesSalariees = passeProfessionnel.copier(filtre);
    
    listeActivitesSalariees = listeActivitesSalariees.copier(new FiltrePeriodesQualifiables());
    listeActivitesSalariees = listeActivitesSalariees.copier(new FiltrePeriodesLiquidables());
    
    ActiviteSalarie periodeActiviteSalariePrec = null;
    for (Iterator iter = listeActivitesSalariees.iterer(); iter.hasNext();)
    {
      ActiviteSalarie periodeActiviteSalarie = (ActiviteSalarie)iter.next();
      if ((periodeActiviteSalariePrec != null) && 
        (!periodeActiviteSalarie.getReglement().equals(periodeActiviteSalariePrec.getReglement()))) {
        return true;
      }
      periodeActiviteSalariePrec = periodeActiviteSalarie;
    }
    return false;
  }
}

/* Location:
 * Qualified Name:     RechercheValiditeProduit
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */