package fr.unedic.cali.asu.csr04.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class DeterminationDureeEffective
{
  fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationDureeEffective m_ofCge01 = fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationDureeEffective.getInstance();
  
  public static DeterminationDureeEffective getInstance()
  {
    return new DeterminationDureeEffective();
  }
  
  public DureeIndemnisation determinerDureeEffectivePourAdmission(Demande p_demande)
    throws ApplicativeException
  {
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierExamen();
    DureeIndemnisation dureeIndemnisation = dossierExamen.getConstitutionDurees().getDureeIndemnisation();
    Quantite dureeEffectivePourAdmissionClassique = m_ofCge01.determinerDureeEffective(p_demande).getDureeEffective();
    Unite uniteQuantiteDuree = Unite.getParCode("4");
    
    BigDecimal dureeEffectiveBornee = bornerDureeEffective(p_demande, dureeEffectivePourAdmissionClassique.getValeur(), true, null);
    controleDuree(dureeEffectiveBornee, p_demande);
    Quantite dureeEffectiveBorneeQuantite = new Quantite(dureeEffectiveBornee, uniteQuantiteDuree);
    dureeIndemnisation.setDureeEffective(dureeEffectiveBorneeQuantite);
    return dureeIndemnisation;
  }
  
  public DureeIndemnisation determinerDureeEffectivePourReprise(Demande p_demande, ResultatExecutionCalculSpec p_resultatCalcul)
    throws ApplicativeException
  {
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierExamen();
    DureeIndemnisation dureeIndemnisation = dossierExamen.getConstitutionDurees().getDureeIndemnisation();
    
    Quantite dureeEffectivePourRepriseClassique = m_ofCge01.calculerDureeEffectivePourReprise(p_demande, dureeIndemnisation.getDureeTheorique());
    Unite uniteQuantiteDuree = Unite.getParCode("4");
    
    BigDecimal dureeEffectiveCalculee = bornerDureeEffective(p_demande, dureeEffectivePourRepriseClassique.getValeur(), false, p_resultatCalcul);
    
    controleDuree(dureeEffectiveCalculee, p_demande);
    
    Quantite dureeEffectiveBornee = new Quantite(dureeEffectiveCalculee, uniteQuantiteDuree);
    dureeIndemnisation.setDureeEffective(dureeEffectiveBornee);
    return dureeIndemnisation;
  }
  
  public BigDecimal bornerDureeEffective(Demande p_demande, BigDecimal p_dureeEffectiveClassique, boolean p_estPourDroitCourant, ResultatExecutionCalculSpec p_resultatCalcul)
    throws ApplicativeException
  {
    DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)p_demande.getDossierExamen();
    Damj dateMaximumPoursuiteIndemnisation = p_demande.getDonneesTemporaires().getDateMaximumPoursuiteIndeminisationChomageTotalSansRupture();
    boolean accordPoursuite = p_demande.getDonneesTemporaires().isAccordPoursuite182JoursChomageTotalSansRupture();
    boolean estDateLimIndemnisationCsrSaisie = dateMaximumPoursuiteIndemnisation != null;
    boolean estCasParticulierSuspension = estCasParticulierSuspension(p_demande);
    BigDecimal dureeEffectiveCalculee = null;
    Damj dateAttribution = dossierExamen.getDateAttribution();
    if ((estCasParticulierSuspension) && (!accordPoursuite))
    {
      BigDecimal reliquatProlongation = new BigDecimal(182);
      if (!p_estPourDroitCourant)
      {
        ResultatExecutionCalculSpec resultatCalcul = p_resultatCalcul;
        if (resultatCalcul == null)
        {
          AttributionAssuranceSpec attributionPrecedente = dossierExamen.getAttributionPrecedente();
          if (attributionPrecedente == null) {
            attributionPrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(p_demande.getChronologieDemandesAssuranceSansCourante(), p_demande, new FiltreAttributionStandardAssurance(true, true, false, true, p_demande));
          }
          if (attributionPrecedente != null) {
            resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionPrecedente, p_demande.getDateRecherche().veille(), true, true);
          }
        }
        if (resultatCalcul != null)
        {
          Quantite reliquatDureeProlongation = resultatCalcul.getReliquatDureeProlongation();
          if (reliquatDureeProlongation != null) {
            reliquatProlongation = reliquatDureeProlongation.getValeur();
          }
        }
      }
      dureeEffectiveCalculee = reliquatProlongation;
    }
    else if ((estCasParticulierSuspension) && (accordPoursuite) && (estDateLimIndemnisationCsrSaisie))
    {
      int dureePeriode = trouverDureeEntreDate(dateAttribution, dateMaximumPoursuiteIndemnisation);
      dureeEffectiveCalculee = new BigDecimal(dureePeriode);
    }
    else
    {
      dureeEffectiveCalculee = p_dureeEffectiveClassique;
    }
    return p_dureeEffectiveClassique.min(dureeEffectiveCalculee).setScale(0);
  }
  
  public void controleDuree(BigDecimal p_dureeEffectiveBornee, Demande p_demande)
    throws CoucheLogiqueException
  {
    Damj dateMaximumPoursuiteIndemnisation = p_demande.getDonneesTemporaires().getDateMaximumPoursuiteIndeminisationChomageTotalSansRupture();
    boolean accordPoursuite = p_demande.getDonneesTemporaires().isAccordPoursuite182JoursChomageTotalSansRupture();
    DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)p_demande.getDossierExamen();
    Damj dateAttribution = dossierExamen.getDateAttribution();
    if (p_dureeEffectiveBornee.intValue() == 0) {
      if (!accordPoursuite) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ERR_DUREE_182_J_CSR_EPUISEE", new Object[] { dateAttribution });
      } else if (dateMaximumPoursuiteIndemnisation != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ERR_DATE_MAX_INDEMN_CSR_AVANT_ATTRIB", new Object[] { dateMaximumPoursuiteIndemnisation, dateAttribution });
      }
    }
  }
  
  private boolean estCasParticulierSuspension(Demande p_demande)
    throws CoucheLogiqueException
  {
    boolean estContexteReprisePendantSuspension = OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(p_demande);
    boolean estContexteRuptureContratSuspension = OutilsChomageSansRCT.estUnContexteRuptureContratPendantSuspension(p_demande);
    return (estContexteReprisePendantSuspension) && (!estContexteRuptureContratSuspension);
  }
  
  private int trouverDureeEntreDate(Damj p_date1, Damj p_date2)
  {
    int dureePeriode = 0;
    if (p_date1.estAvant(p_date2))
    {
      Periode periode = new Periode(p_date1, p_date2);
      dureePeriode = periode.getDuree();
    }
    else
    {
      dureePeriode = 0;
    }
    return dureePeriode;
  }
}

/* Location:
 * Qualified Name:     DeterminationDureeEffective
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */