package fr.unedic.cali.asu.csr04.p01.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.calcul.dom.DureeProlongation;
import fr.unedic.cali.asu.calcul.dom.EtatAuDjiGamme;
import fr.unedic.cali.asu.calcul.dom.temps.ObjectChronoFinChomageSansRct;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeCarences;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodePreavis;
import fr.unedic.cali.asu.cge01.p03.calcul.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Differe;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ElementChomageSansRupture;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ElementsRuptureContratSuspendu;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Reprise;
import fr.unedic.cali.asu.csr04.p01.calcul.outilsfonctionnels.Qualification;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CarenceSpec;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.EtatAuDji;
import fr.unedic.cali.calcul.dom.EvenementLimiteIndemnisationChomageSansRCT;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.GestionSuivi;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ContexteUT;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeEvenementPersonnel;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.QuantiteDroit;
import fr.unedic.cali.dom.QuantiteDroitSpec;
import fr.unedic.cali.outilsfonctionnels.GestionnaireErreur;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class FacadeCalculProduitImpl
  extends fr.unedic.cali.asu.cge01.p03.calcul.FacadeCalculProduitImpl
{
  public Damj recupererDateFinDroitTheorique(CalendrierExecutionCalculSpec p_calendrierExecutionCalcul, AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    if (estUnContexteDeRupturePendantSuspension(p_attribution)) {
      return super.recupererDateFinDroitTheorique(p_calendrierExecutionCalcul, p_attribution);
    }
    Attribution attribution = (Attribution)p_attribution;
    ElementChomageSansRupture element = attribution.getElementChomageSansRupture();
    
    Damj dateFinDroitTheorique = p_attribution.getPji().deplacerVersAvant(new DureeCalendaire(0, 0, attribution.getDureeIndemnisationTheorique().getValeurEntiere() - 1));
    if (attribution.getElementChomageSansRupture().getDecisionProlongation())
    {
      if ((element.getDateMaxIndeminisation() != null) && (element.getDateMaxIndeminisation().estAvant(dateFinDroitTheorique))) {
        dateFinDroitTheorique = element.getDateMaxIndeminisation();
      }
    }
    else if (attribution.getDureeProlongationTheorique() != null) {
      dateFinDroitTheorique = p_attribution.getPji().deplacerVersAvant(new DureeCalendaire(0, 0, attribution.getDureeProlongationTheorique().getValeurEntiere() - 1));
    }
    if ((attribution.getElementChomageSansRupture().getDateRepriseActivite() != null) && (element.getDateRepriseActivite().estAvant(dateFinDroitTheorique))) {
      dateFinDroitTheorique = element.getDateRepriseActivite();
    }
    boolean positionnementEffectue = false;
    if (((CalendrierExecutionCalculPeriodique)p_calendrierExecutionCalcul).getChronologieUnitesTraitements() != null)
    {
      Iterator iterateurUT = ((CalendrierExecutionCalculPeriodique)p_calendrierExecutionCalcul).getChronologieUnitesTraitements().iterer();
      while ((iterateurUT.hasNext()) && (!positionnementEffectue))
      {
        UniteTraitement ut = (UniteTraitement)iterateurUT.next();
        if (dateFinDroitTheorique.estContenueDans(ut.getPeriode()))
        {
          ut.ajouterEvenement(new EvenementLimiteIndemnisationChomageSansRCT(dateFinDroitTheorique));
          positionnementEffectue = true;
        }
      }
    }
    return dateFinDroitTheorique;
  }
  
  public ChronologiePeriodes recupererPeriodesProduit(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesIndividuelles = super.recupererPeriodesProduit(p_attribution);
    
    ElementsRuptureContratSuspendu elementsRuptureContratSuspendu = null;
    ElementChomageSansRupture elementChomageSansRupture = ((Attribution)p_attribution).getElementChomageSansRupture();
    if (!estUnContexteDeRupturePendantSuspension(p_attribution))
    {
      if (elementChomageSansRupture != null) {
        elementsRuptureContratSuspendu = elementChomageSansRupture.getElementsRuptureContratSuspendu();
      }
      if (elementChomageSansRupture != null)
      {
        Damj dateFinProduit = null;
        
        Damj dateRepriseActivite = elementChomageSansRupture.getDateRepriseActivite();
        if (dateRepriseActivite != null) {
          dateFinProduit = dateRepriseActivite;
        }
        boolean estDecisionProlongation = elementChomageSansRupture.getDecisionProlongation();
        if (estDecisionProlongation)
        {
          Damj dateDecisionProlongation = elementChomageSansRupture.getDateMaxIndeminisation();
          if ((dateRepriseActivite == null) || ((dateDecisionProlongation != null) && (dateDecisionProlongation.lendemain().estAvant(dateRepriseActivite)))) {
            dateFinProduit = dateDecisionProlongation.lendemain();
          }
        }
        if ((dateFinProduit != null) && (elementsRuptureContratSuspendu == null)) {
          periodesIndividuelles.ajouter(new ObjectChronoFinChomageSansRct(dateFinProduit));
        }
      }
    }
    else
    {
      Collection periodeDelaiReport = elementChomageSansRupture.getPeriodeDiffere();
      if (periodeDelaiReport != null)
      {
        Iterator itPeriodeDelaiReports = periodeDelaiReport.iterator();
        while (itPeriodeDelaiReports.hasNext())
        {
          CarenceSpec carence = (CarenceSpec)itPeriodeDelaiReports.next();
          if ("Différé".equals(carence.getTypeCarence()))
          {
            Periode periodeCarence = ((Differe)carence).getPeriodeEffet();
            int nbJoursDiffere = ((Differe)carence).getQuantiteInitialJour();
            if ((periodeCarence != null) && (nbJoursDiffere > 0))
            {
              ChronologiePeriodes chronologiePeriodesGAEC = OutillagePeriodes.recupererPeriodesGAEC(p_attribution.getDemandeur(), p_attribution.getDateAttribution(), null);
              Qualification qualification = new Qualification();
              QualificationPeriodes periodesQualifie = qualification.qualificationPeriodesPourAvant(chronologiePeriodesGAEC, p_attribution);
              ChronologiePeriodes chronologiePeriodeMaladie = (ChronologiePeriodes)periodesQualifie.getPeriodesSuspensives().copier(new FiltrePeriodeEvenementPersonnel());
              
              Damj dateDebutDiffere = periodeCarence.getDebut();
              dateDebutDiffere = rechercheTrouMaladie(dateDebutDiffere, chronologiePeriodeMaladie);
              
              DureeCalendaire decalage = new DureeCalendaire(0, 0, nbJoursDiffere - 1);
              periodesIndividuelles.ajouter(new ObjetChronoPeriodeCarences(dateDebutDiffere, dateDebutDiffere.deplacerVersAvant(decalage), 1));
            }
          }
          else if ("ISLR".equals(carence.getTypeCarence()))
          {
            Periode periodeCarence = ((CarencePrefixeAFixer)carence).getPeriodeApplicationCarence();
            if (periodeCarence != null) {
              periodesIndividuelles.ajouter(new ObjetChronoPeriodeCarences(periodeCarence.getDebut(), periodeCarence.getFin(), 2));
            }
          }
          else if ("PMC_NI".equals(carence.getTypeCarence()))
          {
            Periode periodeCarence = ((CarencePrefixeAFixer)carence).getPeriodeApplicationCarence();
            if (periodeCarence != null) {
              periodesIndividuelles.ajouter(new ObjetChronoPeriodePreavis(periodeCarence.getDebut(), periodeCarence.getFin()));
            }
          }
        }
      }
    }
    return periodesIndividuelles;
  }
  
  private static Damj rechercheTrouMaladie(Damj p_dateDebutDiffere, ChronologiePeriodes p_chronoPeriodesMaladie)
  {
    p_chronoPeriodesMaladie.iterer();
    while (p_chronoPeriodesMaladie.encoreSuivant())
    {
      ObjetChronoPeriode periodeMaladie = (ObjetChronoPeriode)p_chronoPeriodesMaladie.elementSuivant();
      if ((periodeMaladie.getDateDebut().estAvantOuCoincideAvec(p_dateDebutDiffere)) && (periodeMaladie.getDateFin().estApresOuCoincideAvec(p_dateDebutDiffere))) {
        return rechercheTrouMaladie(periodeMaladie.getDateFin().lendemain(), p_chronoPeriodesMaladie);
      }
    }
    return p_dateDebutDiffere;
  }
  
  public QualificationPeriodes qualificationPeriodes(ChronologiePeriodes p_chronologiePeriodes, AttributionSpec p_attribution, ContexteUT p_contexteUT)
    throws CoucheLogiqueException
  {
    Qualification qualificationCsr = new Qualification();
    QualificationPeriodes qualificationPeriodes = null;
    Iterator iterator = null;
    ObjetChronoPeriodeCalcul periode = null;
    if (estUnContexteDeRupturePendantSuspension(p_attribution))
    {
      qualificationPeriodes = super.qualificationPeriodes(p_chronologiePeriodes, p_attribution, p_contexteUT);
      
      iterator = p_chronologiePeriodes.iterer();
      while (iterator.hasNext())
      {
        periode = (ObjetChronoPeriodeCalcul)iterator.next();
        qualificationCsr.qualifierUnePeriodeSuspensives(periode, qualificationPeriodes, p_attribution);
      }
      return qualificationPeriodes;
    }
    return qualificationCsr.qualificationPeriodes(p_chronologiePeriodes, p_attribution);
  }
  
  public void initialisationQuantitesIndemnisation(ConstituantsIndemnisation p_constituantsIndemnisation, AttributionSpec p_attribution, Periode p_periodeUT)
    throws ApplicativeException
  {
    Iterator iterator = null;
    QuantiteDroitSpec duree = null;
    Collection collectionDurees = null;
    
    collectionDurees = p_constituantsIndemnisation.getCollectionQuantiteDroit();
    if (collectionDurees != null)
    {
      iterator = collectionDurees.iterator();
      while (iterator.hasNext())
      {
        duree = (QuantiteDroitSpec)iterator.next();
        if (((duree instanceof DureeIndemnisation)) || ((duree instanceof DureeProlongation)))
        {
          duree.activer();
          initialiseElementBaseIndemnisationCourante(p_constituantsIndemnisation, p_attribution, p_periodeUT);
        }
      }
    }
  }
  
  public boolean epuisementQuantiteDroit(Damj p_dateEpuisementQuantite, AttributionSpec p_attribution, QuantiteDroitSpec p_quantiteDroitEpuisee, ConstituantsIndemnisation p_constituantsIndemnisation, UniteTraitement p_ut)
    throws ApplicativeException
  {
    boolean finDeProduit = super.epuisementQuantiteDroit(p_dateEpuisementQuantite, p_attribution, p_quantiteDroitEpuisee, p_constituantsIndemnisation, p_ut);
    if ((!estUnContexteDeRupturePendantSuspension(p_attribution)) && 
      (!finDeProduit)) {
      if ((p_quantiteDroitEpuisee instanceof DureeProlongation))
      {
        ElementChomageSansRupture elementChomageSansRupture = ((Attribution)p_attribution).getElementChomageSansRupture();
        if (elementChomageSansRupture != null) {
          if (elementChomageSansRupture.getDecisionProlongation())
          {
            Damj dateProlongation = elementChomageSansRupture.getDateMaxIndeminisation();
            if ((dateProlongation != null) && (dateProlongation.estAvant(p_dateEpuisementQuantite))) {
              finDeProduit = true;
            }
          }
          else
          {
            finDeProduit = true;
            if ((elementChomageSansRupture.estAccordCP()) && (elementChomageSansRupture.estSinistreOuCalamite())) {
              GestionSuivi.enregistrerEnquetePbjcNcp(p_attribution, p_dateEpuisementQuantite, 26, 0, true, null, this, p_constituantsIndemnisation);
            }
          }
        }
      }
    }
    return finDeProduit;
  }
  
  public EtatAuDji renseignerEtatAuDji(UniteTraitement p_derniereUT, CalendrierExecutionCalculPeriodique p_calendrier, AttributionSpec p_attribution, EtatAuDji p_etatAuDji)
    throws CoucheLogiqueException
  {
    EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)super.renseignerEtatAuDji(p_derniereUT, p_calendrier, p_attribution, p_etatAuDji);
    if (!estUnContexteDeRupturePendantSuspension(p_attribution))
    {
      QuantiteDroitSpec reliquat = p_derniereUT.getConstituantsIndemnisationEnFinUT().getDureeProlongation();
      if (reliquat != null) {
        etatAuDji.setReliquatDureeProlongation(((QuantiteDroit)reliquat).getQuantiteCourante());
      } else {
        etatAuDji.setReliquatDureeProlongation(new Quantite("0", DureeProlongation.UNITE_DEFAUT));
      }
    }
    return etatAuDji;
  }
  
  public ConstituantsIndemnisation creationConstituantsIndemnisation(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    Iterator iterator = null;
    QuantiteDroitSpec duree = null;
    
    Collection collectionDurees = new ArrayList(((Attribution)p_attribution).getListeDurees());
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    
    boolean estUnContexteDeRupturePendantSuspension = estUnContexteDeRupturePendantSuspension(p_attribution);
    iterator = collectionDurees.iterator();
    while (iterator.hasNext())
    {
      duree = (QuantiteDroitSpec)iterator.next();
      if ((!(duree instanceof DureeProlongation)) || (!estUnContexteDeRupturePendantSuspension))
      {
        List listeDureeProlongation = new ArrayList();
        listeDureeProlongation.add(duree);
        constituantsIndemnisation.ajouterQuantiteDroit(listeDureeProlongation, duree);
      }
    }
    if (((p_attribution instanceof Reprise)) && (!estUnContexteDeRupturePendantSuspension))
    {
      Attribution attribution = (Attribution)p_attribution;
      AttributionAssuranceSpec attributionPrecedente = attribution.getAttributionPrecedente();
      
      ElementChomageSansRupture elementChomageSansRupture = ((Attribution)p_attribution).getElementChomageSansRupture();
      if ((elementChomageSansRupture != null) && (!elementChomageSansRupture.getDecisionProlongation())) {
        if ((elementChomageSansRupture.getDateRepriseActivite() != null) && (p_attribution.getDateAttribution().estAvant(elementChomageSansRupture.getDateRepriseActivite())))
        {
          EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)attributionPrecedente.getCalendrierExecutionCalcul().getEtatAuDJI();
          if ((etatAuDji != null) && (etatAuDji.getReliquatDureeProlongation().getValeurEntiere() != 0))
          {
            List listeDureeProlongation = new ArrayList();
            DureeProlongation dureeProlongation = new DureeProlongation(etatAuDji.getReliquatDureeProlongation().getValeurEntiere());
            listeDureeProlongation.add(dureeProlongation);
            constituantsIndemnisation.ajouterQuantiteDroit(listeDureeProlongation, dureeProlongation);
          }
        }
      }
    }
    return constituantsIndemnisation;
  }
  
  public boolean estUnContexteDeRupturePendantSuspension(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    ElementChomageSansRupture elementChomageSansRupture = ((Attribution)p_attribution).getElementChomageSansRupture();
    ElementsRuptureContratSuspendu elementsRuptureContratSuspendu = elementChomageSansRupture.getElementsRuptureContratSuspendu();
    if (elementsRuptureContratSuspendu != null) {
      return elementsRuptureContratSuspendu.estUnContexteDeRupturePendantSuspension();
    }
    return false;
  }
  
  public int calculerCompteurNombreJoursIndemnisesSurUT(UniteTraitement p_ut, int p_cumulNombreJoursServi)
  {
    int nombreJourServiEnDebutUT = 0;
    nombreJourServiEnDebutUT = p_cumulNombreJoursServi + p_ut.getQuantiteIndemnisee().getValeur().intValue();
    p_ut.setEstCumulJoursIndemnise(true);
    return nombreJourServiEnDebutUT;
  }
  
  public void alimenterGrapheAntecedentCalcul(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */