package fr.unedic.cali.asu.cva10.p02.antecedent;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Antecedent;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.outilsfonctionnels.OutilCreationDemande;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursLiquidation;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class GrapheAntecedent
  extends fr.unedic.cali.asu.asr.antecedent.GrapheAntecedent
{
  private static final String PREFIXE_FINANCEMENT = "Droit ARE Antécédent Support : ";
  
  public static GrapheAntecedent getInstance()
  {
    return new GrapheAntecedent();
  }
  
  public void alimenterGrapheDecisionAntecedent(Contexte contexte)
    throws CoucheLogiqueException
  {
    initialiserDemandeSousJacente(DomLiquidationAssurance.getDemande(contexte));
    
    super.alimenterGrapheDecisionAntecedent(contexte);
  }
  
  protected void initialiserDemandeSousJacente(Demande p_demande)
    throws CoucheLogiqueException
  {
    p_demande.getDossierAffectation().setDossierExamen(new Antecedent());
    
    ParcoursLiquidation parcoursLiquidationDemande = null;
    String typeDemande = "ASU_22";
    Damj dateDepot = p_demande.getDateDepot();
    IndividuSpec individu = p_demande.getDemandeur();
    Demande demandeAssociee = null;
    try
    {
      demandeAssociee = (Demande)OutilCreationDemande.creerDemande(typeDemande, dateDepot, individu, p_demande.getFormulaire().getIdPec(), null);
    }
    catch (ApplicativeException e)
    {
      throw new CoucheLogiqueException(e.getCode(), e.getLibelle(), e);
    }
    demandeAssociee.setDemandeur(p_demande.getDemandeur());
    
    p_demande.createDonneesDemandeAssociee();
    demandeAssociee.setCommentaire("DESACTIVER_TRANCHE_EXEC");
    p_demande.getDonneesDemandeAssociee().setDemandeAssociee(demandeAssociee);
    
    demandeAssociee.setSaisieAntecedent(new SaisieAntecedent());
    p_demande.getSaisieAntecedent().copieElements(demandeAssociee.getSaisieAntecedent());
    
    demandeAssociee.getSaisieAntecedent().setCodeProduit(Integer.valueOf(1));
    demandeAssociee.getSaisieAntecedent().setPremierJourIndemnisable(p_demande.getSaisieAntecedent().getDateAttribution());
    
    demandeAssociee.createContexteDemande();
    ContexteDemande contexte = new ContexteDemande();
    contexte.setTypeContexteDemande("ARESJASPDC");
    demandeAssociee.ajouterContexteDemande(contexte);
    
    DomLiquidationDemande domContexte = demandeAssociee.getGamme().creerDomLiquidationDemande();
    domContexte.setDemande(demandeAssociee);
    domContexte.setIdDemande(demandeAssociee.getIdentifiant());
    domContexte.setIndividu(demandeAssociee.getDemandeur());
    domContexte.setContexteService(demandeAssociee.getDemandeur().getContexteService());
    Contexte contexteParcours = new Contexte();
    contexteParcours.setDonnees(domContexte);
    try
    {
      parcoursLiquidationDemande = demandeAssociee.getGamme().getParcoursLiquidation(demandeAssociee);
      parcoursLiquidationDemande.effectuerParcours(contexteParcours);
    }
    catch (CoucheLogiqueException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), "Droit ARE Antécédent Support : ".concat(ex.getLibelle()), ex);
    }
    catch (ApplicativeException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), "Droit ARE Antécédent Support : ".concat(ex.getLibelle()), ex);
    }
  }
  
  protected void alimenterConstitutionMontantBrut(DossierExamenAssuranceSpec p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    Demande demandeAsp = (Demande)p_dossierExamen.getDemandeAssurance();
    Demande demandeAssociee = demandeAsp.getDonneesDemandeAssociee().getDemandeAssociee();
    
    Attribution attributionPrecedente = (Attribution)demandeAsp.rechercherAttributionPrecedenteDuMemeType();
    if (attributionPrecedente != null)
    {
      ConstitutionMontantsBruts cepaMontantBrutAreSousJacent = ((Attribution)demandeAssociee.getAttribution()).getConstitutionMontantsBruts();
      ConstitutionMontantsBruts cepaMontantBrutArePrecedent = attributionPrecedente.getConstitutionMontantsBruts();
      if (cepaMontantBrutArePrecedent.getMontantJournalierBrut().compareTo(cepaMontantBrutAreSousJacent.getMontantJournalierBrut()) == 1)
      {
        Demande demandePrecedente = (Demande)attributionPrecedente.getDemande();
        demandePrecedente.getDossierAffectation().copieElements(demandeAssociee.getDossierAffectation());
      }
    }
    super.alimenterConstitutionMontantBrut(p_dossierExamen, p_saisieAntecedent);
  }
  
  protected void alimenterConditionsAdmissionSupplementaire(Demande p_demande)
    throws CoucheLogiqueException
  {}
}

/* Location:
 * Qualified Name:     GrapheAntecedent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */