package fr.unedic.cali.asu.cva10.p02.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.EreDemandeAssociee;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionQuantiteAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.outilsfonctionnels.OutilCreationDemande;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ParcoursLiquidation;
import fr.unedic.cali.parcours.ResultatServiceDemande;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class ParcoursLiquidationDemandeSousJacente
  extends ParcoursCali
{
  private static final String PREFIXE_FINANCEMENT = "Droit ARE Support : ";
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultat = new Resultat();
    resultat.setEtat(1);
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    
    resultat = liquiderDemandeSousJacente(demande);
    
    resultat.setEtat(0);
    
    OutilTrace.tracerFinParcours();
    
    return resultat;
  }
  
  private Resultat liquiderDemandeSousJacente(Demande p_demande)
    throws ApplicativeException
  {
    DomLiquidationDemande domContexte = null;
    Contexte contexteParcours = null;
    ParcoursLiquidation parcoursLiquidationDemande = null;
    ResultatServiceDemande resultatLiquidation = null;
    
    Demande demandeAsp = p_demande;
    creerDemandeAssociee(demandeAsp);
    
    DemandeAssuranceSpec demandeSousJacente = demandeAsp.getDonneesDemandeAssociee().getDemandeAssociee();
    
    domContexte = demandeSousJacente.getGamme().creerDomLiquidationDemande();
    domContexte.setDemande(demandeSousJacente);
    domContexte.setIdDemande(demandeSousJacente.getIdentifiant());
    domContexte.setIndividu(demandeSousJacente.getDemandeur());
    domContexte.setContexteService(demandeSousJacente.getDemandeur().getContexteService());
    contexteParcours = new Contexte();
    contexteParcours.setDonnees(domContexte);
    
    traiterDonneesForcees(demandeAsp, demandeSousJacente);
    
    demandeSousJacente.getDonneesTemporaires().setTypeContexteDemandeDonneesTemporaires("ARESJASPDC");
    try
    {
      parcoursLiquidationDemande = demandeSousJacente.getGamme().getParcoursLiquidation(demandeSousJacente);
      
      resultatLiquidation = (ResultatServiceDemande)parcoursLiquidationDemande.effectuerParcours(contexteParcours);
    }
    catch (CoucheLogiqueException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), "Droit ARE Support : ".concat(ex.getLibelle()), ex);
    }
    return resultatLiquidation;
  }
  
  private void creerDemandeAssociee(Demande p_demandeAsp)
    throws ApplicativeException
  {
    String typeDemande = "ASU_21";
    Damj dateDepot = p_demandeAsp.getDateDepot();
    IndividuSpec individu = p_demandeAsp.getDemandeur();
    
    Demande demandeAssociee = (Demande)OutilCreationDemande.creerDemande(typeDemande, dateDepot, individu, p_demandeAsp.getFormulaire().getIdPec(), null);
    
    demandeAssociee.setDemandeur(p_demandeAsp.getDemandeur());
    
    ((FormulaireAsu)demandeAssociee.getFormulaire()).setReferenceExterne(p_demandeAsp.getFormulaire().getReferenceExterne());
    
    ((EreDemandeAssociee)demandeAssociee.getEvenementReferenceExamen()).setContexteDemande("ARESJASPDC");
    
    p_demandeAsp.createDonneesDemandeAssociee();
    demandeAssociee.desactiverTrancheExecutable();
    p_demandeAsp.getDonneesDemandeAssociee().setDemandeAssociee(demandeAssociee);
  }
  
  private void traiterDonneesForcees(Demande p_demandeAsp, DemandeAssuranceSpec p_demandeSousJacente)
  {
    OutilDemande.copieDonneesForcees(p_demandeAsp, p_demandeSousJacente);
    DossierExamen dossierExamenAsp = (DossierExamen)p_demandeAsp.getDossierExamen();
    traiterDonneesForceesAffiliation(dossierExamenAsp, p_demandeSousJacente);
    traiterDonneesForceesSjr(dossierExamenAsp, p_demandeSousJacente);
  }
  
  private void traiterDonneesForceesSjr(DossierExamen p_dossierExamenAsp, DemandeAssuranceSpec p_demandeSousJacente)
  {
    DonneesTemporaires donneesForcees = p_demandeSousJacente.getDonneesTemporaires();
    BigDecimal sjrip = p_dossierExamenAsp.getConstitutionSjr().getSjrip().getSjrip();
    Damj dateFinPrc = null;
    if (p_dossierExamenAsp.getConstitutionSjr().getSjrip().getPrc() != null) {
      dateFinPrc = p_dossierExamenAsp.getConstitutionSjr().getSjrip().getPrc().getDateFin();
    }
    if ((sjrip != null) && (dateFinPrc != null))
    {
      Quantite quantiteSjr = new Quantite(sjrip, Unite.get("Euros"));
      donneesForcees.setSjr(quantiteSjr);
      donneesForcees.setTermePrc(dateFinPrc);
    }
  }
  
  private void traiterDonneesForceesAffiliation(DossierExamen p_dossierExamenAsp, DemandeAssuranceSpec p_demandeSousJacente)
  {
    String identifiantFct = p_dossierExamenAsp.getFaitGenerateur().getPeriodeFaitGenerateur().getIdentifiant();
    p_demandeSousJacente.getDonneesTemporaires().setIdentifiantPeriodeFctARetenir(identifiantFct);
    
    ConstitutionQuantiteAffiliation constitutionQuantiteAffiliation = p_dossierExamenAsp.getConstitutionQuantiteAffiliation();
    Quantite affiliationAcquise = constitutionQuantiteAffiliation.getQuantiteAffiliationAcquise();
    JustificationAffiliationSpec justificationAffiliationSpec = constitutionQuantiteAffiliation.getJustificationAffiliation(affiliationAcquise.getUnite());
    
    Pra pra = (Pra)justificationAffiliationSpec.getPeriodeRechercheAffiliation();
    
    Quantite quantiteRequise = pra.getQuantiteAffiliationRequise(affiliationAcquise.getUnite());
    p_demandeSousJacente.getDonneesTemporaires().setQuantiteAffiliation(quantiteRequise.max(affiliationAcquise));
  }
}

/* Location:
 * Qualified Name:     ParcoursLiquidationDemandeSousJacente
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */