package fr.unedic.cali.asu.cve13.p01.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.cve13.p01.calcul.dom.ElementBaseIndemnisation;
import fr.unedic.cali.calcul.dom.ConstituantsCalculActiviteReduiteSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.EvenementFinCumul;
import fr.unedic.cali.calcul.dom.SyntheseARsurUT;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.UniteTraitementForcee;
import fr.unedic.cali.calcul.dom.periode.DsmTravail;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravailJustifiee;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.GestionForcage;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ResultatActiviteReduite;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ElementBaseIndemnisationSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.UniteMonaitaire;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.UniteDuree;
import java.math.BigDecimal;

public class TraitementActiviteReduite
{
  public static void traitementPeriodesGelantes(AttributionSpec p_attribution, ChronologiePeriodes p_periodesGelantes, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduite, UniteTraitement p_ut)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesGelantesDeclareees = new ChronologiePeriodes();
    ChronologiePeriodes periodesGelantesJustifiees = new ChronologiePeriodes();
    
    boolean traitementActiviteReduite = preTraitementPeriodesGelantes(p_attribution, p_ut, p_periodesGelantes, periodesGelantesJustifiees, periodesGelantesDeclareees);
    if (traitementActiviteReduite)
    {
      ResultatActiviteReduite resultatActiviteReduite = appelleActiviteReduite(periodesGelantesJustifiees, p_constituantsCalculActiviteReduite);
      
      postTraitementPeriodesGelantes(p_ut, resultatActiviteReduite);
    }
  }
  
  protected static boolean preTraitementPeriodesGelantes(AttributionSpec p_attribution, UniteTraitement p_ut, ChronologiePeriodes p_periodesGelantes, ChronologiePeriodes p_periodesGelantesJustifiees, ChronologiePeriodes p_periodesGelantesDeclarees)
    throws CoucheLogiqueException
  {
    boolean traitementActiviteReduite = false;
    switch (p_ut.getStatut())
    {
    case -1: 
    case 1: 
    case 2: 
    case 5: 
    case 7: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_ACTIVITE_REDUITE_STATUT_UT_INATTENDU", "Erreur sur le statut de l'Unité de Traitement lors du traitement de l'activité réduite.", null);
    case 3: 
      p_periodesGelantes.iterer();
      while (p_periodesGelantes.encoreSuivant())
      {
        ObjetChronoPeriodeCalcul periodeTravailCalcul = (ObjetChronoPeriodeCalcul)p_periodesGelantes.elementSuivant();
        if ((periodeTravailCalcul instanceof PeriodeTravailJustifiee))
        {
          PeriodeTravailJustifiee periodeJustifiee = (PeriodeTravailJustifiee)periodeTravailCalcul;
          
          Periode periodeOrigine = periodeJustifiee.getPeriodeOrigine();
          if ((periodeOrigine != null) && (periodeOrigine.getDebut() != null) && (periodeOrigine.getDebut().estApresOuCoincideAvec(p_attribution.getDateAttribution()))) {
            p_periodesGelantesJustifiees.ajouter(periodeTravailCalcul);
          }
        }
      }
      if ((p_periodesGelantesJustifiees.getTaille() != 0) || (p_periodesGelantesDeclarees.getTaille() != 0)) {
        traitementActiviteReduite = true;
      }
      break;
    case 4: 
      p_ut.setNeutralisee(true);
      p_ut.setTypeNeutralisation(4);
      break;
    case 6: 
      p_ut.setNeutralisee(true);
      p_ut.setTypeNeutralisation(8);
      break;
    case 0: 
    default: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_ACTIVITE_REDUITE_STATUT_UT_INATTENDU", "Erreur sur le statut de l'Unité de Traitement lors du traitement de l'activité réduite.", null);
    }
    return traitementActiviteReduite;
  }
  
  protected static void postTraitementPeriodesGelantes(UniteTraitement p_ut, ResultatActiviteReduite p_resultatActiviteReduite)
  {
    p_ut.setNeutralisee(p_resultatActiviteReduite.isNeutralise());
    p_ut.setTypeNeutralisation(p_resultatActiviteReduite.getTypeNeutralisation());
    if (p_ut.getTypeNeutralisation() == 3) {
      p_ut.ajouterEvenement(new EvenementFinCumul(p_ut.getDateDebut()));
    }
  }
  
  protected static boolean preTraitementPeriodesDecalantes(AttributionSpec p_attribution, UniteTraitement p_ut, ChronologiePeriodes p_periodesDecalantes, ChronologiePeriodes p_periodesDecalantesJustifiees, ChronologiePeriodes p_periodesDecalantesDeclarees, ElementBaseIndemnisationSpec p_elementBaseIndemnisation)
    throws CoucheLogiqueException
  {
    boolean traitementActiviteReduite = false;
    switch (p_ut.getStatut())
    {
    case -1: 
    case 1: 
    case 2: 
    case 5: 
    case 7: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_ACTIVITE_REDUITE_STATUT_UT_INATTENDU", "Erreur sur le statut de l'Unité de Traitement lors du traitement de l'activité réduite.", null);
    case 3: 
      p_periodesDecalantes.iterer();
      while (p_periodesDecalantes.encoreSuivant())
      {
        ObjetChronoPeriodeCalcul periodeTravailCalcul = (ObjetChronoPeriodeCalcul)p_periodesDecalantes.elementSuivant();
        if ((periodeTravailCalcul instanceof PeriodeTravailJustifiee))
        {
          PeriodeTravailJustifiee periodeJustifiee = (PeriodeTravailJustifiee)periodeTravailCalcul;
          
          Periode periodeOrigine = periodeJustifiee.getPeriodeOrigine();
          if ((periodeOrigine != null) && (periodeOrigine.getDebut() != null) && (periodeOrigine.getDebut().estApresOuCoincideAvec(p_attribution.getDateAttribution()))) {
            p_periodesDecalantesJustifiees.ajouter(periodeTravailCalcul);
          }
        }
      }
      if ((p_periodesDecalantesJustifiees.getTaille() != 0) || (p_periodesDecalantesDeclarees.getTaille() != 0) || (p_ut.getMontantNetRevenusActiviteReprise() != null)) {
        traitementActiviteReduite = true;
      }
      break;
    case 4: 
      ElementBaseIndemnisation ebi = (ElementBaseIndemnisation)p_elementBaseIndemnisation;
      ebi.setEstMontantReduit(true);
      
      BigDecimal gains = new BigDecimal("0");
      BigDecimal heures = new BigDecimal("0");
      BigDecimal totalNbJourTravail = new BigDecimal("0");
      p_periodesDecalantes.iterer();
      while (p_periodesDecalantes.encoreSuivant())
      {
        ObjetChronoPeriodeCalcul periodeTravailCalcul = (ObjetChronoPeriodeCalcul)p_periodesDecalantes.elementSuivant();
        if ((periodeTravailCalcul instanceof DsmTravail))
        {
          if (((DsmTravail)periodeTravailCalcul).getGain() != null) {
            gains = gains.add(((DsmTravail)periodeTravailCalcul).getGain());
          }
          if (((DsmTravail)periodeTravailCalcul).getNombreHeures() != null) {
            heures = heures.add(((DsmTravail)periodeTravailCalcul).getNombreHeures());
          }
          totalNbJourTravail = totalNbJourTravail.add(new BigDecimal(periodeTravailCalcul.getDuree()));
        }
      }
      SyntheseARsurUT syntheseARsurUT = p_ut.getSyntheseARsurUT();
      syntheseARsurUT.setTotalGainUtilisePourDecalage(new QuantiteEuro(gains));
      syntheseARsurUT.setTotalHeureUtilisePourDecalage(new QuantiteEuro(heures));
      syntheseARsurUT.setCumulJourDeTravailAR(new Quantite(totalNbJourTravail, p_ut.getUniteParDefautQuantites()));
      break;
    case 6: 
      break;
    case 0: 
    default: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_ACTIVITE_REDUITE_STATUT_UT_INATTENDU", "Erreur sur le statut de l'Unité de Traitement lors du traitement de l'activité réduite.", null);
    }
    return traitementActiviteReduite;
  }
  
  public static void traitementPeriodesDecalantes(AttributionSpec p_attribution, ChronologiePeriodes p_periodesDecalantes, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduite, UniteTraitement p_ut, ConstituantsIndemnisation p_constituantsIndemnisation)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesDecalantesDeclarees = new ChronologiePeriodes();
    ChronologiePeriodes periodesDecalantesJustifiees = new ChronologiePeriodes();
    
    boolean traitementActiviteReduite = preTraitementPeriodesDecalantes(p_attribution, p_ut, p_periodesDecalantes, periodesDecalantesJustifiees, periodesDecalantesDeclarees, p_constituantsIndemnisation.getElementBaseIndemnisationCourant());
    if (traitementActiviteReduite)
    {
      ResultatActiviteReduite resultatActiviteReduite = appelleActiviteReduite(periodesDecalantesJustifiees, p_constituantsCalculActiviteReduite);
      
      postTraitementPeriodesDecalantes(p_ut, resultatActiviteReduite, p_constituantsIndemnisation, p_periodesDecalantes, p_attribution);
    }
  }
  
  protected static void postTraitementPeriodesDecalantes(UniteTraitement p_ut, ResultatActiviteReduite p_resultatActiviteReduite, ConstituantsIndemnisation p_constituantsIndemnisation, ChronologiePeriodes p_periodesDecalantes, AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    p_ut.getSyntheseARsurUT().setCumulJourDeTravailAR(new Quantite(p_resultatActiviteReduite.getCumulJourDeTravail(), UniteDuree.JOUR));
    
    p_ut.getSyntheseARsurUT().setTotalGainUtilisePourDecalage(new Quantite(p_resultatActiviteReduite.getGainPrisEnCompte(), UniteMonaitaire.EUROS));
    p_ut.getSyntheseARsurUT().setTotalHeureUtilisePourDecalage(new Quantite(p_resultatActiviteReduite.getNbHeuresPrisesEnCompte(), UniteDuree.HEURE));
    
    p_ut.getSyntheseARsurUT().setTotalGainActiviteReduiteJustifie(new Quantite(p_resultatActiviteReduite.getCumulGainJustifie(), UniteMonaitaire.EUROS));
    
    p_ut.getSyntheseARsurUT().setTotalNbHeureActiviteReduiteJustifie(new Quantite(p_resultatActiviteReduite.getCumulNbHeuresJustifiees(), UniteDuree.HEURE));
    if ((p_periodesDecalantes != null) || (p_ut.getMontantNetRevenusActiviteReprise() != null))
    {
      ElementBaseIndemnisation ebi = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
      ebi.setEstMontantReduit(true);
      p_ut.getSyntheseARsurUT().setMontantReduit(true);
      ebi.setTotalGainSurUt(p_resultatActiviteReduite.getCumulGainJustifie());
      if (p_ut.getMontantNetRevenusActiviteReprise() != null)
      {
        UniteTraitementForcee utForcee = GestionForcage.getUniteTraitementForcee(p_attribution.getDemande(), p_ut.getDateDebut(), p_ut.getDateFin(), false);
        ebi.setTotalGainSurUt(utForcee.getMontantNetRevenusActiviteReprise());
      }
    }
  }
  
  protected static ResultatActiviteReduite appelleActiviteReduite(ChronologiePeriodes p_periodesEmploi, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduite)
    throws CoucheLogiqueException
  {
    return ActiviteReduite.genererEvenementActiviteReduite(p_periodesEmploi, p_constituantsCalculActiviteReduite);
  }
}

/* Location:
 * Qualified Name:     TraitementActiviteReduite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */