package fr.unedic.cali.asu.cve13.p01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Decision;
import fr.unedic.cali.asu.produits.liquidation.dom.Rejet;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.dom.ComparateurDecisionSpec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.ElementComparaisonReexamen;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;

public class ComparateurDecision
  extends fr.unedic.cali.asu.liquidation.outilsfonctionnels.ComparateurDecision
  implements ComparateurDecisionSpec, OutilFonctionnel
{
  public static boolean estEgal(DecisionSpec p_decision1, DecisionSpec p_decision2)
  {
    boolean estEgal = false;
    if ((p_decision1 != null) && (p_decision2 != null)) {
      estEgal = (decisionEgal((Decision)p_decision1, (Decision)p_decision2)) && (pjiEgal((Decision)p_decision1, (Decision)p_decision2)) && (reglementEgal((Decision)p_decision1, (Decision)p_decision2)) && (montantBrutEgal((Decision)p_decision1, (Decision)p_decision2)) && (sjrEgal((Decision)p_decision1, (Decision)p_decision2)) && (dateAttributionEgal((Decision)p_decision1, (Decision)p_decision2));
    }
    return estEgal;
  }
  
  private static boolean pjiEgal(Decision p_decision1, Decision p_decision2)
  {
    if (((p_decision1 instanceof Attribution)) && ((p_decision2 instanceof Attribution)))
    {
      Attribution attributionDecision1 = (Attribution)p_decision1;
      Attribution attributionDecision2 = (Attribution)p_decision2;
      
      return attributionDecision1.getConstitutionPointDepartIndemnisation().getPji().equals(attributionDecision2.getConstitutionPointDepartIndemnisation().getPji());
    }
    return ((p_decision1 instanceof Rejet)) && ((p_decision2 instanceof Rejet));
  }
  
  private static boolean reglementEgal(Decision p_decision1, Decision p_decision2)
  {
    if (((p_decision1 instanceof Attribution)) && ((p_decision2 instanceof Attribution))) {
      return p_decision1.getReglementApplicable().getReglement().estNomReglementIdentique(p_decision2.getReglementApplicable().getReglement().getNomReglement());
    }
    return ((p_decision1 instanceof Rejet)) && ((p_decision2 instanceof Rejet));
  }
  
  private static boolean montantBrutEgal(Decision p_decision1, Decision p_decision2)
  {
    if (((p_decision1 instanceof Attribution)) && ((p_decision2 instanceof Attribution)))
    {
      Quantite montantBrutIndemnisationDecision1 = p_decision1.getConstitutionMontantsBruts() != null ? p_decision1.getConstitutionMontantsBruts().getMontantJournalierBrut() : null;
      
      Quantite montantBrutIndemnisationDecision2 = p_decision2.getConstitutionMontantsBruts() != null ? p_decision2.getConstitutionMontantsBruts().getMontantJournalierBrut() : null;
      
      return montantBrutIndemnisationDecision1.equals(montantBrutIndemnisationDecision2);
    }
    return ((p_decision1 instanceof Rejet)) && ((p_decision2 instanceof Rejet));
  }
  
  private static boolean sjrEgal(Decision p_decision1, Decision p_decision2)
  {
    if (((p_decision1 instanceof Attribution)) && ((p_decision2 instanceof Attribution)))
    {
      BigDecimal sjrAvant = null;
      BigDecimal sjrApres = null;
      
      Sjrip sjrpDecision1 = p_decision1.getConstitutionSjr() != null ? p_decision1.getConstitutionSjr().getSjrip() : null;
      Sjrip sjrpDecision2 = p_decision2.getConstitutionSjr() != null ? p_decision2.getConstitutionSjr().getSjrip() : null;
      
      sjrAvant = sjrpDecision1.getSjrInitial().getValeurMontant();
      sjrApres = sjrpDecision2.getSjrInitial().getValeurMontant();
      
      return sjrAvant.compareTo(sjrApres) == 0;
    }
    return ((p_decision1 instanceof Rejet)) && ((p_decision2 instanceof Rejet));
  }
  
  private static boolean dateAttributionEgal(Decision p_decision1, Decision p_decision2)
  {
    if (((p_decision1 instanceof Attribution)) && ((p_decision2 instanceof Attribution))) {
      return p_decision1.getDateAttribution().equals(p_decision2.getDateAttribution());
    }
    return ((p_decision1 instanceof Rejet)) && ((p_decision2 instanceof Rejet));
  }
  
  public static ArrayList rechercheDifferencesComparaisonDecision(DecisionSpec p_decision1, DecisionSpec p_decision2)
  {
    ArrayList listeDifferences = new ArrayList();
    if (!estEgal(p_decision1, p_decision2)) {
      if (decisionEgal(p_decision1, p_decision2))
      {
        Decision decisionAvant = (Decision)p_decision1;
        Decision decisionApres = (Decision)p_decision2;
        if (!pjiEgal(decisionAvant, decisionApres)) {
          alimenterPjiComparaisonDecision(decisionAvant, decisionApres, listeDifferences);
        }
        if (!reglementEgal(decisionAvant, decisionApres)) {
          alimenterReglementComparaisonDecision(decisionAvant, decisionApres, listeDifferences);
        }
        if (!montantBrutEgal(decisionAvant, decisionApres)) {
          alimenterMontantComparaisonDecision(decisionAvant, decisionApres, listeDifferences);
        }
        if (!sjrEgal(decisionAvant, decisionApres)) {
          alimenterSjrComparaisonDecision(decisionAvant, decisionApres, listeDifferences);
        }
        if (!dateAttributionEgal(decisionAvant, decisionApres)) {
          alimenterDateAttributionComparaisonDecision(decisionAvant, decisionApres, listeDifferences);
        }
      }
      else
      {
        alimenterDecisionComparaisonDecision(p_decision1, p_decision2, listeDifferences);
      }
    }
    return listeDifferences;
  }
  
  private static void alimenterPjiComparaisonDecision(Decision p_decisionAvant, Decision p_decisionApres, ArrayList p_liste)
  {
    String libelleElement = "Pji";
    Damj pjiAvant = null;
    Damj pjiApres = null;
    if ((p_decisionAvant instanceof Attribution))
    {
      Attribution attributionDecisionAvant = (Attribution)p_decisionAvant;
      pjiAvant = attributionDecisionAvant.getPji();
    }
    if ((p_decisionApres instanceof Attribution))
    {
      Attribution attributionDecisionApres = (Attribution)p_decisionApres;
      pjiApres = attributionDecisionApres.getPji();
    }
    if ((pjiAvant != null) || (pjiApres != null)) {
      alimenterDifferences(pjiAvant, pjiApres, libelleElement, p_liste);
    }
  }
  
  private static void alimenterReglementComparaisonDecision(Decision p_decisionAvant, Decision p_decisionApres, ArrayList p_liste)
  {
    String libelleElement = "Réglement Applicable";
    String reglementAvant = null;
    String reglementApres = null;
    if ((p_decisionAvant.getReglementApplicable() != null) && 
      (p_decisionAvant.getReglementApplicable().getReglement() != null)) {
      reglementAvant = p_decisionAvant.getReglementApplicable().getReglement().getLibelle();
    }
    if ((p_decisionApres.getReglementApplicable() != null) && 
      (p_decisionApres.getReglementApplicable().getReglement() != null)) {
      reglementApres = p_decisionApres.getReglementApplicable().getReglement().getLibelle();
    }
    if ((reglementAvant != null) || (reglementApres != null)) {
      alimenterDifferences(reglementAvant, reglementApres, libelleElement, p_liste);
    }
  }
  
  private static void alimenterDecisionComparaisonDecision(DecisionSpec p_decisionAvant, DecisionSpec p_decisionApres, ArrayList p_liste)
  {
    String libelleElement = "Libellé Décision";
    String typeDecisionAvant = null;
    String typeDecisionApres = null;
    String libelleDecisionAvant = null;
    String libelleDecisionApres = null;
    if (p_decisionAvant != null)
    {
      typeDecisionAvant = Integer.toString(p_decisionAvant.getNatureDecision());
      libelleDecisionAvant = (String)NaturesDecisions.s_libelleObjectifDecision.get(new BigDecimal(typeDecisionAvant));
    }
    if (p_decisionApres != null)
    {
      typeDecisionApres = Integer.toString(p_decisionApres.getNatureDecision());
      libelleDecisionApres = (String)NaturesDecisions.s_libelleObjectifDecision.get(new BigDecimal(typeDecisionApres));
    }
    alimenterDifferences(libelleDecisionAvant, libelleDecisionApres, libelleElement, p_liste);
  }
  
  private static void alimenterMontantComparaisonDecision(Decision p_decisionAvant, Decision p_decisionApres, ArrayList p_liste)
  {
    String libelleElement = "Montant brut";
    BigDecimal montantBrutAvant = null;
    BigDecimal montantBrutApres = null;
    if ((p_decisionAvant.getConstitutionMontantsBruts() != null) && 
      (p_decisionAvant.getConstitutionMontantsBruts().getMontantJournalierBrut() != null)) {
      montantBrutAvant = p_decisionAvant.getConstitutionMontantsBruts().getMontantJournalierBrut().getValeur();
    }
    if ((p_decisionApres.getConstitutionMontantsBruts() != null) && 
      (p_decisionApres.getConstitutionMontantsBruts().getMontantJournalierBrut() != null)) {
      montantBrutApres = p_decisionApres.getConstitutionMontantsBruts().getMontantJournalierBrut().getValeur();
    }
    if ((montantBrutAvant != null) || (montantBrutApres != null)) {
      alimenterDifferences(montantBrutAvant, montantBrutApres, libelleElement, p_liste);
    }
  }
  
  private static void alimenterSjrComparaisonDecision(Decision p_decisionAvant, Decision p_decisionApres, ArrayList p_liste)
  {
    String libelleElement = "Sjr";
    BigDecimal sjrAvant = null;
    BigDecimal sjrApres = null;
    if ((p_decisionAvant.getConstitutionSjr() != null) && 
      (p_decisionAvant.getConstitutionSjr().getSjrip() != null)) {
      sjrAvant = p_decisionAvant.getConstitutionSjr().getSjrip().getSjrInitial().getValeurMontant();
    }
    if ((p_decisionApres.getConstitutionSjr() != null) && 
      (p_decisionApres.getConstitutionSjr().getSjrip() != null)) {
      sjrApres = p_decisionApres.getConstitutionSjr().getSjrip().getSjrInitial().getValeurMontant();
    }
    if ((sjrAvant != null) || (sjrApres != null)) {
      alimenterDifferences(sjrAvant, sjrApres, libelleElement, p_liste);
    }
  }
  
  private static void alimenterDateAttributionComparaisonDecision(Decision p_decisionAvant, Decision p_decisionApres, ArrayList p_liste)
  {
    String libelleElement = "Date Attribution";
    Damj dateAttributionAvant = null;
    Damj dateAttributionApres = null;
    if (p_decisionAvant != null) {
      dateAttributionAvant = p_decisionAvant.getDateAttribution();
    }
    if (p_decisionApres != null) {
      dateAttributionApres = p_decisionApres.getDateAttribution();
    }
    if ((dateAttributionAvant != null) || (dateAttributionApres != null)) {
      alimenterDifferences(dateAttributionAvant, dateAttributionApres, libelleElement, p_liste);
    }
  }
  
  private static void alimenterDifferences(Object p_valeurAvant, Object p_valeurApres, String p_libelleElement, ArrayList p_liste)
  {
    ElementComparaisonReexamen elementDecision = new ElementComparaisonReexamen(p_libelleElement, p_valeurAvant, p_valeurApres);
    p_liste.add(elementDecision);
  }
}

/* Location:
 * Qualified Name:     ComparateurDecision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */