package fr.unedic.cali.asu.ddm16.p01.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.calcul.outilsfonctionnels.CreationPeriodeNonDeclareeSanction;
import fr.unedic.cali.calcul.dom.ConstituantsCalculActiviteReduiteSpec;
import fr.unedic.cali.calcul.dom.SyntheseARsurUT;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.periode.DsmTravail;
import fr.unedic.cali.calcul.dom.periode.PeriodePrime;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravailJustifiee;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.DeterminationActiviteConserveeReprise;
import fr.unedic.cali.calcul.outilsfonctionnels.DeterminerJustificatifsRevenusAR;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ResultatActiviteReduite;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodePANSConservee;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.UniteMonaitaire;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.UniteDuree;
import java.math.BigDecimal;
import java.util.Collection;

public class TraitementActiviteReduite
{
  public static void traitementPeriodesGelantes(UniteTraitement p_ut)
    throws CoucheLogiqueException
  {
    preTraitementPeriodesGelantes(p_ut);
  }
  
  public static void traitementPeriodesDecalantes(AttributionSpec p_attribution, ChronologiePeriodes p_periodesDecalantes, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduite, UniteTraitement p_ut)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesDecalantesDeclarees = new ChronologiePeriodes();
    ChronologiePeriodes periodesDecalantesJustifiees = new ChronologiePeriodes();
    ChronologiePeriodes periodeNonDeclareeSanction = null;
    ObjetChronoPeriodeCalcul periodeTravailCalcul = null;
    
    boolean traitementActiviteReduite = preTraitementPeriodesDecalantes(p_attribution, p_periodesDecalantes, p_constituantsCalculActiviteReduite, p_ut, periodesDecalantesDeclarees, periodesDecalantesJustifiees, periodeNonDeclareeSanction, periodeTravailCalcul);
    if (traitementActiviteReduite)
    {
      if (periodesDecalantesJustifiees.getTaille() != 0)
      {
        ResultatActiviteReduite resultatActiviteReduite = appelleActiviteReduite(periodesDecalantesJustifiees, p_constituantsCalculActiviteReduite, p_ut);
        
        postTraitementPeriodesDecalantes(p_ut, resultatActiviteReduite);
      }
      if (periodesDecalantesDeclarees.getTaille() != 0)
      {
        ResultatActiviteReduite resultatActiviteReduite = appelleActiviteReduite(periodesDecalantesDeclarees, p_constituantsCalculActiviteReduite, p_ut);
        
        postTraitementPeriodesDecalantes(p_ut, resultatActiviteReduite);
      }
    }
  }
  
  protected static ResultatActiviteReduite appelleActiviteReduite(ChronologiePeriodes p_periodesEmploi, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduite, UniteTraitement p_ut)
    throws CoucheLogiqueException
  {
    BigDecimal salaireSjr = null;
    if (p_constituantsCalculActiviteReduite.getSjrProduit() != null) {
      salaireSjr = p_constituantsCalculActiviteReduite.getSjrProduit().getSalaire();
    }
    DeterminerJustificatifsRevenusAR.traitementRevenusBS(p_periodesEmploi, p_ut.getDateDebut(), null);
    
    return ActiviteReduite.genererEvenementActiviteReduite(p_ut.getDateDebut(), p_periodesEmploi, salaireSjr);
  }
  
  protected static boolean preTraitementPeriodesDecalantes(AttributionSpec p_attribution, ChronologiePeriodes p_periodesDecalantes, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduite, UniteTraitement p_ut, ChronologiePeriodes p_periodesDecalantesDeclareees, ChronologiePeriodes p_periodesDecalantesJustifiees, ChronologiePeriodes p_periodeNonDeclareeSanction, ObjetChronoPeriodeCalcul p_periodeTravailCalcul)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesDecalantesJustifiees = new ChronologiePeriodes();
    boolean traitementActiviteReduite = false;
    
    p_periodesDecalantes.iterer();
    while (p_periodesDecalantes.encoreSuivant())
    {
      p_periodeTravailCalcul = (ObjetChronoPeriodeCalcul)p_periodesDecalantes.elementSuivant();
      if (((p_periodeTravailCalcul instanceof PeriodeTravailJustifiee)) || ((p_periodeTravailCalcul instanceof PeriodePrime)))
      {
        boolean periodeAIgnorer = DeterminationActiviteConserveeReprise.determinerTypeActivite(null, p_ut, p_periodeTravailCalcul, p_attribution);
        if (!periodeAIgnorer) {
          periodesDecalantesJustifiees.ajouter(p_periodeTravailCalcul);
        }
      }
    }
    boolean presencePansConservee = !periodesDecalantesJustifiees.copier(new FiltrePeriodePANSConservee()).estVide();
    switch (p_ut.getStatut())
    {
    case 1: 
    case 2: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_ACTIVITE_REDUITE_STATUT_UT_INATTENDU", "Erreur sur le statut de l'Unité de Traitement lors du traitement de l'activité réduite.", null);
    case 3: 
    case 7: 
      if (periodesDecalantesJustifiees.getTaille() != 0)
      {
        p_periodesDecalantesJustifiees.ajouter(periodesDecalantesJustifiees);
        traitementActiviteReduite = true;
      }
      p_periodeNonDeclareeSanction = CreationPeriodeNonDeclareeSanction.creerPeriodeNonDeclareeSanction(p_attribution.getDemandeur(), p_ut.getDateDebut(), p_periodesDecalantes, false);
      
      ChronologiePeriodes pndSanctionsConverties = new ChronologiePeriodes();
      p_periodeNonDeclareeSanction.iterer();
      while (p_periodeNonDeclareeSanction.encoreSuivant())
      {
        fr.unedic.cali.asu.calcul.dom.periode.PeriodeNonDeclareeSanction pndSanctionAsu = (fr.unedic.cali.asu.calcul.dom.periode.PeriodeNonDeclareeSanction)p_periodeNonDeclareeSanction.elementSuivant();
        fr.unedic.cali.asu.ddm16.p01.calcul.dom.periode.PeriodeNonDeclareeSanction pndSanctionProduit = new fr.unedic.cali.asu.ddm16.p01.calcul.dom.periode.PeriodeNonDeclareeSanction(pndSanctionAsu);
        
        pndSanctionsConverties.ajouter(pndSanctionProduit);
      }
      if ((pndSanctionsConverties != null) && (!pndSanctionsConverties.estVide())) {
        p_ut.getListePNDs().add(pndSanctionsConverties);
      }
      break;
    case 4: 
      BigDecimal gains = new BigDecimal("0");
      BigDecimal heures = new BigDecimal("0");
      BigDecimal totalNbJourTravail = new BigDecimal("0");
      p_periodesDecalantes.iterer();
      while (p_periodesDecalantes.encoreSuivant())
      {
        p_periodeTravailCalcul = (ObjetChronoPeriodeCalcul)p_periodesDecalantes.elementSuivant();
        if ((p_periodeTravailCalcul instanceof DsmTravail))
        {
          if (((DsmTravail)p_periodeTravailCalcul).getGain() != null) {
            gains = gains.add(((DsmTravail)p_periodeTravailCalcul).getGain());
          }
          if (((DsmTravail)p_periodeTravailCalcul).getNombreHeures() != null) {
            heures = heures.add(((DsmTravail)p_periodeTravailCalcul).getNombreHeures());
          }
          totalNbJourTravail = totalNbJourTravail.add(new BigDecimal(p_periodeTravailCalcul.getDuree()));
        }
      }
      SyntheseARsurUT syntheseARsurUT = p_ut.getSyntheseARsurUT();
      syntheseARsurUT.setTotalGainUtilisePourDecalage(new QuantiteEuro(gains));
      syntheseARsurUT.setTotalHeureUtilisePourDecalage(new QuantiteEuro(heures));
      syntheseARsurUT.setCumulJourDeTravailAR(new Quantite(totalNbJourTravail, p_ut.getUniteParDefautQuantites()));
      break;
    case 6: 
      break;
    case 5: 
      p_periodesDecalantes.iterer();
      while (p_periodesDecalantes.encoreSuivant())
      {
        p_periodeTravailCalcul = (ObjetChronoPeriodeCalcul)p_periodesDecalantes.elementSuivant();
        if ((p_periodeTravailCalcul instanceof DsmTravail)) {
          p_periodesDecalantesDeclareees.ajouter(p_periodeTravailCalcul);
        }
      }
      if (p_periodesDecalantesDeclareees.getTaille() != 0) {
        traitementActiviteReduite = true;
      }
      break;
    default: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_ACTIVITE_REDUITE_STATUT_UT_INATTENDU", "Erreur sur le statut de l'Unité de Traitement lors du traitement de l'activité réduite.", null);
    }
    BigDecimal sjr = p_constituantsCalculActiviteReduite.getSjrProduit().getSalaire();
    p_ut.getSyntheseARsurUT().setSeuilRemunerationAR(new Quantite(ActiviteReduite.calculerSeuilMensuel(p_ut.getDateDebut(), sjr, new BigDecimal("0"), false, false, new BigDecimal(0), presencePansConservee), p_ut.getUniteParDefautQuantites()));
    
    return traitementActiviteReduite;
  }
  
  protected static void postTraitementPeriodesDecalantes(UniteTraitement p_ut, ResultatActiviteReduite p_resultatActiviteReduite)
    throws CoucheLogiqueException
  {
    if (p_resultatActiviteReduite.getSeuilRemuneration() != null) {
      p_ut.getSyntheseARsurUT().setSeuilRemunerationAR(new Quantite(p_resultatActiviteReduite.getSeuilRemuneration(), p_ut.getUniteParDefautQuantites()));
    }
    if (p_resultatActiviteReduite.getSeuilRemunerationAvecActConservee() != null) {
      p_ut.getSyntheseARsurUT().setSeuilRemunerationARAvecActConservee(new Quantite(p_resultatActiviteReduite.getSeuilRemunerationAvecActConservee(), p_ut.getUniteParDefautQuantites()));
    }
    p_ut.getSyntheseARsurUT().setTotalGainUtilisePourDecalage(new Quantite(p_resultatActiviteReduite.getGainPrisEnCompte(), UniteMonaitaire.EUROS));
    p_ut.getSyntheseARsurUT().setTotalHeureUtilisePourDecalage(new Quantite(p_resultatActiviteReduite.getNbHeuresPrisesEnCompte(), UniteDuree.HEURE));
    
    p_ut.getSyntheseARsurUT().setTotalGainICCPConserves(new Quantite(p_resultatActiviteReduite.getCumulGainICCPConserves(), UniteMonaitaire.EUROS));
    
    p_ut.getSyntheseARsurUT().setTotalGainICCPRepris(new Quantite(p_resultatActiviteReduite.getCumulGainICCPRepris(), UniteMonaitaire.EUROS));
    
    p_ut.getSyntheseARsurUT().setCumulJourDeTravailAR(new Quantite(p_resultatActiviteReduite.getCumulJourDeTravail(), UniteDuree.JOUR));
    
    p_ut.getSyntheseARsurUT().setTotalGainActiviteReduiteJustifie(new Quantite(p_resultatActiviteReduite.getCumulGainJustifie(), UniteMonaitaire.EUROS));
    
    p_ut.getSyntheseARsurUT().setTotalNbHeureActiviteReduiteJustifie(new Quantite(p_resultatActiviteReduite.getCumulNbHeuresJustifiees(), UniteDuree.HEURE));
  }
  
  protected static void preTraitementPeriodesGelantes(UniteTraitement p_ut)
    throws CoucheLogiqueException
  {
    switch (p_ut.getStatut())
    {
    case 1: 
    case 2: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_ACTIVITE_REDUITE_STATUT_UT_INATTENDU", "Erreur sur le statut de l'Unité de Traitement lors du traitement de l'activité réduite.", null);
    case 3: 
    case 7: 
      break;
    case 4: 
      p_ut.setNeutralisee(true);
      p_ut.setTypeNeutralisation(4);
      break;
    case 5: 
    case 6: 
    default: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_ACTIVITE_REDUITE_STATUT_UT_INATTENDU", "Erreur sur le statut de l'Unité de Traitement lors du traitement de l'activité réduite.", null);
    }
  }
}

/* Location:
 * Qualified Name:     TraitementActiviteReduite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */