package fr.unedic.cali.asu.ddm16.p01.liquidation.outilsfonctionnels;

import fr.unedic.cali.ari.dom.Demande;
import fr.unedic.cali.ari.dom.DonneesForcees;
import fr.unedic.cali.ari.dom.ElementDroit;
import fr.unedic.cali.ari.outilsfonctionnels.OutilElementDroit;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.util.Collection;

public class VerificationDonneesForcees
  implements OutilFonctionnel
{
  private static final int AGE_LEGAL_OBTENTION_ACC = 55;
  
  public static void verifierDonneesForcees(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)p_demande;
    DonneesForcees donneesForcees = demande.getDonneesForcees();
    if (donneesForcees != null)
    {
      Collection listeEltDroit = donneesForcees.getCopieCollectionElementsDroitType("6");
      if ((listeEltDroit != null) && (!listeEltDroit.isEmpty()))
      {
        controleChampsObligatoires(listeEltDroit);
        
        controleDateExamen(listeEltDroit, p_demande);
        
        controlePremierJourIndemnisable(listeEltDroit, p_demande);
      }
    }
  }
  
  private static void controleDateExamen(Collection p_listeEltDroit, DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "DATE_EXAMEN" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    Damj dateExamen = eltDroit.getDate1Generique();
    if (!OutillagePEC.estContenueDansUnePecIndemnisable(p_demande.getDemandeur(), dateExamen)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_ARI_DATE_EXAMEN_HORS_PEC", 1);
    }
  }
  
  private static void controlePremierJourIndemnisable(Collection p_listeEltDroit, DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "DATE_EXAMEN" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    Damj dateExamen = eltDroit.getDate1Generique();
    nomEltRecherche = new String[] { "PJI" };
    eltDroit = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    Damj pji = eltDroit.getDate1Generique();
    if (pji.estAvant(dateExamen)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AATC_PJI_AVANT_DATE_EXAMEN", 1);
    }
    DureeCalendaire ageMaxDepartRetraite = OutilRetraite.getInstance().getAgeMaxDepartRetraite(p_demande.getDemandeur());
    if (p_demande.getDemandeur().getAgeALaDate(pji.getDebutMois()).compareTo(ageMaxDepartRetraite) >= 0) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AATC_PJI_APRES_ARRET_ALLOCATION", new String[] { OutilRetraite.getInstance().formaterAge(ageMaxDepartRetraite) }, 1);
    }
    if (p_demande.getDemandeur().getAgeALaDate(pji).getAnnees() < 55) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AATC_PJI_AVANT_OBTENTION", 1);
    }
  }
  
  private static void controleChampsObligatoires(Collection p_listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "DATE_EXAMEN" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    if ((eltDroit == null) || (eltDroit.getDate1Generique() == null)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_ARI_DATE_EXAMEN", 1);
    }
    nomEltRecherche = new String[] { "PJI" };
    eltDroit = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    if ((eltDroit == null) || (eltDroit.getDate1Generique() == null)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_ARI_PJI_NON_RENSEIGNE", 1);
    }
    nomEltRecherche = new String[] { "SALAIRE_JOURNALIER_REFERENCE" };
    eltDroit = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    if ((eltDroit == null) || (eltDroit.getQuantiteGenerique() == null)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AATC_SJR_NON_RENSEIGNE", 1);
    }
    nomEltRecherche = new String[] { "TERME_PRC" };
    eltDroit = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    if ((eltDroit == null) || (eltDroit.getDate1Generique() == null)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AATC_TERME_PRC_NON_RENSEIGNE", 1);
    }
  }
}

/* Location:
 * Qualified Name:     VerificationDonneesForcees
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */