package fr.unedic.cali.asu.dom;

import fr.unedic.cali.asu.outilsfonctionnels.OutilMappingSjmSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.produits.liquidation.dom.ElementChomageSansRupture;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodePensionInvaliditeChaineeSpec;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.ElementBaseIndemnisationSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.QuantiteDroit;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

public class ElementBaseIndemnisation
  implements ElementBaseIndemnisationSpec
{
  private static final long serialVersionUID = -6178910924363309998L;
  private BigDecimal mCoefficientSaisonnier = null;
  private BigDecimal mCoefficientTempsPartiel = null;
  private BigDecimal mMontantAvantageVieillesse = BigDecimal.ZERO;
  private BigDecimal mCoefficientAvantageVieillesse = BigDecimal.ZERO;
  private BigDecimal mTauxAvantageVieillesse = BigDecimal.ZERO;
  private BigDecimal mMontantPensionInvaliditeADeduire = BigDecimal.ZERO;
  private SalaireJournalierSpec mSalaireJournalier = null;
  private Sjc mSjc = null;
  private BigDecimal mCoefficientSanctionReduction = null;
  private Boolean mAvecPrecompteCRC = null;
  private int mTypeCaractereSaisonnierRetenu;
  private boolean mIsConditionCaractereSaisonnierParRythme = false;
  private int mCodeEmploiA2B;
  private ReglementApplicableSpec mReglementApplicableMontantRetenu;
  private Periode mPrc;
  private int mNbJoursEmploiSurPrc;
  private PeriodeAvantageVieillesse mPeriodeAvantageVieillesse = null;
  private BigDecimal mMontantPeriodeInvalidite = null;
  private BigDecimal mMontantPreavis = null;
  private boolean mIsSjrBaseSurPourcentageSMIC = false;
  private Reglement mReglementApplicable;
  private Quantite mAffiliationRequisePourPRA;
  private SalaireReference mSalaireReference;
  private BigDecimal mNombreHeureTravaillesEtendu;
  private BigDecimal mNombreHeuresTravailleesPlafonnees = null;
  private BigDecimal nombreHeuresTravailleesMajoree = null;
  private int mCoefficientHoraireJour = 0;
  private Damj mDateEffetAV = null;
  private transient Damj mDateMaintienEuropeen = null;
  private transient ProduitSpec mProduitAreActif = null;
  private Collection mListePensionInvalidite = null;
  private Boolean mEstProduitGerantPensionInvalidite = null;
  private ElementBaseIndemnisation mElementBaseIndemnisationDroitAssocie = null;
  private int mCompetenceAdministrative;
  private Quantite mDureeInitialeMaintien = null;
  private Quantite mDureeIndemnisationEffective = null;
  private Collection mListeCarences = null;
  private ConventionGestionSpec mConventionGestion = null;
  private boolean mIsCapitalRetenuCourant;
  private boolean mIsMontantRetenuCourant;
  private ArrayList mListeDurees = new ArrayList();
  private Quantite mDureeProlongationTheorique = null;
  private ElementChomageSansRupture mElementChomageSansRupture = null;
  private ProduitAsuSpec mProduitMontantRetenu = null;
  private BigDecimal mSeuilMensuelPansConservees = null;
  private MaintienEuropeen mMaintienEuropeen = null;
  private Sjr mSjrInitial = null;
  private Sjc mSjcInitial = null;
  private int mCompetenceFinanciere;
  private Reglement mReglementMontantRetenu;
  private Competences competence;
  private Collection<ElementBaseIndemnisation> listeSousEBI;
  private boolean estDureePostPrimeEpuisee;
  private int dureeFranchiseCp;
  private int dureeFranchiseSalaire;
  private int quantiteMensConsomFranchiseCp;
  private int quantiteMensConsomFranchiseSalaire;
  private int rangAllongementPRA = 0;
  private int nombreJoursDelaiAttente = 0;
  private BigDecimal montantBrut;
  private BigDecimal montantBrutPrecompte;
  private Damj dateLimiteIndemnisation = null;
  private BigDecimal montantCRA = null;
  private boolean clauseRattrapage = false;
  private boolean contextePAPPresent = false;
  private boolean contextePapParlementaire = false;
  private boolean estMontantAZero = false;
  private int nombreJoursInactivite = 0;
  private boolean expatrieApresConvention17 = false;
  
  public ProduitSpec getProduitAreActif()
  {
    return mProduitAreActif;
  }
  
  public void setProduitAreActif(ProduitSpec produitAreActif)
  {
    mProduitAreActif = produitAreActif;
  }
  
  public BigDecimal getCoefficientAvantageVieillesse()
  {
    return mCoefficientAvantageVieillesse;
  }
  
  public BigDecimal getCoefficientSaisonnier()
  {
    return mCoefficientSaisonnier;
  }
  
  public BigDecimal getCoefficientTempsPartiel()
  {
    return mCoefficientTempsPartiel;
  }
  
  public BigDecimal getMontantPensionInvaliditeADeduire()
  {
    return mMontantPensionInvaliditeADeduire;
  }
  
  public Sjc getSjc()
  {
    return mSjc;
  }
  
  public Sjr getSjr()
  {
    if (mSalaireJournalier != null) {
      return OutilMappingSjmSjr.convertirSjr(mSalaireJournalier);
    }
    return null;
  }
  
  public Sjm getSjm()
  {
    return OutilMappingSjmSjr.convertirSjm(mSalaireJournalier);
  }
  
  public void setCoefficientSaisonnier(BigDecimal coefficientSaisonnier)
  {
    mCoefficientSaisonnier = coefficientSaisonnier;
  }
  
  public void setCoefficientTempsPartiel(BigDecimal coefficientTempsPartiel)
  {
    mCoefficientTempsPartiel = coefficientTempsPartiel;
  }
  
  public void setCoefficientAvantageVieillesse(BigDecimal coefficientAvantageVieillesse)
  {
    mCoefficientAvantageVieillesse = coefficientAvantageVieillesse;
  }
  
  public void setMontantPensionInvaliditeADeduire(BigDecimal montantPensionInvaliditeADeduire)
  {
    mMontantPensionInvaliditeADeduire = montantPensionInvaliditeADeduire;
  }
  
  public void setSjr(Sjr sjr)
  {
    mSalaireJournalier = sjr;
  }
  
  public void setSjc(Sjc sjc)
  {
    mSjc = sjc;
  }
  
  public BigDecimal getTauxAvantageVieillesse()
  {
    return mTauxAvantageVieillesse;
  }
  
  public void setTauxAvantageVieillesse(BigDecimal tauxAvantageVieillesse)
  {
    mTauxAvantageVieillesse = tauxAvantageVieillesse;
  }
  
  public Boolean getAvecPrecompteCRC()
  {
    return mAvecPrecompteCRC;
  }
  
  public void setAvecPrecompteCRC(Boolean avecPrecompteCRC)
  {
    mAvecPrecompteCRC = avecPrecompteCRC;
  }
  
  public BigDecimal getCoefficientSanctionReduction()
  {
    return mCoefficientSanctionReduction;
  }
  
  public void setCoefficientSanctionReduction(BigDecimal coefficientSanctionReduction)
  {
    mCoefficientSanctionReduction = coefficientSanctionReduction;
  }
  
  public BigDecimal getMontantAvantageVieillesse()
  {
    return mMontantAvantageVieillesse;
  }
  
  public void setMontantAvantageVieillesse(BigDecimal montantAvantageVieillesse)
  {
    mMontantAvantageVieillesse = montantAvantageVieillesse;
  }
  
  public int getTypeCaractereSaisonnierRetenu()
  {
    return mTypeCaractereSaisonnierRetenu;
  }
  
  public void setTypeCaractereSaisonnierRetenu(int typeCaractereSaisonnierRetenu)
  {
    mTypeCaractereSaisonnierRetenu = typeCaractereSaisonnierRetenu;
  }
  
  public boolean isConditionCaractereSaisonnierParRythme()
  {
    return mIsConditionCaractereSaisonnierParRythme;
  }
  
  public void setIsConditionCaractereSaisonnierParRythme(boolean activite3Sur5)
  {
    mIsConditionCaractereSaisonnierParRythme = activite3Sur5;
  }
  
  public boolean isSjrBaseSurPourcentageSMIC()
  {
    return mIsSjrBaseSurPourcentageSMIC;
  }
  
  public void setIsSjrBaseSurPourcentageSMIC(boolean isSjrBaseSurPourcentageSMIC)
  {
    mIsSjrBaseSurPourcentageSMIC = isSjrBaseSurPourcentageSMIC;
  }
  
  public int getCodeEmploiA2B()
  {
    return mCodeEmploiA2B;
  }
  
  public void setCodeEmploiA2B(int codeEmploiA2B)
  {
    mCodeEmploiA2B = codeEmploiA2B;
  }
  
  public ReglementApplicableSpec getReglementApplicableMontantRetenu()
  {
    return mReglementApplicableMontantRetenu;
  }
  
  public void setReglementApplicableMontantRetenu(ReglementApplicableSpec reglementApplicableMontantRetenu)
  {
    mReglementApplicableMontantRetenu = reglementApplicableMontantRetenu;
  }
  
  public ObjetMetierSpec copie()
  {
    ElementBaseIndemnisation copie = new ElementBaseIndemnisation();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    ElementBaseIndemnisation copieEbi = (ElementBaseIndemnisation)copie;
    if (getSjc() != null) {
      mSjc = ((Sjc)getSjc().copie());
    }
    if (getSjr() != null) {
      mSalaireJournalier = ((Sjr)getSjr().copie());
    }
    mCoefficientSaisonnier = getCoefficientSaisonnier();
    mCoefficientTempsPartiel = getCoefficientTempsPartiel();
    
    mIsConditionCaractereSaisonnierParRythme = isConditionCaractereSaisonnierParRythme();
    mTypeCaractereSaisonnierRetenu = getTypeCaractereSaisonnierRetenu();
    
    mIsSjrBaseSurPourcentageSMIC = isSjrBaseSurPourcentageSMIC();
    
    mCoefficientAvantageVieillesse = getCoefficientAvantageVieillesse();
    mTauxAvantageVieillesse = getTauxAvantageVieillesse();
    mMontantAvantageVieillesse = getMontantAvantageVieillesse();
    
    mAvecPrecompteCRC = getAvecPrecompteCRC();
    mMontantPensionInvaliditeADeduire = getMontantPensionInvaliditeADeduire();
    mCoefficientSanctionReduction = getCoefficientSanctionReduction();
    mCodeEmploiA2B = getCodeEmploiA2B();
    mReglementApplicableMontantRetenu = getReglementApplicableMontantRetenu();
    
    dateLimiteIndemnisation = getDateLimiteIndemnisation();
    
    mReglementApplicable = getReglementApplicable();
    mAffiliationRequisePourPRA = getAffiliationRequisePourPRA();
    mNombreHeureTravaillesEtendu = getNombreHeureTravaillesEtendu();
    nombreHeuresTravailleesMajoree = getNombreHeuresTravailleesMajoree();
    
    mSalaireReference = getSalaireReference();
    copieEbi.setDateMaintienEuropeen(getDateMaintienEuropeen());
    
    copieEbi.setEstProduitGerantPensionInvalidite(getEstProduitGerantPensionInvalidite());
    copieEbi.setPrc(getPrc());
    copieEbi.setNbJoursEmploiSurPrc(getNbJoursEmploiSurPrc());
    copieEbi.setNombreHeuresTravailleesPlafonnees(getNombreHeuresTravailleesPlafonnees());
    copieEbi.setCoefficientHoraireJour(getCoefficientHoraireJour());
    copieEbi.setMontantPreavis(getMontantPreavis());
    copieEbi.setProduitAreActif(getProduitAreActif());
    if (getListePensionInvalidite() != null)
    {
      ArrayList listePensionInvalidite = new ArrayList();
      copieEbi.setListePensionInvalidite(listePensionInvalidite);
      
      PeriodePensionInvaliditeChaineeSpec pensionInvalidite = null;
      Iterator iter = getListePensionInvalidite().iterator();
      while (iter.hasNext())
      {
        pensionInvalidite = (PeriodePensionInvaliditeChaineeSpec)iter.next();
        listePensionInvalidite.add(pensionInvalidite.copie());
      }
    }
    copieEbi.setElementBaseIndemnisationDroitAssocie(getElementBaseIndemnisationDroitAssocie());
    
    mCompetenceAdministrative = getCompetenceAdministrative();
    mDureeInitialeMaintien = getDureeInitialeMaintien();
    mDureeIndemnisationEffective = getDureeIndemnisationEffective();
    if ((getListeCarences() != null) && (!getListeCarences().isEmpty()))
    {
      ArrayList listeCarences = new ArrayList();
      copieEbi.setListeCarences(listeCarences);
      
      CarencePrefixeAFixer carence = null;
      Iterator iterCarence = getListeCarences().iterator();
      while (iterCarence.hasNext())
      {
        carence = (CarencePrefixeAFixer)iterCarence.next();
        listeCarences.add(carence.copie());
      }
    }
    mConventionGestion = getConventionGestion();
    mIsCapitalRetenuCourant = isCapitalRetenuCourant();
    mIsMontantRetenuCourant = isMontantRetenuCourant();
    if ((getListeDurees() != null) && (!getListeDurees().isEmpty()))
    {
      ArrayList listeDuree = new ArrayList();
      copieEbi.setListeDurees(listeDuree);
      
      QuantiteDroit duree = null;
      Iterator iterDuree = getListeDurees().iterator();
      while (iterDuree.hasNext())
      {
        duree = (QuantiteDroit)iterDuree.next();
        listeDuree.add(duree.copie());
      }
    }
    mDureeProlongationTheorique = getDureeProlongationTheorique();
    mElementChomageSansRupture = getElementChomageSansRupture();
    mProduitMontantRetenu = getProduitMontantRetenu();
    mSeuilMensuelPansConservees = getSeuilMensuelPansConservees();
    mMaintienEuropeen = getMaintienEuropeen();
    
    estDureePostPrimeEpuisee = isEstDureePostPrimeEpuisee();
    if (getSjcInitial() != null) {
      mSjcInitial = ((Sjc)getSjcInitial().copie());
    }
    if (getSjrInitial() != null) {
      mSjrInitial = ((Sjr)getSjrInitial().copie());
    }
    mCompetenceFinanciere = getCompetenceFinanciere();
    mReglementMontantRetenu = getReglementMontantRetenu();
    copieEbi.setProduitAreActif(getProduitAreActif());
    copieEbi.setCompetence(getCompetence());
    if ((getListeSousEBI() != null) && (!getListeSousEBI().isEmpty()))
    {
      Iterator<ElementBaseIndemnisation> itEbi = getListeSousEBI().iterator();
      ArrayList<ElementBaseIndemnisation> nouvelleListe = new ArrayList();
      while (itEbi.hasNext()) {
        nouvelleListe.add((ElementBaseIndemnisation)((ElementBaseIndemnisation)itEbi.next()).copie());
      }
      copieEbi.setListeSousEBI(nouvelleListe);
    }
    copieEbi.setDureeFranchiseCp(getDureeFranchiseCp());
    copieEbi.setDureeFranchiseSalaire(getDureeFranchiseSalaire());
    copieEbi.setQuantiteMensConsomFranchiseCp(getQuantiteMensConsomFranchiseCp());
    copieEbi.setQuantiteMensConsomFranchiseSalaire(getQuantiteMensConsomFranchiseSalaire());
    copieEbi.setRangAllongementPRA(getRangAllongementPRA());
    copieEbi.setQuantiteMensConsomFranchiseCp(getQuantiteMensConsomFranchiseCp());
    copieEbi.setQuantiteMensConsomFranchiseSalaire(getQuantiteMensConsomFranchiseSalaire());
    copieEbi.setNombreJoursDelaiAttente(getNombreJoursDelaiAttente());
    copieEbi.setDureeFranchiseCp(getDureeFranchiseCp());
    copieEbi.setDureeFranchiseSalaire(getDureeFranchiseSalaire());
    copieEbi.setMontantCRA(getMontantCRA());
    copieEbi.setClauseRattrapage(isClauseRattrapage());
    copieEbi.setMontantBrut(getMontantBrut());
    copieEbi.setMontantBrutPrecompte(getMontantBrutPrecompte());
    copieEbi.setContextePAPPresent(isContextePAPPresent());
    copieEbi.setContextePapParlementaire(isContextePapParlementaire());
    
    copieEbi.setNombreJoursInactivite(getNombreJoursInactivite());
    
    copieEbi.setExpatrieApresConvention17(isExpatrieApresConvention17());
    copieEbi.setEstMontantAZero(estMontantAZero());
  }
  
  public Reglement getReglementApplicable()
  {
    return mReglementApplicable;
  }
  
  public void setReglementApplicable(Reglement reglementApplicable)
  {
    mReglementApplicable = reglementApplicable;
  }
  
  public Quantite getAffiliationRequisePourPRA()
  {
    return mAffiliationRequisePourPRA;
  }
  
  public void setAffiliationRequisePourPRA(Quantite affiliationRequisePourPRA)
  {
    mAffiliationRequisePourPRA = affiliationRequisePourPRA;
  }
  
  public BigDecimal getNombreHeureTravaillesEtendu()
  {
    return mNombreHeureTravaillesEtendu;
  }
  
  public void setNombreHeureTravaillesEtendu(BigDecimal nombreHeureTravaillesEtendu)
  {
    mNombreHeureTravaillesEtendu = nombreHeureTravaillesEtendu;
  }
  
  public SalaireReference getSalaireReference()
  {
    return mSalaireReference;
  }
  
  public void setSalaireReference(SalaireReference salaireReference)
  {
    mSalaireReference = salaireReference;
  }
  
  public Damj getDateFinPRC()
  {
    if (getPrc() != null) {
      return getPrc().getFin();
    }
    return null;
  }
  
  public void setPrc(Periode prc)
  {
    mPrc = prc;
  }
  
  public Periode getPrc()
  {
    return mPrc;
  }
  
  public int getNbJoursEmploiSurPrc()
  {
    return mNbJoursEmploiSurPrc;
  }
  
  public void setNbJoursEmploiSurPrc(int nbJoursEmploiSurPrc)
  {
    mNbJoursEmploiSurPrc = nbJoursEmploiSurPrc;
  }
  
  public int getCoefficientHoraireJour()
  {
    return mCoefficientHoraireJour;
  }
  
  public void setCoefficientHoraireJour(int coefficientHoraireJour)
  {
    mCoefficientHoraireJour = coefficientHoraireJour;
  }
  
  public BigDecimal getNombreHeuresTravailleesPlafonnees()
  {
    return mNombreHeuresTravailleesPlafonnees;
  }
  
  public void setNombreHeuresTravailleesPlafonnees(BigDecimal nombreHeuresTravailleesPlafonnees)
  {
    mNombreHeuresTravailleesPlafonnees = nombreHeuresTravailleesPlafonnees;
  }
  
  public Damj getDateEffetAV()
  {
    return mDateEffetAV;
  }
  
  public void setDateEffetAV(Damj dateEffetAV)
  {
    mDateEffetAV = dateEffetAV;
  }
  
  public Damj getDateEntreeEnStage()
  {
    return null;
  }
  
  public BigDecimal getSjrInitialForce()
  {
    return null;
  }
  
  public BigDecimal getCoefSaisonnierARE()
  {
    return null;
  }
  
  public BigDecimal getCoefTPARE()
  {
    return null;
  }
  
  public PeriodeAvantageVieillesse getPeriodeAvantageVieillesse()
  {
    return mPeriodeAvantageVieillesse;
  }
  
  public void setPeriodeAvantageVieillesse(PeriodeAvantageVieillesse periodeAvantageVieillesse)
  {
    mPeriodeAvantageVieillesse = periodeAvantageVieillesse;
  }
  
  public BigDecimal getMontantPeriodeInvalidite()
  {
    return mMontantPeriodeInvalidite;
  }
  
  public void setMontantPeriodeInvalidite(BigDecimal montantPeriodeInvalidite)
  {
    mMontantPeriodeInvalidite = montantPeriodeInvalidite;
  }
  
  public DureeCalendaire getAgeFinMoisDateAttribution()
  {
    return null;
  }
  
  public BigDecimal getMontantPreavis()
  {
    return mMontantPreavis;
  }
  
  public void setMontantPreavis(BigDecimal montantPreavis)
  {
    mMontantPreavis = montantPreavis;
  }
  
  public Damj getDateMaintienEuropeen()
  {
    return mDateMaintienEuropeen;
  }
  
  public void setDateMaintienEuropeen(Damj dateMaintienEuropeen)
  {
    mDateMaintienEuropeen = dateMaintienEuropeen;
  }
  
  public SalaireJournalierSpec getSalaireJournalier()
  {
    return mSalaireJournalier;
  }
  
  public void setSalaireJournalier(SalaireJournalierSpec salaireJournalier)
  {
    mSalaireJournalier = salaireJournalier;
  }
  
  public Collection getListePensionInvalidite()
  {
    return mListePensionInvalidite;
  }
  
  public void setListePensionInvalidite(Collection listePensionInvalidite)
  {
    mListePensionInvalidite = listePensionInvalidite;
  }
  
  public Boolean getEstProduitGerantPensionInvalidite()
  {
    return mEstProduitGerantPensionInvalidite;
  }
  
  public void setEstProduitGerantPensionInvalidite(Boolean estProduitGerantPensionInvalidite)
  {
    mEstProduitGerantPensionInvalidite = estProduitGerantPensionInvalidite;
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisationDroitAssocie()
  {
    return mElementBaseIndemnisationDroitAssocie;
  }
  
  public void setElementBaseIndemnisationDroitAssocie(ElementBaseIndemnisation ebiDroitAssocie)
  {
    mElementBaseIndemnisationDroitAssocie = ebiDroitAssocie;
  }
  
  public int getCompetenceAdministrative()
  {
    return mCompetenceAdministrative;
  }
  
  public void setCompetenceAdministrative(int competenceAdministrative)
  {
    mCompetenceAdministrative = competenceAdministrative;
  }
  
  public ConventionGestionSpec getConventionGestion()
  {
    return mConventionGestion;
  }
  
  public void setConventionGestion(ConventionGestionSpec conventionGestion)
  {
    mConventionGestion = conventionGestion;
  }
  
  public Quantite getDureeIndemnisationEffective()
  {
    return mDureeIndemnisationEffective;
  }
  
  public void setDureeIndemnisationEffective(Quantite dureeIndemnisationEffective)
  {
    mDureeIndemnisationEffective = dureeIndemnisationEffective;
  }
  
  public Quantite getDureeProlongationTheorique()
  {
    return mDureeProlongationTheorique;
  }
  
  public void setDureeProlongationTheorique(Quantite dureeProlongationTheorique)
  {
    mDureeProlongationTheorique = dureeProlongationTheorique;
  }
  
  public Quantite getDureeInitialeMaintien()
  {
    return mDureeInitialeMaintien;
  }
  
  public void setDureeInitialeMaintien(Quantite dureeInitialeMaintien)
  {
    mDureeInitialeMaintien = dureeInitialeMaintien;
  }
  
  public ElementChomageSansRupture getElementChomageSansRupture()
  {
    return mElementChomageSansRupture;
  }
  
  public void setElementChomageSansRupture(ElementChomageSansRupture elementChomageSansRupture)
  {
    mElementChomageSansRupture = elementChomageSansRupture;
  }
  
  public boolean isCapitalRetenuCourant()
  {
    return mIsCapitalRetenuCourant;
  }
  
  public void setCapitalRetenuCourant(boolean isCapitalRetenuCourant)
  {
    mIsCapitalRetenuCourant = isCapitalRetenuCourant;
  }
  
  public boolean isMontantRetenuCourant()
  {
    return mIsMontantRetenuCourant;
  }
  
  public void setMontantRetenuCourant(boolean isMontantRetenuCourant)
  {
    mIsMontantRetenuCourant = isMontantRetenuCourant;
  }
  
  public Collection getListeCarences()
  {
    return mListeCarences;
  }
  
  public void setListeCarences(Collection listeCarences)
  {
    mListeCarences = listeCarences;
  }
  
  public ArrayList getListeDurees()
  {
    return mListeDurees;
  }
  
  public void setListeDurees(ArrayList listeDurees)
  {
    mListeDurees = listeDurees;
  }
  
  public MaintienEuropeen getMaintienEuropeen()
  {
    return mMaintienEuropeen;
  }
  
  public void setMaintienEuropeen(MaintienEuropeen maintienEuropeen)
  {
    mMaintienEuropeen = maintienEuropeen;
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    return mProduitMontantRetenu;
  }
  
  public void setProduitMontantRetenu(ProduitAsuSpec produitMontantRetenu)
  {
    mProduitMontantRetenu = produitMontantRetenu;
  }
  
  public BigDecimal getSeuilMensuelPansConservees()
  {
    return mSeuilMensuelPansConservees;
  }
  
  public void setSeuilMensuelPansConservees(BigDecimal seuilMensuelPansConservees)
  {
    mSeuilMensuelPansConservees = seuilMensuelPansConservees;
  }
  
  public Sjc getSjcInitial()
  {
    return mSjcInitial;
  }
  
  public void setSjcInitial(Sjc sjcInitial)
  {
    mSjcInitial = sjcInitial;
  }
  
  public Sjr getSjrInitial()
  {
    return mSjrInitial;
  }
  
  public void setSjrInitial(Sjr sjrInitial)
  {
    mSjrInitial = sjrInitial;
  }
  
  public int getCompetenceFinanciere()
  {
    return mCompetenceFinanciere;
  }
  
  public void setCompetenceFinanciere(int competenceFinanciere)
  {
    mCompetenceFinanciere = competenceFinanciere;
  }
  
  public Reglement getReglementMontantRetenu()
  {
    return mReglementMontantRetenu;
  }
  
  public void setReglementMontantRetenu(Reglement reglementMontantRetenu)
  {
    mReglementMontantRetenu = reglementMontantRetenu;
  }
  
  public void setListeSousEBI(Collection<ElementBaseIndemnisation> listeSousEBI)
  {
    this.listeSousEBI = listeSousEBI;
  }
  
  public Collection<ElementBaseIndemnisation> getListeSousEBI()
  {
    return listeSousEBI;
  }
  
  public void setCompetence(Competences competence)
  {
    this.competence = competence;
  }
  
  public Competences getCompetence()
  {
    return competence;
  }
  
  public boolean isEstDureePostPrimeEpuisee()
  {
    return estDureePostPrimeEpuisee;
  }
  
  public void setEstDureePostPrimeEpuisee(boolean estDureePostPrimeEpuisee)
  {
    this.estDureePostPrimeEpuisee = estDureePostPrimeEpuisee;
  }
  
  public int getDureeFranchiseCp()
  {
    return dureeFranchiseCp;
  }
  
  public void setDureeFranchiseCp(int dureeFranchiseCp)
  {
    this.dureeFranchiseCp = dureeFranchiseCp;
  }
  
  public int getDureeFranchiseSalaire()
  {
    return dureeFranchiseSalaire;
  }
  
  public void setDureeFranchiseSalaire(int dureeFranchiseSalaire)
  {
    this.dureeFranchiseSalaire = dureeFranchiseSalaire;
  }
  
  public int getQuantiteMensConsomFranchiseCp()
  {
    return quantiteMensConsomFranchiseCp;
  }
  
  public void setQuantiteMensConsomFranchiseCp(int quantiteMensConsomFranchiseCp)
  {
    this.quantiteMensConsomFranchiseCp = quantiteMensConsomFranchiseCp;
  }
  
  public int getQuantiteMensConsomFranchiseSalaire()
  {
    return quantiteMensConsomFranchiseSalaire;
  }
  
  public void setQuantiteMensConsomFranchiseSalaire(int quantiteMensConsomFranchiseSalaire)
  {
    this.quantiteMensConsomFranchiseSalaire = quantiteMensConsomFranchiseSalaire;
  }
  
  public int getRangAllongementPRA()
  {
    return rangAllongementPRA;
  }
  
  public void setRangAllongementPRA(int rangAllongementPRA)
  {
    this.rangAllongementPRA = rangAllongementPRA;
  }
  
  public int getNombreJoursDelaiAttente()
  {
    return nombreJoursDelaiAttente;
  }
  
  public void setNombreJoursDelaiAttente(int nombreJoursDelaiAttente)
  {
    this.nombreJoursDelaiAttente = nombreJoursDelaiAttente;
  }
  
  public Damj getDateLimiteIndemnisation()
  {
    return dateLimiteIndemnisation;
  }
  
  public void setDateLimiteIndemnisation(Damj dateLimiteIndemnisation)
  {
    this.dateLimiteIndemnisation = dateLimiteIndemnisation;
  }
  
  public BigDecimal getMontantCRA()
  {
    return montantCRA;
  }
  
  public void setMontantCRA(BigDecimal montantCRA)
  {
    this.montantCRA = montantCRA;
  }
  
  public boolean isClauseRattrapage()
  {
    return clauseRattrapage;
  }
  
  public void setClauseRattrapage(boolean clauseRattrapage)
  {
    this.clauseRattrapage = clauseRattrapage;
  }
  
  public BigDecimal getNombreHeuresTravailleesMajoree()
  {
    return nombreHeuresTravailleesMajoree;
  }
  
  public void setNombreHeuresTravailleesMajoree(BigDecimal nombreHeuresTravailleesMajoree)
  {
    this.nombreHeuresTravailleesMajoree = nombreHeuresTravailleesMajoree;
  }
  
  public BigDecimal getMontantBrut()
  {
    return montantBrut;
  }
  
  public void setMontantBrut(BigDecimal montantBrut)
  {
    this.montantBrut = montantBrut;
  }
  
  public BigDecimal getMontantBrutPrecompte()
  {
    return montantBrutPrecompte;
  }
  
  public void setMontantBrutPrecompte(BigDecimal montantBrutPrecompte)
  {
    this.montantBrutPrecompte = montantBrutPrecompte;
  }
  
  public boolean isContextePAPPresent()
  {
    return contextePAPPresent;
  }
  
  public void setContextePAPPresent(boolean contextePAPPresent)
  {
    this.contextePAPPresent = contextePAPPresent;
  }
  
  public int getNombreJoursInactivite()
  {
    return nombreJoursInactivite;
  }
  
  public void setNombreJoursInactivite(int nombreJoursInactivite)
  {
    this.nombreJoursInactivite = nombreJoursInactivite;
  }
  
  public boolean isExpatrieApresConvention17()
  {
    return expatrieApresConvention17;
  }
  
  public void setExpatrieApresConvention17(boolean apresConvention17)
  {
    expatrieApresConvention17 = apresConvention17;
  }
  
  public boolean isContextePapParlementaire()
  {
    return contextePapParlementaire;
  }
  
  public void setContextePapParlementaire(boolean contextePapParlementaire)
  {
    this.contextePapParlementaire = contextePapParlementaire;
  }
  
  public boolean estMontantAZero()
  {
    return estMontantAZero;
  }
  
  public void setEstMontantAZero(boolean estMontantAZero)
  {
    this.estMontantAZero = estMontantAZero;
  }
}

/* Location:
 * Qualified Name:     ElementBaseIndemnisation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */