package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDeterminationDateExamenPourFps;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroitSpectacle;
import fr.unedic.cali.asu.outilsfonctionnels.OutilVerificationContexteEre;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsuExamenFilEau;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.outilsfonctionnels.GestionnaireErreur;
import fr.unedic.cali.outilsfonctionnels.OutilAttribution;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourLigne;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class EreAtAfdFdd
  extends EreGammeAsu
{
  private static final long serialVersionUID = -279910554472916034L;
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (demande.getFormulaire().getDateDepot() != null) {
      setDateDeclenchementExamen(demande.getFormulaire().getDateDepot());
    } else {
      setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    try
    {
      if (getDateEvenement() == null) {
        setDateEvenement(determinerDateExamen(demande));
      }
    }
    catch (ApplicativeException ex)
    {
      setDateEvenement(null);
    }
    return getDateEvenement();
  }
  
  protected Damj determinerDateExamen(DemandeSpec demande)
    throws ApplicativeException
  {
    Damj dateExamen;
    try
    {
      Damj dateRecherche = demande.getFormulaire().getDateDepot();
      if (dateRecherche == null) {
        dateRecherche = demande.getFormulaire().getDateCreationDal();
      }
      Damj lendemainDJIEpuisement;
      Damj lendemainDJIEpuisement;
      if (dateRecherche.estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("Date de debut des produits APS17 et AFD17"))) {
        lendemainDJIEpuisement = recupererOutilDeterminationDateExamen().recupererLendemainFinDeDroitArePrecedentDate(dateRecherche, demande, true);
      } else {
        lendemainDJIEpuisement = recupererOutilDeterminationDateExamen().recupererLendemainFinDeDroitArePrecedentDate(dateRecherche, demande, false);
      }
      dateExamen = recupererOutilDeterminationDateExamen().determinerProchaineDateDansPECIndemnisable(demande, lendemainDJIEpuisement);
      dateExamen = gererForcageDateExamenPourAfd(demande, dateExamen);
    }
    catch (CoucheLogiqueException ex)
    {
      dateExamen = null;
    }
    return dateExamen;
  }
  
  protected Damj gererForcageDateExamenPourAfd(DemandeSpec demande, Damj dateExamen)
    throws ApplicativeException
  {
    Damj dateExamenARetourner = dateExamen;
    
    AttributionSpec derniereAttributionAsu = recupererOutilAttribution().recupererAttributionAssurancePrecedente(getDateDeclenchementExamen(demande).lendemain(), demande.getChronologieDemandesAssuranceSansCourante(), demande);
    
    OutilFinDroitSpectacle outil = recupererOutilFinDroitSpectacle();
    if (outil.estDemandeDateAnniversaire(derniereAttributionAsu)) {
      dateExamenARetourner = outil.gererDateExamenPourDemandeDateAnniversaire(dateExamen, (Demande)demande);
    } else {
      outil.verifierSiDateExamenForceeATort((Demande)demande);
    }
    return dateExamenARetourner;
  }
  
  protected OutilFinDroitSpectacle recupererOutilFinDroitSpectacle()
  {
    return OutilFinDroitSpectacle.getInstance();
  }
  
  protected OutilAttribution recupererOutilAttribution()
  {
    return OutilAttribution.getInstance();
  }
  
  public String getLibelle()
  {
    return "EFD";
  }
  
  public String getLibelleLong()
  {
    return "Demande AT/AFD";
  }
  
  public String getTypeExamen()
  {
    return "ASU_12";
  }
  
  public int getPriorite()
  {
    return 5;
  }
  
  public ObjetMetierSpec copie()
  {
    EreAtAfdFdd copie = new EreAtAfdFdd();
    copieElements(copie);
    return copie;
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    OutilVerificationContexteEre.verifierExistanteAreFdd(demande, demande.getDateDeclenchementExamen());
    OutilVerificationContexteEre.verifierDroitAreEnCours(demande, demande.getDateDeclenchementExamen());
    OutilVerificationContexteEre.verifierDroitApsEnCours(demande, demande.getDateDeclenchementExamen());
    OutilVerificationContexteEre.verifierDroitAtOuAfdEnCours(demande, demande.getDateDeclenchementExamen());
    OutilVerificationContexteEre.verifierPresenceReliquatAre(demande, demande.getDateDeclenchementExamen());
    OutilVerificationContexteEre.verifierPresenceReliquatAps(demande, demande.getDateDeclenchementExamen());
    if (determinerDateExamen(demande) == null) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_DATE_EXAMEN_NON_DETERMINEE");
    }
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionPourLigne("ASU_FDS12");
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    return new AffectationDemandeAsuExamenFilEau();
  }
  
  public void verifierContexteExamen(DemandeSpec demande)
    throws ApplicativeException
  {
    OutilVerificationContexteEre.verifierExistanteAreFdd(demande, demande.getDateExamen());
    OutilVerificationContexteEre.verifierDroitAreEnCours(demande, demande.getDateExamen());
    OutilVerificationContexteEre.verifierDroitApsEnCours(demande, demande.getDateExamen());
    OutilVerificationContexteEre.verifierDroitAtOuAfdEnCours(demande, demande.getDateExamen());
    OutilVerificationContexteEre.verifierPresenceReliquatAre(demande, demande.getDateExamen());
    OutilVerificationContexteEre.verifierPresenceReliquatAps(demande, demande.getDateExamen());
  }
  
  public void determinerContexteDemande(DemandeSpec demande) {}
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {}
  
  protected OutilDeterminationDateExamenPourFps recupererOutilDeterminationDateExamen()
  {
    return OutilDeterminationDateExamenPourFps.getInstance();
  }
}

/* Location:
 * Qualified Name:     EreAtAfdFdd
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */