package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.AffectationDemandeASUClassique;
import fr.unedic.cali.asu.parcours.AffectationDemandeASUFinancement;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.asu.parcours.ParcoursLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursLiquidationAssuranceFinancement;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreVrai;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class EreDemandeAssociee
  extends EreGammeAsu
{
  private static final long serialVersionUID = 3043608857128632068L;
  private transient String contexteDemande = null;
  private Damj dateExamenForcee = null;
  private transient DemandeAssuranceSpec demandeMere;
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    Damj dateIde = null;
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen()))
    {
      setDateDeclenchementExamen(getDateEvenement());
    }
    else
    {
      ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(demande.getDemandeur(), demande.getFormulaire().getIdPec());
      if (periodePEC != null) {
        dateIde = periodePEC.getDateDebut();
      }
      if (dateIde != null) {
        setDateDeclenchementExamen(dateIde);
      } else if (demande.getDateDepot() != null) {
        setDateDeclenchementExamen(demande.getDateDepot());
      } else {
        setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
      }
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    Damj dateExamen = null;
    Demande demandeAssociee = (Demande)demande;
    if (getDateEvenement() != null)
    {
      dateExamen = getDateEvenement();
    }
    else if ((demandeAssociee.getDonneesTemporaires() != null) && ("FINANCATPB".equalsIgnoreCase(demandeAssociee.getDonneesTemporaires().getTypeContexteDemandeDonneesTemporaires())))
    {
      try
      {
        AttributionSpec attributionAsrPrecedente = trouverAttributionAsrPrecedenteValide(demande);
        Demande demandeAsrPrecedente = (Demande)attributionAsrPrecedente.getDemande();
        if (demandeAsrPrecedente != null) {
          dateExamen = demandeAsrPrecedente.getDateExamen();
        }
      }
      catch (ApplicativeException ex)
      {
        dateExamen = null;
      }
    }
    else if ("ARESJASPDC".equalsIgnoreCase(demandeAssociee.getDonneesTemporaires().getTypeContexteDemandeDonneesTemporaires()))
    {
      ObjetChronoPeriodePriseEnCharge periodePEC = OutillagePEC.getPecIndemnisableSuivante(demande.getDemandeur(), demandeAssociee.getDonneesTemporaires().getPeriodeFctARetenir().getDateFin());
      if (periodePEC != null) {
        dateExamen = periodePEC.getDateDebut();
      }
    }
    else if ("ARESJREV".equalsIgnoreCase(demandeAssociee.getDonneesTemporaires().getTypeContexteDemandeDonneesTemporaires()))
    {
      if (dateExamenForcee != null)
      {
        dateExamen = dateExamenForcee;
      }
      else
      {
        TravailSpec fct = demandeAssociee.getDonneesTemporaires().getPeriodeRevision();
        dateExamen = fct.getDateFin().lendemain();
      }
    }
    else if ("ASPSJACENT".equalsIgnoreCase(demandeAssociee.getDonneesTemporaires().getTypeContexteDemandeDonneesTemporaires()))
    {
      dateExamen = demandeMere.getDateExamen();
    }
    else if (getDateEvenement() == null)
    {
      ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(demande.getDemandeur(), demande.getFormulaire().getIdPec());
      if (periodePEC != null) {
        dateExamen = periodePEC.getDateDebut();
      }
    }
    if (dateExamen != null) {
      setDateEvenement(dateExamen);
    }
    return getDateEvenement();
  }
  
  private AttributionSpec trouverAttributionAsrPrecedenteValide(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    AttributionSpec attributionAsrPrecedente = OutilAsr.rechercherAttributionAsrPrecedent(demande);
    if (attributionAsrPrecedente == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_CTX_NE_PERMET_PLUS_LIQUIDER_DMD_FIN_DROIT_ASR", new Object[] { "ASR", "ASR" });
    }
    return attributionAsrPrecedente;
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    if (("ARESJREV".equalsIgnoreCase(((Demande)demande).getDonneesTemporaires().getTypeContexteDemandeDonneesTemporaires())) || ("ASPSJACENT".equalsIgnoreCase(((Demande)demande).getDonneesTemporaires().getTypeContexteDemandeDonneesTemporaires()))) {
      return;
    }
    Damj dateIde = null;
    ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(demande.getDemandeur(), demande.getFormulaire().getIdPec());
    if ((periodePEC != null) && (!periodePEC.isAnnulee())) {
      dateIde = periodePEC.getDateDebut();
    }
    if (dateIde == null)
    {
      ObjetChronoPeriodePriseEnCharge periodePECSuivante = OutillagePEC.getPecIndemnisableSuivante(demande.getDemandeur(), demande.getFormulaire().getDateDepot());
      if (periodePECSuivante == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_CONTEXTE_LIQUIDATION_IMPOSSIBLE");
      }
    }
  }
  
  public String getLibelle()
  {
    return "FINANCEMENT";
  }
  
  public String getLibelleLong()
  {
    return "Financement ATP";
  }
  
  public String getTypeExamen()
  {
    return "ASU_21";
  }
  
  public ObjetMetierSpec copie()
  {
    EreDemandeAssociee copie = new EreDemandeAssociee();
    copieElements(copie);
    return copie;
  }
  
  public int getPriorite()
  {
    return 20;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    if ("ARESJASPDC".equals(getContexteDemande())) {
      return new FiltreDecisionARESurDecision();
    }
    return new FiltreNegation(new FiltreVrai());
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    ParcoursAffectationDemandeAssurance parcours;
    ParcoursAffectationDemandeAssurance parcours;
    if (demande.estEnContexteDemande("ARESJREV")) {
      parcours = new AffectationDemandeASUClassique();
    } else {
      parcours = new AffectationDemandeASUFinancement();
    }
    return parcours;
  }
  
  public ParcoursLiquidationAssurance determinerParcoursLiquidationDemandeAssurance(DemandeSpec demande)
  {
    return new ParcoursLiquidationAssuranceFinancement();
  }
  
  private String getContexteDemande()
  {
    return contexteDemande;
  }
  
  public void setContexteDemande(String contexteDemande)
  {
    this.contexteDemande = contexteDemande;
  }
  
  public void determinerContexteDemande(DemandeSpec demande)
  {
    Demande demandeCourante = (Demande)demande;
    Demande demandeFinancement = ((Demande)demande).getDonneesDemandeAssociee().getDemandeAssociee();
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demandeCourante.getListContexteDemande(), "IDEATP")) {
      demandeFinancement.getDonneesTemporaires().setTypeContexteDemandeDonneesTemporaires("FINANCATP");
    }
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demandeCourante.getListContexteDemande(), "BASCULEATP")) {
      demandeFinancement.getDonneesTemporaires().setTypeContexteDemandeDonneesTemporaires("FINANCATPB");
    }
  }
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    if (getDemandeMere() != null)
    {
      Demande demandeSousJacente = DomLiquidationAssurance.getDemande(contexte);
      ContexteDemandeSpec contexteAdhesionVolontaire = OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent((Demande)getDemandeMere(), 3);
      if ((contexteAdhesionVolontaire instanceof ContexteDemande))
      {
        ContexteDemande contexteDemandeSousJacente = new ContexteDemande();
        
        ((ContexteDemande)contexteAdhesionVolontaire).copieElements(contexteDemandeSousJacente);
        demandeSousJacente.ajouterContexteDemande(contexteDemandeSousJacente);
      }
    }
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    super.copieElements(copie);
    EreDemandeAssociee copieEre = (EreDemandeAssociee)copie;
    
    copieEre.setContexteDemande(getContexteDemande());
  }
  
  public Damj getDateExamenForcee()
  {
    return dateExamenForcee;
  }
  
  public void setDateExamenForcee(Damj dateExamenForcee)
  {
    this.dateExamenForcee = dateExamenForcee;
  }
  
  public void setDemandeMere(DemandeAssuranceSpec demandeMere)
  {
    this.demandeMere = demandeMere;
  }
  
  public DemandeAssuranceSpec getDemandeMere()
  {
    return demandeMere;
  }
}

/* Location:
 * Qualified Name:     EreDemandeAssociee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */