package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.VerificationDonneesForcees;
import fr.unedic.cali.asu.parcours.AffectationDemandeASUDemandeExpress;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class EreDemandeExpresse
  extends EreGammeAsu
{
  private static final long serialVersionUID = -2238240419741163736L;
  private transient TravailSpec periodeExamen;
  
  public String getLibelle()
  {
    return "DEXASU";
  }
  
  public String getLibelleLong()
  {
    return "demande expresse ASU";
  }
  
  public String getTypeExamen()
  {
    return "ASU_02";
  }
  
  public int getPriorite()
  {
    return 8;
  }
  
  public ObjetMetierSpec copie()
  {
    EreDemandeExpresse copie = new EreDemandeExpresse();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    super.copieElements(copie);
    EreDemandeExpresse copieLocal = (EreDemandeExpresse)copie;
    copieLocal.setPeriodeExamen(getPeriodeExamen());
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    if (getDateDeclenchementExamen() == null) {
      if (demande.getFormulaire().getDateDepot() != null) {
        setDateDeclenchementExamen(demande.getFormulaire().getDateDepot());
      } else {
        setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
      }
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    try
    {
      if (getDateEvenement() == null) {
        setDateEvenement(determinerDateExamen(demande));
      }
    }
    catch (CoucheLogiqueException ex)
    {
      setDateEvenement(null);
    }
    return getDateEvenement();
  }
  
  public TravailSpec getPeriodeExamen()
  {
    return periodeExamen;
  }
  
  public void setPeriodeExamen(TravailSpec periode)
  {
    periodeExamen = periode;
  }
  
  public boolean isForcageMotifExamen(DemandeSpec demandeSpec)
  {
    Demande demande = (Demande)demandeSpec;
    if (demande.getDonneesTemporaires() == null) {
      return false;
    }
    return demande.getDonneesTemporaires().getMotifExamen() != 0;
  }
  
  public boolean isForcageDroitOption(DemandeSpec demandeSpec)
  {
    Demande demande = (Demande)demandeSpec;
    if (demande.getDonneesTemporaires() == null) {
      return false;
    }
    return demande.getDonneesTemporaires().isDroitOptionForce();
  }
  
  public Damj determinerDateExamen(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    Damj retour = null;
    if (isForcageMotifExamen(demande))
    {
      Damj dateFinEvennement = ((Demande)demande).getDonneesTemporaires().getDateFinEvenement();
      VerificationDonneesForcees.getInstance().verifierDonneesForceesMotifExamen((Demande)demande);
      retour = OutillagePEC.determinerProchaineDateDansPECIndemnisableSansObjet(demande, dateFinEvennement.lendemain());
    }
    if ((!isForcageMotifExamen(demande)) || (isForcageDroitOption(demande))) {
      retour = demande.getFormulaire().getDateDepot();
    }
    return retour;
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    setDateEvenement(determinerDateExamen(demande));
  }
  
  public boolean verifierBesoinChargementTotalGaec()
  {
    return true;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionARESurDecision();
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    return new AffectationDemandeASUDemandeExpress();
  }
  
  public void determinerContexteDemande(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteParticulierCsr((Demande)demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieClauseRattrapageSpectacle((Demande)demande);
  }
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationAssurance donnees = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demande = donnees.getDemande();
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieDispositifASPouPAPARE(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieDispositifASPouPAPDC(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContextePremiereSortieCsp(demande);
    if (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "SORTIECRA")) {
      DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieClauseRattrapageSpectacle(demande);
    }
    ContexteDemande contexteDemandeEnCoursDispo = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demande, "COURSDISPO");
    if (contexteDemandeEnCoursDispo != null) {
      demande.supprimerContexteDemande(contexteDemandeEnCoursDispo);
    }
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteEnCoursDeDisponibilite(demande);
    
    ContexteDemande contexteDemandeEnSortieDispo = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demande, "POSTDISPO");
    if (contexteDemandeEnSortieDispo != null) {
      demande.supprimerContexteDemande(contexteDemandeEnSortieDispo);
    }
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteEnSortieDeDisponibilite(demande);
  }
  
  public void recalerDateExamenEnContexteSortieCRA()
  {
    if ((getDateEvenement() != null) && (getPeriodeExamen() != null) && (!getPeriodeExamen().getDateFin().lendemain().coincideAvec(getDateEvenement()))) {
      setDateEvenement(getPeriodeExamen().getDateFin().lendemain());
    }
  }
}

/* Location:
 * Qualified Name:     EreDemandeExpresse
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */