package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDeterminationDateExamenPourFps;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroitSpectacle;
import fr.unedic.cali.asu.outilsfonctionnels.OutilVerificationContexteEre;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.parcours.AffectationDemandeASUClassique;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsuCsr;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.temps.Damj;

public class EreFinDroitSpectacle
  extends EreGammeAsu
{
  private static final long serialVersionUID = 1539749002156272392L;
  
  public int getPriorite()
  {
    return 11;
  }
  
  public ObjetMetierSpec copie()
  {
    EreFinDroitSpectacle copie = new EreFinDroitSpectacle();
    copieElements(copie);
    return copie;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (demande.getFormulaire().getDateDepot() != null) {
      setDateDeclenchementExamen(demande.getFormulaire().getDateDepot());
    } else {
      setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    try
    {
      if (getDateEvenement() == null) {
        setDateEvenement(determinerDateExamen(demande));
      }
    }
    catch (ApplicativeException ex)
    {
      setDateEvenement(null);
    }
    return getDateEvenement();
  }
  
  private Damj determinerDateExamen(DemandeSpec demande)
    throws ApplicativeException
  {
    Damj dateExamen = null;
    
    AttributionSpec derniereAttributionAsu = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), getDateDeclenchementExamen(demande).lendemain(), new FiltreAttributionStandardAssurance(true, true, true, false, demande));
    if (derniereAttributionAsu == null)
    {
      if (demande.estMigree()) {
        dateExamen = demande.getDossierAffectation().getDossierExamen().getDateAttribution();
      } else {
        setDateEvenement(null);
      }
    }
    else
    {
      dateExamen = calculerDateExamenSuiteFinDeDroit(derniereAttributionAsu, demande);
      OutilFinDroitSpectacle outil = OutilFinDroitSpectacle.getInstance();
      if (outil.estDemandeDateAnniversaire(derniereAttributionAsu)) {
        dateExamen = outil.gererDateExamenPourDemandeDateAnniversaire(dateExamen, (Demande)demande);
      } else {
        outil.verifierSiDateExamenForceeATort((Demande)demande);
      }
    }
    return dateExamen;
  }
  
  private Damj calculerDateExamenSuiteFinDeDroit(AttributionSpec derniereAttributionAsu, DemandeSpec demande)
    throws ApplicativeException
  {
    Damj dateExamen = null;
    
    Damj djiParEpuisement = ((ProduitAsuSpec)derniereAttributionAsu.getProduit()).recupererDJIParEpuisement(demande, derniereAttributionAsu, true);
    if (djiParEpuisement != null) {
      dateExamen = OutilDeterminationDateExamenPourFps.getInstance().determinerProchaineDateDansPECDemandeurEmploi(demande, djiParEpuisement.lendemain());
    } else {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_DERNIER_DROIT_NON_ARRETE_EPUISMT");
    }
    return dateExamen;
  }
  
  public String getLibelle()
  {
    return "FIN_DROIT_SPECTACLE";
  }
  
  public String getLibelleLong()
  {
    return "demande de Fin de droit spectacle";
  }
  
  public String getTypeExamen()
  {
    return "ASU_08";
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    if (!demande.estMigree()) {
      OutilVerificationContexteEre.verifierAttributionPrecedentePourInstallationAreFdd(demande);
    }
    if (determinerDateExamen(demande) == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_DATE_EXAMEN_NON_DETERMINEE");
    }
  }
  
  public boolean verifierBesoinChargementTotalGaec()
  {
    return true;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionARESurDecision();
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demande)) {
      return new AffectationDemandeAsuCsr();
    }
    return new AffectationDemandeASUClassique();
  }
  
  public void determinerContexteDemande(DemandeSpec demande) {}
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {}
}

/* Location:
 * Qualified Name:     EreFinDroitSpectacle
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */