package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsr;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsuFinAsr;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.spec.EvenementReferenceExamenFinDroitSpec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class EreSuiteFinDroitAsr
  extends EreGammeAsu
  implements EvenementReferenceExamenFinDroitSpec
{
  private transient boolean m_calculerDateExamenHorsLiquidation = false;
  private static final long serialVersionUID = 6021882448185185010L;
  
  public String getLibelle()
  {
    return "FIN ASR";
  }
  
  public String getLibelleLong()
  {
    return "Fin CRP";
  }
  
  public String getTypeExamen()
  {
    return "ASU_17";
  }
  
  public int getPriorite()
  {
    return 15;
  }
  
  public ObjetMetierSpec copie()
  {
    EreSuiteFinDroitAsr copie = new EreSuiteFinDroitAsr();
    copieElements(copie);
    return copie;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec p_demande)
  {
    if ((!p_demande.estDemandeLiquidee()) && (getDateEvenement() != null) && (p_demande.estDecisionnee()) && (!p_demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (p_demande.getDateDepot() != null) {
      setDateDeclenchementExamen(p_demande.getDateDepot());
    } else {
      setDateDeclenchementExamen(p_demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec p_demande)
  {
    Damj dateExamen = null;
    try
    {
      if (isCalculerDateExamenHorsLiquidation()) {
        dateExamen = calculerDateExamenHorsLiquidation(p_demande);
      } else if (p_demande.estDemandeLiquidee()) {
        dateExamen = calculerDateExamenPendantLiquidation(p_demande);
      } else {
        dateExamen = calculerDateExamenHorsLiquidation(p_demande);
      }
    }
    catch (ApplicativeException ex)
    {
      dateExamen = null;
    }
    setDateEvenement(dateExamen);
    return dateExamen;
  }
  
  private Damj calculerDateExamenPendantLiquidation(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    Damj dateExamen = null;
    AttributionAssuranceSpec attributionAsrPrecedente = OutilAsr.rechercherDerniereOdAsr(p_demande);
    
    verifierAsrPrecedentePresente(attributionAsrPrecedente);
    Demande demandeAsrPrecedente = (Demande)attributionAsrPrecedente.getDemande();
    if (demandeAsrPrecedente != null) {
      dateExamen = demandeAsrPrecedente.getDateExamen();
    }
    return dateExamen;
  }
  
  public Damj calculerDateExamenHorsLiquidation(DemandeSpec p_demande)
  {
    Damj dateExamen = null;
    try
    {
      AttributionSpec attributionAsrPrecedente = trouverAttributionAsrPrecedenteValide(p_demande);
      Damj djiAsu = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionAsrPrecedente, null, true).getDernierJourIndemnisable();
      dateExamen = djiAsu.lendemain();
    }
    catch (ApplicativeException ex)
    {
      dateExamen = null;
    }
    return dateExamen;
  }
  
  public void verifierContexte(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    if (p_demande.getDateDepot() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DATE_DEPOT_OBLIGATOIRE");
    }
    trouverAttributionAsrPrecedenteValide(p_demande);
  }
  
  private AttributionSpec trouverAttributionAsrPrecedenteValide(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    AttributionSpec attributionAsrPrecedente = OutilAsr.rechercherDernierDroitAsr(p_demande);
    verifierAsrPrecedentePresente(attributionAsrPrecedente);
    return attributionAsrPrecedente;
  }
  
  private void verifierAsrPrecedentePresente(AttributionSpec p_attributionAsrPrecedente)
    throws CoucheLogiqueException
  {
    if (p_attributionAsrPrecedente == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_CTX_NE_PERMET_PLUS_LIQUIDER_DMD_FIN_DROIT_ASR", new Object[] { "ASR", "ASR" });
    }
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionARESurDecision();
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec p_demande)
  {
    return new AffectationDemandeAsuFinAsr();
  }
  
  public boolean isCalculerDateExamenHorsLiquidation()
  {
    return m_calculerDateExamenHorsLiquidation;
  }
  
  public void setCalculerDateExamenHorsLiquidation(boolean p_calculerDateExamenHorsLiquidation)
  {
    m_calculerDateExamenHorsLiquidation = p_calculerDateExamenHorsLiquidation;
  }
  
  public void determinerContexteDemande(DemandeSpec p_demande) {}
  
  public void determinerContextesLiquidation(Contexte p_contexte)
    throws ApplicativeException
  {}
  
  public AttributionSpec rechercherAttributionPrecedente(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    return trouverAttributionAsrPrecedenteValide(demande);
  }
}

/* Location:
 * Qualified Name:     EreSuiteFinDroitAsr
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */