package fr.unedic.cali.asu.eur05.p01.liquidation.outilsfonctionnels;

import fr.unedic.cali.ari.dom.Demande;
import fr.unedic.cali.ari.dom.DonneesForcees;
import fr.unedic.cali.ari.dom.ElementDroit;
import fr.unedic.cali.ari.outilsfonctionnels.OutilElementDroit;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Hashtable;

public class CREM
{
  private static final int NB_DECIMALES_ARRONDI_0 = 0;
  private static final int NB_DECIMALES_ARRONDI_2 = 2;
  private static final int NB_DECIMALES_ARRONDI_4 = 4;
  
  public static Hashtable getElementsConstitutantVides()
  {
    Hashtable listeConstituant = new Hashtable();
    
    listeConstituant.put("Duree", "");
    listeConstituant.put("Montant journalier", "");
    
    return listeConstituant;
  }
  
  public static Hashtable recupererDonneesImposees(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    Hashtable listeDonneesImposees = getElementsDonneesImposeesVides();
    
    Demande demandeAri = (Demande)p_demande;
    DonneesForcees donneesForcees = demandeAri.getDonneesForcees();
    String[] nomEltRecherche = null;
    if (donneesForcees != null)
    {
      Collection listeEltDroit = donneesForcees.getCopieCollectionElementsDroitType("6");
      if ((listeEltDroit != null) && (!listeEltDroit.isEmpty()))
      {
        nomEltRecherche = new String[] { "DATE_DEBUT_PRESTATION" };
        ElementDroit eltDateDebutPrestation = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
        if (eltDateDebutPrestation != null)
        {
          Damj dateDebutPrestation = eltDateDebutPrestation.getDate1Generique();
          if (dateDebutPrestation != null) {
            listeDonneesImposees.put("Debut prestation possible", dateDebutPrestation.toString());
          }
        }
        nomEltRecherche = new String[] { "NB_JOURS_RELIQUAT" };
        ElementDroit eltNbJoursReliquat = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
        if (eltNbJoursReliquat != null)
        {
          Quantite nbJoursReliquat = eltNbJoursReliquat.getQuantiteGenerique();
          if (nbJoursReliquat != null) {
            listeDonneesImposees.put("Nombre de jours de reliquat", Mathematiques.arrondiASup(nbJoursReliquat.getValeur(), 0).toString());
          }
        }
        nomEltRecherche = new String[] { "NB_JOURS_SEMAINE" };
        ElementDroit eltNbJoursIndemnisesSemaine = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
        if (eltNbJoursIndemnisesSemaine != null)
        {
          Quantite nbJoursIndemnisesSemaine = eltNbJoursIndemnisesSemaine.getQuantiteGenerique();
          if (nbJoursIndemnisesSemaine != null) {
            listeDonneesImposees.put("Nb jour indem. semaine", Mathematiques.arrondiASup(nbJoursIndemnisesSemaine.getValeur(), 0).toString());
          }
        }
        nomEltRecherche = new String[] { "NB_JOURS_MOIS" };
        ElementDroit eltNbJoursIndemnisesMois = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
        if (eltNbJoursIndemnisesMois != null)
        {
          Quantite nbJoursIndemnisesMois = eltNbJoursIndemnisesMois.getQuantiteGenerique();
          if (nbJoursIndemnisesMois != null) {
            listeDonneesImposees.put("Nb jour indem. mois", Mathematiques.arrondiASup(nbJoursIndemnisesMois.getValeur(), 0).toString());
          }
        }
        nomEltRecherche = new String[] { "PJI" };
        ElementDroit eltPji = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
        if (eltPji != null)
        {
          Damj pji = eltPji.getDate1Generique();
          if (pji != null) {
            listeDonneesImposees.put("Premier jour indemnisable", pji.toString());
          }
        }
        nomEltRecherche = new String[] { "MONTANT_JOURNALIER" };
        ElementDroit eltMontantJournalier = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
        if (eltMontantJournalier != null)
        {
          Quantite montantJournalier = eltMontantJournalier.getQuantiteGenerique();
          if (montantJournalier != null) {
            listeDonneesImposees.put("Montant journalier", Mathematiques.arrondiASup(montantJournalier.getValeur(), 2).toString());
          }
        }
        nomEltRecherche = new String[] { "DATE_CHANGEMENT_TAUX_CONVERSION" };
        ElementDroit eltDateChangementTauxConversion = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
        if (eltDateChangementTauxConversion != null)
        {
          Damj dateChangementTauxConversion = eltDateChangementTauxConversion.getDate1Generique();
          if (dateChangementTauxConversion != null) {
            listeDonneesImposees.put("Date chang. taux conversion", dateChangementTauxConversion.toString());
          }
        }
      }
    }
    return listeDonneesImposees;
  }
  
  public static Hashtable getElementsDonneesImposeesVides()
  {
    Hashtable listeDonneesImposees = new Hashtable();
    
    listeDonneesImposees.put("Type demande", "");
    listeDonneesImposees.put("Premier jour indemnisable", "");
    listeDonneesImposees.put("Montant journalier", "");
    listeDonneesImposees.put("Dernier jour indemnisable", "");
    listeDonneesImposees.put("Debut prestation possible", "");
    listeDonneesImposees.put("Nombre de jours de reliquat", "");
    listeDonneesImposees.put("Nb jour indem. semaine", "");
    listeDonneesImposees.put("Nb jour indem. mois", "");
    listeDonneesImposees.put("Date chang. taux conversion", "");
    listeDonneesImposees.put("Salaire journalier de ref", "");
    listeDonneesImposees.put("Terme de la PRC", "");
    listeDonneesImposees.put("Coefficient temps partiel", "");
    listeDonneesImposees.put("FGD", "");
    listeDonneesImposees.put("SJR", "");
    listeDonneesImposees.put("SJC", "");
    listeDonneesImposees.put("Revenu ANS conservee", "");
    listeDonneesImposees.put("Duree 1ere tranche", "");
    listeDonneesImposees.put("Duree 2eme tranche", "");
    listeDonneesImposees.put("Duree 3eme tranche", "");
    listeDonneesImposees.put("Point depart delais reports", "");
    listeDonneesImposees.put("Fin PMC", "");
    listeDonneesImposees.put("Differe ISLR", "");
    listeDonneesImposees.put("Differe ISLR", "");
    listeDonneesImposees.put("Delai attente", "");
    listeDonneesImposees.put("SR calcule sur base SMIC", "");
    listeDonneesImposees.put("Etablissement financeur", "");
    listeDonneesImposees.put("Code affectation", "");
    listeDonneesImposees.put("Convention de gestion Unedic", "");
    listeDonneesImposees.put("Libelle aide", "");
    listeDonneesImposees.put("Montant aide", "");
    listeDonneesImposees.put("Famille aide", "");
    listeDonneesImposees.put("Date d attribution", "");
    listeDonneesImposees.put("Type aide", "");
    listeDonneesImposees.put("Date d attribution", "");
    
    return listeDonneesImposees;
  }
}

/* Location:
 * Qualified Name:     CREM
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */