package fr.unedic.cali.asu.eur05.p01.liquidation.outilsfonctionnels;

import fr.unedic.cali.ari.dom.Demande;
import fr.unedic.cali.ari.dom.DonneesForcees;
import fr.unedic.cali.ari.dom.ElementDroit;
import fr.unedic.cali.ari.outilsfonctionnels.OutilElementDroit;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import java.util.Collection;

public class VerificationDonneesForcees
  implements OutilFonctionnel
{
  private static final int NB_JOURS_SEMAINE_MAX = 7;
  private static final int NB_JOURS_MOIS_MAX = 30;
  
  public static void verifierDonneesForcees(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)p_demande;
    DonneesForcees donneesForcees = demande.getDonneesForcees();
    if (donneesForcees != null)
    {
      Collection listeEltDroit = donneesForcees.getCopieCollectionElementsDroitType("6");
      if ((listeEltDroit != null) && (!listeEltDroit.isEmpty()))
      {
        verifierTypeDemande(listeEltDroit);
        
        Damj dateExamen = verifierDateExamen(listeEltDroit, demande);
        
        verifierPaysOrigine(listeEltDroit);
        
        Damj ddpp = verifierDateDebutPrestationPossible(listeEltDroit);
        
        verifierNbJoursSemaineEtMois(listeEltDroit);
        
        Damj dateLimiteIndem = OutilCalculDonneesNonPersistantes.calculerDateLimiteIndemnisation(ddpp);
        Damj pji = verifierPji(demande, dateExamen, listeEltDroit, ddpp, dateLimiteIndem);
        
        verifierMontantJournalierAuPji(listeEltDroit);
        
        verifierChangementTauxConversion(listeEltDroit, pji, dateLimiteIndem);
      }
    }
  }
  
  private static void verifierPaysOrigine(Collection p_listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "PAYS_ORIGINE" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    if (eltDroit == null) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AUE_PAYS_ORIGINE_NON_RENSEIGNE", 1);
    }
  }
  
  private static Damj verifierDateDebutPrestationPossible(Collection p_listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "DATE_DEBUT_PRESTATION" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    if (eltDroit == null)
    {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AUE_DEBUT_PREST_NON_RENSEIGNE", 1);
      
      return null;
    }
    return eltDroit.getDate1Generique();
  }
  
  private static Damj verifierPji(Demande p_demande, Damj p_dateExamen, Collection p_listeEltDroit, Damj p_dateDebutPrestation, Damj p_dateLimiteIndem)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "PJI" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    if (eltDroit == null)
    {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_ARI_PJI_NON_RENSEIGNE", 1);
      
      return null;
    }
    Damj pji = eltDroit.getDate1Generique();
    if (pji.estAvant(p_dateExamen)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AUE_PJI_AVANT_DATE_EXAMEN", new String[] { pji.toString() }, 1);
    }
    if (pji.estAvant(p_dateDebutPrestation)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AUE_PJI_ANTERIEUR_DEBUT_PREST", new String[] { pji.toString(), p_dateDebutPrestation.toString() }, 1);
    }
    if ((p_dateLimiteIndem != null) && (pji.estApresOuCoincideAvec(p_dateLimiteIndem))) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AUE_PJI_POSTERIEUR_A_LIMITE_IND", new String[] { pji.toString(), p_dateLimiteIndem.toString() }, 1);
    }
    ObjetChronoPeriodePriseEnCharge periodePEC = OutillagePEC.getPeriodePECIndemnisableContenant(p_demande.getDemandeur(), pji);
    if (periodePEC == null) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("HG_PR_CALI_ARI_PJI_HORS_PEC", new Object[] { pji }, 1);
    }
    return pji;
  }
  
  private static void verifierMontantJournalierAuPji(Collection p_listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "MONTANT_JOURNALIER" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    if (eltDroit == null) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_ARI_MT_JOURNALIER_NON_RENSEIGNE", 1);
    }
  }
  
  private static void verifierNbJoursSemaineEtMois(Collection p_listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "NB_JOURS_MOIS" };
    ElementDroit eltDroitNbJoursMois = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    nomEltRecherche = new String[] { "NB_JOURS_SEMAINE" };
    ElementDroit eltDroitNbJoursSemaine = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    if ((eltDroitNbJoursMois != null) && (eltDroitNbJoursSemaine != null))
    {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AUE_NB_J_SM_MOIS_RENSEIGNE", 1);
    }
    else if ((eltDroitNbJoursSemaine != null) && (eltDroitNbJoursSemaine.getQuantiteGenerique() != null))
    {
      int nbJoursSemaine = eltDroitNbJoursSemaine.getQuantiteGenerique().getValeurEntiere();
      if (nbJoursSemaine > 7) {
        fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AUE_NB_JOURS_SEMAINE_MAX", 1);
      }
    }
    else if ((eltDroitNbJoursMois != null) && (eltDroitNbJoursMois.getQuantiteGenerique() != null))
    {
      int nbJoursMois = eltDroitNbJoursMois.getQuantiteGenerique().getValeurEntiere();
      if (nbJoursMois > 30) {
        fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AUE_NB_JOURS_MOIS_MAX", 1);
      }
    }
  }
  
  private static void verifierChangementTauxConversion(Collection p_listeEltDroit, Damj p_pji, Damj p_dateLimiteIndem)
    throws CoucheLogiqueException
  {
    boolean dateChangementTauxRenseignee = false;
    String[] nomEltRecherche = { "DATE_CHANGEMENT_TAUX_CONVERSION" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    if (eltDroit != null)
    {
      dateChangementTauxRenseignee = true;
      Damj dateChangementTaux = eltDroit.getDate1Generique();
      if ((p_pji != null) && (dateChangementTaux.estAvantOuCoincideAvec(p_pji))) {
        fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AUE_DTE_CHT_TX_ANTERIEURE_AU_PJI", 1);
      }
      if ((p_dateLimiteIndem != null) && (dateChangementTaux.estApres(p_dateLimiteIndem))) {
        fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AUE_DTE_CHGT_TX_POST_LIMITE_IND", 1);
      }
    }
    if (dateChangementTauxRenseignee)
    {
      nomEltRecherche = new String[] { "MT_JOURNALIER_CHANGEMENT_TAUX" };
      eltDroit = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
      if (eltDroit == null) {
        fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AUE_MT_J_CHGT_TX_NON_RENSEIGNE", 1);
      }
    }
  }
  
  private static void verifierTypeDemande(Collection p_listeEltDroit)
    throws ContexteException, CoucheLogiqueException
  {
    String[] nomEltRecherche = { "TYPE_DEMANDE" };
    ElementDroit eltDroitTypeDemande = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    if ((eltDroitTypeDemande == null) || (eltDroitTypeDemande.getStringGenerique() == null)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_ARI_TYPE_DEMANDE", 1);
    }
  }
  
  private static Damj verifierDateExamen(Collection p_listeEltDroit, Demande p_demande)
    throws ContexteException, CoucheLogiqueException
  {
    Damj dateExamen = null;
    String[] nomEltRecherche = { "DATE_EXAMEN" };
    ElementDroit eltDroitDateExamen = OutilElementDroit.rechercherElement(p_listeEltDroit, nomEltRecherche);
    if ((eltDroitDateExamen == null) || (eltDroitDateExamen.getDate1Generique() == null))
    {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_ARI_DATE_EXAMEN", 1);
    }
    else
    {
      dateExamen = eltDroitDateExamen.getDate1Generique();
      if (!OutillagePEC.estContenueDansUnePecIndemnisable(p_demande.getDemandeur(), dateExamen)) {
        fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_ARI_DATE_EXAMEN_HORS_PEC", 1);
      }
    }
    return dateExamen;
  }
}

/* Location:
 * Qualified Name:     VerificationDonneesForcees
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */