package fr.unedic.cali.asu.exp03.p01.liquidation.dom;

import fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionDateAttributionFinDroit;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionDureeEffectiveReprise;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionDureeReglementaireRepriseAdhesionVolontaire;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionPointDeDepartFinDroit;
import fr.unedic.cali.asu.cge01.liquidation.parcours.DeterminationCompetencesReprise;
import fr.unedic.cali.asu.cge01.liquidation.parcours.DeterminationConditionChomageInvolontaireReprise;
import fr.unedic.cali.asu.cge01.liquidation.parcours.DeterminationConditionCumulActiviteConserveeReprise;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ParcoursDetecterContributionParticuliereContexteEntreeCsp;
import fr.unedic.cali.asu.cge01.liquidation.parcours.VerifierConditionSurFinDispositifReclassement;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.exp03.liquidation.parcours.ConstitutionDelaisReportsReprise;
import fr.unedic.cali.asu.exp03.p01.liquidation.dom.gen.ObjectifExamenRepriseGen;
import fr.unedic.cali.asu.exp03.p01.liquidation.parcours.ConstitutionDureeReglementaireRepriseRevision;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.parcours.ConstitutionMontantsBrutsReprise;
import fr.unedic.cali.asu.produits.liquidation.parcours.DeterminationConditionDureeNonNulle;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.parcours.ParcoursTraitementSatisfait;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Parcours;
import java.util.List;

public class ObjectifExamenReprise
  extends ObjectifExamenRepriseGen
{
  private static final long serialVersionUID = -1240436534505400107L;
  private static List<ContexteDemandeSpec> s_contexteDemande = null;
  
  public ObjectifExamenReprise(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public ObjectifExamenReprise() {}
  
  public ObjectifExamenReprise(List<ContexteDemandeSpec> p_contexteDemande)
  {
    s_contexteDemande = p_contexteDemande;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    super.copieElements(p_copie);
  }
  
  public ObjetMetierSpec copie()
  {
    ObjectifExamenReprise copie = new ObjectifExamenReprise();
    copieElements(copie);
    return copie;
  }
  
  public Parcours creerParcoursConditionChomageInvolontaire()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(s_contexteDemande, "ARESJASPDC")) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionChomageInvolontaireReprise();
  }
  
  public Parcours creerParcoursSalaireJournalierDeReference()
  {
    return null;
  }
  
  public Parcours creerParcoursSalaireJournalierConserve()
  {
    return null;
  }
  
  public Parcours creerParcoursDureeEffective()
  {
    return new ConstitutionDureeEffectiveReprise();
  }
  
  public Parcours creerParcoursDeterminationCompetenceFinanceAdmDroitResultant()
  {
    return new DeterminationCompetencesReprise();
  }
  
  public Parcours creerParcoursDureesReglementaires()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(s_contexteDemande, "FINASPVOL")) {
      return new ConstitutionDureeReglementaireRepriseAdhesionVolontaire();
    }
    return new ConstitutionDureeReglementaireRepriseRevision();
  }
  
  public Parcours creerParcoursDelaisReports()
  {
    return new ConstitutionDelaisReportsReprise();
  }
  
  public Parcours creerParcoursMontantsBruts()
  {
    return new ConstitutionMontantsBrutsReprise();
  }
  
  public Parcours creerParcoursDateAttribution()
  {
    if (OutilGestionContexteDemande.trouverUnContextePresent(s_contexteDemande, 5) != null) {
      return new ConstitutionDateAttributionFinDroit();
    }
    return super.creerParcoursDateAttribution();
  }
  
  public Parcours creerParcoursPointDeDepart()
  {
    if (OutilGestionContexteDemande.trouverUnContextePresent(s_contexteDemande, 5) != null) {
      return new ConstitutionPointDeDepartFinDroit();
    }
    return super.creerParcoursPointDeDepart();
  }
  
  public Parcours creerParcoursConditionRechercheEmploi()
  {
    if ((OutilGestionContexteDemande.trouverUnContextePresent(s_contexteDemande, 5) != null) || (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(s_contexteDemande, "ARESJASPDC"))) {
      return new ParcoursTraitementSatisfait();
    }
    return super.creerParcoursConditionRechercheEmploi();
  }
  
  public Parcours creerParcoursConditionDureeNonNulle()
  {
    if (OutilGestionContexteDemande.trouverUnContextePresent(s_contexteDemande, 5) != null) {
      return new DeterminationConditionDureeNonNulle();
    }
    return null;
  }
  
  public Parcours creerParcoursConditionCumulPrestationFamiliale()
  {
    if (OutilGestionContexteDemande.trouverUnContextePresent(s_contexteDemande, 5) != null) {
      return new VerifierConditionSurFinDispositifReclassement(super.creerParcoursConditionCumulPrestationFamiliale());
    }
    return super.creerParcoursConditionCumulPrestationFamiliale();
  }
  
  public Parcours creerParcoursConditionMontant()
  {
    if (OutilGestionContexteDemande.trouverUnContextePresent(s_contexteDemande, 5) != null) {
      return new VerifierConditionSurFinDispositifReclassement(super.creerParcoursConditionMontant());
    }
    return super.creerParcoursConditionMontant();
  }
  
  public Parcours creerParcoursConditionCumulActiviteConservee()
  {
    if (OutilGestionContexteDemande.trouverUnContextePresent(s_contexteDemande, 5) != null) {
      return new VerifierConditionSurFinDispositifReclassement(new DeterminationConditionCumulActiviteConserveeReprise());
    }
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(s_contexteDemande, "ARESJASPDC")) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionCumulActiviteConserveeReprise();
  }
  
  public Parcours creerParcoursDetectionContributionParticuliere(Demande p_demande)
  {
    return new ParcoursDetecterContributionParticuliereContexteEntreeCsp();
  }
}

/* Location:
 * Qualified Name:     ObjectifExamenReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */