package fr.unedic.cali.asu.fds12.p03.avant.outilsfonctionnels;

import fr.unedic.cali.asu.spe02.p03.avant.outilsfonctionnels.TraitementDureeConsommableAvant;
import fr.unedic.cali.calcul.dom.ArretProduitAvecRaison;
import fr.unedic.cali.calcul.dom.ConsommationPeriodes;
import fr.unedic.cali.calcul.dom.DureeConsommableAvant;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.UniteTraitementAvant;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyseSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class TraitementPeriodesAnalyseAvant
{
  public static void traitementDesPeriodesAnalyses(AttributionSpec attribution, UniteTraitementAvant utAvant, ChronologiePeriodes periodesAnalyse, QualificationPeriodes qualificationPeriodes, ArretProduitAvecRaison arretProduitAvecRaison)
    throws CoucheLogiqueException
  {
    DureeConsommableAvant dureeFranchiseCP = (DureeConsommableAvant)utAvant.getDureeFranchiseCPEnDebutUT().copie();
    DureeConsommableAvant dureeDiffereFranchiseSalaire = (DureeConsommableAvant)utAvant.getDureeFranchiseSalaireEnDebutUT().copie();
    
    periodesAnalyse.iterer();
    while (periodesAnalyse.encoreSuivant())
    {
      PeriodeAnalyseSpec pa = (PeriodeAnalyseSpec)periodesAnalyse.elementSuivant();
      pa.setQuantiteIndemnisable(new QuantiteJour(new BigDecimal(pa.getDuree())));
      Damj dateDebutConsommationSurPa = pa.getDateDebut();
      Quantite quantiteAImputerSurLaPA = pa.getQuantiteIndemnisable().soustraire(pa.getQuantiteNonIndemnisee());
      Quantite quantiteRestante = new Quantite(quantiteAImputerSurLaPA.getValeur(), quantiteAImputerSurLaPA.getUnite());
      
      quantiteRestante = gestionFranchiseCPNonEpuisee(utAvant, quantiteAImputerSurLaPA, dureeFranchiseCP, dateDebutConsommationSurPa, quantiteRestante);
      
      gestionFranchiseSalaire(utAvant, quantiteAImputerSurLaPA, dureeDiffereFranchiseSalaire, pa, quantiteRestante, arretProduitAvecRaison);
      
      postTraitementPa(utAvant, pa);
    }
    utAvant.setDureeFranchiseCPEnFinUT(dureeFranchiseCP);
    utAvant.setDureeFranchiseSalaireEnFinUT(dureeDiffereFranchiseSalaire);
    
    utAvant.setFranchiseCPConsomme(franchiseCPConsomme(utAvant));
    utAvant.setFranchiseSalaireConsomme(franchiseSalaireConsomme(utAvant));
  }
  
  private static Quantite gestionFranchiseCPNonEpuisee(UniteTraitementAvant utAvant, Quantite quantiteAImputerSurLaPA, DureeConsommableAvant dureeFranchiseSalaire, Damj dateDebutConsommationSurPa, Quantite quantiteRestante)
    throws CoucheLogiqueException
  {
    Quantite quantiteRestanteTmp = quantiteRestante;
    if (dureeFranchiseSalaire.getEtat() != 2) {
      quantiteRestanteTmp = TraitementDureeConsommableAvant.simulerImputationEtImputerLaQuantite(quantiteAImputerSurLaPA, dureeFranchiseSalaire, utAvant, dateDebutConsommationSurPa);
    }
    return quantiteRestanteTmp;
  }
  
  private static Quantite gestionFranchiseSalaire(UniteTraitementAvant utAvant, Quantite quantiteAImputerSurLaPA, DureeConsommableAvant dureeFranchiseSalaire, PeriodeAnalyseSpec pa, Quantite quantiteRestante, ArretProduitAvecRaison arretProduitAvecRaison)
    throws CoucheLogiqueException
  {
    Quantite quantiteRestanteTmp = quantiteRestante;
    if (dureeFranchiseSalaire.getEtat() != 2)
    {
      DureeCalendaire d = new DureeCalendaire(0, 0, quantiteAImputerSurLaPA.soustraire(quantiteRestanteTmp).getValeurEntiere());
      Damj dateDebutConsommationSurPa = pa.getDateDebut().deplacerVersAvant(d);
      if (dureeFranchiseSalaire.getEtat() != 1)
      {
        dureeFranchiseSalaire.activer();
        if (dureeFranchiseSalaire.getQuantiteInitial().getValeurEntiere() > 0)
        {
          Periode p = new Periode(dateDebutConsommationSurPa);
          utAvant.getConsommationPeriodes().setPeriodeFranchiseSalaire(p);
        }
      }
      TraitementDureeConsommableAvant.simulerImputationEtImputerLaQuantiteEtTerminerProduit(quantiteRestanteTmp, pa, dureeFranchiseSalaire, utAvant, dateDebutConsommationSurPa, arretProduitAvecRaison);
    }
    return quantiteRestanteTmp;
  }
  
  private static Quantite franchiseCPConsomme(UniteTraitementAvant utAvant)
  {
    Quantite pmcConsomme;
    Quantite pmcConsomme;
    if (utAvant.getDureeFranchiseCPEnFinUT().getEtat() == 0)
    {
      pmcConsomme = new QuantiteJour("0");
    }
    else
    {
      Quantite pmcConsomme;
      if (utAvant.getDureeFranchiseCPEnDebutUT().getEtat() == 0) {
        pmcConsomme = utAvant.getDureeFranchiseCPEnDebutUT().getQuantiteInitial().soustraire(utAvant.getDureeFranchiseCPEnFinUT().getQuantiteCourante());
      } else {
        pmcConsomme = utAvant.getDureeFranchiseCPEnDebutUT().getQuantiteCourante().soustraire(utAvant.getDureeFranchiseCPEnFinUT().getQuantiteCourante());
      }
    }
    return pmcConsomme;
  }
  
  private static Quantite franchiseSalaireConsomme(UniteTraitementAvant utAvant)
  {
    Quantite pmcConsomme;
    Quantite pmcConsomme;
    if (utAvant.getDureeFranchiseSalaireEnFinUT().getEtat() == 0)
    {
      pmcConsomme = new QuantiteJour("0");
    }
    else
    {
      Quantite pmcConsomme;
      if (utAvant.getDureeFranchiseSalaireEnDebutUT().getEtat() == 0) {
        pmcConsomme = utAvant.getDureeFranchiseSalaireEnDebutUT().getQuantiteInitial().soustraire(utAvant.getDureeFranchiseSalaireEnFinUT().getQuantiteCourante());
      } else {
        pmcConsomme = utAvant.getDureeFranchiseSalaireEnDebutUT().getQuantiteCourante().soustraire(utAvant.getDureeFranchiseSalaireEnFinUT().getQuantiteCourante());
      }
    }
    return pmcConsomme;
  }
  
  private static void postTraitementPa(UniteTraitementAvant utAvant, PeriodeAnalyseSpec pa)
    throws CoucheLogiqueException
  {
    if (pa.isProduitATerminerApresPA()) {
      utAvant.setProduitATerminerApresUT(pa.isProduitATerminerApresPA());
    }
  }
}

/* Location:
 * Qualified Name:     TraitementPeriodesAnalyseAvant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */