package fr.unedic.cali.asu.fps.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.fps.liquidation.outilsaffiliation.spec.IParametresAffiliationFPS;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.CalculAssimilation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.OutilPeriodeAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.JustifierAffiliationSpec;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeEvenementPersonnel;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class CalculAssimilationFPS
  extends CalculAssimilation
{
  public Quantite determinerAssimilation(IndividuSpec individu, ComportementAffiliationSpec comportementCalcul, JustificationAffiliation justification, Map chronologies, Collection collectionAlertesNonBloquantes)
    throws CoucheLogiqueException
  {
    ComportementAffiliationFPS comportement = (ComportementAffiliationFPS)comportementCalcul;
    
    Quantite quantiteTotalAssimilation = super.determinerAssimilation(individu, comportementCalcul, justification, chronologies, collectionAlertesNonBloquantes);
    
    Quantite quantiteAssimilationMaladieLongueDuree = ZERO;
    Quantite quantiteAssimilationMaladieGrave = ZERO;
    if (comportement.isCalculAffiliationAssimilableMaladieLongueDuree())
    {
      verifierComportementMaladieLongueDuree(comportementCalcul);
      
      quantiteAssimilationMaladieLongueDuree = calculerAssimilationMaladieLongueDuree(comportementCalcul, justification, chronologies);
    }
    if (comportement.isCalculAffiliationAssimilableMaladieGrave())
    {
      verifierComportementMaladieGrave(comportementCalcul);
      
      quantiteAssimilationMaladieGrave = calculerAssimilationMaladieGrave(comportementCalcul, justification, chronologies);
    }
    if (quantiteAssimilationMaladieLongueDuree != null) {
      quantiteTotalAssimilation = quantiteTotalAssimilation.ajouter(quantiteAssimilationMaladieLongueDuree);
    }
    if (quantiteAssimilationMaladieGrave != null) {
      quantiteTotalAssimilation = quantiteTotalAssimilation.ajouter(quantiteAssimilationMaladieGrave);
    }
    return quantiteTotalAssimilation;
  }
  
  public Quantite calculerAssimilationMaladieLongueDuree(ComportementAffiliationSpec comportementCalcul, JustificationAffiliation justification, Map chronologies)
  {
    Chronologie chronoPourAssimilationMaladieLiongueDuree = (Chronologie)chronologies.get("chronoAffiMaladiesLongueDuree");
    
    Quantite quantiteTotalHeure = ZERO;
    if (chronoPourAssimilationMaladieLiongueDuree != null)
    {
      IParametresAffiliationFPS parametresAffiliation = (IParametresAffiliationFPS)comportementCalcul.getOutilParametreAffiliation();
      JustifierAffiliationSpec justifierAffiliation = comportementCalcul.getOutilJustifierAffiliation();
      
      Chronologie chronoActivitesAffiliationBase = (Chronologie)chronologies.get("chronoAffiBase");
      
      ChronologiePeriodes chronoActiviteBaseSansChevauchement = null;
      if (!chronoActivitesAffiliationBase.estVide())
      {
        chronoActiviteBaseSansChevauchement = OutilPeriodeAffiliation.construireChronologiePeriode(chronoActivitesAffiliationBase);
        
        chronoActiviteBaseSansChevauchement.fusionnerChevauchementPeriodes();
      }
      else
      {
        chronoActiviteBaseSansChevauchement = new ChronologiePeriodes();
      }
      Iterator<?> itChronoAssimilation = chronoPourAssimilationMaladieLiongueDuree.iterer();
      int nature = 12;
      while (itChronoAssimilation.hasNext())
      {
        PeriodeEvenementPersonnel pep = (PeriodeEvenementPersonnel)itChronoAssimilation.next();
        
        List<?> listePeriodesSansChevauchement = OutilPeriodeAffiliation.determinerListePeriodesSansChevauchementPourChronoSansChevauchement(chronoActiviteBaseSansChevauchement, pep.getPeriode());
        
        int nombreTotalJoursSansChevauchement = OutilPeriodeAffiliation.determinerNombreJoursChronoApresFusionPeriode(listePeriodesSansChevauchement, comportementCalcul.getPeriodeRecherche());
        
        justification.setNombreJourAssimilationSalaire(justification.getNombreJourAssimilationSalaire() + nombreTotalJoursSansChevauchement);
        
        Quantite quantiteAssimiationPourPep = parametresAffiliation.calculerQuantiteHeureMaladieLongueDuree(nombreTotalJoursSansChevauchement);
        
        justifierAffiliation.ajouterAssimilation(justification, nature, quantiteAssimiationPourPep);
        
        quantiteTotalHeure = quantiteTotalHeure.ajouter(quantiteAssimiationPourPep);
      }
    }
    return quantiteTotalHeure;
  }
  
  private Quantite calculerAssimilationMaladieGrave(ComportementAffiliationSpec comportementCalcul, JustificationAffiliation justification, Map chronologies)
  {
    Chronologie chronoPourAssimilationMaladieGrave = (Chronologie)chronologies.get("chronoAffiMaladiesGraves");
    
    Quantite quantiteTotalHeure = ZERO;
    if (chronoPourAssimilationMaladieGrave != null)
    {
      ParametresAffiliationFPS parametresAffiliation = (ParametresAffiliationFPS)comportementCalcul.getOutilParametreAffiliation();
      JustifierAffiliationSpec justifierAffiliation = comportementCalcul.getOutilJustifierAffiliation();
      
      Chronologie chronoActivitesAffiliationBase = (Chronologie)chronologies.get("chronoAffiBase");
      
      ChronologiePeriodes chronoActiviteBaseSansChevauchement = null;
      if (!chronoActivitesAffiliationBase.estVide()) {
        chronoActiviteBaseSansChevauchement = OutilPeriodeAffiliation.construireChronologiePeriode(chronoActivitesAffiliationBase).fusionnerChevauchementPeriodes();
      } else {
        chronoActiviteBaseSansChevauchement = new ChronologiePeriodes();
      }
      int nature = 13;
      
      Iterator<?> itChronoAssimilation = chronoPourAssimilationMaladieGrave.iterer();
      while (itChronoAssimilation.hasNext())
      {
        PeriodeEvenementPersonnel pep = (PeriodeEvenementPersonnel)itChronoAssimilation.next();
        
        List<?> listePeriodesSansChevauchement = OutilPeriodeAffiliation.determinerPeriodesSansChevauchement(chronoActiviteBaseSansChevauchement, pep.getPeriode());
        
        int nombreTotalJoursSansChevauchement = OutilPeriodeAffiliation.determinerNombreJoursChronoApresFusionPeriode(listePeriodesSansChevauchement, comportementCalcul.getPeriodeRecherche());
        
        Quantite quantiteAssimiationPourPep = parametresAffiliation.calculerQuantiteHeureMaladieGrave(nombreTotalJoursSansChevauchement);
        
        justifierAffiliation.ajouterAssimilation(justification, nature, quantiteAssimiationPourPep);
        
        quantiteTotalHeure = quantiteTotalHeure.ajouter(quantiteAssimiationPourPep);
      }
    }
    return quantiteTotalHeure;
  }
  
  public void verifierComportementMaladieLongueDuree(ComportementAffiliationSpec comportement)
    throws CoucheLogiqueException
  {
    verifierComportementBase(comportement);
  }
  
  private void verifierComportementMaladieGrave(ComportementAffiliationSpec comportement)
    throws CoucheLogiqueException
  {
    verifierComportementBase(comportement);
  }
}

/* Location:
 * Qualified Name:     CalculAssimilationFPS
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */