package fr.unedic.cali.asu.fps.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.EreInscriptionDemandeurEmploi;
import fr.unedic.cali.asu.fps.liquidation.outilsaffiliation.ComportementAffiliationFPS;
import fr.unedic.cali.asu.fps.liquidation.outilsaffiliation.ConstructionChronologieFPS;
import fr.unedic.cali.asu.fps.liquidation.outilsaffiliation.JustifierAffiliationFPS;
import fr.unedic.cali.asu.fps.liquidation.outilsaffiliation.spec.IComportementAffiliationFPS;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AllongementPra;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.CalculAppartenance;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ParametresCalculAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ResultatValidationProduit;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ConstructionChronologieSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.JustifierAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.ConteneurDeterminationPeriodeReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationPeriodeReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.filtres.FiltreActiviteSalarieCinemaSpectacle;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P03;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.ComparateurTemporelSurDateFinDecroissante;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreOu;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSpec;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreAttributionSurDecisions;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourNumeroGamme;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionPourCompetence;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public abstract class OutilConditionAffiliationAbstraite
  implements OutilFonctionnel
{
  protected static final JustifierAffiliationSpec JUSTIFIER_AFFILIATION = new JustifierAffiliationFPS();
  protected static final ConstructionChronologieSpec CONSTRUCTION_CHRONOLOGIE = new ConstructionChronologieFPS();
  protected static final BigDecimal ZERO = BigDecimal.ZERO;
  
  public ConditionQuantiteAffiliation determinerConditionAffiliation(DemandeAssuranceSpec demandeAssurance)
    throws CoucheLogiqueException
  {
    ResultatValidationProduit resultatValidation = new ResultatValidationProduit();
    ResultatValidationProduit resultatValidationPremierEtude = null;
    IndividuSpec individu = demandeAssurance.getDemandeur();
    boolean produitValide = false;
    Damj dateBornePRA = determinerBornePRA(demandeAssurance);
    List<AllongementPra> listeAllongementPeriodeAJustifier = null;
    ActiviteSalarie activiteReference = null;
    
    Periode pra = null;
    Quantite quantiteAffiliationRequise = null;
    Quantite quantiteAppartenanceARetenir = null;
    JustificationAffiliation justification = null;
    Collection<ObjetAlertesNonBloquantes> listeAlertesNonBloquantes = new ArrayList();
    
    ParametresCalculAffiliation parametres = new ParametresCalculAffiliation();
    if (presenceDonneesForceesValidationProduit(demandeAssurance))
    {
      resultatValidation = calculerAffiliationForcee(demandeAssurance);
      resultatValidationPremierEtude = resultatValidation;
    }
    else
    {
      Chronologie chronologie = determinerChronologieActivitesReference(demandeAssurance);
      
      chronologie.setComparateur(new ComparateurTemporelSurDateFinDecroissante());
      if (!chronologie.estVide())
      {
        activiteReference = (ActiviteSalarie)chronologie.premierElement();
        
        parametres.setFaitGenerateurDroit(activiteReference);
        
        parametres.setDateExamen(demandeAssurance.getDateExamen());
        parametres.setDemande((Demande)demandeAssurance);
        
        Damj dateTermePra = determinerTermePRA(activiteReference.getDateFin(), parametres.getDateExamen(), demandeAssurance.estEnContexteDemande("APSPOSTCRA"));
        
        parametres.setReglementEtudie(getReglementA8());
        List<AllongementPra> listeAllongementPRAA8 = new ArrayList();
        Periode periodeReferenceA8 = determinerPRA(individu, parametres, dateTermePra, dateBornePRA, listeAllongementPRAA8);
        
        Quantite quantiteReglementA8 = calculerAffiliationPourReglement(individu, parametres, periodeReferenceA8);
        
        parametres.setReglementEtudie(getReglementA10());
        List<AllongementPra> listeAllongementPRAA10 = new ArrayList();
        Periode periodeReferenceA10 = determinerPRA(individu, parametres, dateTermePra, dateBornePRA, listeAllongementPRAA10);
        
        Quantite quantiteReglementA10 = calculerAffiliationPourReglement(individu, parametres, periodeReferenceA10);
        
        Reglement reglementApplicable = determinerReglementApplicable(quantiteReglementA8, quantiteReglementA10, activiteReference);
        parametres.setReglementEtudie(reglementApplicable);
        
        pra = trouverPeriodeReferenceAffiliationRetenir(periodeReferenceA8, periodeReferenceA10, reglementApplicable);
        
        quantiteAffiliationRequise = determinerAffiliationRequise(parametres);
        
        ValidationProduit validationProduit = new ValidationProduit();
        justification = validationProduit.createJustificationAffiliation();
        
        parametres.setDemande((Demande)demandeAssurance);
        
        quantiteAppartenanceARetenir = calculerAffiliation(individu, justification, parametres, pra, quantiteAffiliationRequise, listeAlertesNonBloquantes);
        
        ProduitAsuSpec produit = (ProduitAsuSpec)demandeAssurance.getDossierAffectation().getProduit();
        if (estAffiliationAcquiseSuffisante(quantiteAppartenanceARetenir, quantiteAffiliationRequise, justification, produit))
        {
          produitValide = true;
          
          listeAllongementPeriodeAJustifier = determinerListeAllongementPeriodePourJustification(reglementApplicable, listeAllongementPRAA8, listeAllongementPRAA10);
        }
      }
      alimenterResultatCalculAffiliation(resultatValidation, parametres, activiteReference, pra, quantiteAffiliationRequise, quantiteAppartenanceARetenir, justification, produitValide);
      
      resultatValidationPremierEtude = new ResultatValidationProduit();
      
      alimenterResultatCalculAffiliation(resultatValidationPremierEtude, parametres, activiteReference, pra, quantiteAffiliationRequise, quantiteAppartenanceARetenir, justification, produitValide);
      
      JUSTIFIER_AFFILIATION.justifierAllongementPeriodeReference(resultatValidationPremierEtude.getJustificationAffiliation(), listeAllongementPeriodeAJustifier);
    }
    if (produitValide)
    {
      JUSTIFIER_AFFILIATION.justifierAllongementPeriodeReference(resultatValidation.getJustificationAffiliation(), listeAllongementPeriodeAJustifier);
      
      alimenterAlertesNonBloquantesPourDemande(demandeAssurance, listeAlertesNonBloquantes);
    }
    else
    {
      resultatValidation = resultatValidationPremierEtude;
    }
    return alimenterCAPA07DepuisResultatValidation(demandeAssurance, resultatValidation);
  }
  
  protected ResultatValidationProduit calculerAffiliationForcee(DemandeAssuranceSpec demandeAssurance)
    throws CoucheLogiqueException
  {
    ResultatValidationProduit resultatValidation = new ResultatValidationProduit();
    IndividuSpec individu = demandeAssurance.getDemandeur();
    boolean produitValide = false;
    Damj dateBornePRA = determinerBornePRA(demandeAssurance);
    List<AllongementPra> listeAllongementPeriodeAJustifier = null;
    ActiviteSalarie activiteReference = (ActiviteSalarie)demandeAssurance.getDonneesTemporaires().getPeriodeFctARetenir();
    
    Periode pra = null;
    Quantite quantiteAffiliationRequise = null;
    Quantite quantiteAppartenanceARetenir = null;
    
    ParametresCalculAffiliation parametres = new ParametresCalculAffiliation();
    
    parametres.setReglementEtudie(determinerReglementApplicableDonneesForcees(demandeAssurance));
    if (demandeAssurance.getDonneesTemporaires().getRangAllongementPraSpectacle() != null) {
      parametres.setRangEtude(demandeAssurance.getDonneesTemporaires().getRangAllongementPraSpectacle().intValue());
    }
    parametres.setFaitGenerateurDroit(activiteReference);
    
    parametres.setDateExamen(demandeAssurance.getDateExamen());
    parametres.setDemande((Demande)demandeAssurance);
    
    Damj dateTermePra = determinerTermePRA(activiteReference.getDateFin(), parametres.getDateExamen(), demandeAssurance.estEnContexteDemande("APSPOSTCRA"));
    
    listeAllongementPeriodeAJustifier = new ArrayList();
    pra = determinerPRA(individu, parametres, dateTermePra, dateBornePRA, listeAllongementPeriodeAJustifier);
    
    quantiteAffiliationRequise = determinerAffiliationRequise(parametres);
    
    quantiteAppartenanceARetenir = demandeAssurance.getDonneesTemporaires().getQuantiteAffiliation();
    
    ProduitAsuSpec produit = (ProduitAsuSpec)demandeAssurance.getDossierAffectation().getProduit();
    if (estAffiliationAcquiseSuffisante(quantiteAppartenanceARetenir, quantiteAffiliationRequise, null, produit)) {
      produitValide = true;
    }
    alimenterResultatCalculAffiliation(resultatValidation, parametres, activiteReference, pra, quantiteAffiliationRequise, quantiteAppartenanceARetenir, null, produitValide);
    
    return resultatValidation;
  }
  
  protected ConditionQuantiteAffiliation alimenterCAPA07DepuisResultatValidation(DemandeAssuranceSpec demande, ResultatValidationProduit resultatValidationProduit)
  {
    ConditionQuantiteAffiliation capa07 = ((DossierExamen)demande.getDossierExamen()).getConditionAttributionAdmission().createConditionQuantiteAffiliation();
    
    DossierAffecte dossierAffecte = (DossierAffecte)demande.getDossierAffectation();
    ValidationProduit validationProduit = (ValidationProduit)dossierAffecte.getValidationProduit();
    if (resultatValidationProduit != null)
    {
      validationProduit.setCatEmploiPart(resultatValidationProduit.getCatEmploiPart());
      validationProduit.setDateFinPeriode(resultatValidationProduit.getDateFinPeriode());
      validationProduit.setDjtpPeriode(resultatValidationProduit.getDjtpPeriode());
      validationProduit.setIdentifiantPeriodeValidationProduit(resultatValidationProduit.getIdentifiantPeriodeValidationProduit());
      validationProduit.setMotifFinPeriode(resultatValidationProduit.getMotifFinPeriode());
      validationProduit.setNomReglementApplicable(resultatValidationProduit.getNomReglementApplicable());
      validationProduit.setPeriodePra(resultatValidationProduit.getPeriodePra());
      validationProduit.setPeriodeValidationProduit(resultatValidationProduit.getPeriodeValidationProduit());
      validationProduit.setPopOccHorsFrance(resultatValidationProduit.getPopOccHorsFrance());
      validationProduit.setQteAcquise(resultatValidationProduit.getQteAcquise());
      validationProduit.setQuantiteAcquise(resultatValidationProduit.getQuantiteAcquise());
      if (resultatValidationProduit.getReglementApplicable() != null) {
        validationProduit.setReglementApplicable(resultatValidationProduit.getReglementApplicable());
      }
      validationProduit.setHeuresRequises(resultatValidationProduit.getHeuresRequises());
      validationProduit.setRangAllongement(resultatValidationProduit.getRangAllongement());
      
      JustificationAffiliation justification = resultatValidationProduit.getJustificationAffiliation();
      if (justification != null)
      {
        JustificationAffiliation justificationPourValidation = validationProduit.createJustificationAffiliation();
        justification.copieElements(justificationPourValidation);
      }
      if (validationProduit.getProduitValide() == null) {
        validationProduit.setProduitValide(dossierAffecte.getProduit());
      }
      capa07.setEtatSatisfait(resultatValidationProduit.isProduitValide());
    }
    capa07.setValidationProduit(validationProduit);
    if ((resultatValidationProduit == null) || (!resultatValidationProduit.isProduitValide()))
    {
      capa07.setEtatSatisfait(false);
      capa07.setCodeMotifEchec(71);
    }
    return capa07;
  }
  
  protected Reglement determinerReglementApplicable(Quantite quantiteA8, Quantite quantiteA10, ActiviteSalarie activiteReference)
  {
    if (quantiteA8.equals(quantiteA10)) {
      return activiteReference.getReglement();
    }
    if (quantiteA10.max(quantiteA8).equals(quantiteA8)) {
      return getReglementA8();
    }
    return getReglementA10();
  }
  
  protected Periode trouverPeriodeReferenceAffiliationRetenir(Periode periodeReferenceA8, Periode periodeReferenceA10, Reglement reglementApplicable)
  {
    if (reglementApplicable.getLibelleCourt().equals("A8")) {
      return periodeReferenceA8;
    }
    return periodeReferenceA10;
  }
  
  protected List<AllongementPra> determinerListeAllongementPeriodePourJustification(Reglement reglementApplicable, List<AllongementPra> listeAllongementPRAA8, List<AllongementPra> listeAllongementPRAA10)
  {
    if (reglementApplicable.equals(getReglementA10())) {
      return listeAllongementPRAA10;
    }
    return listeAllongementPRAA8;
  }
  
  protected void alimenterResultatCalculAffiliation(ResultatValidationProduit resultatCalcul, ParametresCalculAffiliation parametres, ActiviteSalarie activite, Periode pra, Quantite quantiteHeureRequise, Quantite quantiteHeureAcquise, JustificationAffiliation justification, boolean estProduitValide)
  {
    if (activite != null)
    {
      resultatCalcul.setCatEmploiPart(activite.getCategorieEmploiParticulier());
      resultatCalcul.setDateFinPeriode(activite.getDateFin());
      resultatCalcul.setDjtpPeriode(activite.getDernierJourTravaillePaye());
      resultatCalcul.setIdentifiantPeriodeValidationProduit(activite.getIdentifiant());
      resultatCalcul.setMotifFinPeriode(activite.getMotifFin());
      resultatCalcul.setPopOccHorsFrance(activite.getContrat().getPohf());
      resultatCalcul.setPeriodeValidationProduit(activite);
    }
    if (parametres != null)
    {
      if (parametres.getReglementEtudie() != null)
      {
        resultatCalcul.setReglementApplicable(parametres.getReglementEtudie());
        resultatCalcul.setNomReglementApplicable(parametres.getReglementEtudie().getLibelleCourt());
      }
      resultatCalcul.setRangAllongement(parametres.getRangEtude());
    }
    resultatCalcul.setQteAcquise(quantiteHeureAcquise);
    resultatCalcul.setQuantiteAcquise(quantiteHeureAcquise);
    resultatCalcul.setHeuresRequises(quantiteHeureRequise);
    resultatCalcul.setPeriodePra(pra);
    resultatCalcul.setJustificationAffiliation(justification);
    resultatCalcul.setEstProduitValide(estProduitValide);
  }
  
  protected void alimenterAlertesNonBloquantesPourDemande(DemandeAssuranceSpec demande, Collection<ObjetAlertesNonBloquantes> listeAlertesNonBloquantes)
  {
    if (listeAlertesNonBloquantes != null)
    {
      List listeAlertePNDS = new ArrayList();
      
      Iterator itAlertesNonBloquantes = listeAlertesNonBloquantes.iterator();
      while (itAlertesNonBloquantes.hasNext())
      {
        ObjetAlertesNonBloquantes alerteNonBloquantes = (ObjetAlertesNonBloquantes)itAlertesNonBloquantes.next();
        switch (alerteNonBloquantes.getTypeNature())
        {
        case 7: 
          listeAlertePNDS.add(alerteNonBloquantes);
        }
      }
      if ((listeAlertePNDS != null) && (!listeAlertePNDS.isEmpty())) {
        demande.getAlertesNonBloquantes().put("A11MNB9", listeAlertePNDS);
      }
    }
  }
  
  protected Quantite calculerAffiliation(IndividuSpec individu, JustificationAffiliation justification, ParametresCalculAffiliation parametres, Periode periodeReference, Quantite quantiteAffiliationRequise, Collection<ObjetAlertesNonBloquantes> collectionAlertesNonBloquantes)
    throws CoucheLogiqueException
  {
    List<Reglement> listeReglementPrisEnCompte = new ArrayList();
    listeReglementPrisEnCompte.add(getReglementA8());
    listeReglementPrisEnCompte.add(getReglementA10());
    ComportementAffiliationSpec comportement = instancierComportementAffiliationFPS();
    
    comportement.setCalculTouteAffiliation(true);
    comportement.setChronologieActivitesParticipantes(recupererChronologiePourCalculAffiliation(individu));
    comportement.setFaitGenerateur(parametres.getFaitGenerateurDroit());
    comportement.setListeReglementPrisEnCompte(listeReglementPrisEnCompte);
    comportement.setPeriodeRecherche(periodeReference);
    comportement.setQuantiteAffiliationRequise(quantiteAffiliationRequise);
    comportement.setReglementCandidat(parametres.getReglementEtudie());
    comportement.setJustifierPeriodesSansAffiliation(false);
    
    comportement.setDateExamen(parametres.getDateExamen());
    
    comportement.setConvertisseurUniteAffiliation(((ProduitAsuSpec)getProduit()).determinerConvertisseurUniteAffiliation());
    
    comportement.setDemande(parametres.getDemande());
    
    return CalculAppartenance.calculerQuantiteAffiliation(individu, comportement, justification, collectionAlertesNonBloquantes);
  }
  
  protected IComportementAffiliationFPS instancierComportementAffiliationFPS()
  {
    return ComportementAffiliationFPS.creerInstance();
  }
  
  protected Quantite calculerAffiliationPourReglement(IndividuSpec individu, ParametresCalculAffiliation parametres, Periode periodeReference)
    throws CoucheLogiqueException
  {
    List<Reglement> listeReglementPrisEnCompte = new ArrayList();
    listeReglementPrisEnCompte.add(parametres.getReglementEtudie());
    
    ComportementAffiliationSpec comportement = instancierComportementAffiliationFPS();
    
    comportement.setCalculTouteAffiliation(false);
    comportement.setCalculAffiliationDeBase(true);
    comportement.setChronologieActivitesParticipantes(recupererChronologiePourCalculAffiliation(individu));
    comportement.setFaitGenerateur(parametres.getFaitGenerateurDroit());
    
    comportement.setDateExamen(parametres.getDateExamen());
    comportement.setListeReglementPrisEnCompte(listeReglementPrisEnCompte);
    comportement.setPeriodeRecherche(periodeReference);
    comportement.setReglementCandidat(parametres.getReglementEtudie());
    
    comportement.setConvertisseurUniteAffiliation(((ProduitAsuSpec)getProduit()).determinerConvertisseurUniteAffiliation());
    
    comportement.setDemande(parametres.getDemande());
    
    return CalculAppartenance.calculerQuantiteAffiliation(individu, comportement, null, null);
  }
  
  public Chronologie recupererChronologiePourCalculAffiliation(IndividuSpec individu)
  {
    Chronologie pasPeriodePasseProfessionnel = individu.getChronoPeriodePasseProfessionnelLiquidation();
    
    FiltreOu elementsAPrendreEnCompte = new FiltreOu();
    FiltreNegation nonTravail = new FiltreNegation(new FiltreTravailSpec());
    FiltrePeriodesLiquidables travailLiquidable = new FiltrePeriodesLiquidables();
    elementsAPrendreEnCompte.ajouterFiltre(travailLiquidable);
    elementsAPrendreEnCompte.ajouterFiltre(nonTravail);
    return pasPeriodePasseProfessionnel.copier(elementsAPrendreEnCompte);
  }
  
  protected Periode determinerPRA(IndividuSpec individu, ParametresCalculAffiliation parametres, Damj termePra, Damj bornePRA, List<AllongementPra> listeAllongements)
  {
    ConteneurDeterminationPeriodeReference conteneur = new ConteneurDeterminationPeriodeReference();
    conteneur.setIndividu(individu);
    conteneur.setConstructionChronologie(CONSTRUCTION_CHRONOLOGIE);
    conteneur.setDureeInitialePeriodeReference(determinerDureePRA(parametres));
    conteneur.setTermePeriodeReference(termePra);
    conteneur.setDateBornePRA(bornePRA);
    conteneur.setListeAllongementPRA(listeAllongements);
    conteneur.setJustifierAffiliation(JUSTIFIER_AFFILIATION);
    conteneur.setPrimo(false);
    conteneur.setEstContexteSortieClauseRattrapage(false);
    return getOutilDeterminationPRA().determinerPeriodeDeReference(conteneur);
  }
  
  protected DeterminationPeriodeReference getOutilDeterminationPRA()
  {
    return DeterminationPeriodeReference.getInstance();
  }
  
  protected boolean estAffiliationAcquiseSuffisante(Quantite affiliationAcquise, Quantite affiliationRequise, JustificationAffiliation justification, ProduitAsuSpec produit)
  {
    if (justification != null)
    {
      Iterator<?> itPeriodeElementaireAffi = justification.getListPeriodeElementaireAffiliation().iterator();
      BigDecimal totalAffiliationBase = ZERO;
      while (itPeriodeElementaireAffi.hasNext())
      {
        PeriodeElementaireAffiliation periodeElementaire = (PeriodeElementaireAffiliation)itPeriodeElementaireAffi.next();
        totalAffiliationBase = totalAffiliationBase.add(periodeElementaire.getAffiliationRetenue(produit).getValeur());
      }
      if (totalAffiliationBase.equals(ZERO)) {
        return false;
      }
    }
    return affiliationAcquise.max(affiliationRequise).equals(affiliationAcquise);
  }
  
  protected Damj getTermePeriodeRecherche(DemandeAssuranceSpec demande)
  {
    return demande.getDateExamen().veille();
  }
  
  protected Periode determinerPeriodePourActiviteReference(DemandeAssuranceSpec demande)
  {
    Damj termePeriodeRecherche = getTermePeriodeRecherche(demande);
    Damj debutPeriodeRecherche = Damj.NUIT_DES_TEMPS;
    
    AttributionSpec attribution = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getDemandeur().getChronoDemandesNonTriees(), demande.getDateExamen().lendemain(), new FiltreOuvertureDroitStandardAssurance(true, true, false, false, null));
    if (attribution != null) {
      debutPeriodeRecherche = attribution.getDateAttribution();
    }
    if (estEnContexteIDE(demande))
    {
      DureeCalendaire dureeDelaiRecherche = ((DossierAffecte)demande.getDossierAffectation()).getDelaiRecherche().getDureeCalendaire();
      Damj dateDebutDelais = CalculDelais.determinerDelaiCalendaire(termePeriodeRecherche, dureeDelaiRecherche).getDebut();
      if (dateDebutDelais.estApres(debutPeriodeRecherche)) {
        debutPeriodeRecherche = dateDebutDelais;
      }
    }
    return new Periode(debutPeriodeRecherche, termePeriodeRecherche);
  }
  
  protected Chronologie determinerChronologieActivitesReference(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Periode periodeRechercheActiviteReference = determinerPeriodePourActiviteReference(demande);
    if (periodeRechercheActiviteReference != null)
    {
      FiltresTemporel filtreRechercheActiviteReference = new FiltresTemporel();
      filtreRechercheActiviteReference.ajouterFiltre(new FiltreActiviteSalarie());
      filtreRechercheActiviteReference.ajouterFiltre(new FiltreFinDansBornes(periodeRechercheActiviteReference));
      
      filtreRechercheActiviteReference.ajouterFiltre(new FiltreActiviteSalarieCinemaSpectacle());
      return demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtreRechercheActiviteReference);
    }
    return new ChronologiePeriodes();
  }
  
  protected boolean estEnContexteIDE(DemandeAssuranceSpec demande)
  {
    return demande.getEvenementReferenceExamen() instanceof EreInscriptionDemandeurEmploi;
  }
  
  protected static boolean presenceDonneesForceesValidationProduit(DemandeAssuranceSpec demande)
  {
    return (demande.getDonneesTemporaires().isSaisieCasSpectacleDonneesTemporaire()) && (demande.getDonneesTemporaires().getReglementApplicableSpectacle() != null);
  }
  
  protected static Reglement determinerReglementApplicableDonneesForcees(DemandeAssuranceSpec demandeAssurance)
  {
    return ProduitAsuSpe02P03.getInstance().getReglement(demandeAssurance.getDonneesTemporaires().getReglementApplicableSpectacle());
  }
  
  protected Reglement getReglementA8()
  {
    return ProduitAsuSpe02P03.getInstance().getReglement("A8");
  }
  
  protected Reglement getReglementA10()
  {
    return ProduitAsuSpe02P03.getInstance().getReglement("A10");
  }
  
  protected abstract Quantite determinerAffiliationRequise(ParametresCalculAffiliation paramParametresCalculAffiliation);
  
  protected abstract DureeCalendaire determinerDureePRA(ParametresCalculAffiliation paramParametresCalculAffiliation);
  
  protected abstract Damj determinerBornePRA(DemandeAssuranceSpec paramDemandeAssuranceSpec)
    throws CoucheLogiqueException;
  
  protected abstract Damj determinerTermePRA(Damj paramDamj1, Damj paramDamj2, boolean paramBoolean);
  
  protected abstract ProduitSpec getProduit();
  
  protected Damj trouverLendemainFgPourBornePra(DemandeSpec demandeParam, FiltreCaliSpec filtreElementsAExclure)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)demandeParam;
    Damj dateBornePra = Damj.NUIT_DES_TEMPS;
    
    FiltreET filtre = new FiltreET();
    filtre.ajouterFiltre(new FiltreAttributionSurDecisions(true));
    filtre.ajouterFiltre(new FiltreDemandePourNumeroGamme(1));
    filtre.ajouterFiltre(new FiltreDecisionPourCompetence(1, 1));
    filtre.ajouterFiltre(new FiltreNegation(filtreElementsAExclure));
    
    AttributionSpec attributionPrecedente = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demandeParam.getDemandeur().getChronoDemandesNonTriees(), demandeParam.getDateRecherche().lendemain(), filtre);
    if (attributionPrecedente != null)
    {
      Damj dateFaitGenerateurDernierSinistre = ((Demande)attributionPrecedente.getDemande()).getDateFaitGenerateurOuDernierSinistre();
      if (dateFaitGenerateurDernierSinistre != null) {
        dateBornePra = dateFaitGenerateurDernierSinistre.lendemain();
      }
    }
    boolean estContexteSp = demande.estEnContexteDroitAnterieurSecteurPublic();
    if ((estContexteSp) && (demande.getDonneesTemporaires().getDateFgDroitAnterieurSp().estApres(dateBornePra))) {
      dateBornePra = demande.getDonneesTemporaires().getDateFgDroitAnterieurSp().lendemain();
    }
    return dateBornePra;
  }
}

/* Location:
 * Qualified Name:     OutilConditionAffiliationAbstraite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */