package fr.unedic.cali.asu.fps.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.LigneAsuCSR04;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.LigneAsuCsa06;
import fr.unedic.cali.dom.affectation.LigneAsuSpe02;
import fr.unedic.cali.dom.affectation.LigneAsuSsp07;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreAttributionAssurancePourProduit;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateDeclenchementExamenAvantOuCoincideDateEtInclusParPriorite;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreAttributionEnCoursIndemnisationPourDate;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.FiltresTemporel;

public class OutilConditionBeneficeAutreProduitFPS
{
  public static boolean verifierPresenceIndemnisationEnCoursPourProduit(DemandeSpec p_demande, ProduitSpec p_produit)
    throws ApplicativeException
  {
    FiltreET filtreDecisionAssuranceEnCoursIndemnisation = new FiltreET();
    filtreDecisionAssuranceEnCoursIndemnisation.ajouterFiltre(new FiltreAttributionStandardAssurance(true, true, false, false, null));
    filtreDecisionAssuranceEnCoursIndemnisation.ajouterFiltre(new FiltreAttributionEnCoursIndemnisationPourDate(p_demande.getDateExamen()));
    AttributionSpec attribution = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(p_demande.getChronologieDemandesAssuranceSansCourante(), p_demande, filtreDecisionAssuranceEnCoursIndemnisation);
    if (attribution != null)
    {
      ProduitSpec produitEnCours = attribution.getProduit();
      if (produitEnCours.equals(p_produit)) {
        return false;
      }
    }
    return true;
  }
  
  public static void verifierPresenceAttributionPrecedentePourProduitFds(DemandeSpec p_demande, ProduitSpec p_produit)
    throws ApplicativeException
  {
    FiltresTemporel filtre = new FiltresTemporel();
    filtre.ajouterFiltre(new FiltreAttributionAssurancePourProduit(p_produit));
    
    filtre.ajouterFiltre(new FiltreDateDeclenchementExamenAvantOuCoincideDateEtInclusParPriorite(p_demande.getDateDeclenchementExamen(), p_demande));
    Chronologie chronoAttributionPourProduit = p_demande.getDemandeur().getChronoDemandeAssurance().copier(filtre);
    
    boolean conditionOK = true;
    if (!chronoAttributionPourProduit.estVide()) {
      conditionOK = presenceAttributionAssuranceSuivanteAREOuAPS((DemandeAssuranceSpec)chronoAttributionPourProduit.dernierElement());
    }
    if (!conditionOK) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DEMANDE_BENEF_AUTRE_PROD_PROD");
    }
  }
  
  private static boolean presenceAttributionAssuranceSuivanteAREOuAPS(DemandeAssuranceSpec p_demande)
  {
    AttributionSpec attributionSuivante = (AttributionSpec)OutilRecherche.rechercherDecisionSuivante(p_demande.getChronologieDemandesAssuranceSansCourante(), p_demande, new FiltreAttributionStandardAssurance(true, true, true, false, p_demande));
    if (attributionSuivante == null) {
      return false;
    }
    if (estUneAttributionAPSOuARE(attributionSuivante)) {
      return true;
    }
    return presenceAttributionAssuranceSuivanteAREOuAPS((DemandeAssuranceSpec)attributionSuivante.getDemande());
  }
  
  private static boolean estUneAttributionAPSOuARE(AttributionSpec p_attribution)
  {
    ProduitSpec produit = p_attribution.getProduit();
    LigneSpec ligne = produit.getLigne();
    
    return (LigneAsuCge01.getInstance().equals(ligne)) || (LigneAsuSpe02.getInstance().equals(ligne)) || (LigneAsuCsa06.getInstance().equals(ligne)) || (LigneAsuCSR04.getInstance().equals(ligne)) || (LigneAsuSsp07.getInstance().equals(ligne));
  }
}

/* Location:
 * Qualified Name:     OutilConditionBeneficeAutreProduitFPS
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */