package fr.unedic.cali.asu.liquidation.pnds.outilsfonctionnels;

import fr.unedic.cali.asu.liquidation.pnds.StrategiePNDSSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeNonDeclaree;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.autresdoms.ga.dom.TravailSalarie;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.pnds.PeriodeNonDeclareeSanction;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.OutilOptimisationChronologie;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class StrategiePNDSCgeApresMEP08SI1
  implements StrategiePNDSSpec
{
  private static final int NB_JOURS_ADMISIBLE_PND = 3;
  
  public PeriodeNonDeclareeSanction determinerPNDS(IndividuSpec p_individu, ActiviteSalarie p_activite, Damj p_dateDebut, Damj p_dateFin, Damj p_dateExamen)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronologieResultat = new ChronologiePeriodes();
    ChronologiePeriodes chronologiePnd = new ChronologiePeriodes();
    Salaire periodeSalaireCourante = null;
    Periode periodeCalculPNDS = new Periode(p_dateDebut, p_dateFin);
    
    Chronologie chronoPeriodesSalaire = p_activite.getListeSalaires();
    chronoPeriodesSalaire.iterer();
    while (chronoPeriodesSalaire.encoreSuivant())
    {
      periodeSalaireCourante = (Salaire)chronoPeriodesSalaire.elementSuivant();
      ChronologiePeriodes chronoPeriodePNDSurPeriode = determinerChronologiePNDSurPeriode(periodeSalaireCourante.getCollectionPND(), periodeCalculPNDS);
      if (chronoPeriodePNDSurPeriode != null) {
        chronologiePnd.ajouter(chronoPeriodePNDSurPeriode);
      }
    }
    if ((chronologiePnd != null) && (!chronologiePnd.estVide()))
    {
      List listeAttributions = p_individu.getListeAttributionsChevauchantPeriode(new Periode(p_activite.getDateDebut(), p_activite.getDateFin()), p_dateExamen);
      if ((listeAttributions != null) && (!listeAttributions.isEmpty())) {
        chronologieResultat = determinerChronoPnds(chronologiePnd, listeAttributions);
      }
    }
    PeriodeNonDeclareeSanction resultat = PeriodeNonDeclareeSanction.creerInstance(chronologieResultat);
    resultat.setPeriodeActivite(p_activite);
    return resultat;
  }
  
  private ChronologiePeriodes determinerChronologiePNDSurPeriode(Collection p_collectionPND, Periode p_periode)
  {
    if ((p_collectionPND != null) && (!p_collectionPND.isEmpty()))
    {
      ChronologiePeriodes resultat = new ChronologiePeriodes();
      Iterator itCollectionPND = p_collectionPND.iterator();
      while (itCollectionPND.hasNext())
      {
        ObjetChronoPeriode periodePND = (ObjetChronoPeriode)itCollectionPND.next();
        Periode intersection = periodePND.periodeIntersection(p_periode);
        if (intersection != null) {
          resultat.ajouterB(new ObjetChronoPeriodeConcrete(intersection));
        }
      }
      return resultat;
    }
    return null;
  }
  
  public Collection determinerPNDS(IndividuSpec p_individu, Collection p_listeAttributions, Damj p_dateDebut, Damj p_dateFin, Damj p_dateExamen)
  {
    ChronologiePeriodes chronologieResultat = new ChronologiePeriodes();
    ChronologiePeriodes chronologiePnd = new ChronologiePeriodes();
    Periode periodeCalculPND = new Periode(p_dateDebut, p_dateFin);
    if ((p_listeAttributions != null) && (!p_listeAttributions.isEmpty()))
    {
      FiltresTemporel filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltreChevauchePeriode(new Periode(p_dateDebut, p_dateFin)));
      Chronologie chronoPasseProfessionnel = p_individu.getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
      Iterator iteratorPeriode = chronoPasseProfessionnel.iterer();
      while (iteratorPeriode.hasNext())
      {
        ObjetChronoPeriode periodeActivite = (ObjetChronoPeriode)iteratorPeriode.next();
        if ((periodeActivite instanceof TravailSalarie))
        {
          Chronologie chronoPeriodesSalaire = ((TravailSalarie)periodeActivite).getListeSalaires();
          chronoPeriodesSalaire.iterer();
          
          determinerChronoPNDSelonChronoSalaire(chronoPeriodesSalaire, chronologiePnd, periodeCalculPND);
        }
        else if ((periodeActivite instanceof ActiviteSalarie))
        {
          periodeActivite = ((ActiviteSalarie)periodeActivite).getPeriodeActiviteSalarieGaec();
          Chronologie chronoPeriodesSalaire = ((TravailSalarie)periodeActivite).getListeSalaires();
          chronoPeriodesSalaire.iterer();
          
          determinerChronoPNDSelonChronoSalaire(chronoPeriodesSalaire, chronologiePnd, periodeCalculPND);
        }
      }
      chronologieResultat = determinerChronoPnds(chronologiePnd, p_listeAttributions);
    }
    PeriodeNonDeclareeSanction pnds = PeriodeNonDeclareeSanction.creerInstance(chronologieResultat);
    Collection resultat = new ArrayList();
    resultat.add(pnds);
    return resultat;
  }
  
  private void determinerChronoPNDSelonChronoSalaire(Chronologie p_chronoPeriodesSalaire, ChronologiePeriodes p_chronologiePnd, Periode p_periodeCalculPND)
  {
    while (p_chronoPeriodesSalaire.encoreSuivant())
    {
      Salaire periodeSalaire = (Salaire)p_chronoPeriodesSalaire.elementSuivant();
      
      ChronologiePeriodes chronoPeriodePNDSurPeriode = determinerChronologiePNDSurPeriode(periodeSalaire.getCollectionPND(), p_periodeCalculPND);
      if (chronoPeriodePNDSurPeriode != null) {
        p_chronologiePnd.ajouter(chronoPeriodePNDSurPeriode);
      }
    }
  }
  
  private ChronologiePeriodes determinerChronoPnds(ChronologiePeriodes chronoPnd, Collection listeAttributions)
  {
    ChronologiePeriodes chronologieResultat = new ChronologiePeriodes();
    Iterator iteratorListeAttribution = null;
    AttributionSpec attributionCourante = null;
    if (!chronoPnd.estVide())
    {
      ChronologiePeriodes chronologieResultatTemp = new ChronologiePeriodes();
      
      OutilOptimisationChronologie outilOptimisationChronologie = new OutilOptimisationChronologie(chronologieResultatTemp);
      iteratorListeAttribution = listeAttributions.iterator();
      while (iteratorListeAttribution.hasNext())
      {
        attributionCourante = (AttributionSpec)iteratorListeAttribution.next();
        if ((attributionCourante.estValidee()) && ((attributionCourante.getGamme().getNomUnique().equals("ASU")) || (attributionCourante.getGamme().getNomUnique().equals("SOL")) || (attributionCourante.getGamme().getNomUnique().equals("FOR"))) && 
        
          (attributionCourante.getCalendrierExecutionCalcul() != null))
        {
          Periode periode = new Periode(attributionCourante.getDateAttribution(), attributionCourante.getCalendrierExecutionCalcul().getDernierJourIndemnisable());
          
          Iterator iteratorPeriodeAvecPnd = chronoPnd.iterer();
          while (iteratorPeriodeAvecPnd.hasNext())
          {
            ObjetChronoPeriode chronoPeriode = (ObjetChronoPeriode)iteratorPeriodeAvecPnd.next();
            if ((chronoPeriode.chevauche(periode)) && (!chronologieResultatTemp.contientElement(chronoPeriode))) {
              outilOptimisationChronologie.ajouter(chronoPeriode);
            }
          }
        }
      }
      chronologieResultatTemp = (ChronologiePeriodes)outilOptimisationChronologie.getChronologieTriee();
      
      chronologieResultat = filtreChronoNombreJoursAdmissible(chronologieResultatTemp);
      
      chronologieResultat = filtreIntersectioPNDAttributions(chronologieResultat, listeAttributions);
      if (chronologieResultat.contientChevauchementElements()) {
        chronologieResultat = chronologieResultat.fusionnerChevauchementPeriodes();
      }
      chronologieResultat = filtreChronoNombreJoursAdmissible(chronologieResultat);
    }
    return chronologieResultat;
  }
  
  private ChronologiePeriodes filtreChronoNombreJoursAdmissible(ChronologiePeriodes p_chronoPNDS)
  {
    ChronologiePeriodes chronologieResultat = (ChronologiePeriodes)p_chronoPNDS.copie();
    
    ChronologiePeriodes chronologieResultatTemp = (ChronologiePeriodes)p_chronoPNDS.copie();
    ChronologiePeriodes chronologieResultatTempB = (ChronologiePeriodes)p_chronoPNDS.copie();
    Iterator iteratorA = chronologieResultatTemp.iterer();
    Iterator iteratorB = null;
    Iterator iteratorC = null;
    ObjetChronoPeriode chronoPeriodeB = null;
    int nbJourPNDTotalPourMois = 0;
    while (iteratorA.hasNext())
    {
      ObjetChronoPeriode chronoPeriodeA = (ObjetChronoPeriode)iteratorA.next();
      Damj moisCourant = chronoPeriodeA.getDateDebut().getDebutMois();
      for (iteratorB = chronologieResultatTempB.iterer(); iteratorB.hasNext();)
      {
        chronoPeriodeB = (ObjetChronoPeriode)iteratorB.next();
        if (chronoPeriodeB.getDateDebut().getDebutMois().coincideAvec(moisCourant)) {
          nbJourPNDTotalPourMois += chronoPeriodeB.getDuree();
        }
      }
      if (nbJourPNDTotalPourMois <= 3) {
        for (iteratorC = chronologieResultat.iterer(); iteratorC.hasNext();)
        {
          ObjetChronoPeriode chronoPeriodeC = (ObjetChronoPeriode)iteratorC.next();
          if ((chronoPeriodeC.getDateDebut().coincideAvec(chronoPeriodeA.getDateDebut())) && (chronoPeriodeC.getDateFin().coincideAvec(chronoPeriodeA.getDateFin()))) {
            iteratorC.remove();
          }
        }
      }
      nbJourPNDTotalPourMois = 0;
    }
    return chronologieResultat;
  }
  
  private ChronologiePeriodes filtreIntersectioPNDAttributions(ChronologiePeriodes chronologiePNDS, Collection listeAttributions)
  {
    ChronologiePeriodes chronologieResultat = new ChronologiePeriodes();
    OutilOptimisationChronologie outilOptimisationChronologie = new OutilOptimisationChronologie(chronologieResultat);
    Iterator iteratorListeAttribution = null;
    AttributionSpec attributionCourante = null;
    ChronologiePeriodes chronologieResultatTemp = (ChronologiePeriodes)chronologiePNDS.copie();
    Iterator iteratorPeriodeAvecPndsA = chronologieResultatTemp.iterer();
    while (iteratorPeriodeAvecPndsA.hasNext())
    {
      ObjetChronoPeriode chronoPeriodeA = (ObjetChronoPeriode)iteratorPeriodeAvecPndsA.next();
      Periode periodePNDSCourante = new Periode(chronoPeriodeA.getDateDebut(), chronoPeriodeA.getDateFin());
      
      iteratorListeAttribution = listeAttributions.iterator();
      while (iteratorListeAttribution.hasNext())
      {
        attributionCourante = (AttributionSpec)iteratorListeAttribution.next();
        if ((attributionCourante.estValidee()) && ((attributionCourante.getGamme().getNomUnique().equals("SOL")) || (attributionCourante.getGamme().getNomUnique().equals("ASU")) || (attributionCourante.getGamme().getNomUnique().equals("FOR"))) && 
        
          (attributionCourante.getCalendrierExecutionCalcul() != null))
        {
          Periode periodeAttributionCourante = new Periode(attributionCourante.getDateAttribution(), attributionCourante.getCalendrierExecutionCalcul().getDernierJourIndemnisable());
          if (periodePNDSCourante.chevauche(periodeAttributionCourante)) {
            if (periodePNDSCourante.estContenueDans(periodeAttributionCourante))
            {
              outilOptimisationChronologie.ajouter(chronoPeriodeA);
            }
            else
            {
              PeriodeNonDeclaree chronoPeriode = new PeriodeNonDeclaree();
              if (periodePNDSCourante.estChevaucheeAuDebut(periodeAttributionCourante))
              {
                chronoPeriode.setDateDebut(periodePNDSCourante.getDebut());
                chronoPeriode.setDateFin(periodeAttributionCourante.getFin());
                outilOptimisationChronologie.ajouter(chronoPeriode);
              }
              else
              {
                chronoPeriode.setDateDebut(periodeAttributionCourante.getDebut());
                chronoPeriode.setDateFin(periodePNDSCourante.getFin());
                outilOptimisationChronologie.ajouter(chronoPeriode);
              }
            }
          }
        }
      }
    }
    return (ChronologiePeriodes)outilOptimisationChronologie.getChronologieTriee();
  }
}

/* Location:
 * Qualified Name:     StrategiePNDSCgeApresMEP08SI1
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */