package fr.unedic.cali.asu.liquidation.pnds.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.liquidation.pnds.StrategiePNDSSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.pnds.PeriodeNonDeclareeSanction;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.Map;

public class StrategiePNDSCgeApresMEP09SI2
  implements StrategiePNDSSpec
{
  public PeriodeNonDeclareeSanction determinerPNDS(IndividuSpec individu, ActiviteSalarie activite, Damj dateDebut, Damj dateFin, Damj dateExamen)
    throws ApplicativeException
  {
    PeriodeNonDeclareeSanction resultat = null;
    
    Periode periodeReferencePNDS = determinerPeriodeComplete(dateDebut, dateFin);
    
    Map<PeriodeGaecSpec, PeriodeNonDeclareeSanction> listePNDSIndividu = individu.getListePNDSIndividu();
    if ((listePNDSIndividu != null) && (!listePNDSIndividu.isEmpty()))
    {
      PeriodeNonDeclareeSanction pnds = (PeriodeNonDeclareeSanction)listePNDSIndividu.get(activite);
      resultat = constuirePNDSSurPeriodeDeReference(pnds, periodeReferencePNDS);
    }
    return resultat;
  }
  
  public Collection<PeriodeNonDeclareeSanction> determinerPNDS(IndividuSpec individu, Collection listeAttributions, Damj dateDebut, Damj dateFin, Damj dateExamen)
    throws ApplicativeException
  {
    Collection<PeriodeNonDeclareeSanction> listePndsSurPeriodeReference = new ArrayList();
    
    Periode periodePNDS = determinerPeriodeComplete(dateDebut, dateFin);
    
    Map<PeriodeGaecSpec, PeriodeNonDeclareeSanction> listePNDSIndividu = individu.getListePNDSIndividu();
    if ((listePNDSIndividu != null) && (!listePNDSIndividu.isEmpty()))
    {
      Collection<PeriodeNonDeclareeSanction> listePndsParActivites = listePNDSIndividu.values();
      Iterator<PeriodeNonDeclareeSanction> itPnds = listePndsParActivites.iterator();
      while (itPnds.hasNext())
      {
        PeriodeNonDeclareeSanction pnds = (PeriodeNonDeclareeSanction)itPnds.next();
        PeriodeNonDeclareeSanction resultat = constuirePNDSSurPeriodeDeReference(pnds, periodePNDS);
        if (resultat != null) {
          listePndsSurPeriodeReference.add(resultat);
        }
      }
    }
    return listePndsSurPeriodeReference;
  }
  
  private Periode determinerPeriodeComplete(Damj dateDebut, Damj dateFin)
  {
    Damj dateDebutPeriode = dateDebut;
    Damj dateFinPeriode = dateFin;
    if (!dateDebutPeriode.estLeDebutDuMois()) {
      dateDebutPeriode = dateDebutPeriode.getDebutMois();
    }
    if (!dateFinPeriode.estLaFinDuMois()) {
      dateFinPeriode = dateFinPeriode.getFinMois();
    }
    return new Periode(dateDebutPeriode, dateFinPeriode);
  }
  
  private PeriodeNonDeclareeSanction constuirePNDSSurPeriodeDeReference(PeriodeNonDeclareeSanction pndsHorsPeriode, Periode periodeReference)
  {
    PeriodeNonDeclareeSanction pndsSurPeriodeReference = null;
    ChronologiePeriodes chronoPndsSurPeriodeReference = new ChronologiePeriodes();
    if ((pndsHorsPeriode != null) && (pndsHorsPeriode.getChronoPeriodePNDS() != null) && (!pndsHorsPeriode.getChronoPeriodePNDS().estVide()))
    {
      Chronologie chronoPnds = pndsHorsPeriode.getChronoPeriodePNDS().copier(new FiltreChevauchePeriode(periodeReference));
      chronoPnds.iterer();
      while (chronoPnds.encoreSuivant())
      {
        ObjetChronoPeriode periodeChronoPnds = (ObjetChronoPeriode)chronoPnds.elementSuivant();
        Periode periodeInter = periodeChronoPnds.periodeIntersection(periodeReference);
        if (periodeInter != null) {
          chronoPndsSurPeriodeReference.ajouterB(new ObjetChronoPeriodeConcrete(periodeInter));
        }
      }
      if (!chronoPndsSurPeriodeReference.estVide())
      {
        pndsSurPeriodeReference = PeriodeNonDeclareeSanction.creerInstance(chronoPndsSurPeriodeReference);
        pndsSurPeriodeReference.setPeriodeActivite(pndsHorsPeriode.getPeriodeActivite());
      }
    }
    return pndsSurPeriodeReference;
  }
}

/* Location:
 * Qualified Name:     StrategiePNDSCgeApresMEP09SI2
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */