package fr.unedic.cali.asu.may17.p02.calcul.dom;

import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.may17.p02.calcul.dom.gen.MontantGen;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import java.math.BigDecimal;

public class Montant
  extends MontantGen
  implements MontantAsuSpec
{
  private static final long serialVersionUID = -4100655066251297475L;
  public static final String PLAFOND = "17";
  public static final String PLANCHER_50 = "18";
  public static final String PLANCHER_35 = "19";
  public static final String MINI = "02";
  protected transient Quantite m_mini = null;
  protected transient Quantite m_plancher = null;
  protected transient Quantite m_plafond = null;
  protected transient Quantite m_montantBrutSansPensionInvaliditeADeduire = null;
  protected transient Quantite m_pensionInvaliditeADeduirePriseEnCompte = null;
  protected transient Quantite m_montantJournalierAvantageVieillesse = null;
  protected transient Quantite m_montantJournalierAvantageVieillesseDeduit = null;
  protected transient Quantite m_montantBrutSansAvantageVieillesseDeduit = null;
  protected transient String m_justificationCalculMontant = null;
  protected transient String m_type = "NORMAL";
  
  public Montant()
  {
    setAvecPrecompteCRC(false);
  }
  
  public Montant(DomPCSpec p_montantPC)
  {
    super(p_montantPC);
  }
  
  public Quantite getMini()
  {
    return m_mini;
  }
  
  public Quantite getMontantNet()
  {
    return null;
  }
  
  public Quantite getPlafond()
  {
    return m_plafond;
  }
  
  public Quantite getPlancher()
  {
    return m_plancher;
  }
  
  public String getType()
  {
    return m_type;
  }
  
  public void setMini(Quantite p_mini)
  {
    m_mini = p_mini;
  }
  
  public void setPlafond(Quantite p_plafond)
  {
    m_plafond = p_plafond;
  }
  
  public void setPlancher(Quantite p_plancher)
  {
    m_plancher = p_plancher;
  }
  
  public Quantite getMontantBrutSansPensionInvaliditeADeduire()
  {
    return m_montantBrutSansPensionInvaliditeADeduire;
  }
  
  public void setMontantBrutSansPensionInvaliditeADeduire(Quantite p_quantite)
  {
    m_montantBrutSansPensionInvaliditeADeduire = p_quantite;
  }
  
  public Quantite getPensionInvaliditeADeduirePriseEnCompte()
  {
    if (m_pensionInvaliditeADeduirePriseEnCompte == null) {
      m_pensionInvaliditeADeduirePriseEnCompte = new QuantiteEuro("0");
    }
    return m_pensionInvaliditeADeduirePriseEnCompte;
  }
  
  public void setPensionInvaliditeADeduirePriseEnCompte(Quantite p_quantite)
  {
    m_pensionInvaliditeADeduirePriseEnCompte = p_quantite;
  }
  
  public Quantite getMontantJournalierAvantageVieillesse()
  {
    if (m_montantJournalierAvantageVieillesse == null) {
      m_montantJournalierAvantageVieillesse = new QuantiteEuro("0");
    }
    return m_montantJournalierAvantageVieillesse;
  }
  
  public void setMontantJournalierAvantageVieillesse(Quantite p_quantite)
  {
    m_montantJournalierAvantageVieillesse = p_quantite;
  }
  
  public Quantite getMontantJournalierAvantageVieillesseDeduit()
  {
    if (m_montantJournalierAvantageVieillesseDeduit == null) {
      m_montantJournalierAvantageVieillesseDeduit = new QuantiteEuro("0");
    }
    return m_montantJournalierAvantageVieillesseDeduit;
  }
  
  public void setMontantJournalierAvantageVieillesseDeduit(Quantite p_quantite)
  {
    m_montantJournalierAvantageVieillesseDeduit = p_quantite;
  }
  
  public Quantite getMontantBrutSansAvantageVieillesseDeduit()
  {
    if (m_montantBrutSansAvantageVieillesseDeduit == null) {
      m_montantBrutSansAvantageVieillesseDeduit = new QuantiteEuro("0");
    }
    return m_montantBrutSansAvantageVieillesseDeduit;
  }
  
  public void setMontantBrutSansAvantageVieillesseDeduit(Quantite p_quantite)
  {
    m_montantBrutSansAvantageVieillesseDeduit = p_quantite;
  }
  
  public String getJustificationCalculMontant()
  {
    return m_justificationCalculMontant;
  }
  
  public void setJustificationCalculMontant(String p_justificationCalculMontant)
  {
    m_justificationCalculMontant = p_justificationCalculMontant;
  }
  
  public BigDecimal getMontantPrecompte()
  {
    return getMontantBrut().getValeur().subtract(getCrc().getValeur());
  }
  
  public Quantite getMontantPrecompteEffectif()
  {
    if (getAvecPrecompteCRC()) {
      return new Quantite(getMontantBrut().getValeur().subtract(getCrc().getValeur()), getMontantBrut().getUnite());
    }
    return getMontantBrut();
  }
  
  public void setType(String p_type)
  {
    m_type = p_type;
  }
  
  public ObjetMetierSpec copie()
  {
    Montant copie = new Montant();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    Montant copie = (Montant)p_copie;
    super.copieElements(copie);
    m_type = getType();
    m_mini = getMini();
    m_plafond = getPlafond();
    m_montantBrutSansPensionInvaliditeADeduire = getMontantBrutSansPensionInvaliditeADeduire();
    m_pensionInvaliditeADeduirePriseEnCompte = getPensionInvaliditeADeduirePriseEnCompte();
    m_montantJournalierAvantageVieillesse = getMontantJournalierAvantageVieillesse();
    m_montantJournalierAvantageVieillesseDeduit = getMontantJournalierAvantageVieillesseDeduit();
    m_montantBrutSansAvantageVieillesseDeduit = getMontantBrutSansAvantageVieillesseDeduit();
    m_justificationCalculMontant = getJustificationCalculMontant();
  }
  
  public String toString()
  {
    StringBuffer string = new StringBuffer();
    string.append("\nMontant : " + getMontantBrut() + "\n");
    return string.toString();
  }
  
  public Quantite getCsgEstimee()
  {
    return null;
  }
  
  public Quantite getCrdsEstimee()
  {
    return null;
  }
  
  public Quantite getCcamEstimee(boolean p_topAlsaceMoselle)
  {
    return null;
  }
  
  public Quantite getMontantNetEstime(boolean p_topAlsaceMoselle)
  {
    return null;
  }
  
  public MontantAsuSpec getMontantAreExecute()
  {
    return null;
  }
  
  public MontantAsuSpec getMontantAreNonExecute()
  {
    return null;
  }
  
  public BigDecimal getSjrMontantMax()
  {
    return null;
  }
  
  public BigDecimal getPlafondASP()
  {
    return null;
  }
  
  public Montant getMontantSJR()
  {
    return null;
  }
}

/* Location:
 * Qualified Name:     Montant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */