package fr.unedic.cali.asu.may17.p02.liquidation.dom;

import fr.unedic.cali.ari.dom.Demande;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.may17.p02.liquidation.dom.gen.AdmissionGen;
import fr.unedic.cali.asu.may17.p02.liquidation.outilsfonctionnels.OutilCalculDonneesNonPersistantes;
import fr.unedic.cali.asu.may17.p02.liquidation.outilsfonctionnels.RecuperationElementIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodePensionInvaliditeChaineeSpec;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvantSpec;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.List;

public class Admission
  extends AdmissionGen
  implements OdSpec
{
  private static final long serialVersionUID = 1738816388134178916L;
  protected transient ElementBaseIndemnisation ebiAdmission = null;
  protected transient CalendrierExecutionAvantSpec calendrierExecutionAvantSpec = null;
  private transient Damj pjiEffectif;
  
  public Admission(DomPCSpec pc)
  {
    super(pc);
    setNatureDecision(10);
  }
  
  private Admission()
  {
    setNatureDecision(10);
  }
  
  public Admission(ProduitSpec produit)
  {
    setNatureDecision(10);
    setCodeProduit(produit.getCode());
  }
  
  public ObjetMetierSpec copie()
  {
    Admission copie = new Admission();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec pcopie)
  {
    Admission copie = (Admission)pcopie;
    copie.setCodeProduit(super.getCodeProduit());
    super.copieElements(copie);
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
    throws CoucheLogiqueException
  {
    if (ebiAdmission == null) {
      ebiAdmission = RecuperationElementIndemnisation.recupererElementBaseIndemnisation(this);
    }
    return ebiAdmission;
  }
  
  public BigDecimal getCoefficientTP()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverCoefficientTP((Demande)getDemande());
  }
  
  public Damj getTermePRC()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverTermePRC((Demande)getDemande());
  }
  
  public List getListeDurees()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverListeDurees((Demande)getDemande());
  }
  
  public BigDecimal getDureeTranche1()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverDureeTranche1((Demande)getDemande());
  }
  
  public BigDecimal getDureeTranche2()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverDureeTranche2((Demande)getDemande());
  }
  
  public BigDecimal getDureeTranche3()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverDureeTranche3((Demande)getDemande());
  }
  
  public BigDecimal getMontantTranche1()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverMontantTranche1((Demande)getDemande());
  }
  
  public BigDecimal getMontantTranche2()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverMontantTranche2((Demande)getDemande());
  }
  
  public BigDecimal getMontantTranche3()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverMontantTranche3((Demande)getDemande());
  }
  
  public BigDecimal getCapitalTranche1()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverCapitalTranche1((Demande)getDemande());
  }
  
  public BigDecimal getCapitalTranche2()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverCapitalTranche2((Demande)getDemande());
  }
  
  public BigDecimal getCapitalTranche3()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverCapitalTranche3((Demande)getDemande());
  }
  
  public BigDecimal getMontantCrcTranche1()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverMontantCrcTranche1((Demande)getDemande());
  }
  
  public BigDecimal getMontantCrcTranche2()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverMontantCrcTranche2((Demande)getDemande());
  }
  
  public BigDecimal getMontantCrcTranche3()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverMontantCrcTranche3((Demande)getDemande());
  }
  
  public BigDecimal getMontantPensionInvaliditeADeduire()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverMontantMontantPensionInvaliditeADeduire((Demande)getDemande());
  }
  
  public BigDecimal getMontantAvantageVieillesse()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverMontantAvantageVieillesse((Demande)getDemande());
  }
  
  public Damj getDateFaitGenerateur()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverDateFaitGenerateur((Demande)getDemande());
  }
  
  public Damj getDateFinPMC()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverDateFinPMC((Demande)getDemande());
  }
  
  public int getNbJoursICCP()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverNbJoursICCP((Demande)getDemande());
  }
  
  public int getNbJoursISLR()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverNbJoursISLR((Demande)getDemande());
  }
  
  public int getNbJoursDelaiAttente()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverNbJoursDelaiAttente((Demande)getDemande());
  }
  
  public Damj getPointDepartDelaisReport()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverPointDepartDelaisReport((Demande)getDemande());
  }
  
  public Damj getPjiTheorique()
  {
    try
    {
      return OutilCalculDonneesNonPersistantes.trouverPjiTheorique((Demande)getDemande());
    }
    catch (CoucheLogiqueException ex) {}
    return null;
  }
  
  public boolean isPresenceActiviteConservee()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverPresenceActiviteConservee((Demande)getDemande());
  }
  
  public List getListeCarences()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverListeCarences((Demande)getDemande());
  }
  
  public BigDecimal getSJRInitial()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverSJRInitial((Demande)getDemande());
  }
  
  public BigDecimal getSJCInitial()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverSJCInitial((Demande)getDemande());
  }
  
  public DureeCalendaire getAgeFaitGenerateur()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverAgeFaitGenerateur((Demande)getDemande());
  }
  
  public BigDecimal getSJRRP()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverSJRRP((Demande)getDemande());
  }
  
  public BigDecimal getRevenuMensuelANSConservee()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverRevenuMensuelANSConservee((Demande)getDemande());
  }
  
  public boolean isTopContratsRemuneresBaseSmic()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverTopContratsRemuneresBaseSmic((Demande)getDemande());
  }
  
  public CalendrierExecutionCalculSpec getCalendrierExecutionCalcul()
  {
    return super.getCalendrierExecutionCalcul();
  }
  
  public void setCalendrierExecutionCalcul(CalendrierExecutionCalculSpec calendrier)
  {
    DomManager.supprimer(super.getCalendrierExecutionCalcul(), calendrier);
    super.setCalendrierExecutionCalcul(calendrier);
  }
  
  public CalendrierExecutionAvantSpec getCalendrierExecutionAvant()
  {
    return calendrierExecutionAvantSpec;
  }
  
  public void setCalendrierExecutionAvant(CalendrierExecutionAvantSpec calendrierAvant)
  {
    calendrierExecutionAvantSpec = calendrierAvant;
  }
  
  public void setPjiEffectif(Damj pjiEffectif)
  {
    this.pjiEffectif = pjiEffectif;
  }
  
  public Damj getPjiEffectif()
  {
    return pjiEffectif;
  }
  
  public Damj getPji()
  {
    if (pjiEffectif != null) {
      return pjiEffectif;
    }
    return getPjiTheorique();
  }
  
  public boolean estPjiEffectif()
  {
    return pjiEffectif != null;
  }
  
  public Attribution getAttributionAssurance()
  {
    return new AttributionAssuranceMayotte(this);
  }
  
  public BigDecimal getDureeIndemnisationInitiale()
  {
    try
    {
      return getDureeTranche1().add(getDureeTranche2()).add(getDureeTranche3());
    }
    catch (CoucheLogiqueException ex) {}
    return BigDecimal.ZERO;
  }
  
  public ConventionGestionSpec getConventionGestion()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.creerConventionGestion((Demande)getDemande());
  }
  
  public int getCompetenceAdministrative()
    throws CoucheLogiqueException
  {
    int competenceAdministrative = 0;
    String stringCompetence = OutilCalculDonneesNonPersistantes.trouverCompetenceAdministrative((Demande)getDemande());
    if ((stringCompetence != null) && (!"".equals(stringCompetence))) {
      competenceAdministrative = Integer.parseInt(stringCompetence);
    }
    return competenceAdministrative;
  }
  
  public int getCompetenceFinanciere()
    throws CoucheLogiqueException
  {
    int competenceFinanciere = 0;
    String stringCompetence = OutilCalculDonneesNonPersistantes.trouverCompetenceFinanciere((Demande)getDemande());
    if ((stringCompetence != null) && (!"".equals(stringCompetence))) {
      competenceFinanciere = Integer.parseInt(stringCompetence);
    }
    return competenceFinanciere;
  }
  
  public Collection<PeriodePensionInvaliditeChaineeSpec> getListePensionsInvalidite()
    throws CoucheLogiqueException
  {
    return OutilCalculDonneesNonPersistantes.trouverListePensionsInvalidite((Demande)getDemande());
  }
  
  public ProduitSpec getProduitExecution()
  {
    return getProduit();
  }
  
  public void marquerGraphePersistant()
  {
    super.marquerGraphePersistant();
    DomManager.persisterEnProfondeur(super.getCalendrierExecutionCalcul());
  }
}

/* Location:
 * Qualified Name:     Admission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */