package fr.unedic.cali.asu.migration.graphes;

import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.EreDemandeExpresse;
import fr.unedic.cali.asu.dom.EreFinDroitSpectacle;
import fr.unedic.cali.asu.dom.EreFinDroitSuiteRepriseNonSaisonniere;
import fr.unedic.cali.asu.dom.EreInscriptionDemandeurEmploi;
import fr.unedic.cali.asu.dom.ErePassageCPSuiteRejetDV;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.migration.mapping.MappingMontantBrutJournalier;
import fr.unedic.cali.asu.migration.mapping.MappingUniteAffiliation;
import fr.unedic.cali.autresdoms.cohab.dom.CodesErreursMigration;
import fr.unedic.cali.autresdoms.cohab.dom.DemandeMigreeEnErreur;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.migration.GrapheLiquidation;
import fr.unedic.cali.outilsfonctionnels.ConstructionCSOIA;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieEtantFCT;
import fr.unedic.cohabitation.sigma.migration.dom.DecisionMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeV1;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;

public abstract class GrapheAssurance
  extends GrapheLiquidation
{
  protected String getTypeDemande()
  {
    return "Demande d'Assurance ";
  }
  
  protected DemandeSpec construireGraphe(DemandeMigreeV1 p_demandeV1)
  {
    if (!(p_demandeV1 instanceof DemandeMigreeAsuV1)) {
      return null;
    }
    DemandeMigreeAsuV1 demandeTemporaireSigma = (DemandeMigreeAsuV1)p_demandeV1;
    
    Demande demandeAsu = new Demande();
    
    demandeAsu.createDonneesTemporaires();
    demandeAsu.createFormulaireAsu();
    demandeAsu.setEstFormulaireCharge(true);
    demandeAsu.setEvenementReferenceExamen(creerEvenementReferenceExamen(demandeTemporaireSigma));
    
    ObjectifExamen objectif = creerObjectifDecision(demandeTemporaireSigma);
    demandeAsu.setObjectifCourant(objectif);
    demandeAsu.ajouterObjectifExamen(objectif);
    
    demandeAsu.createReliquat();
    
    return demandeAsu;
  }
  
  protected abstract ObjectifExamen creerObjectifDecision(DemandeMigreeAsuV1 paramDemandeMigreeAsuV1);
  
  public void postTraitementMigrerDemande(DemandeMigreeV1 p_demandeV1, DemandeSpec p_demande, DemandeMigreeEnErreur p_demandeMigreeEnErreur)
    throws CoucheLogiqueException
  {
    miseAJourDemandeOrigine(p_demande);
    
    p_demandeMigreeEnErreur.getListeErreurs().addAll(getListeErreurs());
  }
  
  protected void miseAJourDemandeOrigine(DemandeSpec p_demande) {}
  
  protected void alimenterDonnees(DemandeMigreeV1 p_demandeV1, DemandeSpec p_demande)
  {
    if (!(p_demandeV1 instanceof DemandeMigreeAsuV1)) {
      return;
    }
    Demande demandeAsu = (Demande)p_demande;
    
    DemandeMigreeAsuV1 demandeTemporaireSigma = (DemandeMigreeAsuV1)p_demandeV1;
    
    alimenterTopMigree(demandeTemporaireSigma, demandeAsu);
    alimenterTopNeutralisee(demandeTemporaireSigma, demandeAsu);
    
    alimenterDonneesTemporaires(demandeTemporaireSigma, demandeAsu);
    alimenterFormulaire(demandeTemporaireSigma, demandeAsu);
    alimenterEre(demandeTemporaireSigma, demandeAsu);
    
    alimenterReliquat(demandeTemporaireSigma, demandeAsu);
    
    alimenterComportementDemandeNonLiquidable(demandeTemporaireSigma, demandeAsu);
  }
  
  protected void alimenterComportementDemandeNonLiquidable(DemandeMigreeAsuV1 p_demandeV1, Demande p_demande)
  {
    if (p_demandeV1.isEstNeutraliseeLiquidation()) {
      p_demande.setComportmentDemandeMigree(1);
    }
  }
  
  protected void alimenterDonneesForcage(DemandeMigreeV1 p_demandeV1, DemandeSpec p_demande)
  {
    if (!(p_demandeV1 instanceof DemandeMigreeAsuV1)) {
      return;
    }
    Demande demandeAsu = (Demande)p_demande;
    
    DemandeMigreeAsuV1 demandeTemporaireSigma = (DemandeMigreeAsuV1)p_demandeV1;
    
    alimenterEre(demandeTemporaireSigma, demandeAsu);
    alimenterAllongementDelaiDecheance(demandeTemporaireSigma, demandeAsu);
  }
  
  protected void alimenterPeriodeForcee(DemandeMigreeV1 p_demandeV1, DemandeSpec p_demande)
  {
    DossierAffectation dossierAffectation = (DossierAffectation)p_demande.getDossierAffectation();
    DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)dossierAffectation.getDossierExamen();
    DecisionMigreeAsuV1 decisionAsu = ((DemandeMigreeAsuV1)p_demandeV1).getDecision();
    if (decisionAsu.isAfficherPeriodesFCT())
    {
      dossierAffectation.setIdentifiantSinistre(decisionAsu.getIdPeriodeFgd());
      
      dossierExamen.getFaitGenerateur().setIdentifiantPeriodeFaitGenerateur(decisionAsu.getIdPeriodeFgd());
      dossierAffectation.getValidationProduit().setIdentifiantPeriodeValidationProduit(decisionAsu.getIdPeriodeValidation());
      
      dossierExamen.getFaitGenerateur().setPeriodeFaitGenerateur(dossierExamen.getFaitGenerateur().getPeriodeFaitGenerateur());
    }
  }
  
  protected Collection getListControle()
  {
    return new ArrayList();
  }
  
  protected Collection getListRecalcule()
  {
    return new ArrayList();
  }
  
  protected Collection getListMappeur()
  {
    Collection listMappeur = new ArrayList();
    
    listMappeur.add(new MappingUniteAffiliation());
    
    listMappeur.add(new MappingMontantBrutJournalier());
    
    return listMappeur;
  }
  
  public DemandeMigreeV1 lireDonnees(DemandeSpec p_demande)
  {
    DemandeMigreeAsuV1 demandeLue = new DemandeMigreeAsuV1();
    
    DecisionMigreeAsuV1 decisionLue = new DecisionMigreeAsuV1();
    
    demandeLue.ajouterDecision(decisionLue);
    
    Demande demandeAsu = (Demande)p_demande;
    
    lireAllongementDelaiDecheance(demandeAsu, demandeLue);
    
    lireCapitalReliquatSecteurPublic(demandeAsu, demandeLue);
    
    lireEre(demandeAsu, demandeLue);
    
    lireFormulaire(demandeAsu, demandeLue);
    
    lireReliquat(demandeAsu, demandeLue);
    
    return demandeLue;
  }
  
  protected void alimenterListePeriodesFCT(Demande p_demandeAsu, DecisionMigreeAsuV1 p_decisionLue)
  {
    if ((((DossierAffectation)p_demandeAsu.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit() == null) || (((DossierExamenAssuranceSpec)p_demandeAsu.getDossierAffectation().getDossierExamen()).getFaitGenerateur().getPeriodeFaitGenerateur() == null))
    {
      Damj dateDebutFgdOdprecedente = Damj.NUIT_DES_TEMPS;
      if (p_demandeAsu.getDateFaitGenerateurOdPrecedente() != null) {
        dateDebutFgdOdprecedente = p_demandeAsu.getDateFaitGenerateurOdPrecedente();
      }
      Damj dateDeclenchementExamen = p_demandeAsu.getDateDeclenchementExamen();
      
      DelaiRechercheProduit delaiRechercheSinistres = new DelaiRechercheProduit(dateDebutFgdOdprecedente.lendemain(), dateDeclenchementExamen.veille());
      
      FiltresTemporel filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltreFinDansBornes(new Periode(delaiRechercheSinistres.getDebut(), delaiRechercheSinistres.getFin())));
      filtres.ajouterFiltre(new FiltreActiviteSalarieEtantFCT());
      
      Chronologie periodesFCT = p_demandeAsu.getDemandeur().getChronoPeriodePasseProfessionnel().copier(filtres);
      p_decisionLue.setChronologiePeriodesFCT(periodesFCT);
      p_decisionLue.setAfficherPeriodesFCT(true);
    }
    else
    {
      p_decisionLue.setAfficherPeriodesFCT(false);
    }
  }
  
  private DureeCalendaire recupererDelaiAllongement(DemandeAssuranceSpec p_demande)
  {
    DureeCalendaire delai = null;
    if ((p_demande.getDonneesTemporaires() != null) && (p_demande.getDonneesTemporaires().getAllongementDelaiForclusion() != null) && (p_demande.getDonneesTemporaires().getAllongementDelaiForclusion().getJours() != 0)) {
      delai = p_demande.getDonneesTemporaires().getAllongementDelaiForclusion();
    }
    return delai;
  }
  
  protected EvenementReferenceExamenSpec creerEvenementReferenceExamen(DemandeMigreeAsuV1 p_demandeTemporaireSource)
  {
    EvenementReferenceExamenSpec evenementReferenceExamen = null;
    
    String typeExamen = null;
    try
    {
      typeExamen = ConstructionCSOIA.getTypeExamenDepuisV1("ASU", null, null, p_demandeTemporaireSource.getTypeExamen());
    }
    catch (CoucheLogiqueException ex)
    {
      typeExamen = "";
    }
    if (typeExamen.equalsIgnoreCase("ASU_01")) {
      evenementReferenceExamen = new EreInscriptionDemandeurEmploi();
    } else if (typeExamen.equalsIgnoreCase("ASU_02")) {
      evenementReferenceExamen = new EreDemandeExpresse();
    } else if (typeExamen.equalsIgnoreCase("ASU_03")) {
      evenementReferenceExamen = new EreFinDroitSuiteRepriseNonSaisonniere();
    } else if (typeExamen.equalsIgnoreCase("ASU_05")) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_HG_EVT_REF_EXAM"));
    } else if (typeExamen.equalsIgnoreCase("ASU_04")) {
      evenementReferenceExamen = new ErePassageCPSuiteRejetDV();
    } else if (typeExamen.equalsIgnoreCase("ASU_08")) {
      evenementReferenceExamen = new EreFinDroitSpectacle();
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_HG_EVT_REF_EXAM"));
    }
    return evenementReferenceExamen;
  }
  
  protected void alimenterEre(DemandeMigreeAsuV1 p_demandeV1, Demande p_demande)
  {
    Damj dateExamen = p_demandeV1.getDateExamen();
    if (dateExamen != null)
    {
      p_demande.getEvenementReferenceExamen().setDateDeclenchementExamen(dateExamen);
      p_demande.getEvenementReferenceExamen().setDateEvenement(dateExamen);
    }
    else
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_HG_EVT_DATE_EXAM"));
    }
  }
  
  protected void alimenterFormulaire(DemandeMigreeAsuV1 p_demandeV1, Demande p_demande)
  {
    FormulaireAsu formulaire = (FormulaireAsu)p_demande.getFormulaire();
    if (p_demandeV1.getDateDepot() != null) {
      formulaire.setDateDepot(p_demandeV1.getDateDepot());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_HG_DATE_DEPOT"));
    }
    if (p_demandeV1.getIdPec() != null) {
      formulaire.setIdPec(Integer.parseInt(p_demandeV1.getIdPec()));
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_HG_ID_PEC"));
    }
    if ((p_demandeV1.getReferenceExterne() != null) && (!p_demandeV1.getReferenceExterne().equalsIgnoreCase(""))) {
      formulaire.setReferenceExterne(p_demandeV1.getReferenceExterne());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_REF_EXT_DEMANDE"));
    }
    formulaire.setMotifEnvoi(p_demandeV1.getTypeExamen());
  }
  
  protected void alimenterDonneesTemporaires(DemandeMigreeAsuV1 p_demandeV1, Demande p_demande)
  {
    alimenterAllongementDelaiDecheance(p_demandeV1, p_demande);
    alimenterCapitalReliquatSecteurPublic(p_demandeV1, p_demande);
  }
  
  protected void alimenterAllongementDelaiDecheance(DemandeMigreeAsuV1 p_demandeV1, Demande p_demande)
  {
    DonneesTemporaires donneesTemporaires = p_demande.getDonneesTemporaires();
    if (p_demandeV1.getAllongementDelaiDecheance() != null)
    {
      DureeCalendaire allongementDelaiDecheance = new DureeCalendaire(0, 0, p_demandeV1.getAllongementDelaiDecheance().intValue());
      donneesTemporaires.setAllongementDelaiDecheance(allongementDelaiDecheance);
    }
  }
  
  protected void alimenterCapitalReliquatSecteurPublic(DemandeMigreeAsuV1 p_demandeV1, Demande p_demande)
  {
    DonneesTemporaires donneesTemporaires = p_demande.getDonneesTemporaires();
    if (p_demandeV1.getDecision().getCapitalPrecedentSP() != null) {
      donneesTemporaires.setCapitalReliquatSecteurPublic(p_demandeV1.getDecision().getCapitalPrecedentSP());
    }
  }
  
  protected void alimenterReliquat(DemandeMigreeAsuV1 p_demandeV1, Demande p_demande)
  {
    Reliquat reliquat = p_demande.getReliquat();
    if (p_demandeV1.getDecision().getCumulMoisActiviteReduite() != null) {
      reliquat.setCumulMoisActiviteReduite(p_demandeV1.getDecision().getCumulMoisActiviteReduite().intValue());
    }
  }
  
  protected void lireAllongementDelaiDecheance(Demande p_demande, DemandeMigreeAsuV1 p_demandeLue)
  {
    if (p_demande.getDonneesTemporaires().getAllongementDelaiDecheance() != null) {
      p_demandeLue.setAllongementDelaiDecheance(new BigDecimal(p_demande.getDonneesTemporaires().getAllongementDelaiDecheance().getJours()));
    } else {
      p_demandeLue.setAllongementDelaiDecheance(new BigDecimal(0));
    }
  }
  
  protected void lireCapitalReliquatSecteurPublic(Demande p_demande, DemandeMigreeAsuV1 p_demandeLue)
  {
    if (p_demande.getDonneesTemporaires().getCapitalReliquatSecteurPublic() != null) {
      p_demandeLue.getDecision().setCapitalPrecedentSP(p_demande.getDonneesTemporaires().getCapitalReliquatSecteurPublic().getValeur());
    }
  }
  
  protected void lireEre(Demande p_demande, DemandeMigreeAsuV1 p_demandeLue)
  {
    p_demandeLue.setDateExamen(p_demande.getEvenementReferenceExamen().getDateExamen(p_demande));
  }
  
  protected void lireFormulaire(Demande p_demande, DemandeMigreeAsuV1 p_demandeLue)
  {
    FormulaireAsu formulaire = (FormulaireAsu)p_demande.getFormulaire();
    
    p_demandeLue.setDateDepot(formulaire.getDateDepot());
    
    p_demandeLue.setIdPec(Integer.valueOf(formulaire.getIdPec()).toString());
    if (formulaire.getReferenceExterne() != null) {
      p_demandeLue.setReferenceExterne(formulaire.getReferenceExterne());
    } else {
      p_demandeLue.setReferenceExterne("");
    }
    if (formulaire.getMotifEnvoi() != null) {
      p_demandeLue.setTypeExamen(formulaire.getMotifEnvoi());
    } else {
      p_demandeLue.setTypeExamen("");
    }
  }
  
  protected void lireReliquat(Demande p_demande, DemandeMigreeAsuV1 p_demandeLue)
  {
    if (p_demande.getReliquat() != null) {
      p_demandeLue.getDecision().setCumulMoisActiviteReduite(new BigDecimal(p_demande.getReliquat().getCumulMoisActiviteReduite()));
    }
  }
}

/* Location:
 * Qualified Name:     GrapheAssurance
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */