package fr.unedic.cali.asu.migration.graphes;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ErePassageCPSuiteRejetDV;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.outilsfonctionnels.OutilTranchesExecutables;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Decision;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Od;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.autresdoms.cohab.dom.CodesErreursMigration;
import fr.unedic.cali.autresdoms.cohab.dom.DemandeMigreeEnErreur;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P04;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSolCge01P01;
import fr.unedic.cali.dom.affectation.ProduitSolSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cohabitation.sigma.migration.dom.DecisionMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeV1;
import fr.unedic.util.services.ApplicativeRuntimeException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import java.math.BigDecimal;
import java.util.Collection;

public class GrapheOd
  extends GrapheDecision
{
  protected void creerCaps(DossierExamen p_dossierExamen)
  {
    p_dossierExamen.createConditionFaitGenerateur();
  }
  
  protected void creerCeps(DossierExamen p_dossierExamen)
  {
    p_dossierExamen.getConstitutionElementsActifs().createConstitutionMontantsBruts();
    p_dossierExamen.getConstitutionElementsActifs().createConstitutionDurees();
    p_dossierExamen.createConstitutionSjr();
    p_dossierExamen.createConstitutionSjc();
    p_dossierExamen.createConstitutionDelais();
    p_dossierExamen.createConstitutionQuantiteAffiliation();
    p_dossierExamen.createConstitutionReglementApplicable();
    p_dossierExamen.createConstitutionDateAttribution();
    p_dossierExamen.createConstitutionPointDepartIndemnisation();
    p_dossierExamen.createConstitutionCaractereSaisonnier();
    p_dossierExamen.createConstitutionCoefficientSaisonnier();
    p_dossierExamen.getConstitutionElementsActifs().createConstitutionCoefficientTempsPartiel();
  }
  
  protected ObjectifExamen creerObjectifDecision(DemandeMigreeAsuV1 p_demandeTemporaireSource)
  {
    ObjectifExamen objectifExamen = null;
    
    ProduitAsuSpec produitAsu = (ProduitAsuSpec)Parametres.getProduit(p_demandeTemporaireSource.getCodeProduit());
    
    objectifExamen = (ObjectifExamen)produitAsu.creerObjectifExamen(10, null);
    objectifExamen.setEtat(23);
    
    return objectifExamen;
  }
  
  protected Decision creerDecision(int p_natureDecision)
  {
    Decision nouvelleDecision = null;
    
    nouvelleDecision = new Od();
    nouvelleDecision.setNatureDecision(10);
    
    return nouvelleDecision;
  }
  
  protected DossierAffectation creerDossierAffectation()
  {
    DossierAffectation dossierAffectation = new DossierAffecte(1);
    ValidationProduit validation = new ValidationProduit();
    dossierAffectation.setValidationProduit(validation);
    
    return dossierAffectation;
  }
  
  protected void alimenterIdentifiant(DecisionMigreeAsuV1 p_decisionTemporaireSource, Decision p_decisionInstallee)
  {
    BigDecimal idAdmission = p_decisionTemporaireSource.getIdAdmission();
    if (idAdmission != null)
    {
      Od decisionOd = (Od)p_decisionInstallee;
      decisionOd.setReferenceExterne(idAdmission.toString());
    }
    else
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_ID_ADMISSION"));
    }
  }
  
  protected void alimenterCaps(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    alimenterConditionFaitGenerateur(p_decisionTemporaireSource, p_dossierExamen);
  }
  
  protected void alimenterCeps(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    alimenterConstitutionDurees(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionMontantsBruts(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionSjr(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionSjc(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionDelaisReport(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionQuantiteAffiliation(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionReglementApplicable(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionDateAttribution(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionPji(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionCaractereSaisonnier(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionCoefficientSaisonnier(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionCoefficientTempsPartiel(p_decisionTemporaireSource, p_dossierExamen);
  }
  
  protected void lireCaps(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    lireConditionFaitGenerateur(p_decision, p_decisionLue);
  }
  
  protected void lireCeps(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    lireConstitutionDurees(p_decision, p_decisionLue);
    lireConstitutionMontantsBruts(p_decision, p_decisionLue);
    lireConstitutionSjr(p_decision, p_decisionLue);
    lireConstitutionSjc(p_decision, p_decisionLue);
    lireConstitutionDelaisReport(p_decision, p_decisionLue);
    lireConstitutionQuantiteAffiliation(p_decision, p_decisionLue);
    lireConstitutionReglementApplicable(p_decision, p_decisionLue);
    lireConstitutionDateAttribution(p_decision, p_decisionLue);
    lireConstitutionPji(p_decision, p_decisionLue);
    lireConstitutionCaractereSaisonnier(p_decision, p_decisionLue);
    lireConstitutionCoefficientSaisonnier(p_decision, p_decisionLue);
    lireConstitutionCoefficientTempsPartiel(p_decision, p_decisionLue);
  }
  
  protected void lireIdentifiant(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    p_decisionLue.setIdAdmission(new BigDecimal(((Od)p_decision).getReferenceExterne()));
  }
  
  public void postTraitementMigrerDemande(DemandeMigreeV1 p_demandeV1, DemandeSpec p_demande, DemandeMigreeEnErreur p_demandeMigreeEnErreur)
    throws CoucheLogiqueException
  {
    super.postTraitementMigrerDemande(p_demandeV1, p_demande, p_demandeMigreeEnErreur);
    
    DecisionMigreeAsuV1 decisionMigreeAsuV1 = ((DemandeMigreeAsuV1)p_demandeV1).getDecision();
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierAffectation().getDossierExamen();
    
    alimenterListeActivitesConservees(decisionMigreeAsuV1, dossierExamen);
    
    alimenterCodeEmploiA2b(p_demande);
    
    alimenterAvisCP(p_demande);
    
    alimenterTranches(dossierExamen);
    
    p_demandeMigreeEnErreur.getListeErreurs().addAll(getListeErreurs());
  }
  
  protected void alimenterAvisCP(DemandeSpec p_demande)
  {
    Demande demande = (Demande)p_demande;
    if ((demande.getEvenementReferenceExamen() instanceof ErePassageCPSuiteRejetDV)) {
      demande.getDonneesTemporaires().setAvisCommissionParitaire((short)1);
    }
  }
  
  protected void alimenterCodeEmploiA2b(DemandeSpec p_demande)
  {
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierAffectation().getDossierExamen();
    
    ConstitutionSjr constitutionSjr = dossierExamen.getConstitutionSjr();
    Reglement reglement = dossierExamen.getReglementApplicable().getReglement();
    if ((dossierExamen.getConstitutionSjr() != null) && (reglement != null) && (reglement.equals(ProduitAsuCge01P04.getInstance().getReglement("A2b"))))
    {
      try
      {
        GammeAsu.getInstance().positionnerCriteresQualifSurPas(p_demande, p_demande.getDemandeur(), dossierExamen.getFaitGenerateur().getPeriodeFaitGenerateur());
      }
      catch (CoucheLogiqueException ex) {}
      int codeEmploiA2b = ((ProduitAsuSpec)dossierExamen.getDossierAffecte().getProduit()).getCodeEmploiA2b(dossierExamen.getDemande());
      if (codeEmploiA2b != 0) {
        constitutionSjr.setCodeEmploiA2b(codeEmploiA2b);
      } else {
        getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_EMPLOI_A2B"));
      }
    }
  }
  
  protected void alimenterNbJoursActiviteCourrierASS(DemandeSpec p_demande)
  {
    ProduitSolSpec produitASS = ProduitSolCge01P01.getInstance();
    if (((DemandeAssuranceSpec)p_demande).getOdAcquise() != null)
    {
      AttributionSpec attributionCourante = (AttributionSpec)p_demande.getDossierAffectation().getDossierExamen();
      try
      {
        ((AttributionAssuranceSpec)attributionCourante).setNbJoursActiviteCourrierASS(produitASS.determinerNbJoursActiviteAcquisePourCourrierAss(p_demande.getDemandeur(), attributionCourante));
      }
      catch (ApplicativeException ae)
      {
        throw new ApplicativeRuntimeException("Migration - Graphe Od", ae);
      }
    }
  }
  
  protected Chronologie getChronoActivitesConservees(DossierExamen p_dossierExamen)
    throws CoucheLogiqueException
  {
    return ConstructionChronologie.determinerChronoActivitesSalarieesConservees((Demande)p_dossierExamen.getDemande());
  }
  
  protected Prc getPrcSjr(DossierExamen p_dossierExamen)
  {
    return p_dossierExamen.getConstitutionSjr().getSjrip().getPrc();
  }
  
  protected void alimenterDonnees(DemandeMigreeV1 p_demandeV1, DemandeSpec p_demande)
  {
    super.alimenterDonnees(p_demandeV1, p_demande);
    
    DemandeMigreeAsuV1 demandeTemporaireSigma = (DemandeMigreeAsuV1)p_demandeV1;
    DecisionMigreeAsuV1 decisionTemporaireSigma = demandeTemporaireSigma.getDecision();
    
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierAffectation().getDossierExamen();
    alimenterCumulAR(decisionTemporaireSigma, dossierExamen);
  }
  
  protected void alimenterCumulAR(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    if (p_decisionTemporaireSource.getCumulMoisActiviteReduite() != null)
    {
      Od decisionOd = (Od)p_dossierExamen;
      decisionOd.setCumulMoisActiviteReduite(p_decisionTemporaireSource.getCumulMoisActiviteReduite());
    }
  }
  
  public DemandeMigreeV1 lireDonnees(DemandeSpec p_demande)
  {
    DemandeMigreeAsuV1 demandeLue = (DemandeMigreeAsuV1)super.lireDonnees(p_demande);
    DecisionMigreeAsuV1 decisionLue = demandeLue.getDecision();
    
    alimenterListePeriodesFCT((Demande)p_demande, decisionLue);
    
    return demandeLue;
  }
  
  protected void alimenterTranches(DossierExamen p_dossierExamen)
  {
    OutilTranchesExecutables.alimenterTranches((AttributionAssuranceSpec)p_dossierExamen);
  }
  
  protected void alimenterDonneesForcage(DemandeMigreeV1 p_demandeV1, DemandeSpec p_demande)
  {
    super.alimenterDonneesForcage(p_demandeV1, p_demande);
    alimenterPeriodeForcee(p_demandeV1, p_demande);
  }
}

/* Location:
 * Qualified Name:     GrapheOd
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */