package fr.unedic.cali.asu.mnt.dom;

import fr.unedic.archi.commun.lang.ExceptionUtil;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.mnt.dom.gen.DemandeMaintienGen;
import fr.unedic.cali.asu.outilsfonctionnels.RechercherDemandeMaintien;
import fr.unedic.cali.asu.produits.liquidation.dom.Novation;
import fr.unedic.cali.calcul.dom.UniteTraitementForcee;
import fr.unedic.cali.dom.ClassementAdministratif;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.Prescription;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.affectation.GammeMnt;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.dom.pivot.DemandePivot;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.ApplicativeRuntimeException;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class DemandeMaintien
  extends DemandeMaintienGen
  implements DemandeMaintienSpec
{
  private static final long serialVersionUID = -4506776691641603944L;
  private transient IndividuSpec demandeur = null;
  private transient boolean estEnCoursDeReexamen = false;
  private transient Damj dateEnvoiQuestionnaire = null;
  private transient int revisionANotifier;
  
  public DemandeMaintien()
  {
    if (super.getDossierExamen() != null) {
      super.getDossierExamen().setDemande(this);
    }
  }
  
  public DemandeMaintien(DomPCSpec pc)
  {
    super(pc);
    if (super.getDossierExamen() != null) {
      super.getDossierExamen().setDemande(this);
    }
  }
  
  public DemandeAssuranceSpec getDemandeMaintenue()
  {
    if (super.getDossierExamen() != null) {
      super.getDossierExamen().setDemande(this);
    }
    return RechercherDemandeMaintien.rechercherDemandeMaintenu(this);
  }
  
  public void setDemandeMaintenue(DemandeAssuranceSpec demandeASU)
  {
    if (super.getDossierExamen() != null) {
      super.getDossierExamen().setDemande(this);
    }
    super.setDemandeMaintenue(demandeASU);
  }
  
  public AttributionAssuranceSpec getAttributionAssurance()
  {
    AttributionAssuranceSpec attribution = null;
    try
    {
      attribution = (AttributionAssuranceSpec)RechercherDemandeMaintien.rechercherAttributionAssurancePrecedentePourMaintien(this);
    }
    catch (ApplicativeException ex)
    {
      attribution = null;
    }
    return attribution;
  }
  
  public FormulaireSpec getFormulaire()
  {
    if (!estFormulaireCharge())
    {
      setEstFormulaireCharge(true);
      if (getFormulaire().getReferenceExterne() != null)
      {
        FormulaireSpec formulaire = getDemandeur().getFormulaire(this);
        if (formulaire != null) {
          if (super.getFormulaire() != null) {
            super.getFormulaire().miseAjour(formulaire);
          } else {
            super.setFormulaire((FormulaireMaintien)formulaire);
          }
        }
      }
    }
    return super.getFormulaire();
  }
  
  public void setFormulaire(FormulaireSpec formulaire)
  {
    if ((super.getFormulaire() != null) && (super.getFormulaire() != formulaire)) {
      DomManager.supprimer(super.getFormulaire(), formulaire);
    }
    super.setFormulaire((FormulaireMaintien)formulaire);
  }
  
  public void ajouterMotifReexamen(String motifReexamen)
  {
    if ((motifReexamen != null) && (!getListeMotifsReexamen().contains(motifReexamen)) && (!"".equals(super.getMotifReexamenPrincipal()))) {
      super.ajouterMotifReexamen(motifReexamen);
    } else {
      setMotifReexamenPrincipal(motifReexamen);
    }
  }
  
  public Collection getListeMotifsReexamen()
  {
    return super.getCollectionMotifReexamen();
  }
  
  public void setListeMotifsReexamen(Collection listeMotifsReexamen)
  {
    if (listeMotifsReexamen == null)
    {
      remplacerCollectionMotifReexamen(new ArrayList());
      setMotifReexamenPrincipal(null);
    }
    else
    {
      super.remplacerCollectionMotifReexamen(listeMotifsReexamen);
    }
  }
  
  public void setEnReExamen(boolean reExamen)
  {
    if (reExamen) {
      ajouterMotifReexamen("1");
    } else {
      supprimerMotifReexamen("1");
    }
  }
  
  public void setClassementAdministratif(ClassementAdministratif administratif)
  {
    DomManager.supprimer(super.getClassementAdministratif(), administratif);
    super.setClassementAdministratif(administratif);
  }
  
  public DonneesForcees getDonneesForcees()
  {
    if (super.getDonneesForcees() == null) {
      super.setDonneesForcees(new DonneesForcees());
    }
    return super.getDonneesForcees();
  }
  
  public void setDonneesForcees(DonneesForcees donneesForcees)
  {
    DomManager.supprimer(super.getDonneesForcees(), donneesForcees);
    super.setDonneesForcees(donneesForcees);
  }
  
  public Damj getDateEnvoiQuestionnaire()
  {
    return dateEnvoiQuestionnaire;
  }
  
  public void setDateEnvoiQuestionnaire(Damj pDateEnvoiQuestionnaire)
  {
    dateEnvoiQuestionnaire = pDateEnvoiQuestionnaire;
  }
  
  public DossierExamen getDossierExamen()
  {
    if (super.getDossierExamen() != null) {
      super.getDossierExamen().setDemande(this);
    }
    return super.getDossierExamen();
  }
  
  public void setDossierExamen(DossierExamen dossierExamen)
  {
    DomManager.supprimer(super.getDossierExamen(), dossierExamen);
    super.setDossierExamen(dossierExamen);
    if (super.getDossierExamen() != null) {
      super.getDossierExamen().setDemande(this);
    }
  }
  
  public int getNumeroGamme()
  {
    return 5;
  }
  
  public GammeSpec getGamme()
  {
    return GammeMnt.getInstance();
  }
  
  public IndividuSpec getDemandeur()
  {
    return demandeur;
  }
  
  public void setDemandeur(IndividuSpec pDemandeur)
  {
    demandeur = pDemandeur;
  }
  
  public ObjetMetierSpec copie()
  {
    DemandeMaintien copie = new DemandeMaintien();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec pCopie)
  {
    DemandeMaintien copie = (DemandeMaintien)pCopie;
    
    super.copieElements(copie);
    
    copie.setEnReExamen(estEnReExamen());
    copie.setDonneesForcees((DonneesForcees)getDonneesForcees().copie());
    copie.setFormulaire((FormulaireMaintien)getFormulaire().copie());
    copie.setRevisionANotifier(getRevisionANotifier());
    if (getEvenementReferenceExamen() != null) {
      copie.setEvenementReferenceExamen((EvenementReferenceExamenSpec)getEvenementReferenceExamen().copie());
    }
    if (getClassementAdministratif() != null) {
      copie.setClassementAdministratif((ClassementAdministratif)getClassementAdministratif().copie());
    }
    Iterator iterMotifsReex = getListeMotifsReexamen().iterator();
    while (iterMotifsReex.hasNext()) {
      copie.ajouterMotifReexamen((String)iterMotifsReex.next());
    }
    copie.setMotifReexamenPrincipal(getMotifReexamenPrincipal());
    copie.setDateEnvoiQuestionnaire(getDateEnvoiQuestionnaire());
    if (getDossierExamen() != null) {
      copie.setDossierExamen((DossierExamen)getDossierExamen().copie());
    }
    copie.setMigree(getMigree());
    copie.setEstNeutraliseeLiquidation(estNeutraliseeLiquidation());
    copie.setEstNeutraliseeCalcul(estNeutraliseeCalcul());
    
    copie.setDatePremiereValidation(getDatePremiereValidation());
    copie.setDateDerniereValidation(getDateDerniereValidation());
    
    copie.setDateAnnulationReexamen(getDateAnnulationReexamen());
  }
  
  public void jdoPreDelete()
  {
    DomManager.supprimer(super.getClassementAdministratif());
    DomManager.supprimer(super.getDonneesForcees());
    DomManager.supprimer(getListeMotifsReexamen());
    DomManager.supprimer(super.getFormulaire());
    DomManager.supprimer(super.getDossierExamen());
    DomManager.supprimer(super.getEvenementReferenceExamen());
  }
  
  public void marquerGraphePersistant()
  {
    super.marquerGraphePersistant();
    DomManager.persisterEnProfondeur(super.getClassementAdministratif());
    DomManager.persisterEnProfondeur(super.getDonneesForcees());
    DomManager.persisterEnProfondeur(super.getFormulaire());
    DomManager.persisterEnProfondeur(super.getDossierExamen());
    DomManager.persisterEnProfondeur(super.getEvenementReferenceExamen());
    DomManager.persisterEnProfondeur(super.getDemandeMaintenue());
  }
  
  public void setEvenementReferenceExamen(EvenementReferenceExamenSpec ereSpec)
  {
    DomManager.supprimer(super.getEvenementReferenceExamen(), ereSpec);
    super.setEvenementReferenceExamen(ereSpec);
  }
  
  public boolean estClasseeOuDecisionneeValidee()
  {
    boolean demandeDecisionneeValidee = false;
    if ((getDossierExamen() != null) && ((getDossierExamen() instanceof Decision)))
    {
      demandeDecisionneeValidee = ((Decision)getDossierExamen()).estValidee();
    }
    else if (getClassementAdministratif() != null)
    {
      demandeDecisionneeValidee = true;
      if ((getClassementAdministratif() instanceof Prescription)) {
        demandeDecisionneeValidee = ((Prescription)getClassementAdministratif()).isValidite();
      }
    }
    return demandeDecisionneeValidee;
  }
  
  public boolean estLiquideeAvecConflits()
  {
    throw new UnsupportedOperationException();
  }
  
  public Collection getForcageExecution()
  {
    return null;
  }
  
  public void ajouterForcageExecution(UniteTraitementForcee ut) {}
  
  public void creerCalendrierExecutionCalculForce() {}
  
  public void supprimerCalendrierExecutionCalculForce() {}
  
  public Damj getDateIde()
  {
    throw new UnsupportedOperationException();
  }
  
  public DemandePivot getDemandePivot()
  {
    return null;
  }
  
  public DossierAffectationSpec getDossierAffectation()
  {
    return null;
  }
  
  public List getListeDossiersExamen()
  {
    ArrayList listeDossierExamen = new ArrayList();
    if (getDossierExamen() != null) {
      listeDossierExamen.add(getDossierExamen());
    }
    return listeDossierExamen;
  }
  
  public void mettreAJourDemande(DemandeSpec demandeSauvegarder)
  {
    DemandeMaintien demandeSauvegardee = (DemandeMaintien)demandeSauvegarder;
    
    setClassementAdministratif(demandeSauvegardee.getClassementAdministratif());
    setDossierExamen(demandeSauvegardee.getDossierExamen());
    setEnReExamen(demandeSauvegardee.estEnReExamen());
    setQuantiteJourReliquat(demandeSauvegardee.getQuantiteJourReliquat());
    
    setMotifReexamenPrincipal(demandeSauvegarder.getMotifReexamenPrincipal());
    for (Iterator itMotifReExamen = demandeSauvegarder.getListeMotifsReexamen().iterator(); itMotifReExamen.hasNext();)
    {
      String motifReExamen = (String)itMotifReExamen.next();
      ajouterMotifReexamen(motifReExamen);
    }
  }
  
  public void setDemandePivot(DemandePivot demandePivot)
  {
    throw new UnsupportedOperationException();
  }
  
  public void setLiquideeAvecConflits(boolean liquideeAvecConflits)
  {
    throw new UnsupportedOperationException();
  }
  
  public void validerDecision()
  {
    if ((getDossierExamen() != null) && ((getDossierExamen() instanceof Decision))) {
      ((Decision)getDossierExamen()).setValidee(true);
    }
  }
  
  public boolean estEnCoursDeReexamen()
  {
    return estEnCoursDeReexamen;
  }
  
  public void setEnCoursDeReexamen(boolean estEnCoursReexamen)
  {
    estEnCoursDeReexamen = estEnCoursReexamen;
  }
  
  public int getMigree()
  {
    return super.getEstMigree();
  }
  
  public void setMigree(int demandeMigree)
  {
    super.setEstMigree(demandeMigree);
  }
  
  public boolean estNeutraliseeCalcul()
  {
    return super.isEstNeutraliseeCalcul();
  }
  
  public boolean estNeutraliseeLiquidation()
  {
    return super.isEstNeutraliseeLiquidation();
  }
  
  public boolean estLiquidable()
  {
    return super.isEstLiquidable();
  }
  
  public boolean estDeneutralisable()
  {
    return super.isEstDeneutralisable();
  }
  
  public boolean estNonReexaminable()
  {
    return super.isEstNeutraliseeLiquidation();
  }
  
  public void setNonReexaminable(boolean demandeNonReexaminable)
  {
    super.setEstNeutraliseeLiquidation(demandeNonReexaminable);
  }
  
  public void annulerDecisions()
  {
    setDossierExamen(null);
    setDateEvenement(null);
  }
  
  public void setMotifReexamenPrincipal(String motifReexamenPrincipal)
  {
    super.setMotifReexamenPrincipal(motifReexamenPrincipal);
    if (motifReexamenPrincipal != null) {
      setDateEvenement(null);
    }
  }
  
  public Damj getDateFinAppletLiquidation()
  {
    return null;
  }
  
  public boolean estCategorieParticuliere()
  {
    return false;
  }
  
  public boolean estReexecutee()
  {
    return false;
  }
  
  public Damj getDateDerniereNotification()
  {
    return null;
  }
  
  public void setDateDerniereNotification(Damj dateDerniereNotification) {}
  
  public ProduitAsuSpec getProduitMaintenu()
  {
    ProduitAsuSpec produitMaintenu = null;
    
    DemandeAssuranceSpec demandeMaintenue = getDemandeMaintenue();
    boolean estDemandeMaintenueAttributionAssurance = (demandeMaintenue != null) && ((demandeMaintenue.getDossierExamen() instanceof AttributionAssuranceSpec));
    if ((estDemandeMaintenueAttributionAssurance) && (!demandeMaintenue.estEnReExamen()) && ((demandeMaintenue.getClassementAdministratif() == null) || (!demandeMaintenue.getClassementAdministratif().estClassementValide())))
    {
      AttributionAssuranceSpec attributionMaitre = ((AttributionAssuranceSpec)demandeMaintenue.getDossierExamen()).getOuvertureDroitCapitalRetenu();
      if ((attributionMaitre != null) && (attributionMaitre.getDossierAffecte() != null)) {
        produitMaintenu = (ProduitAsuSpec)attributionMaitre.getProduit();
      }
    }
    return produitMaintenu;
  }
  
  public Quantite getMontantJournalierDroitMaintenu()
    throws ApplicativeException
  {
    Quantite montant = null;
    
    AttributionAssuranceSpec attribution = getAttributionAssurance();
    if ((attribution != null) && (attribution.getDossierAffecte() != null))
    {
      ProduitAsuSpec produit = (ProduitAsuSpec)attribution.getProduit();
      Damj dateCalcul;
      Damj dateCalcul;
      if ((produit != null) && (getDateExamen() != null)) {
        dateCalcul = getDateExamen();
      } else {
        dateCalcul = getEvenementReferenceExamen().getDateDeclenchementExamen(this);
      }
      GammeAsuSpec gamme = (GammeAsuSpec)attribution.getGamme();
      DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant = gamme.mapperDonneesEntreesRecuperationMontant(attribution);
      donneesEntreesRecuperationMontant.setDateCalculMontant(dateCalcul);
      if (produit != null) {
        montant = produit.recupererMontant(donneesEntreesRecuperationMontant).getMontantBrut();
      }
    }
    return montant;
  }
  
  public FaitGenerateurSpec getFGDDroitMaintenu()
  {
    FaitGenerateurSpec faitGenerateur = null;
    DemandeAssuranceSpec demandeMaintenue = getDemandeMaintenue();
    if (demandeMaintenue != null)
    {
      faitGenerateur = demandeMaintenue.getFaitGenerateur();
      if ((faitGenerateur == null) && ((demandeMaintenue.getDossierExamen() instanceof Novation)))
      {
        Novation novation = (Novation)demandeMaintenue.getDossierExamen();
        faitGenerateur = ((AttributionAssuranceSpec)novation.getOuvertureDroit()).getConditionFaitGenerateur();
      }
    }
    return faitGenerateur;
  }
  
  public Reglement getReglementDroitMaintenu()
  {
    Reglement reglementApplicable = null;
    
    AttributionAssuranceSpec attribution = getAttributionAssurance();
    if ((attribution != null) && (attribution.getReglementApplicable() != null)) {
      reglementApplicable = attribution.getReglementApplicable().getReglement();
    }
    return reglementApplicable;
  }
  
  public boolean contientDonneesForcees()
  {
    return false;
  }
  
  public Damj getDateAttribution()
  {
    Damj dateAttribution = null;
    if ((getDossierExamen() != null) && ((getDossierExamen() instanceof AttributionAssuranceSpec))) {
      dateAttribution = getDossierExamen().getDateAttribution();
    }
    return dateAttribution;
  }
  
  public void supprimerUniteTraitementForcee(UniteTraitementForcee forcageExecution)
  {
    throw ExceptionUtil.shouldNotPassHere("");
  }
  
  public String getCommentaire()
  {
    return null;
  }
  
  public void setCommentaire(String commentaire) {}
  
  public int getComportmentDemandeMigree()
  {
    return 0;
  }
  
  public void setComportmentDemandeMigree(int comportmentDemandeMigree) {}
  
  public String getRsodMaintenu()
  {
    return ((FormulaireMaintien)getFormulaire()).getRsodMaintenu();
  }
  
  public int getRevisionANotifier()
  {
    return revisionANotifier;
  }
  
  public void setRevisionANotifier(int revisionANotifiee)
  {
    revisionANotifier = revisionANotifiee;
  }
  
  public String getModeLiquidation()
  {
    return null;
  }
  
  public void setModeLiquidation(String modeLiquidation) {}
  
  public void restaurerDossiersAffectations()
    throws ApplicativeRuntimeException
  {}
  
  public void supprimerDossiersAffectations() {}
  
  public void verifierCoherenceDossiersAffectations()
    throws ApplicativeRuntimeException
  {}
  
  public boolean estEnContexteDemande(String typeContexte)
  {
    return false;
  }
  
  public boolean estEnContexteDemande(int regroupementContexte)
  {
    return false;
  }
  
  public void remplacerCollectionMotifReexamen(Collection collectionACopier)
  {
    for (Iterator iter = super.getCollectionMotifReexamen().iterator(); iter.hasNext();)
    {
      String element = (String)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionMotifReexamen(collectionACopier);
  }
}

/* Location:
 * Qualified Name:     DemandeMaintien
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */