package fr.unedic.cali.asu.mnt.dom;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.mnt.dom.gen.DossierExamenGen;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;

public abstract class DossierExamen
  extends DossierExamenGen
  implements DossierExamenMaintienSpec
{
  public static final int PRECONDITIONS_EXA_AUTO_OK = 1;
  public static final int PRECONDITIONS_EXA_AUTO_KO = 2;
  public static final int PRECONDITIONS_EXA_AUTO_INDETERMINEES = 0;
  private static HashMap s_libelleDecision = new HashMap();
  
  static
  {
    s_libelleDecision.put(new BigDecimal(16), NaturesDecisions.s_libelleObjectifDecision.get(new BigDecimal(16)));
    
    s_libelleDecision.put(new BigDecimal(23), NaturesDecisions.s_libelleObjectifDecision.get(new BigDecimal(23)));
    
    s_libelleDecision.put(new BigDecimal(24), NaturesDecisions.s_libelleObjectifDecision.get(new BigDecimal(24)));
    
    s_libelleDecision.put(new BigDecimal(25), NaturesDecisions.s_libelleObjectifDecision.get(new BigDecimal(25)));
  }
  
  public DossierExamen(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  protected DossierExamen(Damj p_dateEvenement)
  {
    super(p_dateEvenement);
  }
  
  protected void copie(DossierExamen p_source)
  {
    if (p_source != null)
    {
      setConditionsAttributionAdmission((ConditionsAttributionAdmission)p_source.getConditionsAttributionAdmission().copie());
      setDemande(p_source.getDemande());
    }
  }
  
  public static String getLibelleDecision(BigDecimal p_codeNature)
  {
    return (String)s_libelleDecision.get(p_codeNature);
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public ConditionsAttributionAdmission getConditionsAttributionAdmission()
  {
    if (super.getConditionsAttributionAdmission() == null) {
      super.setConditionsAttributionAdmission(new ConditionsAttributionAdmission());
    }
    return super.getConditionsAttributionAdmission();
  }
  
  public void setConditionsAttributionAdmission(ConditionsAttributionAdmission p_conditionsAttributionAdmission)
  {
    DomManager.supprimer(super.getConditionsAttributionAdmission(), p_conditionsAttributionAdmission);
    super.setConditionsAttributionAdmission(p_conditionsAttributionAdmission);
  }
  
  public ConditionAppartenanceMaintien getConditionAppartenance()
  {
    return getConditionsAttributionAdmission().getConditionAppartenance();
  }
  
  public void setConditionAppartenance(ConditionAppartenanceMaintien p_conditionAppartenance)
  {
    getConditionsAttributionAdmission().setConditionAppartenance(p_conditionAppartenance);
  }
  
  public ConditionActiviteMaintien getConditionActivite()
  {
    return getConditionsAttributionAdmission().getConditionActivite();
  }
  
  public void setConditionActivite(ConditionActiviteMaintien p_conditionActivite)
  {
    getConditionsAttributionAdmission().setConditionActivite(p_conditionActivite);
  }
  
  public ConditionNombreTrimestresMaintien getConditionNombreTrimestres()
  {
    return getConditionsAttributionAdmission().getConditionNombreTrimestres();
  }
  
  public void setConditionNombreTrimestres(ConditionNombreTrimestresMaintien p_conditionNombreTrimestres)
  {
    getConditionsAttributionAdmission().setConditionNombreTrimestres(p_conditionNombreTrimestres);
  }
  
  public ConditionAgeMaintien getConditionAge()
  {
    return getConditionsAttributionAdmission().getConditionAge();
  }
  
  public void setConditionAge(ConditionAgeMaintien p_conditionAge)
  {
    getConditionsAttributionAdmission().setConditionAge(p_conditionAge);
  }
  
  public ConditionDureeIndemnisationMaintien getConditionDureeIndemnisation()
  {
    return getConditionsAttributionAdmission().getConditionDureeIndemnisation();
  }
  
  public void setConditionDureeIndemnisation(ConditionDureeIndemnisationMaintien p_conditionDureeIndemnisation)
  {
    getConditionsAttributionAdmission().setConditionDureeIndemnisation(p_conditionDureeIndemnisation);
  }
  
  public ConditionDecisionCPMaintien getConditionDecisionCP()
  {
    return getConditionsAttributionAdmission().getConditionDecisionCP();
  }
  
  public void setConditionDecisionCP(ConditionDecisionCPMaintien p_conditionDecisionCP)
  {
    getConditionsAttributionAdmission().setConditionDecisionCP(p_conditionDecisionCP);
  }
  
  public DossierExamenSpec changerEtat(int p_typeDossierExamen)
    throws CoucheLogiqueException
  {
    DossierExamen nouveauDossier = null;
    switch (p_typeDossierExamen)
    {
    case 0: 
      nouveauDossier = new Examen();
      break;
    case 23: 
      nouveauDossier = new Accord();
      break;
    case 24: 
    case 25: 
      nouveauDossier = new Attente(p_typeDossierExamen);
      break;
    case 16: 
      nouveauDossier = new Refus();
      break;
    default: 
      throw new UnsupportedOperationException("Impossible de changer l'etat du dossier d'examen vers le nouvel etat : " + p_typeDossierExamen);
    }
    if (nouveauDossier != null) {
      nouveauDossier.copie(this);
    }
    return nouveauDossier;
  }
  
  public String toString()
  {
    StringBuffer sb = new StringBuffer();
    sb.append("DossierExamen:");
    return sb.toString();
  }
  
  public void jdoPreDelete()
  {
    DomManager.supprimer(super.getConditionsAttributionAdmission());
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getConditionsAttributionAdmission());
  }
  
  public Damj getDateAttribution()
  {
    return getDemande().getDateExamen();
  }
  
  public Damj getDateAttributionAssurance()
  {
    return ((DemandeMaintien)getDemande()).getAttributionAssurance().getDateAttribution();
  }
  
  public Damj getDateEvenement()
  {
    return getDateAttribution();
  }
  
  public void setDateEvenement(Damj p_dateEvenement)
  {
    m_dateEvenement = p_dateEvenement;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    DossierExamen copie = (DossierExamen)p_copie;
    if (getConditionsAttributionAdmission() != null) {
      copie.setConditionsAttributionAdmission((ConditionsAttributionAdmission)getConditionsAttributionAdmission().copie());
    }
    copie.setDateEvenement(getDateEvenement());
  }
  
  public int preconditionsExamenAutomatiqueSatisfaites()
  {
    int situation = 0;
    if ((getConditionAge() != null) && (getConditionAge().estSatisfait()) && (getConditionDureeIndemnisation() != null) && (getConditionDureeIndemnisation().estSatisfait())) {
      situation = 1;
    } else if ((getConditionAge() != null) && (getConditionDureeIndemnisation() != null) && ((!getConditionAge().estSatisfait()) || (!getConditionDureeIndemnisation().estSatisfait()))) {
      situation = 2;
    }
    return situation;
  }
  
  public DemandeSpec getDemandeOrigine()
  {
    return null;
  }
  
  public DossierAffectationSpec getDossierAffecte()
  {
    return null;
  }
  
  public void setDossierAffecte(DossierAffectationSpec p_dossierAffectation)
  {
    DemandeMaintien demandeMaintien = (DemandeMaintien)super.getDemande();
    demandeMaintien.getDossierExamen().setDossierAffecte(p_dossierAffectation);
  }
  
  public List getListConditionsAttribution()
  {
    return getConditionsAttributionActives().getListeConditionsAttribution();
  }
  
  public boolean isEstSinistreOuCalamiteNaturelle()
  {
    return false;
  }
  
  protected DossierExamen() {}
  
  protected abstract ConditionsAttributionSpec getConditionsAttributionActives();
  
  public void jdoPostLoad() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreStore() {}
}

/* Location:
 * Qualified Name:     DossierExamen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */