package fr.unedic.cali.asu.mnt.parcours;

import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.DonneesForcees;
import fr.unedic.cali.asu.mnt.outilsfonctionnels.MappeurUnitesPourMaintien;
import fr.unedic.cali.asu.parametres.AccesListeUnitesReglement;
import fr.unedic.cali.asu.parametres.ValeurListeUnitesReglement;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.parcours.EnregistrerDemande;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.util.Iterator;
import java.util.List;

public class EnregistrerDemandeMaintien
  extends EnregistrerDemande
{
  public DemandeSpec mettreAJourOuCreerDemandeGamme(IndividuSpec p_individu, String p_idDemandeAMettreAJour, DemandeSpec p_demandeTemporaire, Damj p_dateTraitement)
    throws CoucheLogiqueException
  {
    DemandeMaintien demandeExistante = null;
    if ((p_idDemandeAMettreAJour != null) && (!p_idDemandeAMettreAJour.equals(""))) {
      demandeExistante = (DemandeMaintien)p_individu.rechercherDemande(p_idDemandeAMettreAJour);
    }
    mettreAJourDonneesDemande(demandeExistante, p_demandeTemporaire);
    controlerDonneesForcees(demandeExistante);
    return demandeExistante;
  }
  
  private void controlerDonneesForcees(DemandeMaintien p_demandeMaintien)
    throws ContexteException, CoucheLogiqueException
  {
    Reglement reglementMaintenu = p_demandeMaintien.getReglementDroitMaintenu();
    DonneesForcees donneesForcees = p_demandeMaintien.getDonneesForcees();
    if ((donneesForcees.getQuantiteActiviteTroisAns() != null) && 
      (!reglementMaintenu.estNomReglementIdentique("A8")) && (!reglementMaintenu.estNomReglementIdentique("A10"))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_NL_MNT_FORCAGE_ACT_3_ANS", 1);
    }
    Quantite qteAppartenance = donneesForcees.getQuantiteAppartenance();
    if ((qteAppartenance != null) && (reglementMaintenu != null) && 
      (qteAppartenance.getUnite().getNom().equalsIgnoreCase("heure")) && (!reglementMaintenu.estNomReglementIdentique("A8")) && (!reglementMaintenu.estNomReglementIdentique("A10"))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_NL_MNT_FORCAGE_APPART_UNITE_A8_A10");
    }
    Quantite qteActiviteCinqAns = donneesForcees.getQuantiteActiviteCinqAns();
    if ((qteActiviteCinqAns != null) && (reglementMaintenu != null))
    {
      List listeUnites = AccesListeUnitesReglement.get(reglementMaintenu, null).getListeUnites();
      Iterator iterUnite = listeUnites.iterator();
      Unite uniteReglement = (Unite)iterUnite.next();
      Unite uniteActivite = qteActiviteCinqAns.getUnite();
      boolean uniteOK = uniteReglement.equals(uniteActivite);
      if (!uniteOK) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_NL_MNT_FORCAGE_ACT_5_ANS_PB_UNITE", 1);
      }
    }
  }
  
  private void mettreAJourDonneesDemande(DemandeSpec p_demandeAMettreAJour, DemandeSpec p_demandeTemporaire)
    throws CoucheLogiqueException
  {
    DemandeMaintien demandeAMettreAJour = (DemandeMaintien)p_demandeAMettreAJour;
    DemandeMaintien demandeTemporaire = (DemandeMaintien)p_demandeTemporaire;
    
    demandeAMettreAJour.setDonneesForcees(demandeTemporaire.getDonneesForcees());
    
    mettreAJourUnitesDonneesForcees(demandeAMettreAJour);
    
    demandeAMettreAJour.setClassementAdministratif(demandeTemporaire.getClassementAdministratif());
    
    demandeAMettreAJour.setNotifieeCourrier(demandeTemporaire.estNotifieeCourrier());
  }
  
  private void mettreAJourUnitesDonneesForcees(DemandeMaintien p_demandeAMettreAJour)
  {
    MappeurUnitesPourMaintien mappeur = MappeurUnitesPourMaintien.getInstance();
    if (p_demandeAMettreAJour.getReglementDroitMaintenu() != null)
    {
      String reglement = p_demandeAMettreAJour.getReglementDroitMaintenu().getNomReglement();
      
      Quantite qte5AnsTypeDuree = p_demandeAMettreAJour.getDonneesForcees().getQuantiteActiviteCinqAns();
      if (qte5AnsTypeDuree != null)
      {
        String codeUniteAffi = mappeur.mapperUniteDureeVersUniteAffi(reglement, qte5AnsTypeDuree.getUnite().getCode());
        Quantite qte5AnsTypeAffi = new Quantite(qte5AnsTypeDuree.getValeur(), Unite.getParCode(codeUniteAffi));
        p_demandeAMettreAJour.getDonneesForcees().setQuantiteActiviteCinqAns(qte5AnsTypeAffi);
      }
      Quantite qteAppartenanceForcee = p_demandeAMettreAJour.getDonneesForcees().getQuantiteAppartenance();
      if ((qteAppartenanceForcee != null) && (!"2".equals(qteAppartenanceForcee.getUnite().getCode())))
      {
        String codeUniteAffi = mappeur.mapperUniteDureeVersUniteAffi(reglement, qteAppartenanceForcee.getUnite().getCode());
        Quantite qteAppartenanceTypeAffi = new Quantite(qteAppartenanceForcee.getValeur(), Unite.getParCode(codeUniteAffi));
        p_demandeAMettreAJour.getDonneesForcees().setQuantiteAppartenance(qteAppartenanceTypeAffi);
      }
    }
  }
}

/* Location:
 * Qualified Name:     EnregistrerDemandeMaintien
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */