package fr.unedic.cali.asu.occasionnel.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesSortieNPDE;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.SituationDemandeur;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.CalculAffiliation;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.DeterminationSituationDemandeur;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.OutilLiquidationSimplifiee;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.OutilPeriodesAffiliation;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.OutilRecherchePra;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesEntreeOutilLiquidationSimplifiee;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesEntreeOutilPeriodesAffiliation;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesEntreeOutilRecherchePra;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesSortieOutilLiquidationSimplifiee;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesSortieOutilRecherchePra;
import fr.unedic.cali.asu.parcours.DomLiquidationSimplifiee;
import fr.unedic.cali.autresdoms.d12i.dom.DonneesNPDE;
import fr.unedic.cali.dom.Entretien;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.occasionnel.outilsfonctionnels.CriteresTraitementPopulation;
import fr.unedic.cali.occasionnel.outilsfonctionnels.ResultatTraitementPopulation;
import fr.unedic.cali.occasionnel.outilsfonctionnels.TraitementPopulationSpec;
import fr.unedic.cali.outilsfonctionnels.OutilDeterminationDateExamen;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.List;

public class TraitementICCPConservationSurLiquidationSimplifieeNPDE
  implements TraitementPopulationSpec
{
  static final int ANNEE_LIVRAISON_CORRECTIF = 2015;
  private static final int MOIS_LIVRAISON_CORRECTIF = 11;
  private static final int JOUR_LIVRAISON_CORRECTIF = 6;
  private static Damj dateLivraisonCorrectif = new Damj(2015, 11, 6);
  
  public ResultatTraitementPopulation effectuerTraitement(CriteresTraitementPopulation criteres)
    throws ApplicativeException
  {
    IndividuSpec individu = criteres.getIndividu();
    Chronologie demandesAssurances = individu.getChronoDemandeAssurance();
    demandesAssurances.iterer();
    while (demandesAssurances.encoreSuivant())
    {
      Demande demandeCourante = (Demande)demandesAssurances.elementSuivant();
      if ((estUneDemandeLiquideeEnSimplifieeNPDEAvantCorrectif(demandeCourante)) && (estUneReprise(demandeCourante)) && (aICCPConservatoiresForces(demandeCourante))) {
        redeterminerICCPConservatoire(demandeCourante, individu);
      }
    }
    return new ResultatTraitementPopulation();
  }
  
  private boolean estUneDemandeLiquideeEnSimplifieeNPDEAvantCorrectif(Demande demande)
  {
    return ("S".equals(demande.getDonneesSortieNPDE().getModeTraitementDemande())) && (dateLivraisonCorrectif.estApres(demande.getDateDeclenchementExamen()));
  }
  
  private boolean estUneReprise(Demande demande)
  {
    AttributionAssuranceSpec attribution = demande.getAttribution();
    return (attribution != null) && (NaturesDecisions.estdeTypeReprise(attribution.getNatureDecision()));
  }
  
  private boolean aICCPConservatoiresForces(Demande demande)
  {
    return (demande.getDonneesTemporaires() != null) && (demande.getDonneesTemporaires().getQuantiteJoursDiffereIccpConservatoire() != null) && (BigDecimal.ZERO.compareTo(demande.getDonneesTemporaires().getQuantiteJoursDiffereIccpConservatoire().getValeur()) < 0);
  }
  
  private void redeterminerICCPConservatoire(Demande demande, IndividuSpec individu)
    throws ApplicativeException
  {
    DomLiquidationSimplifiee dom = new DomLiquidationSimplifiee();
    dom.setDemande(demande);
    dom.setIndividu(individu);
    traitementPreLiquidationSimplifiee(demande);
    
    DonneesEntreeOutilPeriodesAffiliation donneesAffi = new DonneesEntreeOutilPeriodesAffiliation();
    DonneesEntreeOutilRecherchePra donneesPra = new DonneesEntreeOutilRecherchePra();
    DonneesEntreeOutilLiquidationSimplifiee donneesLiquidation = new DonneesEntreeOutilLiquidationSimplifiee();
    
    DeterminationSituationDemandeur situationDemandeur = new DeterminationSituationDemandeur();
    situationDemandeur.rechercherSituationdemandeur(dom);
    
    alimenterEntretien(dom, donneesAffi);
    
    liquiderEnSimplifiee(dom, donneesAffi, donneesPra, donneesLiquidation);
  }
  
  private void traitementPreLiquidationSimplifiee(Demande demande)
    throws ApplicativeException
  {
    demande.setDemandeLiquidee(true);
    OutilDeterminationDateExamen.getInstance().determinerDateExamen(demande);
  }
  
  private void alimenterEntretien(DomLiquidationSimplifiee dom, DonneesEntreeOutilPeriodesAffiliation donneesAffi)
  {
    Demande demande = (Demande)dom.getDemande();
    
    alimenterDonneesEntreeAffi(donneesAffi, dom);
    demande.setEntretien(OutilPeriodesAffiliation.recupererInformationsEntretien(donneesAffi));
  }
  
  private void liquiderEnSimplifiee(DomLiquidationSimplifiee dom, DonneesEntreeOutilPeriodesAffiliation donneesAffi, DonneesEntreeOutilRecherchePra donneesPra, DonneesEntreeOutilLiquidationSimplifiee donneesLiquidation)
    throws ApplicativeException
  {
    alimenterDonneesEntreePra(donneesPra, dom);
    Damj finPra = OutilRecherchePra.recupererDateFinPra(donneesPra);
    DureeCalendaire age = dom.getIndividu().getAgeALaDate(finPra);
    
    donneesPra.setDateFinPra(finPra);
    donneesPra.setAgeALaFct(age);
    DonneesSortieOutilRecherchePra donneesSortiePra = OutilRecherchePra.recupererPra(donneesPra);
    
    donneesAffi.setPra(donneesSortiePra.getPra());
    Demande demande = (Demande)dom.getDemande();
    
    OutilPeriodesAffiliation.calculerAffiliationDeclaree(demande.getEntretien(), donneesAffi);
    
    Chronologie gaec = CalculAffiliation.determinerPeriodesParticipantesAvecDeclare(dom.getIndividu(), donneesSortiePra.getPra(), dom.getSituationDemandeur().getDateInscription());
    
    donneesAffi.setChronoPeriodesGAEC(gaec);
    donneesLiquidation.setAffiTotale(OutilPeriodesAffiliation.calculerAffiliationTotale(donneesAffi));
    
    alimenterDonneesEntreeOutilLiquidation(donneesLiquidation, donneesAffi, donneesSortiePra, dom);
    DonneesSortieOutilLiquidationSimplifiee sortieLiquidation = OutilLiquidationSimplifiee.liquider(donneesLiquidation);
    
    dom.setNatureDecisionAttendue(sortieLiquidation.getNatureDecision());
    dom.setCodeMotifEchecANotifier(String.valueOf(sortieLiquidation.getCodeMotifRejet()));
    ((Demande)dom.getDemande()).getDonneesTemporaires().setQuantiteJoursDiffereIccpConservatoire(sortieLiquidation.getJoursIccpConservatoire());
  }
  
  private void alimenterDonneesEntreeAffi(DonneesEntreeOutilPeriodesAffiliation donneesAffi, DomLiquidationSimplifiee dom)
  {
    Demande demande = (Demande)dom.getDemande();
    SituationDemandeur situation = dom.getSituationDemandeur();
    DonneesNPDE donneesD12i = demande.getDonneesNPDE();
    donneesAffi.setPresenceFormation(donneesD12i.isEstPresenceFormation());
    
    List<Temporel> periodesD12i = donneesD12i.getListePeriodeAffiliationDeclaree();
    
    Chronologie chrono = new ChronologiePeriodes();
    if (periodesD12i != null)
    {
      Iterator<Temporel> it = periodesD12i.iterator();
      while (it.hasNext())
      {
        Temporel periode = (Temporel)it.next();
        if ((estPeriodeTerminee(periode)) && (estPeriodeTermineeApresDernierFaitGenerateurDeDroit(periode, situation.getDateFgdAsuPrecedent()))) {
          chrono.ajouter(periode);
        }
      }
    }
    donneesAffi.setChronoPeriodesDeclarees(chrono);
  }
  
  private void alimenterDonneesEntreePra(DonneesEntreeOutilRecherchePra donneesPra, DomLiquidationSimplifiee dom)
    throws ApplicativeException
  {
    Demande demande = (Demande)dom.getDemande();
    SituationDemandeur situation = dom.getSituationDemandeur();
    
    donneesPra.setDateInscription(situation.getDateInscription());
    donneesPra.setDernierDeclare(demande.getEntretien().getDateFinContrat());
    donneesPra.setDvPrecedantRepriseIPR(situation.getDateDVprecedantRepriseIPR());
    donneesPra.setEtatReliquat(situation.getEtatReliquat());
    donneesPra.setFgdAsuPrecedent(situation.getDateFgdAsuPrecedent());
    donneesPra.setDerniereFctPeriodeGAEC(situation.getDateFinDernierePeriodeGaec());
  }
  
  private void alimenterDonneesEntreeOutilLiquidation(DonneesEntreeOutilLiquidationSimplifiee donneesLiquidation, DonneesEntreeOutilPeriodesAffiliation donneesAffi, DonneesSortieOutilRecherchePra donneesSortiePra, DomLiquidationSimplifiee dom)
  {
    Demande demande = (Demande)dom.getDemande();
    SituationDemandeur situation = dom.getSituationDemandeur();
    
    donneesLiquidation.setAffiRequise(donneesSortiePra.getAffiRequise());
    donneesLiquidation.setDerniereCi(situation.getDateDerniereCessation());
    donneesLiquidation.setDernierePeriodeGaec(situation.getDateDebutDernierePeriodeGaec());
    donneesLiquidation.setEstPrimo(dom.isEstPrimoDemandeur());
    donneesLiquidation.setEtatReliquat(situation.getEtatReliquat());
    
    boolean produitGerantIccp = false;
    ProduitAsuSpec produit = (ProduitAsuSpec)situation.getProduitReliquat();
    if (produit != null) {
      produitGerantIccp = produit.estProduitGerantIccpEnContexteRepriseSimplifiee();
    }
    donneesLiquidation.setEstProduitGerantIccpEnContexteRepriseSimplifiee(produitGerantIccp);
    donneesLiquidation.setAffiDeclare(demande.getEntretien().getQuantiteAffiliation().getValeurEntiere());
    donneesLiquidation.setDateInscription(situation.getDateInscription());
    donneesLiquidation.setPresenceFormation(donneesAffi.isPresenceFormation());
  }
  
  private boolean estPeriodeTerminee(Temporel periode)
  {
    return (periode.getDateFin() != null) && (!periode.getDateFin().coincideAvec(Damj.FIN_DES_TEMPS));
  }
  
  private boolean estPeriodeTermineeApresDernierFaitGenerateurDeDroit(Temporel periode, Damj dateDernierFaitGenerateur)
  {
    return (dateDernierFaitGenerateur == null) || ((periode.getDateFin() != null) && (periode.getDateFin().estApres(dateDernierFaitGenerateur)));
  }
}

/* Location:
 * Qualified Name:     TraitementICCPConservationSurLiquidationSimplifieeNPDE
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */