package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.CodesMotifsEchec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ContributionParticuliereSpec;
import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesDAL;
import fr.unedic.cali.asu.dom.DonneesSortieNPDE;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.dom.cge01.AttributionAssuranceCgeSpec;
import fr.unedic.cali.asu.dom.conteneur.DonneesRessortissant;
import fr.unedic.cali.asu.fabriques.FabriqueStrategieRejetDvAss;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieRejetDvAssSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.DureeReglementaireSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.FinancementSpec;
import fr.unedic.cali.autresdoms.d12i.spec.DonneesDALSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ClassementCompetenceSecteurPublic;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.NovationSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.RejetSpec;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.echange.Decision;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.RechercherReliquat;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionSolidariteAss;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.List;
import java.util.Map;
import org.apache.commons.lang.StringUtils;

public final class AlimenterBaseEchanges
{
  private static final int DUREE_ZERO = 0;
  private static final int FEVRIER = 2;
  private static final int VINGT_NEUF = 29;
  public static final int TAILLE_ID_LIDO = 17;
  
  public static void alimenterDonneesGamme(DemandeSpec demandeCali, Decision demandeEchange)
    throws ApplicativeException
  {
    Demande demandeCourante = (Demande)demandeCali;
    CompetenceSpec competence = null;
    
    demandeEchange.setTopDroitOptionAss(demandeCourante.estDroitOptionASS() ? 1 : 0);
    
    demandeEchange.setContributionNonPropositionCTP(demandeCourante.getDonneesTemporaires().getMontantContributionPourNonCTP());
    
    String classementAdministratif = fr.unedic.cali.outilsfonctionnels.AlimenterBaseEchanges.determineClassementAdministratif(demandeCali);
    demandeEchange.setClassementAdministratif(classementAdministratif);
    if (classementAdministratif != null)
    {
      alimenterClassementAdministratif(demandeCali, demandeEchange, classementAdministratif);
    }
    else
    {
      demandeEchange.setLibelleEmployeur(renseignerLibelleEmployeur(competence));
      DossierExamenSpec dossierExamenCourant = demandeCali.getDossierAffectation().getDossierExamen();
      
      demandeEchange.setReferenceExterneDemande(demandeCali.getFormulaire().getReferenceExterne());
      
      demandeEchange.setTypeEchecExamen(determineTypeEchecExamen(demandeCourante));
      
      demandeEchange.setOrigineDecision(0);
      
      alimenterNatureEtIdentifiant(demandeCali, demandeEchange, dossierExamenCourant);
      
      demandeEchange.setMotifEchec(determineMotifEchec(demandeCourante));
      if (demandeCourante.getDossierAffectation().getProduit() != null) {
        demandeEchange.setProduit(determinerProduitDecision(demandeCourante).getNom());
      }
      alimenterTopAppelContrib(demandeCali, demandeEchange);
      
      alimentaterDossierExamenAssurance(demandeCali, demandeEchange, dossierExamenCourant);
      
      alimenterRejetAsuAss(demandeCali, demandeEchange);
      
      alimenterDonneesProduit(demandeCali, demandeEchange, dossierExamenCourant);
      
      alimenterAttribRejet(demandeCali, demandeEchange, dossierExamenCourant);
      
      alimenterObjectifDecisionne(demandeCali, demandeEchange);
    }
    alimenterDonneesCreationAttenteNPDE(demandeEchange, demandeCali.getCodeAttente());
    alimenterDonneesCreationAttenteIncoherenceSalaireNPDE(demandeEchange, (Demande)demandeCali);
    
    alimenterDonneesRessortissant(demandeCali, demandeEchange);
  }
  
  protected static void alimenterDonneesRessortissant(DemandeSpec demandeCali, Decision demandeEchange)
  {
    DonneesRessortissant donneesRessortissant = ((Demande)demandeCali).getDonneesRessortissant();
    if (donneesRessortissant.estIncoherenceInfoRessortissant())
    {
      demandeEchange.setAttenteNationaliteAValider(String.valueOf(1));
      demandeEchange.setIdentifiantPeriodeIncoherenceRessortissant(new BigDecimal(OutilActiviteSalarie.formaterIdentifiantPeriodeGaec(donneesRessortissant.getIdPeriodeIncoherenteRessortissant(), 17)));
    }
    else
    {
      demandeEchange.setAttenteNationaliteAValider(String.valueOf(0));
    }
  }
  
  private static void alimentaterDossierExamenAssurance(DemandeSpec demandeCali, Decision decisionEchange, DossierExamenSpec dossierExamenCourant)
    throws ApplicativeException
  {
    Demande demandeCourante = (Demande)demandeCali;
    if ((dossierExamenCourant instanceof DossierExamenAssuranceSpec))
    {
      if ((((DossierExamenAssuranceSpec)dossierExamenCourant).getContributionParticuliere() != null) && (!demandeCourante.estEnReExamen())) {
        alimenterDonneesContributionParticuliere(decisionEchange, demandeCourante, dossierExamenCourant);
      }
      if ((demandeCourante.getDateExamen() != null) && (GestionnaireDateApplication.getInstance().recupererDateApplication("Detection nouvelle demande ASS").estAvantOuCoincideAvec(demandeCourante.getDateExamen())) && (detecterNouvelleDemandeASS(demandeCourante))) {
        decisionEchange.setTopDemandeASSSuiteDecheance(1);
      } else {
        decisionEchange.setTopDemandeASSSuiteDecheance(0);
      }
      alimenterDonneesCspSurLigneCge(dossierExamenCourant, decisionEchange);
      alimenterDonneesPap(dossierExamenCourant, decisionEchange);
      if (((DossierExamenAssuranceSpec)dossierExamenCourant).getContexteDdeExpresse() == 8) {
        if ((dossierExamenCourant instanceof RejetSpec)) {
          decisionEchange.setTopEchecDemandeExpresseEnCoursIndemnisation(1);
        } else {
          decisionEchange.setTopEchecDemandeExpresseEnCoursIndemnisation(0);
        }
      }
      decisionEchange.setCompetenceAdministrative(determinerCompetence(demandeCourante));
      
      alimentationMotifRejet(demandeCali, decisionEchange);
    }
  }
  
  private static void alimenterRejetAsuAss(DemandeSpec demandeCali, Decision demandeEchange)
    throws ApplicativeException
  {
    if (0 == demandeEchange.getTopDemandeASSSuiteDecheance())
    {
      int topLiqAutoRepriseAss = determinerTopLiqAutoRepriseAss(demandeCali);
      demandeEchange.setTopRejetASUReliquatASS(topLiqAutoRepriseAss);
    }
    else
    {
      demandeEchange.setTopRejetASUReliquatASS(0);
    }
  }
  
  private static void alimentationMotifRejet(DemandeSpec demandeCali, Decision demandeEchange)
  {
    Demande demandeCourante = (Demande)demandeCali;
    int motifRejet = determinerMotifRejetPourSigma(demandeCali);
    if (motifRejet != 0)
    {
      if (motifRejet == 71) {
        demandeEchange.setMotifRejet(determineCodeRejetAffi((DossierExamenAssuranceSpec)demandeCourante.getDossierExamen()));
      } else {
        fr.unedic.cali.outilsfonctionnels.AlimenterBaseEchanges.renseignerCodeRejet(demandeCali, demandeEchange);
      }
    }
    else if ((StringUtils.isNotEmpty(demandeCali.getCodeMotifEchecPourSigmaSauvegarde())) && ((demandeCali.getDossierAffectation().getDossierExamen() instanceof RejetSpec))) {
      demandeEchange.setMotifRejet(Integer.parseInt(demandeCali.getCodeMotifEchecPourSigmaSauvegarde()));
    }
  }
  
  private static void alimenterTopAppelContrib(DemandeSpec demandeCali, Decision demandeEchange)
  {
    if (demandeCali.getTopAppelContribution()) {
      demandeEchange.setTopAppelContributions(1);
    } else {
      demandeEchange.setTopAppelContributions(0);
    }
  }
  
  private static void alimenterNatureEtIdentifiant(DemandeSpec demandeCali, Decision demandeEchange, DossierExamenSpec dossierExamenCourant)
  {
    Demande demandeCourante = (Demande)demandeCali;
    if ((dossierExamenCourant instanceof DecisionSpec))
    {
      if (demandeCourante.getAttribution() != null)
      {
        demandeEchange.setIdentifiantOd(Integer.parseInt(demandeCourante.getAttribution().getRsod()));
        demandeEchange.setIdentifiantReprise(Integer.parseInt(demandeCourante.getAttribution().getRsrp()));
      }
      if (((DecisionSpec)dossierExamenCourant).getNatureDecision() == 14) {
        demandeEchange.setNatureDecision(((Demande)demandeCali).getDossierAffectationReprise().getTypeRepriseContextuellePourSuivi());
      } else {
        demandeEchange.setNatureDecision(determineNatureDecision(dossierExamenCourant));
      }
    }
    else if (dossierExamenCourant == null)
    {
      demandeEchange.setNatureDecision(0);
    }
  }
  
  private static void alimenterAttribRejet(DemandeSpec demandeCali, Decision demandeEchange, DossierExamenSpec dossierExamenCourant)
    throws ApplicativeException
  {
    Demande demandeCourante = (Demande)demandeCali;
    if ((dossierExamenCourant instanceof AttributionAssuranceSpec))
    {
      demandeEchange.setSituationParticuliere(((AttributionAssuranceSpec)dossierExamenCourant).getSituationParticuliere());
      
      demandeEchange.setInvestigationFraude(((DecisionAssuranceSpec)dossierExamenCourant).isInvestigationFraude());
    }
    else if ((dossierExamenCourant instanceof RejetSpec))
    {
      alimenterRejetAsuAssCpa(demandeCourante, demandeEchange);
      if (demandeEchange.getTopDetectionClauseRattrapage() == 0) {
        alimenterDonneesCreationDalFps((RejetSpec)dossierExamenCourant, demandeEchange);
      }
      alimenterDonneesCreationDalATA(demandeCali, demandeEchange);
      
      alimenterDonneesCreationDalAsrAtp(demandeCali, demandeEchange);
    }
  }
  
  private static void alimenterRejetAsuAssCpa(Demande demandeCourante, Decision demandeEchange)
  {
    if (0 == demandeEchange.getTopDemandeASSSuiteDecheance()) {
      demandeEchange.setTopRejetASUCpaASS(renseignerToprejetAsuCategorieParticuliere(demandeCourante));
    } else {
      demandeEchange.setTopRejetASUCpaASS(0);
    }
  }
  
  private static void alimenterClassementAdministratif(DemandeSpec demandeCali, Decision demandeEchange, String classementAdministratif)
  {
    demandeEchange.setCompetenceAdministrative("AC");
    CompetenceSpec competence = null;
    if (classementAdministratif.equals("SP"))
    {
      ClassementCompetenceSecteurPublic classementSP = (ClassementCompetenceSecteurPublic)demandeCali.getClassementAdministratif();
      demandeEchange.setMotifRejet(DeterminerMotifRejetSecteurPublic.alimenterMotifRejetSecteurPublic(demandeCali));
      demandeEchange.setLibelleEmployeur(classementSP.getEmployeurCompetent());
    }
    else if (OutilsRevisions.estContexteAttributionEnCoursRevisionAre14AvecRejetDv(demandeCali))
    {
      demandeEchange.setMotifRejet(91);
    }
    else
    {
      demandeEchange.setLibelleEmployeur(renseignerLibelleEmployeur(competence));
    }
  }
  
  private static void alimenterObjectifDecisionne(DemandeSpec demandeCali, Decision demandeEchange)
  {
    ObjectifExamen objectifDecisionne = ((Demande)demandeCali).getObjectifDecisionne();
    if (objectifDecisionne != null) {
      if ((((Demande)demandeCali).estDroitOptionReadmission()) && ("SP".equals(determinerCompetence((Demande)demandeCali)))) {
        demandeEchange.setObjectifLiquidation(4);
      } else {
        demandeEchange.setObjectifLiquidation(objectifDecisionne.getType());
      }
    }
  }
  
  private static void alimenterDonneesProduit(DemandeSpec demandeCali, Decision demandeEchange, DossierExamenSpec dossierExamenCourant)
    throws ApplicativeException
  {
    ProduitSpec produit = demandeCali.getDossierAffectation().getProduit();
    if ((produit != null) && (dossierExamenCourant != null)) {
      produit.alimenterBaseEchangesProduit(dossierExamenCourant, demandeEchange);
    }
  }
  
  protected static boolean detecterNouvelleDemandeASS(Demande demande)
  {
    return ((GammeAsu)demande.getGamme()).detecterAssSuiteDecheance(demande);
  }
  
  protected static boolean detecterRepriseAssSuiteReinscription(DemandeSpec demande)
  {
    return ((GammeAsu)demande.getGamme()).detecterRepriseAssSuiteReinscription(demande);
  }
  
  private static void afficherANBLiqAutoRepriseAss(Demande demandeCourante)
  {
    Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
    ObjetAlertesNonBloquantes alerte = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
    
    listePeriodes.add(alerte);
    demandeCourante.getAlertesNonBloquantes().put("LIQ_AUTO_REPRISE_ASS", listePeriodes);
  }
  
  protected static void alimenterDonneesCspSurLigneCge(DossierExamenSpec dossierExamen, Decision demandeEchange)
    throws CoucheLogiqueException
  {
    if ((dossierExamen != null) && (dossierExamen.getDemande().estEnContexteDemande(6))) {
      if ((dossierExamen instanceof AttributionSpec))
      {
        AttributionAssuranceCgeSpec attributionCge = (AttributionAssuranceCgeSpec)dossierExamen;
        Demande demandeAssurance = (Demande)attributionCge.getDemande();
        
        alimenterTopPremiereDemandePostPrimeCsp(demandeAssurance, demandeEchange);
        
        Damj dateFinDispositifCSP = attributionCge.getDateLimiteIndemnisation();
        
        alimenterTopAllongementCSP(attributionCge, demandeEchange, dateFinDispositifCSP);
        
        Quantite dureePostPrime = attributionCge.getDureeReglementaire().getDureePostPrimeCspConstitutionDurees();
        if (dureePostPrime != null)
        {
          demandeEchange.setDureePostPrime(dureePostPrime.getValeur());
          alimenterTopDiminutionMontant(dureePostPrime, dateFinDispositifCSP, attributionCge.getDateAttribution(), demandeEchange);
        }
        demandeEchange.setCodeSousProduit(((AttributionSpec)dossierExamen).determinerCodeSousProduitPourSigma());
        if ((!(dossierExamen instanceof RevisionSpec)) && (!((AttributionAssuranceSpec)dossierExamen).estEnReexamen())) {
          demandeEchange.setDateBanalisee(dateFinDispositifCSP);
        }
      }
      else
      {
        demandeEchange.setCodeSousProduit("01");
      }
    }
  }
  
  private static void alimenterTopPremiereDemandePostPrimeCsp(Demande demandeAssurance, Decision demandeEchange)
  {
    boolean estPremiereDemandeSuitePrime = demandeAssurance.estEnContexteDemande("ASPPOSTPRI");
    if (estPremiereDemandeSuitePrime) {
      demandeEchange.setIndicateurPremiereDemandePostPrime("1");
    }
  }
  
  private static void alimenterTopAllongementCSP(AttributionAssuranceCgeSpec attributionCge, Decision demandeEchange, Damj dateFinDispositifCSP)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionEnEntreeCSP = (AttributionAssuranceSpec)OutilAsp.getInstance().recupererAttributionEntreeCsp(attributionCge);
    if (attributionEnEntreeCSP != null)
    {
      Damj dateFinDispositifCspInitiale = attributionEnEntreeCSP.getDateLimiteIndemnisation();
      if ((dateFinDispositifCspInitiale != null) && (!dateFinDispositifCspInitiale.coincideAvec(dateFinDispositifCSP))) {
        demandeEchange.setIndicateurAllongementDureeCSP("1");
      }
    }
  }
  
  private static void alimenterTopDiminutionMontant(Quantite dureePostPrime, Damj dateFinDispositifCSP, Damj dateAttribution, Decision demandeEchange)
  {
    if (dureePostPrime.getValeurEntiere() == 0)
    {
      demandeEchange.setIndicateurDiminutionMontantCSP("1");
    }
    else
    {
      DureeCalendaire dureePostPrimeCalendaire = new DureeCalendaire(0, 0, dureePostPrime.getValeurEntiere());
      Damj dateFinDroitAspDCTheorique = calculerDateFinAspDCTheorique(dateAttribution, dureePostPrimeCalendaire);
      if (dateFinDroitAspDCTheorique.estAvant(dateFinDispositifCSP)) {
        demandeEchange.setIndicateurDiminutionMontantCSP("1");
      }
    }
  }
  
  private static Damj calculerDateFinAspDCTheorique(Damj dateAttribution, DureeCalendaire dureePostPrime)
  {
    Damj dateFinDroitAspDCTheorique;
    Damj dateFinDroitAspDCTheorique;
    if ((dateAttribution.getMois() == 2) && (dateAttribution.getJour() == 29)) {
      dateFinDroitAspDCTheorique = dateAttribution.deplacerVersAvant(dureePostPrime);
    } else {
      dateFinDroitAspDCTheorique = dateAttribution.deplacerVersAvant(dureePostPrime).veille();
    }
    return dateFinDroitAspDCTheorique;
  }
  
  private static int renseignerToprejetAsuCategorieParticuliere(Demande demandeCourante)
  {
    int valeurRetourne = 0;
    if (demandeCourante.getDonneesDalEnrichies() != null)
    {
      int categorieParticuliere = demandeCourante.getDonneesDalEnrichies().getCategorieParticuliere();
      boolean estCategorieParticuliereAssCpa = (categorieParticuliere == 3) || (categorieParticuliere == 2) || (categorieParticuliere == 1);
      if (estCategorieParticuliereAssCpa) {
        valeurRetourne = 1;
      } else {
        valeurRetourne = 0;
      }
    }
    return valeurRetourne;
  }
  
  private static int determineTypeEchecExamen(DemandeSpec demande)
  {
    int typeEchecExamen = 0;
    
    DossierExamenSpec dossierExamen = null;
    if (!demande.getListeDossiersExamen().isEmpty()) {
      dossierExamen = (DossierExamenSpec)demande.getListeDossiersExamen().get(0);
    }
    if ((dossierExamen instanceof DecisionSpec))
    {
      int natureDecision = ((DecisionSpec)dossierExamen).getNatureDecision();
      if (((Demande)demande).getDecisionAutomatique() == 2)
      {
        if (natureDecision != 27) {
          typeEchecExamen = 2;
        }
      }
      else if ((((Demande)demande).getDecisionAutomatique() == 1) && (natureDecision != 28)) {
        typeEchecExamen = 1;
      }
    }
    else if (((Demande)demande).getDecisionAutomatique() == 1)
    {
      typeEchecExamen = 1;
    }
    else if (((Demande)demande).getDecisionAutomatique() == 2)
    {
      typeEchecExamen = 2;
    }
    else if ("S".equalsIgnoreCase(demande.getModeLiquidation()))
    {
      typeEchecExamen = 3;
    }
    return typeEchecExamen;
  }
  
  private static int determineMotifEchec(DemandeSpec demande)
  {
    int motifEchec = 0;
    
    DossierExamenSpec dossierExamen = null;
    if (!demande.getListeDossiersExamen().isEmpty()) {
      dossierExamen = (DossierExamenSpec)demande.getListeDossiersExamen().get(0);
    }
    if ("S".equalsIgnoreCase(demande.getModeLiquidation())) {
      motifEchec = 90;
    } else {
      determinerMotifEchecHorsLiquidationSimplifiee(demande, motifEchec, dossierExamen);
    }
    return motifEchec;
  }
  
  private static int determinerMotifEchecHorsLiquidationSimplifiee(DemandeSpec demande, int motifEchec, DossierExamenSpec dossierExamen)
  {
    int motif = motifEchec;
    if ((dossierExamen instanceof DecisionSpec))
    {
      int natureDecision = ((DecisionSpec)dossierExamen).getNatureDecision();
      if (((Demande)demande).getDecisionAutomatique() == 2)
      {
        if (natureDecision != 27) {
          motif = 88;
        }
      }
      else {
        motif = traiterRejetAutoSigma(demande, motif, natureDecision);
      }
    }
    else if (((Demande)demande).getDecisionAutomatique() == 1)
    {
      motif = 87;
    }
    else if (((Demande)demande).getDecisionAutomatique() == 2)
    {
      motif = 88;
    }
    else if (((Demande)demande).getDecisionAutomatique() == 3)
    {
      motif = 89;
    }
    return motif;
  }
  
  private static int traiterRejetAutoSigma(DemandeSpec demande, int motif, int natureDecision)
  {
    int resultat = motif;
    if (((Demande)demande).getDecisionAutomatique() == 1)
    {
      if (natureDecision != 28) {
        resultat = 87;
      }
    }
    else if (((Demande)demande).getDecisionAutomatique() == 3) {
      resultat = 89;
    }
    return resultat;
  }
  
  protected static int determinerTopLiqAutoRepriseAss(DemandeSpec demande)
    throws ApplicativeException
  {
    String typeExamen = demande.getEvenementReferenceExamen().getTypeExamen();
    
    boolean estContexteLiqAutoRepriseAss = detecterRepriseAssSuiteReinscription(demande);
    if ((estContexteLiqAutoRepriseAss) && ("ASU_01".equalsIgnoreCase(typeExamen)))
    {
      AttributionSpec attributionSolidaritePrecedente = rechercherAttributionAssPrecedente(demande);
      
      boolean estReliquatAssValide = estReliquatAssValide(demande, attributionSolidaritePrecedente);
      
      return verifierConditionsLiqAutoRepriseAss(estContexteLiqAutoRepriseAss, estReliquatAssValide, demande);
    }
    return 0;
  }
  
  protected static int verifierConditionsLiqAutoRepriseAss(boolean estContexteLiqAutoRepriseAss, boolean estReliquatAssValide, DemandeSpec demande)
  {
    int valeurRetourne = 0;
    Demande demandeCourante = (Demande)demande;
    if ((estContexteLiqAutoRepriseAss) && (estReliquatAssValide))
    {
      valeurRetourne = 1;
      
      afficherANBLiqAutoRepriseAss(demandeCourante);
    }
    return valeurRetourne;
  }
  
  protected static boolean estReliquatAssValide(DemandeSpec demande, AttributionSpec attributionSolidaritePrecedente)
    throws ApplicativeException
  {
    boolean estReliquatValide = false;
    Damj dateExamen = demande.getDateExamen();
    if ((attributionSolidaritePrecedente != null) && (dateExamen != null))
    {
      StrategieRejetDvAssSpec strategie = recupererStrategieRejetDvAss(dateExamen);
      if ((strategie == null) || (strategie.verifierCreationDalASS(attributionSolidaritePrecedente, demande)))
      {
        attributionSolidaritePrecedente.setDemandeSuivantePourTraitementReliquat(demande);
        estReliquatValide = RechercherReliquat.rechercherValiditeReliquatPourAss(attributionSolidaritePrecedente, dateExamen);
      }
    }
    return estReliquatValide;
  }
  
  protected static StrategieRejetDvAssSpec recupererStrategieRejetDvAss(Damj dateExamen)
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(dateExamen);
    return (StrategieRejetDvAssSpec)FabriqueStrategieRejetDvAss.getInstance().getStrategie(critere);
  }
  
  protected static AttributionSpec rechercherAttributionAssPrecedente(DemandeSpec demande)
  {
    return (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getDemandeur().getChronoDemandesNonTriees(), demande, new FiltreAttributionSolidariteAss(true));
  }
  
  private static String determinerCompetence(Demande demande)
  {
    String strCompetence = "";
    CompetenceSpec competence = ((DossierExamenAssuranceSpec)demande.getDossierExamen()).getCompetence();
    if (competence != null)
    {
      if (competence.getCompetenceAdministrative() == 1) {
        strCompetence = "AC";
      } else if (competence.getCompetenceAdministrative() == 2) {
        strCompetence = "SP";
      }
      if ((competence.getConventionGestion() != null) && ("2".equals(competence.getConventionGestion().getSignataire()))) {
        strCompetence = "CG";
      }
    }
    return strCompetence;
  }
  
  private static String renseignerLibelleEmployeur(CompetenceSpec competence)
  {
    String libelleEmployeur = "";
    if (competence != null) {
      libelleEmployeur = competence.getLibelleEmployeurCompetent();
    }
    return libelleEmployeur;
  }
  
  private static int determineCodeRejetAffi(DossierExamenAssuranceSpec rejet)
  {
    ProduitSpec produit = ((DossierAffecte)rejet.getDossierAffecte()).getProduit();
    Reglement reglementARetenir;
    Reglement reglementARetenir;
    if ((produit != null) && (produit.getNom().equals("ASU_SPE02_03")))
    {
      ValidationProduit validationProduit = ((DossierAffecte)rejet.getDossierAffecte()).getValidationProduit();
      reglementARetenir = validationProduit.getReglementApplicable();
    }
    else
    {
      ActiviteSalarie periodeReglementARetenir = (ActiviteSalarie)((Demande)rejet.getDemande()).getDonneesTemporaires().getPeriodeFctARetenir();
      if (periodeReglementARetenir == null) {
        periodeReglementARetenir = rejet.getFaitGenerateur().getPeriodeFaitGenerateur();
      }
      reglementARetenir = periodeReglementARetenir.getReglement();
    }
    int codeRejet = ((Integer)CodesMotifsEchec.s_codeMotifRejetAffi.get(reglementARetenir.getNomReglement())).intValue();
    
    return codeRejet;
  }
  
  public static int determineNatureDecision(DossierExamenSpec dossier)
  {
    int nature = ((DecisionSpec)dossier).getNatureDecision();
    
    AttributionAssuranceSpec attribution = ((Demande)dossier.getDemande()).getAttribution();
    if ((attribution != null) && (attribution.estTopeeRenoncement())) {
      nature = 98;
    } else if (OutilsRevisions.estContexteAttributionEnCoursRevisionAre14AvecRejetDv(dossier.getDemande())) {
      nature = 29;
    }
    return nature;
  }
  
  private static int determinerMotifRejetPourSigma(DemandeSpec demandeCali)
  {
    int motifRejet = 0;
    if (((demandeCali.getDossierAffectation().getDossierExamen() instanceof RejetSpec)) && (demandeCali.getCodeMotifEchecPourSigma() != null) && (!"".equalsIgnoreCase(demandeCali.getCodeMotifEchecPourSigma()))) {
      motifRejet = Integer.parseInt(demandeCali.getCodeMotifEchecPourSigma());
    }
    return motifRejet;
  }
  
  private static void alimenterDonneesCreationDalFps(RejetSpec rejetAre, Decision decisionEchange)
    throws ApplicativeException
  {
    Demande demandeAsuCourante = (Demande)rejetAre.getDemande();
    
    boolean rejetAffiliationInsufisante = determinerMotifRejetPourSigma(demandeAsuCourante) == 71;
    
    DemandeAssuranceSpec demandeReliquatFps = determinerDemandeReliquatFps(demandeAsuCourante);
    if ((demandeAsuCourante.estUneDemandeAreFdd()) && (rejetAffiliationInsufisante))
    {
      decisionEchange.setCreationDALSuiteRejet(1);
      
      decisionEchange.setTypeExamenCreationDemande("R1");
    }
    else if ((demandeAsuCourante.estUneDemandeApsFdd()) && (rejetAffiliationInsufisante))
    {
      decisionEchange.setCreationDALSuiteRejet(1);
      
      decisionEchange.setTypeExamenCreationDemande("R4");
    }
    else if ((estDemandeIdeEtDemandeReliquatFps(demandeAsuCourante.estUneDemandeAreIde(), demandeReliquatFps)) && (demandeReliquatFps.estUneDemandeAps()))
    {
      decisionEchange.setCreationDALSuiteRejet(1);
      
      decisionEchange.setTypeExamenCreationDemande("R3");
    }
    else if ((estDemandeIdeEtDemandeReliquatFps(demandeAsuCourante.estUneDemandeAreIde(), demandeReliquatFps)) && (demandeReliquatFps.estUneDemandeAtAfd()))
    {
      decisionEchange.setCreationDALSuiteRejet(1);
      
      decisionEchange.setTypeExamenCreationDemande("R6");
    }
  }
  
  private static boolean estDemandeIdeEtDemandeReliquatFps(boolean estDemandeAreIde, DemandeAssuranceSpec demandeReliquatFps)
  {
    return (estDemandeAreIde) && (demandeReliquatFps != null);
  }
  
  private static void alimenterDonneesCreationDalATA(DemandeSpec demandeCali, Decision decisionEchange)
    throws ApplicativeException
  {
    Demande demande = (Demande)demandeCali;
    if (demande.getDonneesDalEnrichies() != null)
    {
      int categorieParticuliere = demande.getDonneesDalEnrichies().getCategorieParticuliere();
      boolean estCategorieParticuliereAtaApatrideOuTraite = (categorieParticuliere == 6) || (categorieParticuliere == 7);
      
      boolean estCategorieParticuliereAta = (categorieParticuliere == 4) || (categorieParticuliere == 8) || (categorieParticuliere == 5);
      
      boolean estCategorieParticuliereAtaExpat = categorieParticuliere == 5;
      if ((estCategorieParticuliereAta) || (estCategorieParticuliereAtaExpat) || (estCategorieParticuliereAtaApatrideOuTraite))
      {
        decisionEchange.setTypeExamenCreationDemande("A2");
        decisionEchange.setCreationDALSuiteRejet(1);
      }
    }
  }
  
  private static DemandeAssuranceSpec determinerDemandeReliquatFps(DemandeAssuranceSpec demandeAsuCourante)
    throws ApplicativeException
  {
    DemandeAssuranceSpec demandeReliquatFpsRetournee = null;
    
    AttributionAssuranceSpec attributionAssurancePrecedente = demandeAsuCourante.rechercherAttributionPrecedenteDuMemeType();
    if (attributionAssurancePrecedente != null)
    {
      DemandeAssuranceSpec demandeAssurancePrecedente = (DemandeAssuranceSpec)attributionAssurancePrecedente.getDemande();
      if ((demandeAssurancePrecedente.estUneDemandeAps()) || (demandeAssurancePrecedente.estUneDemandeAtAfd()))
      {
        Quantite qteReliquatFps = ((ProduitAsuSpec)attributionAssurancePrecedente.getProduit()).determinerReliquatHorsMaintien(attributionAssurancePrecedente, demandeAsuCourante.getDateRecherche().veille());
        if ((qteReliquatFps != null) && (qteReliquatFps.getValeurEntiere() > 0)) {
          demandeReliquatFpsRetournee = demandeAssurancePrecedente;
        }
      }
    }
    return demandeReliquatFpsRetournee;
  }
  
  private static void alimenterDonneesCreationDalAsrAtp(DemandeSpec demandeCali, Decision decisionEchange)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)demandeCali;
    boolean contexteOk = false;
    if ((!OutilDemande.estUneDemandeAtp(demande)) && (!OutilDemande.estUneDemandeAsr(demande)) && (demande.getDonneesDAL().estTopFinDeDroit())) {
      contexteOk = true;
    }
    if (contexteOk)
    {
      controlerFinancement(demandeCali);
      decisionEchange.setTopRejetASUReliquatASS(2);
    }
  }
  
  private static void controlerFinancement(DemandeSpec demandeCali)
    throws CoucheLogiqueException
  {
    Demande demandeFddAtp = (Demande)OutilRecherche.rechercherDemandePrecedente(demandeCali.getDemandeur().getChronoDemandeAssurance(), demandeCali, null);
    if (demandeFddAtp.estUneDemandeFinDroitAtp())
    {
      AttributionAssuranceSpec attributionAtp = OutilAtp.rechercherAttributionAtpOrigine(demandeFddAtp, demandeFddAtp.getDateDeclenchementExamen());
      if (attributionAtp != null) {
        if (attributionAtp.getAttributionFinancement() != null)
        {
          FinancementSpec financement = (FinancementSpec)attributionAtp.getAttributionFinancement();
          leverBlocageFinancement(financement);
        }
        else
        {
          GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ATP_SANS_FINANCEMENT_UNEDIC_ASS");
        }
      }
    }
  }
  
  private static void leverBlocageFinancement(FinancementSpec financement)
    throws CoucheLogiqueException
  {
    if (financement != null)
    {
      if ("P" != financement.getNatureFinancement()) {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ATP_SANS_FINANCEMENT_UNEDIC_ASS");
      }
    }
    else {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ATP_SANS_FINANCEMENT_UNEDIC_ASS");
    }
  }
  
  private static void alimenterDonneesContributionParticuliere(Decision demandeEchange, Demande demandeCourante, DossierExamenSpec dossierExamenCourant)
  {
    ContributionParticuliereSpec contributionParticuliere = ((DossierExamenAssuranceSpec)dossierExamenCourant).getContributionParticuliere();
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "AREENTRCSP")) {
      alimenterDonneesContributionParticuliereContexteAreEntreeCsp(demandeEchange, demandeCourante, dossierExamenCourant, contributionParticuliere);
    } else {
      alimenterDonneesContributionParticuliereAutreContexte(demandeEchange, contributionParticuliere);
    }
  }
  
  private static void alimenterDonneesContributionParticuliereContexteAreEntreeCsp(Decision demandeEchange, Demande demandeCourante, DossierExamenSpec dossierExamenCourant, ContributionParticuliereSpec contributionParticuliere)
  {
    ValidationProduit validationProduit = ((DossierAffectation)demandeCourante.getDossierAffectation()).getValidationProduit();
    int motifFin = 0;
    if ((validationProduit != null) && (validationProduit.getPeriodeValidationProduit() != null)) {
      motifFin = Integer.parseInt(validationProduit.getPeriodeValidationProduit().getMotifFin());
    }
    if (((dossierExamenCourant instanceof NovationSpec)) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "AREENTRCSP")))
    {
      ActiviteSalarie periodeValidation = (ActiviteSalarie)demandeCourante.getDossierAffectationAdmission().getSinistre();
      motifFin = periodeValidation.getCodeMotifFin();
    }
    if (((motifFin == 45) || (motifFin == 49)) && (contributionParticuliere.isTopDetectionContributionPreavis()))
    {
      demandeEchange.setTopContribSpecifique(1);
      demandeEchange.setSituationParticuliere("9");
      demandeEchange.setContributionNonPropositionCTP(contributionParticuliere.getMontantPreavisCtp());
      demandeEchange.setTopAppelContributions(1);
      demandeEchange.setEstContribPreavis(0);
      demandeEchange.setEstContribDif(0);
      demandeEchange.setMontantPreavisCR(null);
      demandeEchange.setMontantFormationD(null);
    }
    else
    {
      if (contributionParticuliere.isTopDetectionContributionPreavis()) {
        demandeEchange.setEstContribPreavis(1);
      } else {
        demandeEchange.setEstContribPreavis(0);
      }
      if (contributionParticuliere.isTopDetectionContributionDif()) {
        demandeEchange.setEstContribDif(1);
      } else {
        demandeEchange.setEstContribDif(0);
      }
      demandeEchange.setMontantPreavisCR(contributionParticuliere.getMontantPreavisCtp());
      demandeEchange.setMontantFormationD(contributionParticuliere.getMontantFormationDifCtp());
    }
  }
  
  private static void alimenterDonneesContributionParticuliereAutreContexte(Decision demandeEchange, ContributionParticuliereSpec contributionParticuliere)
  {
    int typeContrib = contributionParticuliere.getTypeContributionParticuliere();
    switch (typeContrib)
    {
    case 2: 
      demandeEchange.setTopContribSpecifique(1);
      demandeEchange.setTopContribSupplementaire(0);
      break;
    case 1: 
      demandeEchange.setTopContribSpecifique(0);
      demandeEchange.setTopContribSupplementaire(1);
      break;
    case 3: 
      demandeEchange.setTopContribSpecifique(1);
      demandeEchange.setTopContribSupplementaire(1);
      break;
    case 0: 
      demandeEchange.setTopContribSpecifique(0);
      demandeEchange.setTopContribSupplementaire(0);
      demandeEchange.setTopAppelContributions(1);
      break;
    }
  }
  
  public static ProduitSpec determinerProduitDecision(Demande demandeAssurance)
  {
    ProduitSpec produit = demandeAssurance.getDossierAffectation().getProduit();
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeAssurance, 6)) {
      produit = OutilAsp.getInstance().recupererProduitReglementaire(demandeAssurance);
    }
    return produit;
  }
  
  protected static Decision alimenterDonneesCreationAttenteNPDE(Decision decisionEchange, String codeAttente)
  {
    if (!conserverCodeSegmentInitial(codeAttente)) {
      decisionEchange.setCodeSegment("ATTE");
    }
    decisionEchange.setCodeTypeAttente(codeAttente);
    
    return decisionEchange;
  }
  
  private static boolean conserverCodeSegmentInitial(String codeAttente)
  {
    List<String> listeCodeAttenteSansChangement = new ArrayList();
    listeCodeAttenteSansChangement.add(null);
    listeCodeAttenteSansChangement.add("");
    listeCodeAttenteSansChangement.add("J");
    listeCodeAttenteSansChangement.add("Z");
    return listeCodeAttenteSansChangement.contains(codeAttente);
  }
  
  private static void alimenterDonneesCreationAttenteIncoherenceSalaireNPDE(Decision decisionEchange, Demande demande)
  {
    if ((demande.getDonneesSortieNPDE().isAttenteIncohrenceSalaireLevee()) && (!demande.estEnReExamen()))
    {
      List<ObjetAlertesNonBloquantes> listeAlertes = (List)demande.getAlertesNonBloquantes().get("A11MNB5");
      if (listeAlertes != null)
      {
        decisionEchange.setAttenteIncoherenceSalaireNPDE(1);
        
        ObjetAlertesNonBloquantes alertes = (ObjetAlertesNonBloquantes)listeAlertes.get(0);
        decisionEchange.setIdentifiantPeriodeIncoherenceSalaireNPDE(new BigDecimal(OutilActiviteSalarie.formaterIdentifiantPeriodeGaec(alertes.getIdentifiantActivite(), 17)));
      }
    }
    else
    {
      decisionEchange.setAttenteIncoherenceSalaireNPDE(0);
    }
  }
  
  protected static void alimenterDonneesPap(DossierExamenSpec dossierExamen, Decision decisionEchange)
  {
    if ((dossierExamen != null) && (dossierExamen.getDemande().estEnContexteDemande(10)))
    {
      String codeSousProduit = ((DecisionSpec)dossierExamen).determinerCodeSousProduitPourSigma();
      if ((dossierExamen instanceof AttributionSpec))
      {
        Demande demande = (Demande)dossierExamen.getDemande();
        decisionEchange.setNombreMoisPreavis(demande.getDonneesTemporaires().getNombreMoisPreavis());
        decisionEchange.setPresenceDerniersSalaires(demande.getDonneesTemporaires().isPresenceDerniersSalaires());
        decisionEchange.setCodeSousProduit(codeSousProduit);
      }
      else
      {
        decisionEchange.setCodeSousProduitRejet(codeSousProduit);
      }
    }
  }
}

/* Location:
 * Qualified Name:     AlimenterBaseEchanges
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */