package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.fabriques.FabriqueStrategieIslr;
import fr.unedic.cali.asu.fabriques.FabriqueStrategieIslrIndemniteLetT;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieIslrIndemniteLetTSpec;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieIslrSpec;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;

public class ConstitutionISLR
{
  private static final BigDecimal PER_CENT_110 = new BigDecimal(1.1D);
  private static ConstitutionISLR s_instance = new ConstitutionISLR();
  
  public static ConstitutionISLR getInstance()
  {
    return s_instance;
  }
  
  public QuantiteEuro calculeISLR(Collection p_listeIndemnites, int p_codeMotifRuptureCT, int p_categorieEmploiParticulier, Damj p_dateFaitGenerateurOuDernierSinistre)
    throws CoucheLogiqueException
  {
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(p_dateFaitGenerateurOuDernierSinistre);
    StrategieIslrSpec strategieIslrCourante = (StrategieIslrSpec)FabriqueStrategieIslr.getInstance().getStrategie(critereStrategie);
    QuantiteEuro retourISLR = strategieIslrCourante.calculeISLR(p_listeIndemnites, p_codeMotifRuptureCT, p_categorieEmploiParticulier, p_dateFaitGenerateurOuDernierSinistre);
    
    return retourISLR;
  }
  
  protected QuantiteEuro calculeISLRUnitaireStandard(BigDecimal p_montantE, BigDecimal p_total, BigDecimal p_substrat)
  {
    BigDecimal valeurZero = new BigDecimal("0");
    if (p_total == null) {
      return new QuantiteEuro("0");
    }
    if (p_montantE == null) {
      return new QuantiteEuro(p_total);
    }
    if (p_substrat.compareTo(p_montantE) > 0) {
      return new QuantiteEuro(valeurZero.max(p_total.subtract(p_montantE)));
    }
    return new QuantiteEuro(valeurZero.max(p_total.subtract(p_substrat)));
  }
  
  protected BigDecimal calculerISLICP(BigDecimal p_montantIcp, BigDecimal p_montantIcpEstime)
  {
    if (p_montantIcp == null) {
      return BigDecimal.ZERO;
    }
    if (p_montantIcpEstime == null) {
      return p_montantIcp;
    }
    if (p_montantIcp.compareTo(p_montantIcpEstime) > 0) {
      return p_montantIcp.subtract(p_montantIcpEstime);
    }
    return BigDecimal.ZERO;
  }
  
  protected QuantiteEuro calculeISLRUnitaireCasAssistanteMaternelle(BigDecimal p_montantE, BigDecimal p_total, BigDecimal p_rmat)
  {
    BigDecimal valeurZero = new BigDecimal("0");
    if (p_total == null) {
      return new QuantiteEuro("0");
    }
    if (p_montantE == null) {
      return new QuantiteEuro(p_total);
    }
    if (p_rmat.compareTo(p_montantE.multiply(PER_CENT_110)) > 0) {
      return new QuantiteEuro(valeurZero.max(p_total.subtract(p_montantE)));
    }
    return new QuantiteEuro(valeurZero.max(p_total.subtract(p_rmat)));
  }
  
  protected QuantiteEuro calculeISLRPourFCDouFMIouCNE(BigDecimal p_total, BigDecimal p_montantFCDouFMIouCNE)
  {
    BigDecimal valeurZero = new BigDecimal("0");
    QuantiteEuro islr = new QuantiteEuro(valeurZero);
    if (p_total != null) {
      islr = new QuantiteEuro(valeurZero.max(p_total.subtract(p_montantFCDouFMIouCNE)));
    }
    return islr;
  }
  
  protected QuantiteEuro determinerMontantIslrSurValeursMontantsLSLCT(BigDecimal p_montantE, BigDecimal p_montantL, BigDecimal p_montantSL, BigDecimal p_montantC, BigDecimal p_montantT, Damj p_dateFaitGenerateurOuDernierSinistre)
  {
    QuantiteEuro retourISLR = new QuantiteEuro("0");
    BigDecimal total = null;
    BigDecimal substrat = null;
    if ((p_montantL == null) && (p_montantSL == null) && (p_montantC == null) && (p_montantT != null))
    {
      retourISLR = new QuantiteEuro(p_montantT);
    }
    else if ((p_montantL == null) && (p_montantSL == null) && (p_montantC != null) && (p_montantT == null))
    {
      total = p_montantC;
      substrat = p_montantC;
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    else if ((p_montantL == null) && (p_montantSL == null) && (p_montantC != null) && (p_montantT != null))
    {
      total = p_montantC.add(p_montantT);
      substrat = p_montantC;
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    else if ((p_montantL == null) && (p_montantSL != null) && (p_montantC == null) && (p_montantT == null))
    {
      total = p_montantSL;
      substrat = p_montantSL;
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    else if ((p_montantL == null) && (p_montantSL != null) && (p_montantC == null) && (p_montantT != null))
    {
      total = p_montantSL.add(p_montantT);
      substrat = p_montantSL;
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    else if ((p_montantL == null) && (p_montantSL != null) && (p_montantC != null) && (p_montantT == null))
    {
      total = p_montantC;
      substrat = p_montantSL;
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    else if ((p_montantL == null) && (p_montantSL != null) && (p_montantC != null) && (p_montantT != null))
    {
      total = p_montantC.add(p_montantT);
      substrat = p_montantSL;
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    else if ((p_montantL != null) && (p_montantSL == null) && (p_montantC == null) && (p_montantT == null))
    {
      total = p_montantL;
      substrat = p_montantL;
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    else if ((p_montantL != null) && (p_montantSL == null) && (p_montantC == null) && (p_montantT != null))
    {
      CritereStrategie critereStrategie = new CritereStrategie();
      critereStrategie.setDatePivot(p_dateFaitGenerateurOuDernierSinistre);
      StrategieIslrIndemniteLetTSpec strategieIslrIndemniteLetT = (StrategieIslrIndemniteLetTSpec)FabriqueStrategieIslrIndemniteLetT.getInstance().getStrategie(critereStrategie);
      total = strategieIslrIndemniteLetT.calculTotalIndemniteLetT(p_montantL, p_montantT, p_dateFaitGenerateurOuDernierSinistre);
      
      substrat = p_montantL;
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    else if ((p_montantL != null) && (p_montantSL == null) && (p_montantC != null) && (p_montantT == null))
    {
      total = p_montantC;
      substrat = p_montantL;
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    else if ((p_montantL != null) && (p_montantSL == null) && (p_montantC != null) && (p_montantT != null))
    {
      total = p_montantC.add(p_montantT);
      substrat = p_montantL;
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    else if ((p_montantL != null) && (p_montantSL != null) && (p_montantC == null) && (p_montantT == null))
    {
      total = p_montantL.add(p_montantSL);
      substrat = p_montantL.add(p_montantSL);
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    else if ((p_montantL != null) && (p_montantSL != null) && (p_montantC == null) && (p_montantT != null))
    {
      substrat = p_montantL.add(p_montantSL);
      total = p_montantT.add(substrat);
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    else if ((p_montantL != null) && (p_montantSL != null) && (p_montantC != null) && (p_montantT == null))
    {
      total = p_montantC;
      substrat = p_montantL.add(p_montantSL);
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    else if ((p_montantL != null) && (p_montantSL != null) && (p_montantC != null) && (p_montantT != null))
    {
      total = p_montantC.add(p_montantT);
      substrat = p_montantL.add(p_montantSL);
      retourISLR = calculeISLRUnitaireStandard(p_montantE, total, substrat);
    }
    return retourISLR;
  }
}

/* Location:
 * Qualified Name:     ConstitutionISLR
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */