package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.EreDemandeExpresse;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.d12i.spec.DonneesDALSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeFctPrincipale;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.util.List;

public class ConstitutionListeEreConvention2017
  extends ConstitutionListeEre
{
  private static ConstitutionListeEreConvention2017 instance = new ConstitutionListeEreConvention2017();
  
  public static ConstitutionListeEreConvention2017 getInstance()
  {
    return instance;
  }
  
  protected void constituterContexte(Demande demande, boolean estContexteDroitAnterieurSecteurPublic, Chronologie chronoFCTParticipantes, DomLiquidationAssurance donnees)
    throws ApplicativeException
  {
    Damj dateDeterminationContexte = recupererDateDeterminationContexte(demande);
    if ((estSuiteRejetDVAvecReliquatValide(dateDeterminationContexte, demande, estContexteDroitAnterieurSecteurPublic)) && (!estDroitOptionForce(demande))) {
      donnees.setContexteOuvertureDroitAuPlusTot(true);
    } else {
      donnees.setContexteOuvertureDroitAuPlusTot(false);
    }
  }
  
  protected Damj recupererDateDeterminationContexte(Demande demande)
  {
    return ((FormulaireAsu)demande.getFormulaire()).getDateDepotOrigine().veille();
  }
  
  protected void determinerListeErePourOuvertureDroitAuPlusTard(Demande demande, List<EvenementReferenceExamenSpec> listeEre, Chronologie chronoPeriodesParticipantes, EreDemandeExpresse ereParDefaut)
    throws CoucheLogiqueException
  {
    if (!chronoPeriodesParticipantes.estVide())
    {
      ActiviteSalarie dernierSinistreDja = null;
      Damj dateDepot = ((FormulaireAsu)demande.getFormulaire()).getDateDepotOrigine();
      Damj dja = demande.getDonneesDalEnrichies().getDernierJourAtteste();
      if ((dja != null) && (dja.estAvant(dateDepot)) && (!estDroitOptionForce(demande)))
      {
        dernierSinistreDja = rechercherDernierSinitre(dja, chronoPeriodesParticipantes);
        if (dernierSinistreDja != null)
        {
          EreDemandeExpresse ereDja = new EreDemandeExpresse();
          positionnerDateEvenement(demande, ereDja, dja);
          ereDja.setPeriodeExamen(dernierSinistreDja);
          listeEre.add(ereDja);
        }
      }
      ActiviteSalarie dernierSinistreDateDepot = rechercherDernierSinitre(dateDepot, chronoPeriodesParticipantes);
      if ((dernierSinistreDja == null) || ((dernierSinistreDateDepot != null) && (!dernierSinistreDja.getIdentifiant().equals(dernierSinistreDateDepot.getIdentifiant()))))
      {
        EreDemandeExpresse ereDateDepot = new EreDemandeExpresse();
        positionnerDateEvenement(demande, ereDateDepot, dernierSinistreDateDepot.getDateFin());
        ereDateDepot.setPeriodeExamen(dernierSinistreDateDepot);
        listeEre.add(ereDateDepot);
      }
    }
    else
    {
      positionnerDateEvenement(demande, ereParDefaut, ((FormulaireAsu)demande.getFormulaire()).getDateDepotOrigine().veille());
      listeEre.add(ereParDefaut);
    }
  }
  
  protected ActiviteSalarie rechercherDernierSinitre(Damj dateExamen, Chronologie chronoPeriodesParticipantes)
    throws CoucheLogiqueException
  {
    ActiviteSalarie dernierSinistre = (ActiviteSalarie)RechercherDernierSinistre.rechercherDernierSinistre(dateExamen, chronoPeriodesParticipantes);
    if (dernierSinistre != null)
    {
      Chronologie chronoFctConcomittante = detecterFctConcomittante(chronoPeriodesParticipantes, dernierSinistre);
      if ((dernierSinistre.estUneFctConcomittante()) && (!dernierSinistre.estFctPrincipale()))
      {
        Chronologie chronoFctPrincipale = chronoFctConcomittante.copier(new FiltrePeriodeFctPrincipale(dernierSinistre.getDateFin()));
        if (chronoFctPrincipale.getTaille() > 0) {
          dernierSinistre = (ActiviteSalarie)chronoFctPrincipale.premierElement();
        } else {
          GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_CTX_ABS_FCT_PRINCIPALE_AVEC_DATE", new Object[] { dernierSinistre.getDateFin() });
        }
      }
    }
    return dernierSinistre;
  }
  
  protected boolean estSuiteRejetDVAvecReliquatValide(Damj dateDeterminationContexte, Demande demande, boolean estContexteDroitAnterieurSecteurPublic)
    throws ApplicativeException
  {
    boolean estPresenceRejetDv = estPresenceRejetDv(dateDeterminationContexte, demande);
    boolean estPresenceReliquatValide = estPresenceReliquatValide(dateDeterminationContexte, demande, estContexteDroitAnterieurSecteurPublic);
    return (estPresenceRejetDv) && (estPresenceReliquatValide);
  }
  
  protected boolean estPresenceRejetDv(Damj dateDeterminationContexte, Demande demande)
  {
    DossierExamenAssuranceSpec decisionPrecedente = (DossierExamenAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), dateDeterminationContexte.veille(), new FiltreDecisionARESurDecision());
    
    return (decisionPrecedente != null) && (decisionPrecedente.estRejetDV());
  }
  
  protected boolean estPresenceReliquatValide(Damj dateDeterminationContexte, Demande demande, boolean estContexteDroitAnterieurSecteurPublic)
    throws ApplicativeException
  {
    boolean estPresenceReliquat = false;
    if (estContexteDroitAnterieurSecteurPublic)
    {
      estPresenceReliquat = true;
    }
    else
    {
      AttributionAssuranceSpec attributionPrecedente = demande.rechercherAttributionPrecedenteDuMemeType();
      if (attributionPrecedente != null)
      {
        attributionPrecedente.setDemandeSuivantePourTraitementReliquat(demande);
        ResultatExecutionCalculSpec resultatCalcul = appelCalcul(attributionPrecedente, dateDeterminationContexte);
        estPresenceReliquat = resultatCalcul.getEtatAttribution() == 3;
      }
    }
    return estPresenceReliquat;
  }
  
  protected ResultatExecutionCalculSpec appelCalcul(AttributionAssuranceSpec attribution, Damj dateDeterminationContexte)
    throws ApplicativeException
  {
    return AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attribution, dateDeterminationContexte, true, true);
  }
  
  protected Damj getBorneSuperieure(Demande demande)
  {
    Damj borneSup = ((FormulaireAsu)demande.getFormulaire()).getDateDepotOrigine();
    if (borneSup == null) {
      borneSup = demande.getFormulaire().getDateDepot();
    }
    return borneSup;
  }
}

/* Location:
 * Qualified Name:     ConstitutionListeEreConvention2017
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */