package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.EreGammeAsu;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.produits.liquidation.dom.Antecedent;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Preavis;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.OutilAttribution;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieRuptureContratSuiteChomageSansRupture;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSurMemeContratGAEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSuspensionChomageSansRCT;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionAssurance;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreAttributionSurDecisions;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourNumeroGamme;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreAttributionEnCoursIndemnisationPourDate;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieDecoupeePourContexteDecoupage;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieSurObjetChronoPeriode;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieSuspensionDecoupee;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreObjetChronoPeriodeChevaucheDate;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreDebutApresDate;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class DetectionContexteParticulierLiquidation
{
  public final Damj dateApplicationContextePmvs = new Damj(2013, 8, 4);
  private static DetectionContexteParticulierLiquidation instance;
  
  public static DetectionContexteParticulierLiquidation getInstance()
  {
    if (instance == null) {
      instance = new DetectionContexteParticulierLiquidation();
    }
    return instance;
  }
  
  public void determinerContexteParticulierLiquidationAssurance(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Demande demandeAssurance = (Demande)demande;
    demandeAssurance.clearCollectionContexteDemande();
    if (demande.getDonneesTemporaires().getTypeContexteDemandeDonneesTemporaires() != null)
    {
      ContexteDemande contexte = new ContexteDemande();
      contexte.setTypeContexteDemande(demande.getDonneesTemporaires().getTypeContexteDemandeDonneesTemporaires());
      demandeAssurance.ajouterContexteDemande(contexte);
    }
    else
    {
      EreGammeAsu ereAsu = (EreGammeAsu)demande.getEvenementReferenceExamen();
      ereAsu.determinerContexteDemande(demande);
    }
  }
  
  public void detectionContexteParticulierCsr(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Demande demandeAssurance = (Demande)demande;
    ActiviteSalarie periodeDeSuspension = OutilsChomageSansRCT.trouverPeriodeDeSuspension(demandeAssurance);
    
    Demande premiereDemandeSuspension = OutilsChomageSansRCT.trouverPremiereDemandeSurSuspension(demandeAssurance, periodeDeSuspension);
    if (OutilsChomageSansRCT.estCsrEnCoursDeSuspension(demandeAssurance, premiereDemandeSuspension, periodeDeSuspension))
    {
      ContexteDemande contexte = new ContexteDemande();
      ((Demande)demande).ajouterContexteDemande(contexte);
      contexte.setTypeContexteDemande("CSRSUSP");
      contexte.setDateDebutJustifContexte(periodeDeSuspension.getDateDebut());
      contexte.setDateFinJustifContexte(periodeDeSuspension.getDateFin());
      contexte.setIdPremiereDemandeCsrDansSuspension(premiereDemandeSuspension.getIdentifiant());
      if (estRuptureContratEnCoursDeSuspension(demandeAssurance)) {
        contexte.setTypeContexteDemande("RUPCTRSUSP");
      }
    }
  }
  
  public boolean estContexteParticulierCsrDetecte(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    boolean retour = false;
    Demande demandeAssurance = (Demande)demande;
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demandeAssurance))
    {
      retour = true;
    }
    else
    {
      ActiviteSalarie periodeDeSuspension = OutilsChomageSansRCT.trouverPeriodeDeSuspension(demandeAssurance);
      
      Demande premiereDemandeSuspension = OutilsChomageSansRCT.trouverPremiereDemandeSurSuspension(demandeAssurance, periodeDeSuspension);
      if (OutilsChomageSansRCT.estCsrEnCoursDeSuspension(demandeAssurance, premiereDemandeSuspension, periodeDeSuspension)) {
        retour = true;
      }
    }
    return retour;
  }
  
  private boolean estRuptureContratEnCoursDeSuspension(Demande demandeEnContexteCsrEnCoursSuspension)
    throws CoucheLogiqueException
  {
    ActiviteSalarie periodeValidationProduit = OutilsChomageSansRCT.trouverDernierSinistre(demandeEnContexteCsrEnCoursSuspension);
    if (periodeValidationProduit == null) {
      return false;
    }
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieSurMemeContratGAEC(periodeValidationProduit));
    filtres.ajouterFiltre(new FiltreDebutApresDate(periodeValidationProduit.getDateFin()));
    
    Chronologie chronoMemeActiviteGaecApresDate = demandeEnContexteCsrEnCoursSuspension.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    
    filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieRuptureContratSuiteChomageSansRupture());
    Chronologie chronoPeriodesRuptureContrat = chronoMemeActiviteGaecApresDate.copier(filtres);
    if (!chronoPeriodesRuptureContrat.estVide())
    {
      ActiviteSalarie activiteSalarie = (ActiviteSalarie)chronoPeriodesRuptureContrat.premierElement();
      if (activiteSalarie.getContrat().estSuspensionChomageSansRCT()) {
        return true;
      }
      if (activiteSalarie.getContrat().getPreavis() != null)
      {
        FiltresTemporel filtreSuspension = new FiltresTemporel();
        filtreSuspension.ajouterFiltre(new FiltreActiviteSalarieSuspensionChomageSansRCT());
        
        Chronologie chronoPeriodesSuspensionSurContrat = chronoMemeActiviteGaecApresDate.copier(filtreSuspension);
        if (!chronoPeriodesSuspensionSurContrat.estVide())
        {
          ActiviteSalarie suspension = (ActiviteSalarie)chronoPeriodesSuspensionSurContrat.premierElement();
          
          Preavis preavis = activiteSalarie.getContrat().getPreavis();
          if (preavis.getPeriodeNonEffectueeNonPayee() != null) {
            return (preavis.getPeriodeNonEffectueeNonPayee().getDebut().equals(suspension.getDateFin().lendemain())) && (preavis.getPeriodeNonEffectueeNonPayee().getFin().equals(activiteSalarie.getDateFin()));
          }
          return false;
        }
      }
    }
    return false;
  }
  
  public fr.unedic.cali.asu.dom.AttributionAssuranceSpec trouverOdArePrecedente(Demande demande)
  {
    FiltreET odAre = new FiltreET();
    odAre.ajouterFiltre(new FiltreOuvertureDroitStandardAssurance(true, false, true, false, demande));
    odAre.ajouterFiltre(new FiltreDecisionARESurDecision());
    return (fr.unedic.cali.asu.dom.AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, odAre);
  }
  
  public void detectionContexteEnCoursPmvs(DemandeAssuranceSpec demandeAssurance, TravailSpec dernierSinistre, Damj dateExamen)
    throws CoucheLogiqueException
  {
    OutilGestionContexteDemande.supprimerContexteDemande((Demande)demandeAssurance, "CRSPMVS");
    if ((dernierSinistre != null) && (dateExamen != null) && (dernierSinistre.getDateFin().estApresOuCoincideAvec(dateApplicationContextePmvs)))
    {
      Demande demande = (Demande)demandeAssurance;
      
      FiltreET filtrePmvsExamenEtDebutEtFinDernierSinistreDansPmvs = new FiltreET();
      filtrePmvsExamenEtDebutEtFinDernierSinistreDansPmvs.ajouterFiltre(new FiltreActiviteSalarieDecoupeePourContexteDecoupage("MVS"));
      
      filtrePmvsExamenEtDebutEtFinDernierSinistreDansPmvs.ajouterFiltre(new FiltreActiviteSalarieSuspensionDecoupee());
      
      filtrePmvsExamenEtDebutEtFinDernierSinistreDansPmvs.ajouterFiltre(new FiltreObjetChronoPeriodeChevaucheDate(dateExamen, null));
      
      filtrePmvsExamenEtDebutEtFinDernierSinistreDansPmvs.ajouterFiltre(new FiltreObjetChronoPeriodeChevaucheDate(dernierSinistre.getDateFin(), null));
      
      filtrePmvsExamenEtDebutEtFinDernierSinistreDansPmvs.ajouterFiltre(new FiltreObjetChronoPeriodeChevaucheDate(dernierSinistre.getDateDebut(), null));
      
      Chronologie chronologie = demandeAssurance.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtrePmvsExamenEtDebutEtFinDernierSinistreDansPmvs);
      if (!chronologie.estVide())
      {
        ActiviteSalarie pmvs = (ActiviteSalarie)chronologie.premierElement();
        ContexteDemande contexteDemande = new ContexteDemande();
        contexteDemande.setTypeContexteDemande("CRSPMVS");
        
        contexteDemande.setIdentifiantPeriodeCaliJustifContexte(pmvs.getIdentifiant());
        contexteDemande.setDateDebutJustifContexte(pmvs.getDateDebut());
        contexteDemande.setDateFinJustifContexte(pmvs.getDateFin());
        demande.ajouterContexteDemande(contexteDemande);
      }
    }
  }
  
  public void detectionContexteEnCoursPmvsReconduit(DemandeAssuranceSpec demandeAssuranceCourante, DecisionAssuranceSpec decisionPrecedente, Damj dateExamen)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)demandeAssuranceCourante;
    if ((decisionPrecedente != null) && (dateExamen != null))
    {
      FiltreET filtrePmvsExamenEtDebutEtFinDernierSinistreDansPmvs = new FiltreET();
      filtrePmvsExamenEtDebutEtFinDernierSinistreDansPmvs.ajouterFiltre(new FiltreActiviteSalarieDecoupeePourContexteDecoupage("MVS"));
      
      filtrePmvsExamenEtDebutEtFinDernierSinistreDansPmvs.ajouterFiltre(new FiltreActiviteSalarieSuspensionDecoupee());
      
      filtrePmvsExamenEtDebutEtFinDernierSinistreDansPmvs.ajouterFiltre(new FiltreObjetChronoPeriodeChevaucheDate(dateExamen, null));
      
      Chronologie chronologie = demandeAssuranceCourante.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtrePmvsExamenEtDebutEtFinDernierSinistreDansPmvs);
      
      ContexteDemande contexteDemande = (ContexteDemande)OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent((Demande)decisionPrecedente.getDemande(), 2);
      
      boolean preRequisValide = (contexteDemande != null) && (chronologie != null) && (!chronologie.estVide());
      if ((preRequisValide) && (contexteDemande.getDateDebutJustifContexte().estAvantOuCoincideAvec(dateExamen)) && (contexteDemande.getDateFinJustifContexte().estApresOuCoincideAvec(dateExamen)))
      {
        ContexteDemande contextePmvsReconduit = (ContexteDemande)contexteDemande.copie();
        contextePmvsReconduit.setTypeContexteDemande("CRSPMVSREC");
        contextePmvsReconduit.setDateDebutJustifContexte(contexteDemande.getDateDebutJustifContexte());
        contextePmvsReconduit.setDateFinJustifContexte(contexteDemande.getDateFinJustifContexte());
        contextePmvsReconduit.setIdentifiantPeriodeCaliJustifContexte(contexteDemande.getIdentifiantPeriodeCaliJustifContexte());
        demande.ajouterContexteDemande(contextePmvsReconduit);
      }
    }
    Demande rejetDV = GestionDemandeDv122eJour.retrouverDemandePortantDv(demandeAssuranceCourante);
    if ((rejetDV != null) && (!demandeAssuranceCourante.estEnContexteDemande(2)) && (rejetDV.estEnContexteDemande(2))) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DEMANDE_IPR_HORS_PMVS");
    }
  }
  
  private Chronologie trouverAttributionsEnContextePmvsDansPra(Demande demandeCourante, Periode periodePra, Damj dateExamen)
  {
    FiltreET filtrePeriodeIndemniseeEnContextePmvs = new FiltreET();
    filtrePeriodeIndemniseeEnContextePmvs.ajouterFiltre(new FiltreAttributionEnCoursIndemnisationPourDate(periodePra));
    filtrePeriodeIndemniseeEnContextePmvs.ajouterFiltre(new FiltreDemandePourTypeContexteDemande(2));
    
    return OutilRecherche.rechercherDecisionsPrecedentes(demandeCourante.getChronologieDemandesAssuranceSansCourante(), dateExamen, filtrePeriodeIndemniseeEnContextePmvs);
  }
  
  public Chronologie detectionContexteSuiteOdPmvs(Demande demandeCourante, Periode periodePra, Damj dateExamen)
  {
    ContexteDemande contexteDemandeDejaCalcule = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demandeCourante, "SUITEPMVS");
    Chronologie attributions;
    if (contexteDemandeDejaCalcule == null)
    {
      Chronologie attributions = trouverAttributionsEnContextePmvsDansPra(demandeCourante, periodePra, dateExamen);
      if ((attributions != null) && (!attributions.estVide()))
      {
        ContexteDemande contexteDemande = new ContexteDemande();
        contexteDemande.setTypeContexteDemande("SUITEPMVS");
        contexteDemande.setChronologiesAttributionPmvsEnCoursDansPra(attributions);
        demandeCourante.ajouterContexteDemande(contexteDemande);
      }
    }
    else
    {
      attributions = contexteDemandeDejaCalcule.getChronologiesAttributionPmvsEnCoursDansPra();
    }
    return attributions;
  }
  
  public void detectionContexteAreEnEntreeCSPouPAP(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    if (recupererOutilAsp().estAreEnEntreeCSPouPAP(demandeCourante)) {
      ajouterContexteDemande(demandeCourante, "AREENTRCSP");
    }
  }
  
  public void ajoutContexteAspAreOuDc(Demande demande)
  {
    boolean contexteAspAreOuDcAbsent = verifierAbsenceContexteProduitCspPAP(demande);
    if (contexteAspAreOuDcAbsent)
    {
      FiltreCaliSpec filtreAttributionAssurance = new FiltreAttributionStandardAssurance(false, true, false, false, null);
      fr.unedic.cali.asu.dom.AttributionAssuranceSpec attributionAssurancePrecedente = (fr.unedic.cali.asu.dom.AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreAttributionAssurance);
      
      ContexteDemandeSpec contexte = OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent((Demande)attributionAssurancePrecedente.getDemande(), 7);
      
      ajouterContexteDemande(demande, contexte.getTypeContexteDemande());
    }
  }
  
  private boolean verifierAbsenceContexteProduitCspPAP(Demande demande)
  {
    return !OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 7);
  }
  
  public void detectionContexteAreEnCoursCSPouPAP(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    if (recupererOutilAsp().estAreEnCoursCSPouPAP(demandeCourante))
    {
      ajouterContexteDemande(demandeCourante, "ARECOURCSP");
      Demande demandeEnEntreCSPPrecedente = recupererEntreeEnCspPap(demandeCourante);
      ajoutContexteAspAreOuDcOuPapPourEnCoursCspOuPap(demandeCourante, demandeEnEntreCSPPrecedente);
      detecterContextePapParlementaireSurDemandeEnEntreeCspPap(demandeCourante, demandeEnEntreCSPPrecedente);
      
      detectionContexteRetourEnCspSuitePrime(demandeCourante);
    }
  }
  
  protected Demande recupererEntreeEnCspPap(Demande demandeCourante)
  {
    return (Demande)OutilRecherche.rechercherDemandePrecedente(demandeCourante.getChronologieDemandesAssuranceSansCourante(), demandeCourante, new FiltreDemandePourTypeContexteDemande("AREENTRCSP"));
  }
  
  protected void detecterContextePapParlementaireSurDemandeEnEntreeCspPap(Demande demandeCourante, Demande demandeEntreeCspPap)
  {
    if ((demandeEntreeCspPap != null) && (demandeEntreeCspPap.estEnContexteDemande("PAPPARLEM")))
    {
      ContexteDemande contexteDemande = new ContexteDemande();
      contexteDemande.setTypeContexteDemande("PAPPARLEM");
      demandeCourante.ajouterContexteDemande(contexteDemande);
    }
  }
  
  public void ajoutContexteAspAreOuDcOuPapPourEnCoursCspOuPap(Demande demande, Demande demandeEnEntreCSPPrecedente)
  {
    OutilGestionContexteDemande.supprimerContexteDemande(demande, "ASPARE");
    OutilGestionContexteDemande.supprimerContexteDemande(demande, "ASPDC");
    OutilGestionContexteDemande.supprimerContexteDemande(demande, "PAPARE");
    OutilGestionContexteDemande.supprimerContexteDemande(demande, "PAPDC");
    if (demandeEnEntreCSPPrecedente != null)
    {
      ContexteDemandeSpec contexte = OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent(demandeEnEntreCSPPrecedente, 7);
      
      ajouterContexteDemande(demande, contexte.getTypeContexteDemande());
    }
  }
  
  public void ajouterContexteDemande(DemandeAssuranceSpec demande, String contexteRelatifAuProduit)
  {
    ContexteDemande contexte = new ContexteDemande();
    contexte.setTypeContexteDemande(contexteRelatifAuProduit);
    demande.ajouterContexteDemande(contexte);
  }
  
  public void detectionContexteSortieDispositifASPouPAPARE(Demande demandeCourante)
  {
    if (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "ARECOURCSP")) {
      if (recupererOutilAsp().estContexteSortieDispositifASPouPAPARE(demandeCourante, "ASPARE"))
      {
        ContexteDemande contexteDemande = new ContexteDemande();
        contexteDemande.setTypeContexteDemande("POSTCSPARE");
        demandeCourante.ajouterContexteDemande(contexteDemande);
      }
      else if (recupererOutilAsp().estContexteSortieDispositifASPouPAPARE(demandeCourante, "PAPARE"))
      {
        ContexteDemande contexteDemande = new ContexteDemande();
        contexteDemande.setTypeContexteDemande("POSTPAPARE");
        demandeCourante.ajouterContexteDemande(contexteDemande);
      }
    }
  }
  
  public void detectionContexteSortieDispositifASPouPAPDC(Demande demandeCourante)
  {
    if (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "ARECOURCSP")) {
      if (recupererOutilAsp().estContexteSortieDispositifASPouPAPDC(demandeCourante, "ASPDC"))
      {
        ContexteDemande contexteDemande = new ContexteDemande();
        contexteDemande.setTypeContexteDemande("POSTCSPDC");
        demandeCourante.ajouterContexteDemande(contexteDemande);
      }
      else if (recupererOutilAsp().estContexteSortieDispositifASPouPAPDC(demandeCourante, "PAPDC"))
      {
        ContexteDemande contexteDemande = new ContexteDemande();
        contexteDemande.setTypeContexteDemande("POSTPAPDC");
        demandeCourante.ajouterContexteDemande(contexteDemande);
      }
    }
  }
  
  public void detectionContextePremiereSortieCsp(Demande demandeCourante)
  {
    boolean estEnSortieDeDispositif = OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demandeCourante, new String[] { "POSTCSPDC", "POSTCSPARE", "POSTPAPDC", "POSTPAPARE" });
    if ((estEnSortieDeDispositif) && (estContextePremiereDdeSortieCsp(demandeCourante)))
    {
      ContexteDemande contexteDemande = new ContexteDemande();
      contexteDemande.setTypeContexteDemande("PREPOSTCSP");
      demandeCourante.ajouterContexteDemande(contexteDemande);
    }
  }
  
  private boolean estContextePremiereDdeSortieCsp(Demande demande)
  {
    DecisionSpec decisionPrecedente = recupererDecisionPrecedente(demande);
    boolean estContextePremiereDdeSortieCsp = false;
    Demande demandePrecedente = (Demande)decisionPrecedente.getDemande();
    String typeExamenDemandePrecedente = demandePrecedente.getEvenementReferenceExamen().getTypeExamen();
    boolean estDemandePrecedenteFinAsp = "ASU_25".equals(typeExamenDemandePrecedente);
    if (!estDemandePrecedenteFinAsp) {
      if ("ASU_28".equals(typeExamenDemandePrecedente))
      {
        estContextePremiereDdeSortieCsp = estContextePremiereDdeSortieCsp(demandePrecedente);
      }
      else if (NaturesDecisions.estdeTypeAttribution(decisionPrecedente.getNatureDecision()))
      {
        boolean estDecisionPrecedenteSortieCspOuPap = estDecisionPrecedenteSortieCspOuPap(demandePrecedente);
        if (!estDecisionPrecedenteSortieCspOuPap)
        {
          AttributionSpec attributionPrecedente = (AttributionSpec)decisionPrecedente;
          ProduitSpec produitExecution = attributionPrecedente.getProduitExecution();
          boolean estProduitCsp = (produitExecution.getCode() == 67) || (produitExecution.getCode() == 66) || (produitExecution.getCode() == 51) || (produitExecution.getCode() == 50);
          
          boolean estDecisionPrecedenteAntecedentConversion = estDecisionPrecedenteAntecedentConversion(attributionPrecedente);
          estContextePremiereDdeSortieCsp = (estProduitCsp) || (estDecisionPrecedenteAntecedentConversion);
        }
      }
      else
      {
        estContextePremiereDdeSortieCsp = estContextePremiereDdeSortieCsp(demandePrecedente);
      }
    }
    return estContextePremiereDdeSortieCsp;
  }
  
  private boolean estDecisionPrecedenteAntecedentConversion(AttributionSpec attributionPrecedente)
  {
    return ((attributionPrecedente instanceof Antecedent)) && (((Antecedent)attributionPrecedente).getSaisieAntecedent().getContexteDemande().intValue() == 9);
  }
  
  private boolean estDecisionPrecedenteSortieCspOuPap(Demande demandePrecedente)
  {
    boolean estDecisionPrecedenteSortieCsp = (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandePrecedente, "POSTCSPDC")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandePrecedente, "POSTCSPARE"));
    
    boolean estDecisionPrecedenteSortiePap = (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandePrecedente, "POSTPAPDC")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandePrecedente, "POSTPAPARE"));
    
    return (estDecisionPrecedenteSortieCsp) || (estDecisionPrecedenteSortiePap);
  }
  
  private DecisionSpec recupererDecisionPrecedente(Demande demandeCourante)
  {
    return OutilRecherche.rechercherDecisionPrecedente(demandeCourante.getChronologieDemandesAssuranceSansCourante(), demandeCourante, new FiltreDecisionARESurDecision());
  }
  
  public void detectionContexteSortieClauseRattrapageSpectacle(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    Damj dateExamen = demandeCourante.getDateExamen();
    if (dateExamen != null)
    {
      Damj dateRechercheContexte = demandeCourante.getDateFaitGenerateurOuDernierSinistre();
      if (dateRechercheContexte == null) {
        dateRechercheContexte = dateExamen;
      }
      fr.unedic.cali.asu.dom.AttributionAssuranceSpec attributionPrecedente = demandeCourante.rechercherAttributionPrecedenteDuMemeType();
      if ((attributionPrecedente != null) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attributionPrecedente.getDemande(), 8)))
      {
        Damj dateLimite = attributionPrecedente.getDateLimiteIndemnisation();
        if ((dateLimite != null) && (dateRechercheContexte.estAvantOuCoincideAvec(dateLimite)))
        {
          ContexteDemande contexteDemande = new ContexteDemande();
          contexteDemande.setTypeContexteDemande("SORTIECRA");
          demandeCourante.ajouterContexteDemande(contexteDemande);
        }
      }
    }
  }
  
  public void detectionContexteRetourEnCspSuitePrime(Demande demandeCourante)
  {
    boolean estReliquatValide = false;
    if ((demandeCourante.getReliquat() != null) && (demandeCourante.getReliquat().isReliquatValide())) {
      estReliquatValide = true;
    }
    boolean estDemandeEnCoursCsp = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "ARECOURCSP");
    
    boolean estEnContexteAspDc = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "ASPDC");
    if ((estDemandeEnCoursCsp) && (estEnContexteAspDc) && (estReliquatValide))
    {
      FiltreOU filtre = new FiltreOU();
      filtre.ajouterFiltre(new FiltreAttributionAssurance(false, false, false, false, null));
      
      FiltreET filtreAttributionInr = new FiltreET();
      filtreAttributionInr.ajouterFiltre(new FiltreAttributionSurDecisions());
      filtreAttributionInr.ajouterFiltre(new FiltreDemandePourNumeroGamme(6));
      filtre.ajouterFiltre(filtreAttributionInr);
      
      DecisionSpec attributionPrecedente = OutilRecherche.rechercherDecisionPrecedente(demandeCourante.getChronologieDemandesSansCourante(), demandeCourante, filtre);
      
      boolean estDemandePrime = "INR_04".equals(attributionPrecedente.getDemande().getEvenementReferenceExamen().getTypeExamen());
      if (estDemandePrime)
      {
        ContexteDemande contexteDemande = new ContexteDemande();
        contexteDemande.setTypeContexteDemande("ASPPOSTPRI");
        demandeCourante.ajouterContexteDemande(contexteDemande);
      }
    }
  }
  
  public boolean detectionContexteRechargement(Demande demandeCourante, Demande demandePortantDv)
    throws CoucheLogiqueException
  {
    boolean retour = false;
    if (demandePortantDv.estEnContexteDemande("RECHARGE"))
    {
      ContexteDemande contexteDemande = new ContexteDemande();
      contexteDemande.setTypeContexteDemande("RECHARGE");
      demandeCourante.ajouterContexteDemande(contexteDemande);
      retour = true;
    }
    return retour;
  }
  
  public void detectionContextePremiereSortieCspExamenDv(Demande demandeCourante, Demande demandePortantDv)
  {
    boolean estContextePremiereDdeSortieCsp = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandePortantDv, "PREPOSTCSP");
    if (estContextePremiereDdeSortieCsp)
    {
      ContexteDemande contexteDemande = new ContexteDemande();
      contexteDemande.setTypeContexteDemande("PREPOSTCSP");
      demandeCourante.ajouterContexteDemande(contexteDemande);
    }
  }
  
  public void detectionContexteDisponibiliteExamenDv(Demande demandeIpr, DemandeAssuranceSpec demandePortantDv)
  {
    if (demandePortantDv.estEnContexteDemande("COURSDISPO"))
    {
      ContexteDemande contexteDemande = new ContexteDemande();
      contexteDemande.setTypeContexteDemande("COURSDISPO");
      demandeIpr.ajouterContexteDemande(contexteDemande);
    }
    if (demandePortantDv.estEnContexteDemande("POSTDISPO"))
    {
      ContexteDemande contexteDemande = new ContexteDemande();
      contexteDemande.setTypeContexteDemande("POSTDISPO");
      demandeIpr.ajouterContexteDemande(contexteDemande);
    }
  }
  
  public void detectionContexteEnCoursDeDisponibilite(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    Damj dateExamen = demandeCourante.getDateExamen();
    if ((dateExamen != null) && (estApresOuConincideAvecDateApplicationPeriodesSuspensives(dateExamen)))
    {
      IndividuSpec individu = demandeCourante.getDemandeur();
      ChronologiePeriodes chronoPassePro = individu.getChronoPeriodePasseProfessionnelLiquidation();
      IncidentSpec periodeSuspensiveEnCours = recupererPeriodeSuspensiveEnCours(dateExamen, chronoPassePro);
      if (periodeSuspensiveEnCours != null)
      {
        ContexteDemande contexteDemande = new ContexteDemande();
        contexteDemande.setTypeContexteDemande("COURSDISPO");
        contexteDemande.setPeriodeSuspensiveEnCours(periodeSuspensiveEnCours);
        demandeCourante.ajouterContexteDemande(contexteDemande);
      }
    }
  }
  
  public IncidentSpec recupererPeriodeSuspensiveEnCours(Damj dateExamen, ChronologiePeriodes chronoPassePro)
  {
    IncidentSpec periodeSuspensiveEnCours = null;
    
    FiltreActiviteSalarieSurObjetChronoPeriode filtreActiviteSalarie = new FiltreActiviteSalarieSurObjetChronoPeriode();
    Chronologie chronoActiviteSalarie = chronoPassePro.copier(filtreActiviteSalarie);
    Iterator<?> itActiviteSalarie = chronoActiviteSalarie.iterer();
    while (itActiviteSalarie.hasNext())
    {
      ActiviteSalarie activiteSalarie = (ActiviteSalarie)itActiviteSalarie.next();
      Chronologie chronoPeriodesSuspensives = activiteSalarie.getListePeriodesIncident();
      Iterator<?> itPeriodesSuspensives = chronoPeriodesSuspensives.iterer();
      while ((dateExamen.estContenueDans(activiteSalarie.getPeriode())) && (itPeriodesSuspensives.hasNext()))
      {
        IncidentSpec periodeSuspensive = (IncidentSpec)itPeriodesSuspensives.next();
        int natureDePeriodeSuspensive = periodeSuspensive.getNature();
        if ((recupererListeNaturesPeriodeDeDisponibiliteEligibles().contains(Integer.valueOf(natureDePeriodeSuspensive))) && (dateExamen.estContenueDans(periodeSuspensive.getPeriode())))
        {
          periodeSuspensiveEnCours = periodeSuspensive;
          break;
        }
      }
      if (periodeSuspensiveEnCours != null) {
        break;
      }
    }
    return periodeSuspensiveEnCours;
  }
  
  public void detectionContexteEnSortieDeDisponibilite(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    Damj dateExamen = demandeCourante.getDateExamen();
    if ((dateExamen != null) && (estApresOuConincideAvecDateApplicationPeriodesSuspensives(dateExamen)) && (!demandeCourante.estEnContexteDemande("COURSDISPO")))
    {
      fr.unedic.cali.asu.dom.AttributionAssuranceSpec attributionPrecedente = demandeCourante.rechercherAttributionPrecedenteDuMemeType();
      if ((attributionPrecedente != null) && (attributionPrecedente.getDemande().estEnContexteDemande("COURSDISPO")))
      {
        ContexteDemande contexteDemande = new ContexteDemande();
        contexteDemande.setTypeContexteDemande("POSTDISPO");
        demandeCourante.ajouterContexteDemande(contexteDemande);
      }
    }
  }
  
  protected boolean estApresOuConincideAvecDateApplicationPeriodesSuspensives(Damj dateExamen)
    throws CoucheLogiqueException
  {
    Damj dateApplication = GestionnaireDateApplication.getInstance().recupererDateApplication("Périodes suspensives en cours");
    return dateExamen.estApresOuCoincideAvec(dateApplication);
  }
  
  protected DemandeSpec rechercherDemandePrecedente(Demande demandeCourante, FiltreCaliSpec filtre, Chronologie chronologieDeamndeSansCourante)
  {
    return OutilRecherche.rechercherDemandePrecedente(chronologieDeamndeSansCourante, demandeCourante, filtre);
  }
  
  protected List<Integer> recupererListeNaturesPeriodeDeDisponibiliteEligibles()
  {
    List<Integer> listePeriodesDispoEligibles = new ArrayList();
    listePeriodesDispoEligibles.add(Integer.valueOf(55));
    listePeriodesDispoEligibles.add(Integer.valueOf(11));
    listePeriodesDispoEligibles.add(Integer.valueOf(56));
    listePeriodesDispoEligibles.add(Integer.valueOf(57));
    listePeriodesDispoEligibles.add(Integer.valueOf(58));
    listePeriodesDispoEligibles.add(Integer.valueOf(59));
    
    return listePeriodesDispoEligibles;
  }
  
  public void detectionContexteAps(Demande demandeCourante)
  {
    fr.unedic.cali.dom.AttributionAssuranceSpec attributionPrecedente = recupererAttributionPrecedente(demandeCourante);
    if ((attributionPrecedente != null) && (attributionPrecedente.getDemande().estEnContexteDemande(8)))
    {
      ContexteDemande contexteDemande = new ContexteDemande();
      contexteDemande.setTypeContexteDemande("APSPOSTCRA");
      demandeCourante.ajouterContexteDemande(contexteDemande);
    }
    else
    {
      ContexteDemande contexteDemande = new ContexteDemande();
      contexteDemande.setTypeContexteDemande("APSDC");
      demandeCourante.ajouterContexteDemande(contexteDemande);
    }
  }
  
  protected fr.unedic.cali.dom.AttributionAssuranceSpec recupererAttributionPrecedente(Demande demande)
  {
    Damj dateRecherche = demande.getDateDepot();
    if (dateRecherche == null) {
      dateRecherche = demande.getFormulaire().getDateCreationDal();
    }
    return OutilAttribution.getInstance().recupererAttributionAssurancePrecedente(dateRecherche, demande.getChronologieDemandesAssuranceSansCourante(), null);
  }
  
  protected OutilAsp recupererOutilAsp()
  {
    return OutilAsp.getInstance();
  }
}

/* Location:
 * Qualified Name:     DetectionContexteParticulierLiquidation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */