package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.ConditionChomageInvolontaireSpec;
import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.fabriques.FabriquePositionnementCriteresQualification;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.spec.StrategiePositionnementCriteresQualificationSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeFormationAssimilable;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.ComparateurSurDateDeclenchementDemandeDecroissante;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDemandesRevision;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreFormation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeCes;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeDsmTravail;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeIndemnisationIjss;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesDeclareesMaladie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreRevisionAre14DV;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionAssurance;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.ListIterator;
import org.apache.commons.lang.StringUtils;

public final class GestionDemandeDv122eJour
{
  private static final int TAILLE_REFERENCE_EXTERNE_DEMANDE = 7;
  public static final int DELAI_121_JOURS = 121;
  public static final int DUREE_21_JOURS = 21;
  
  private static DossierExamenAssuranceSpec rechercherDernierRejetDV(DemandeAssuranceSpec demandeAsuCourante)
    throws CoucheLogiqueException
  {
    DossierExamenAssuranceSpec rejetDV = null;
    
    Demande demandeRejetDV = retrouverDemandePortantDv(demandeAsuCourante);
    if (demandeRejetDV != null)
    {
      rejetDV = (DossierExamenAssuranceSpec)demandeRejetDV.getDossierAffectation().getDossierExamen();
      if (!rejetDV.estRejetDV()) {
        rejetDV = (DossierExamenAssuranceSpec)demandeRejetDV.getDossierAffectationAdmission().getDossierExamen();
      }
    }
    else
    {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ERR_RECHERCHER_REJET_DV_POUR_DEMANDE_DV122");
    }
    return rejetDV;
  }
  
  public static Demande retrouverDemandePortantDv(DemandeSpec demandeCourante)
    throws CoucheLogiqueException
  {
    if ("ASU_04".equals(demandeCourante.getEvenementReferenceExamen().getTypeExamen()))
    {
      Demande demandePortantDvARetourner = retrouverDemandePortantDvAvecLienFormulaire(demandeCourante);
      if (demandePortantDvARetourner != null)
      {
        controlerPresenceExamenDVUnique(demandeCourante, demandePortantDvARetourner);
        return demandePortantDvARetourner;
      }
      return retrouverDemandePortantDvAncienneMethode(demandeCourante);
    }
    return null;
  }
  
  public static Demande retrouverPremiereDemandePortantDv(DemandeSpec demandeCourante)
    throws CoucheLogiqueException
  {
    if ("ASU_04".equals(demandeCourante.getEvenementReferenceExamen().getTypeExamen()))
    {
      Demande demandePortantDvARetourner = retrouverDemandePortantDvAvecLienFormulaire(demandeCourante);
      if (demandePortantDvARetourner != null) {
        return demandePortantDvARetourner;
      }
      return retrouverDemandePortantDvAncienneMethode(demandeCourante);
    }
    return null;
  }
  
  private static Demande retrouverDemandePortantDvAvecLienFormulaire(DemandeSpec demandeCourante)
    throws CoucheLogiqueException
  {
    Chronologie demandesAssurancePortantDv = demandeCourante.getDemandeur().getChronoDemandeAssurance();
    
    fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation filtreDemandeAsuSansRevision = new fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation(new FiltreDemandesRevision());
    demandesAssurancePortantDv = demandesAssurancePortantDv.copier(filtreDemandeAsuSansRevision);
    
    demandesAssurancePortantDv.setComparateur(new ComparateurSurDateDeclenchementDemandeDecroissante());
    Iterator<?> itDemandesAssurancePortantDv = demandesAssurancePortantDv.iterer();
    
    Demande demandePortantDvARetourner = null;
    int referenceRejetDV = ((FormulaireAsu)demandeCourante.getFormulaire()).getReferenceExterneDemandeLiee();
    while (itDemandesAssurancePortantDv.hasNext())
    {
      Demande demandePortantDvCourante = (Demande)itDemandesAssurancePortantDv.next();
      int referenceExterne = Integer.parseInt(((FormulaireAsu)demandePortantDvCourante.getFormulaire()).getReferenceExterne());
      if (referenceExterne == referenceRejetDV)
      {
        DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)demandePortantDvCourante.getDossierExamen();
        if ((dossierExamen != null) && (dossierExamen.estRejetDV())) {
          demandePortantDvARetourner = demandePortantDvCourante;
        }
      }
    }
    if ((demandePortantDvARetourner == null) && (referenceRejetDV != 0) && (!demandeCourante.estMigree())) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CONTEXTE_REJET_DV_LIE_EXAMEN_CP", new Object[] { formaterReferenceExterneRejetDv(referenceRejetDV), demandeCourante.getDateDeclenchementExamen() });
    }
    return demandePortantDvARetourner;
  }
  
  private static void controlerPresenceExamenDVUnique(DemandeSpec demandeCourante, DemandeSpec demandePortantDvCourante)
    throws CoucheLogiqueException
  {
    Chronologie demandesAssurancePortantDv = demandeCourante.getDemandeur().getChronoDemandeAssurance();
    
    fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation filtreDemandeAsuSansRevision = new fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation(new FiltreDemandesRevision());
    demandesAssurancePortantDv = demandesAssurancePortantDv.copier(filtreDemandeAsuSansRevision);
    
    demandesAssurancePortantDv.setComparateur(new ComparateurSurDateDeclenchementDemandeDecroissante());
    
    Iterator<?> itDemandesAssurancePortantDv = demandesAssurancePortantDv.iterer();
    while (itDemandesAssurancePortantDv.hasNext())
    {
      Demande demandePortantDvTemp = (Demande)itDemandesAssurancePortantDv.next();
      if (presenceMultiExamenDV(demandePortantDvTemp, demandeCourante)) {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CONTEXTE_PRESENCE_EXAMEN_DV_MULTIPLE", new Object[] { demandePortantDvTemp.getDateDeclenchementExamen(), demandePortantDvCourante.getDateDeclenchementExamen() });
      }
    }
  }
  
  private static boolean presenceMultiExamenDV(Demande demandePortantDvTemp, DemandeSpec demandeCourante)
  {
    int referenceRejetDV = ((FormulaireAsu)demandeCourante.getFormulaire()).getReferenceExterneDemandeLiee();
    int referenceExterne = ((FormulaireAsu)demandePortantDvTemp.getFormulaire()).getReferenceExterneDemandeLiee();
    boolean demandeDVOK = (demandePortantDvTemp.getEvenementReferenceExamen().getTypeExamen().equalsIgnoreCase("ASU_04")) && (demandePortantDvTemp.estDecisionnee()) && (!demandePortantDvTemp.estEnReExamen());
    
    return (demandeDVOK) && (!demandeCourante.getIdentifiant().equalsIgnoreCase(demandePortantDvTemp.getIdentifiant())) && (referenceExterne == referenceRejetDV);
  }
  
  private static String formaterReferenceExterneRejetDv(int refExterneInt)
  {
    String refExterne = Integer.toString(refExterneInt);
    refExterne = StringUtils.leftPad(refExterne, 7, "0");
    return refExterne;
  }
  
  private static Demande retrouverDemandePortantDvAncienneMethode(DemandeSpec demandeCourante)
  {
    Chronologie demandesAssurancePortantDv = demandeCourante.getDemandeur().getChronoDemandeAssurance();
    
    fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation filtreDemandeAsuSansRevision = new fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation(new FiltreDemandesRevision());
    demandesAssurancePortantDv = demandesAssurancePortantDv.copier(filtreDemandeAsuSansRevision);
    
    demandesAssurancePortantDv.setComparateur(new ComparateurSurDateDeclenchementDemandeDecroissante());
    Iterator<?> itDemandesAssurancePortantDv = demandesAssurancePortantDv.iterer();
    while (itDemandesAssurancePortantDv.hasNext())
    {
      Demande demandePortantDvCourante = (Demande)itDemandesAssurancePortantDv.next();
      if (!demandePortantDvCourante.equals(demandeCourante))
      {
        DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)demandePortantDvCourante.getDossierExamen();
        if ((dossierExamen != null) && (dossierExamen.estRejetDV())) {
          return demandePortantDvCourante;
        }
      }
    }
    return null;
  }
  
  public static void affecterProduit(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    DossierExamenAssuranceSpec dossierExamenRejetDv = rechercherDernierRejetDV(demande);
    
    DossierAffecte dossierAffecteRejetDV = (DossierAffecte)((Demande)dossierExamenRejetDv.getDossierAffecte().getDemande()).getDossierAffectationAdmission();
    
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteEnCoursPmvsReconduit(demande, (DecisionAssuranceSpec)dossierExamenRejetDv, demande.getDateExamen());
    
    DossierAffecte dossierAffecte = (DossierAffecte)demande.getDossierAffectation();
    
    ValidationProduit validationProduitRejetDV = dossierAffecteRejetDV.getValidationProduit();
    if ((validationProduitRejetDV != null) && (validationProduitRejetDV.getPeriodeValidationProduit() != null))
    {
      ActiviteSalarie periodeValidationProduitRejetDv = validationProduitRejetDV.getPeriodeValidationProduit();
      if ((periodeValidationProduitRejetDv.getCollectionOrigineInformationPAS().contains(Integer.valueOf(10))) && (!demande.getDonneesTemporaires().isEstCoordCee())) {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ERR_DV_COORD_CE_NON_COCHE", new Object[] { dossierExamenRejetDv.getDemande().getDateExamen(), demande.getDateExamen() });
      }
      dossierAffecte.setValidationProduit((ValidationProduit)validationProduitRejetDV.copie());
    }
    if (dossierAffecteRejetDV.getDelaiRecherche() != null) {
      dossierAffecte.setDelaiRecherche((DelaiRechercheProduit)dossierAffecteRejetDV.getDelaiRecherche().copie());
    }
    dossierAffecte.setDecorReglementaire(dossierAffecteRejetDV.getDecorReglementaire());
    dossierAffecte.setProduitSecours(dossierAffecteRejetDV.getProduitSecours());
    dossierAffecte.setIdentifiantSinistre(dossierAffecteRejetDV.getIdentifiantSinistre());
    dossierAffecte.setJustificationAffectation(dossierAffecteRejetDV.getJustificationAffectation());
    dossierAffecte.setTypeDossier(dossierAffecteRejetDV.getTypeDossier());
    dossierAffecte.setProduitForce(dossierAffecteRejetDV.getProduitForce());
    
    ConteneurAccesDecorReglementaire conteneurDecorReglementaire = new ConteneurAccesDecorReglementaire();
    conteneurDecorReglementaire.setDemande(demande);
    conteneurDecorReglementaire.setDernierSinistre(dossierAffecte.getSinistre());
    
    conteneurDecorReglementaire.setBesoinCritereQualif(true);
    
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demande.getDateExamen());
    StrategiePositionnementCriteresQualificationSpec strategieCriteresQualif = (StrategiePositionnementCriteresQualificationSpec)FabriquePositionnementCriteresQualification.getInstance().getStrategie(critere);
    
    strategieCriteresQualif.positionnerCriteresQualifications(conteneurDecorReglementaire, dossierAffecte.getDecorReglementaire());
  }
  
  public static FaitGenerateurSpec rechercherConditionFaitGenerateur(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    DemandeAssuranceSpec demandeDernierRejetDv = (DemandeAssuranceSpec)rechercherDernierRejetDV(demande).getDemande();
    DossierExamenAssuranceSpec dossierExamenAssurance = (DossierExamenAssuranceSpec)demandeDernierRejetDv.getDossierAffectationAdmission().getDossierExamen();
    return dossierExamenAssurance.getFaitGenerateur();
  }
  
  public static Damj constituerDateExamen(DemandeSpec demande)
  {
    Damj dateExamen = null;
    try
    {
      Demande demandePortantDv = retrouverDemandePortantDv(demande);
      if (demandePortantDv != null)
      {
        if (demandePortantDv.estEnReExamen()) {
          GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DEMANDE_DV_EN_REEXAMEN");
        }
        Damj datePointDeDepart = calculerPointDepart(demandePortantDv, demande);
        if (datePointDeDepart == null) {
          return null;
        }
        Periode periodeDelai = new Periode(datePointDeDepart, datePointDeDepart.deplacerVersAvant(new DureeCalendaire(0, 0, 121)));
        
        int allongementDelai = determinerAllongementDelai(demande, periodeDelai);
        
        Damj dateFinDelai = periodeDelai.getFin().deplacerVersAvant(new DureeCalendaire(0, 0, allongementDelai));
        Periode periodeDelaiConsolide = new Periode(periodeDelai.getDebut(), dateFinDelai);
        verifierPresencePasDansDelaiExamen(demande, periodeDelaiConsolide);
        dateFinDelai = affecterDateFinDelaisPourCesEtFormation(demande, demandePortantDv, periodeDelaiConsolide);
        
        dateExamen = dateFinDelai;
        if (OutillagePEC.getPeriodePecDemandeurEmploiContenant(demande.getDemandeur(), dateFinDelai) == null)
        {
          Damj premierJourPecDemandeur = OutillagePEC.getPremierJourPECDemandeur(demande.getDemandeur(), dateFinDelai);
          if (premierJourPecDemandeur != null) {
            dateExamen = premierJourPecDemandeur;
          }
        }
        if (demandePortantDv.getDateExamen() == null) {
          dateExamen = null;
        } else if (dateExamen.estAvant(demandePortantDv.getDateExamen())) {
          dateExamen = demandePortantDv.getDateExamen();
        }
      }
    }
    catch (CoucheLogiqueException ex)
    {
      dateExamen = null;
    }
    return dateExamen;
  }
  
  private static int determinerAllongementDelai(DemandeSpec demande, Periode periodeDelai)
  {
    int allongementDelai = 0;
    
    Periode periodeRecherche = new Periode(periodeDelai.getDebut(), periodeDelai.getFin());
    boolean modificationDelai;
    do
    {
      modificationDelai = false;
      
      ChronologiePeriodes chronoMaladie = retrouverPeriodesMaladieSurPeriodesRecherche(demande, periodeRecherche);
      if (!chronoMaladie.estVide())
      {
        chronoMaladie = OutillageChronologiePeriodes.fusionnerPeriodesAccolees(chronoMaladie);
        
        Iterator<?> itChronoMaladie = chronoMaladie.iterer();
        while ((itChronoMaladie.hasNext()) && (!modificationDelai))
        {
          ObjetChronoPeriode periodeMaladie = (ObjetChronoPeriode)itChronoMaladie.next();
          if (periodeMaladie.getDateDebut().estAvant(periodeRecherche.getDebut())) {
            periodeMaladie.setDateDebut(periodeRecherche.getDebut());
          }
          if (periodeMaladie.getDuree() > 21)
          {
            modificationDelai = true;
            allongementDelai += periodeMaladie.getDuree();
            periodeRecherche.setFin(periodeRecherche.getFin().deplacerVersAvant(new DureeCalendaire(0, 0, periodeMaladie.getDuree())));
            
            periodeRecherche.setDebut(periodeMaladie.getDateFin().lendemain());
          }
        }
      }
      else
      {
        modificationDelai = false;
      }
    } while (modificationDelai);
    return allongementDelai;
  }
  
  public static Damj recupererPeriodePointDepart(Demande demandePortantDv, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    DossierAffectation dossierAffectationAdmission = demandePortantDv.getDossierAffectationAdmission();
    
    TravailSpec periodePointDepart = dossierAffectationAdmission.getSinistre();
    
    boolean estObjectifRepriseSurRejetDv = NaturesDecisions.estdeTypeReprise(demandePortantDv.getObjectifDecisionne().getSousType());
    boolean estObjectifNovationSurRejetDv = NaturesDecisions.estdeTypeNovation(demandePortantDv.getObjectifDecisionne().getSousType());
    boolean estObjectifPoursuiteSurRejetDv = NaturesDecisions.estdeTypePoursuite(demandePortantDv.getObjectifDecisionne().getSousType());
    if ((estObjectifRepriseSurRejetDv) || (estObjectifNovationSurRejetDv) || (estObjectifPoursuiteSurRejetDv))
    {
      String identifiantPeriode = ((DossierExamenAssuranceSpec)demandePortantDv.getDossierAffectationReprise().getDossierExamen()).getConditionChomageInvolontaire().getIdentifiantActivitePortantDV();
      
      TravailSpec travailDv = null;
      if (identifiantPeriode != null) {
        travailDv = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(identifiantPeriode);
      }
      if ((periodePointDepart == null) || ((travailDv != null) && (travailDv.getDateFin().estApres(periodePointDepart.getDateFin())))) {
        periodePointDepart = travailDv;
      }
    }
    else
    {
      periodePointDepart = ((DossierExamenAssuranceSpec)dossierAffectationAdmission.getDossierExamen()).getFaitGenerateur().getPeriodeFaitGenerateur();
    }
    Damj dateDebutDispo = gererCasPeriodeSuspensive(demandePortantDv);
    Damj dateRetour;
    if (periodePointDepart != null)
    {
      Damj dateRetour = periodePointDepart.getDateFin().lendemain();
      if ((dateRetour != null) && (dateDebutDispo != null)) {
        dateRetour = Damj.max(dateRetour, dateDebutDispo);
      }
    }
    else
    {
      dateRetour = dateDebutDispo;
    }
    return dateRetour;
  }
  
  private static Damj gererCasPeriodeSuspensive(DemandeSpec demande)
  {
    Damj dateRetour = null;
    if (demande.estEnContexteDemande(11))
    {
      IncidentSpec incident = DetectionContexteParticulierLiquidation.getInstance().recupererPeriodeSuspensiveEnCours(demande.getDateExamen(), demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
      if (incident != null) {
        dateRetour = incident.getDateDebut();
      }
    }
    return dateRetour;
  }
  
  public static Damj calculerPointDepart(Demande demandePortantDv, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    Damj datePointDeDepart = null;
    if ("ASU_29".equals(demandePortantDv.getEvenementReferenceExamen().getTypeExamen()))
    {
      Damj dateExamen = demandePortantDv.getDateExamen();
      if (dateExamen != null) {
        datePointDeDepart = dateExamen;
      } else {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_L_CALI_DATE_EXAMEN_INTROUVABLE");
      }
    }
    else
    {
      datePointDeDepart = recupererPeriodePointDepart(demandePortantDv, demande);
      if (datePointDeDepart == null) {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_PERIODE_SUPPR_GAEC", new Object[] { demandePortantDv.getDateRecherche().toString() });
      }
      try
      {
        datePointDeDepart = bornerPointDepartAdjiPrecedent((Demande)demande, demandePortantDv, datePointDeDepart);
      }
      catch (ApplicativeException ex)
      {
        datePointDeDepart = null;
      }
    }
    return datePointDeDepart;
  }
  
  private static Damj bornerPointDepartAdjiPrecedent(Demande demande, Demande demandePortantRejetDv, Damj pointDepartActuel)
    throws ApplicativeException
  {
    Damj pointDeDepart = pointDepartActuel;
    if (GestionnaireDateApplication.getInstance().recupererDateApplication("Application du droit d'option élargi.").estAvantOuCoincideAvec(demandePortantRejetDv.getDateExamen()))
    {
      Damj dateRechercheDemandePortantDv = demandePortantRejetDv.getDateRecherche();
      
      FiltreET filtreAttributionAsu = new FiltreET();
      filtreAttributionAsu.ajouterFiltre(new FiltreAttributionAssurance(true, true, false, false, null));
      filtreAttributionAsu.ajouterFiltre(new fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation(new FiltreRevisionAre14DV()));
      AttributionSpec attributionAssurancePrecedente = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), dateRechercheDemandePortantDv, filtreAttributionAsu);
      if (attributionAssurancePrecedente != null)
      {
        ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionAssurancePrecedente, dateRechercheDemandePortantDv.veille(), true, true);
        Damj dateBorneRetenu;
        Damj dateBorneRetenu;
        if (resultatCalcul.getDernierJourIndemnisable() != null) {
          dateBorneRetenu = resultatCalcul.getDernierJourIndemnisable().lendemain();
        } else {
          dateBorneRetenu = attributionAssurancePrecedente.getDateAttribution();
        }
        if (dateBorneRetenu.estApres(pointDeDepart)) {
          pointDeDepart = dateBorneRetenu;
        }
      }
    }
    return pointDeDepart;
  }
  
  private static ChronologiePeriodes retrouverPeriodesMaladieSurPeriodesRecherche(DemandeSpec demande, Periode periodeRecherche)
  {
    FiltrePeriodesSurFiltresExclusifs filtreExclusif = new FiltrePeriodesSurFiltresExclusifs();
    filtreExclusif.ajouterFiltre(new FiltrePeriodeIndemnisationIjss());
    filtreExclusif.ajouterFiltre(new FiltrePeriodesDeclareesMaladie());
    
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(filtreExclusif);
    filtres.ajouterFiltre(new FiltreChevauchePeriode(periodeRecherche));
    
    ChronologiePeriodes chrono = (ChronologiePeriodes)demande.getDemandeur().getChronoPeriodePasseProfessionnelPourLiquidationSansFiltrageDNJ().copier(filtres);
    
    ChronologiePeriodes resultat = new ChronologiePeriodes();
    
    ListIterator it = chrono.iterer();
    while (it.hasNext())
    {
      PeriodeGaecSpec periode = (PeriodeGaecSpec)it.next();
      resultat.ajouter(new ObjetChronoPeriodeConcrete(periode.getDateDebut(), periode.getDateFin()));
    }
    return resultat;
  }
  
  private static void verifierPresencePasDansDelaiExamen(DemandeSpec demande, Periode periodeRecherche)
  {
    Chronologie listePas = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    Demande demandeAssurance = (Demande)demande;
    if ((listePas != null) && (!listePas.estVide()))
    {
      FiltrePeriodesSurFiltresExclusifs filtres2 = new FiltrePeriodesSurFiltresExclusifs();
      filtres2.ajouterFiltre(new FiltrePeriodesLiquidables());
      filtres2.ajouterFiltre(new FiltrePeriodeDsmTravail());
      
      FiltresTemporel filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltreChevauchePeriode(periodeRecherche));
      filtres.ajouterFiltre(filtres2);
      
      Chronologie chronoResultante = listePas.copier(filtres);
      if (!chronoResultante.estVide())
      {
        Iterator<?> itPeriodes = chronoResultante.iterer();
        Collection<ObjetAlertesNonBloquantes> listePeriodesEnAlertes = new ArrayList();
        while (itPeriodes.hasNext())
        {
          PeriodeGaecSpec periodeDansDelai = (PeriodeGaecSpec)itPeriodes.next();
          if (periodeDansDelai.getDateFin().estAvant(periodeRecherche.getFin())) {
            listePeriodesEnAlertes.add(new ObjetAlertesNonBloquantes(periodeDansDelai.getDateDebut(), periodeDansDelai.getDateFin(), 2));
          }
        }
        if (!listePeriodesEnAlertes.isEmpty())
        {
          if (demandeAssurance.getAlertesNonBloquantes() == null) {
            demandeAssurance.setAlertesNonBloquantes(new Hashtable());
          }
          demandeAssurance.getAlertesNonBloquantes().put("A5MNB1", listePeriodesEnAlertes);
        }
      }
    }
  }
  
  private static Damj affecterDateFinDelaisPourCesEtFormation(DemandeSpec demande, DemandeSpec demandePortantDv, Periode periodeRecherche)
  {
    Damj jourFinDelais = periodeRecherche.getFin();
    
    ActiviteSalarie periodeAvecDv = ConstructionChronologie.retrouverFctAvecDvPourDemandeDv(demandePortantDv);
    if (!new FiltrePeriodeCes().accepter(periodeAvecDv))
    {
      Chronologie listePas = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
      if ((listePas != null) && (!listePas.estVide()))
      {
        FiltresTemporel filtres = new FiltresTemporel();
        filtres.ajouterFiltre(new FiltreChevauchePeriode(periodeRecherche));
        filtres.ajouterFiltre(new FiltreFormation());
        Chronologie chronoFormation = listePas.copier(filtres);
        if (!chronoFormation.estVide())
        {
          PeriodeFormationAssimilable periodeFormation = (PeriodeFormationAssimilable)chronoFormation.dernierElement();
          if (periodeFormation.getDateFin().estApres(periodeRecherche.getFin())) {
            jourFinDelais = periodeFormation.getDateFin();
          }
        }
      }
    }
    return jourFinDelais;
  }
}

/* Location:
 * Qualified Name:     GestionDemandeDv122eJour
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */