package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsp;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.affectation.LigneAsuCaa14;
import fr.unedic.cali.dom.affectation.LigneAsuCva10;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.fabriques.FabriqueConvention2014;
import fr.unedic.cali.outilsfonctionnels.ComparateurSurDateDeclenchementDemandeDecroissante;
import fr.unedic.cali.outilsfonctionnels.OutilActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDemandeAsp;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionAsp;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitAssurance;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreAttributionSurDecisions;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourNatureDecision;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourProduit;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourClassement;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourReferenceExterne;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import java.util.Collection;

public class OutilAsp
{
  private static OutilAsp instance;
  private static final String SITUATION_EMPLOI = "CSP";
  private static final String SITUATION_PARTICULIERE_PAP = "PAP";
  
  public static OutilAsp getInstance()
  {
    if (instance == null) {
      instance = new OutilAsp();
    }
    return instance;
  }
  
  public AttributionAssuranceSpec rechercherAttributionAspOrigine(DemandeSpec demande, Damj date)
  {
    AttributionAssuranceSpec derniereAttributionAsp = rechercherAttributionAspPrecedent(demande, date);
    if (derniereAttributionAsp != null) {
      return (AttributionAssuranceSpec)derniereAttributionAsp.getOuvertureDroit();
    }
    return null;
  }
  
  public AttributionAssuranceSpec rechercherAttributionAspPrecedent(DemandeSpec demande, Damj date)
  {
    FiltreET filtreEt = new FiltreET();
    filtreEt.ajouterFiltre(new FiltreAttributionStandardAssurance(false, true, false, false, null));
    FiltreOU filtreOu = new FiltreOU();
    filtreOu.ajouterFiltre(new FiltreDecisionPourProduit(50));
    filtreOu.ajouterFiltre(new FiltreDecisionPourProduit(51));
    filtreEt.ajouterFiltre(filtreOu);
    
    return (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), date.lendemain(), filtreEt);
  }
  
  public Demande getDemandeAspPrecedente(DemandeSpec demande, Damj dateRecherche)
  {
    FiltresTemporel listeFiltres = new FiltresTemporel();
    listeFiltres.ajouterFiltre(new FiltreDemandeAsp());
    
    DemandeSpec demandeRetour = null;
    Chronologie chronologieDemandes = demande.getDemandeur().getChronoDemandes().copier(listeFiltres);
    chronologieDemandes.setComparateur(new ComparateurSurDateDeclenchementDemandeDecroissante());
    chronologieDemandes.iterer();
    while (chronologieDemandes.encoreSuivant())
    {
      DemandeSpec demandeTemp = (DemandeSpec)chronologieDemandes.elementSuivant();
      if ((demandeTemp.estDecisionnee()) && (demandeTemp.getDateRecherche().estAvantOuCoincideAvec(dateRecherche)))
      {
        demandeRetour = demandeTemp;
        break;
      }
    }
    return (Demande)demandeRetour;
  }
  
  public DemandeSpec rechercherDemandeAspLiee(DemandeSpec demande)
  {
    DemandeSpec retour = null;
    
    AttributionSpec attributionAspPrecedente = rechercherAttributionAspLiee(demande);
    if (attributionAspPrecedente != null) {
      retour = rechercherAttributionAspLiee(demande).getDemande();
    }
    return retour;
  }
  
  public AttributionSpec rechercherAttributionAspLiee(DemandeSpec demande)
  {
    AttributionSpec retour = null;
    
    int referenceRejetDV = ((FormulaireAsu)demande.getFormulaire()).getReferenceExterneDemandeLiee();
    if (referenceRejetDV != 0)
    {
      FiltreET filtreOdAsp = new FiltreET();
      filtreOdAsp.ajouterFiltre(new FiltreOuvertureDroitStandardAssurance(false, true, false, false, null));
      filtreOdAsp.ajouterFiltre(new FiltreAttributionAsp());
      filtreOdAsp.ajouterFiltre(new FiltreDemandePourReferenceExterne(referenceRejetDV));
      
      retour = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande.getDateDepot().lendemain(), filtreOdAsp);
    }
    return retour;
  }
  
  public boolean estUneDemandeFinDroitSP(DemandeSpec demande)
  {
    boolean retour = false;
    Attribution attributionAspLiee = (Attribution)getInstance().rechercherAttributionAspLiee(demande);
    if (attributionAspLiee != null)
    {
      CompetenceSpec competence = attributionAspLiee.getCompetence();
      if ((competence != null) && (competence.getCompetenceAdministrative() == 2)) {
        retour = true;
      }
    }
    return retour;
  }
  
  public boolean estAreEnEntreeCSPouPAP(DemandeAssuranceSpec demande)
  {
    boolean estDemandeASPouPap = (OutilDemande.estUneDemandeAspOuPap(demande)) || (OutilDemande.estUneDemandeAntecedentAsp(demande));
    ActiviteSalarie dernierSinistre = null;
    boolean estDerniereSinistreCspOuPap = false;
    if ((demande.getDossierAffectationAdmission() != null) && ((demande.getDossierAffectationAdmission().getSinistre() instanceof ActiviteSalarie)))
    {
      dernierSinistre = (ActiviteSalarie)demande.getDossierAffectationAdmission().getSinistre();
      estDerniereSinistreCspOuPap = OutilActiviteSalarie.getInstance().estAeCSPouPAP(dernierSinistre);
    }
    boolean estUnProduitAre = ProduitAbstrait.estDuType(5, demande.getDossierAffectation().getProduit());
    boolean estPremiereDemande = true;
    if ((estDemandeASPouPap) && (estDerniereSinistreCspOuPap) && (estUnProduitAre))
    {
      FiltreET filtreDemandes = new FiltreET();
      filtreDemandes.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("AREENTRCSP"));
      
      DemandeSpec demandePrecedenteEnContexteEntreeCSP = OutilRecherche.rechercherDemandePrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreDemandes);
      if ((demandePrecedenteEnContexteEntreeCSP != null) && (demandePrecedenteEnContexteEntreeCSP.getDateRecherche().estApres(dernierSinistre.getDateFin()))) {
        estPremiereDemande = false;
      }
    }
    return (estDemandeASPouPap) && (estDerniereSinistreCspOuPap) && (estUnProduitAre) && (estPremiereDemande);
  }
  
  public boolean estAreEnCoursCSPouPAP(DemandeAssuranceSpec demande)
  {
    boolean estNonAreEntreeEnCSPouPAP = !estAreEnEntreeCSPouPAP(demande);
    boolean estUnProduitAre = ProduitAbstrait.estDuType(5, demande.getDossierAffectation().getProduit());
    
    ObjetChronoPeriodePriseEnCharge periodePEC = OutillagePEC.getPeriodePECIndemnisableContenant(demande.getDemandeur(), demande.getDateExamen());
    boolean estEnCoursPecCSPouPAP;
    boolean estEnCoursPecCSPouPAP;
    if (periodePEC != null)
    {
      estEnCoursPecCSPouPAP = ("CSP".equals(periodePEC.getSituationEmploi())) || ("PAP".equals(periodePEC.getSituationEmploi()));
    }
    else
    {
      periodePEC = OutillagePEC.getPecIndemnisableSuivante(demande.getDemandeur(), demande.getDateExamen());
      estEnCoursPecCSPouPAP = ("ASU_28".equals(demande.getEvenementReferenceExamen().getTypeExamen())) && (periodePEC != null) && (("CSP".equals(periodePEC.getSituationEmploi())) || ("PAP".equals(periodePEC.getSituationEmploi())));
    }
    boolean presenceDemandeEnEntreeCSPouPAP = false;
    if (demande.estEnContexteDroitAnterieurSecteurPublicValide())
    {
      presenceDemandeEnEntreeCSPouPAP = true;
    }
    else
    {
      FiltreET filtreAttributionAreEntreeCspOuPap = new FiltreET();
      filtreAttributionAreEntreeCspOuPap.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("AREENTRCSP"));
      filtreAttributionAreEntreeCspOuPap.ajouterFiltre(new FiltreAttributionSurDecisions(true));
      Demande demandeEnEntreCSPouPAPPrecedente = (Demande)OutilRecherche.rechercherDemandePrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreAttributionAreEntreeCspOuPap);
      if (demandeEnEntreCSPouPAPPrecedente != null)
      {
        FiltreET filtres = new FiltreET();
        
        FiltreOU filtreContexte = new FiltreOU();
        filtreContexte.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("POSTCSPARE"));
        filtreContexte.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("POSTCSPDC"));
        filtreContexte.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("POSTPAPARE"));
        filtreContexte.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("POSTPAPDC"));
        
        filtres.ajouterFiltre(filtreContexte);
        filtres.ajouterFiltre(new FiltreNegation(new FiltreDemandePourClassement("SO")));
        filtres.ajouterFiltre(new FiltreAttributionSurDecisions(true));
        Chronologie demandesSortiesCSP = OutilRecherche.rechercherDemandesPrecedentes(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtres);
        if (demandesSortiesCSP != null) {
          demandesSortiesCSP = OutilRecherche.rechercherDemandesSuivantes(demandesSortiesCSP, demandeEnEntreCSPouPAPPrecedente, filtres);
        }
        if (demandesSortiesCSP != null) {
          presenceDemandeEnEntreeCSPouPAP = demandesSortiesCSP.estVide();
        }
      }
    }
    return (estNonAreEntreeEnCSPouPAP) && (estUnProduitAre) && (estEnCoursPecCSPouPAP) && (presenceDemandeEnEntreeCSPouPAP);
  }
  
  public Damj determinerDateFinDernierDispositifCSP(IndividuSpec individu, Damj dateRecherche)
  {
    Damj dateFinDispositif = null;
    FiltreET filtreDemandeASP = new FiltreET();
    filtreDemandeASP.ajouterFiltre(new FiltreDemandePourERE("ASU_24"));
    filtreDemandeASP.ajouterFiltre(new FiltreNegation(new FiltreDemandePourClassement("SO")));
    DemandeSpec dernierDemandeASP = OutilRecherche.rechercherDemandePrecedente(individu.getChronoDemandeAssurance(), dateRecherche, filtreDemandeASP);
    if (dernierDemandeASP != null)
    {
      ObjetChronoPeriodePriseEnCharge periodePEC = OutillagePEC.getPeriodePECIndemnisableContenant(individu, dernierDemandeASP.getDateRecherche());
      if (periodePEC != null) {
        dateFinDispositif = periodePEC.getDateFin();
      }
    }
    return dateFinDispositif;
  }
  
  public ActiviteSalarie recupererAeCspPourEntreeEnDispositifCSP(IndividuSpec individu, Damj dateRecherche)
  {
    ActiviteSalarie aeCSPEntreDispositif = null;
    FiltreET filtreDemandes = new FiltreET();
    filtreDemandes.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("AREENTRCSP"));
    filtreDemandes.ajouterFiltre(new FiltreNegation(new FiltreDemandePourClassement("SO")));
    
    Demande demandePrecedenteEnContexteEntreeCSP = (Demande)OutilRecherche.rechercherDemandePrecedente(individu.getChronoDemandeAssurance(), dateRecherche, filtreDemandes);
    if ((demandePrecedenteEnContexteEntreeCSP != null) && (demandePrecedenteEnContexteEntreeCSP.getDossierAffectationAdmission() != null)) {
      aeCSPEntreDispositif = (ActiviteSalarie)demandePrecedenteEnContexteEntreeCSP.getDossierAffectationAdmission().getSinistre();
    }
    return aeCSPEntreDispositif;
  }
  
  public ActiviteSalarie recupererAeCspPourEntreeEnDispositifCSP(IndividuSpec individu, AttributionAssuranceSpec attribution)
  {
    ActiviteSalarie aeCSP = null;
    if (attribution != null) {
      if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), "AREENTRCSP"))
      {
        aeCSP = (ActiviteSalarie)attribution.getDemandeAssurance().getDossierAffectationAdmission().getSinistre();
      }
      else if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), "ARECOURCSP"))
      {
        aeCSP = recupererAeCspPourEntreeEnDispositifCSP(individu, attribution.getDateAttribution());
      }
      else
      {
        OdAssuranceSpec odASP = (OdAssuranceSpec)attribution.getOuvertureDroit();
        aeCSP = odASP.getFaitGenerateur().getPeriodeFaitGenerateur();
      }
    }
    return aeCSP;
  }
  
  public boolean estContexteSortieDispositifASPouPAPARE(Demande demande, String contexteDispositif)
  {
    boolean estSortieDispositif = false;
    if ((!estAreEnEntreeCSPouPAP(demande)) && (!estAreEnCoursCSPouPAP(demande)))
    {
      FiltreET filtreDemandes = new FiltreET();
      FiltreOU filtreContexte = new FiltreOU();
      filtreContexte.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("AREENTRCSP"));
      filtreContexte.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("ARECOURCSP"));
      filtreDemandes.ajouterFiltre(new FiltreDemandePourTypeContexteDemande(contexteDispositif));
      filtreDemandes.ajouterFiltre(new FiltreNegation(new FiltreDemandePourClassement("SO")));
      
      filtreDemandes.ajouterFiltre(new FiltreAttributionSurDecisions(true));
      
      Demande demandePrecedenteEnContexteEntreeCSP = (Demande)OutilRecherche.rechercherDemandePrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreDemandes);
      if (demandePrecedenteEnContexteEntreeCSP != null)
      {
        FiltreET filtreODAre = new FiltreET();
        filtreODAre.ajouterFiltre(new FiltreOuvertureDroitAssurance(false, true, false, true, demande));
        filtreODAre.ajouterFiltre(new FiltreDecisionARESurDecision());
        filtreODAre.ajouterFiltre(new FiltreNegation(new FiltreDemandePourTypeContexteDemande(6)));
        
        AttributionSpec dernierOdAre = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreODAre);
        if ((dernierOdAre == null) || (dernierOdAre.getDateAttribution().estAvantOuCoincideAvec(demandePrecedenteEnContexteEntreeCSP.getDateExamen()))) {
          estSortieDispositif = true;
        }
      }
    }
    return estSortieDispositif;
  }
  
  public boolean estPremiereDemandeSortieDispositifCspOuPap(DemandeAssuranceSpec demandeAssurance)
  {
    boolean retour = false;
    if ("ASU_01".equals(demandeAssurance.getEvenementReferenceExamen().getTypeExamen()))
    {
      ObjetChronoPeriodePriseEnCharge pecPrecedente = OutillagePEC.getPecIndemnisablePrecedente(demandeAssurance.getDemandeur(), demandeAssurance.getFormulaire().getIdPec());
      while (OutillagePEC.estPecAutreEtatMembreCoordination(pecPrecedente)) {
        pecPrecedente = OutillagePEC.getPecIndemnisablePrecedente(demandeAssurance.getDemandeur(), pecPrecedente.getIdentifiantPec());
      }
      if (pecPrecedente != null) {
        retour = (OutillagePEC.estUnePECCSP(pecPrecedente)) || (OutillagePEC.estUnePECPAP(pecPrecedente));
      }
    }
    return retour;
  }
  
  public boolean estContexteSortieDispositifASPouPAPDC(Demande demande, String contexteDispositif)
  {
    boolean estSortieDispositif = false;
    FiltreET filtreDemandes = new FiltreET();
    
    filtreDemandes.ajouterFiltre(new FiltreDemandePourERE("ASU_25"));
    filtreDemandes.ajouterFiltre(new FiltreDecisionARESurDecision());
    filtreDemandes.ajouterFiltre(new FiltreNegation(new FiltreDemandePourClassement("SO")));
    FiltreOU filtreOu = new FiltreOU();
    filtreOu.ajouterFiltre(filtreDemandes);
    FiltreET filtreAttributionASP = new FiltreET();
    filtreAttributionASP.ajouterFiltre(new FiltreDemandePourTypeContexteDemande(contexteDispositif));
    
    filtreAttributionASP.ajouterFiltre(new FiltreAttributionSurDecisions(true));
    filtreOu.ajouterFiltre(filtreAttributionASP);
    
    Demande demandeASPDC = (Demande)OutilRecherche.rechercherDemandePrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreOu);
    
    DemandeSpec dernierClassementSPenCSP = recupererDernierClassementSPSurPECCSP(demande);
    if ((demandeASPDC == null) || ((dernierClassementSPenCSP != null) && (demandeASPDC.getDateRecherche().estAvant(dernierClassementSPenCSP.getDateRecherche())))) {
      demandeASPDC = (Demande)dernierClassementSPenCSP;
    }
    if ((demandeASPDC != null) && ((("ASU_25".equals(demandeASPDC.getEvenementReferenceExamen().getTypeExamen())) && (FabriqueConvention2014.DATE_APPLICATION.estAvantOuCoincideAvec(demandeASPDC.getDateRecherche()))) || (!"ASU_25".equals(demandeASPDC.getEvenementReferenceExamen().getTypeExamen()))))
    {
      FiltreET filtreODAre = new FiltreET();
      filtreODAre.ajouterFiltre(new FiltreOuvertureDroitAssurance(false, true, false, true, demande));
      filtreODAre.ajouterFiltre(new FiltreDecisionARESurDecision());
      filtreODAre.ajouterFiltre(new FiltreNegation(new FiltreDemandePourTypeContexteDemande(6)));
      
      AttributionSpec dernierOdAre = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreODAre);
      if (dernierOdAre != null)
      {
        if (("ASU_25".equals(dernierOdAre.getDemande().getEvenementReferenceExamen().getTypeExamen())) || (dernierOdAre.getDateAttribution().estAvant(demandeASPDC.getDateRecherche()))) {
          estSortieDispositif = true;
        }
      }
      else {
        estSortieDispositif = true;
      }
    }
    return estSortieDispositif;
  }
  
  public ProduitAsuSpec recupererProduitReglementaire(DemandeSpec demande)
  {
    Demande demandeCourante = (Demande)demande;
    AffectationDemandeAsp affectationAsp = new AffectationDemandeAsp();
    
    TravailSpec periodeRechercheDecor = demandeCourante.getDossierAffectationAdmission().getSinistre();
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "ARECOURCSP")) {
      periodeRechercheDecor = recupererAeCspPourEntreeEnDispositifCSP(demandeCourante.getDemandeur(), demandeCourante.getDateRecherche());
    }
    Damj dateRecherche;
    try
    {
      dateRecherche = affectationAsp.determinerDateRechercheDecor(periodeRechercheDecor, demandeCourante);
    }
    catch (CoucheLogiqueException ex)
    {
      dateRecherche = periodeRechercheDecor.getDateFin();
    }
    LigneSpec ligne = LigneAsuCaa14.getInstance();
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, 9)) {
      ligne = LigneAsuCva10.getInstance();
    }
    return (ProduitAsuSpec)ligne.getProduitActif(dateRecherche);
  }
  
  public AttributionSpec recupererAttributionEntreeCsp(AttributionSpec attribution)
  {
    Demande demandeCourante = (Demande)attribution.getDemande();
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "AREENTRCSP")) {
      return attribution;
    }
    Demande demandeEnEntreCSPPrecedente = (Demande)OutilRecherche.rechercherDemandePrecedente(demandeCourante.getChronologieDemandesAssuranceSansCourante(), demandeCourante, new FiltreDemandePourTypeContexteDemande("AREENTRCSP"));
    if (demandeEnEntreCSPPrecedente != null) {
      return demandeEnEntreCSPPrecedente.getAttribution();
    }
    return null;
  }
  
  public Collection<DemandeAssuranceSpec> recupererAdmissionsDurantDispositifCSP(AttributionSpec attribution)
  {
    Demande demandeCourante = (Demande)attribution.getDemande();
    
    AttributionSpec attributionEntreeCsp = recupererAttributionEntreeCsp(attribution);
    Demande demandeEntreeCsp = (Demande)attributionEntreeCsp.getDemande();
    
    FiltreOU filtreDemandes = new FiltreOU();
    filtreDemandes.ajouterFiltre(new FiltreDecisionPourNatureDecision(10));
    filtreDemandes.ajouterFiltre(new FiltreDecisionPourNatureDecision(12));
    filtreDemandes.ajouterFiltre(new FiltreDecisionPourNatureDecision(45));
    filtreDemandes.ajouterFiltre(new FiltreDecisionPourNatureDecision(44));
    filtreDemandes.ajouterFiltre(new FiltreDecisionPourNatureDecision(47));
    filtreDemandes.ajouterFiltre(new FiltreDecisionPourNatureDecision(48));
    
    Chronologie admissionsApresEntreeCsp = null;
    if (demandeEntreeCsp != null)
    {
      admissionsApresEntreeCsp = OutilRecherche.rechercherDemandesSuivantes(demandeEntreeCsp.getChronologieDemandesAssuranceSansCourante(), demandeEntreeCsp, filtreDemandes);
      if (admissionsApresEntreeCsp != null) {
        admissionsApresEntreeCsp = OutilRecherche.rechercherDemandesPrecedentes(admissionsApresEntreeCsp, demandeCourante, filtreDemandes);
      }
    }
    Collection<DemandeAssuranceSpec> demandesARetourner = admissionsApresEntreeCsp.mapperVersCollection();
    if (!demandeCourante.equals(demandeEntreeCsp)) {
      demandesARetourner.add(demandeEntreeCsp);
    }
    return demandesARetourner;
  }
  
  private DemandeSpec recupererDernierClassementSPSurPECCSP(DemandeSpec demandeCourante)
  {
    FiltreET filtreClassementsSP = new FiltreET();
    FiltreOU filtreDemandeConcernee = new FiltreOU();
    filtreDemandeConcernee.ajouterFiltre(new FiltreDemandePourERE("ASU_29"));
    filtreDemandeConcernee.ajouterFiltre(new FiltreDemandePourERE("ASU_24"));
    filtreClassementsSP.ajouterFiltre(filtreDemandeConcernee);
    filtreClassementsSP.ajouterFiltre(new FiltreDemandePourClassement("SP"));
    
    Chronologie classementsSP = OutilRecherche.rechercherDemandesPrecedentes(demandeCourante.getChronologieDemandesAssuranceSansCourante(), Damj.FIN_DES_TEMPS, filtreClassementsSP);
    
    DemandeSpec dernierClassementSPencoursCSP = null;
    if ((classementsSP != null) && (!classementsSP.estVide()))
    {
      classementsSP.setComparateur(new ComparateurSurDateDeclenchementDemandeDecroissante());
      classementsSP.iterer();
      while ((dernierClassementSPencoursCSP == null) && (classementsSP.encoreSuivant()))
      {
        DemandeSpec classementSPCourant = (DemandeSpec)classementsSP.elementSuivant();
        if (estSurPECCSPouPAP(classementSPCourant)) {
          dernierClassementSPencoursCSP = classementSPCourant;
        }
      }
    }
    return dernierClassementSPencoursCSP;
  }
  
  private boolean estSurPECCSPouPAP(DemandeSpec classementSP)
  {
    ObjetChronoPeriodePriseEnCharge pec;
    ObjetChronoPeriodePriseEnCharge pec;
    if ("ASU_24".equals(classementSP.getEvenementReferenceExamen().getTypeExamen())) {
      pec = OutillagePEC.getPeriodePEC(classementSP.getDemandeur(), classementSP.getFormulaire().getIdPec());
    } else {
      pec = OutillagePEC.getPeriodePECIndemnisableContenant(classementSP.getDemandeur(), classementSP.getDateRecherche());
    }
    boolean estSurPECCSPouPAP = false;
    if (pec != null) {
      estSurPECCSPouPAP = (OutillagePEC.estUnePECCSP(pec)) || (OutillagePEC.estUnePECPAP(pec));
    }
    return estSurPECCSPouPAP;
  }
  
  public Damj calculerPointDepartCSP(Demande demande)
  {
    Damj dateCalculDateLimite = null;
    Demande demandeEntreeCsp;
    Demande demandeEntreeCsp;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP")) {
      demandeEntreeCsp = (Demande)OutilRecherche.rechercherDemandePrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, new FiltreDemandePourTypeContexteDemande("AREENTRCSP"));
    } else {
      demandeEntreeCsp = demande;
    }
    if (demandeEntreeCsp != null) {
      dateCalculDateLimite = demandeEntreeCsp.getDateAttribution();
    }
    return dateCalculDateLimite;
  }
  
  public boolean estDeTypeOD(Demande demande)
  {
    int type;
    int type;
    if (demande.getObjectifCourant() != null) {
      type = demande.getObjectifCourant().getSousType();
    } else {
      type = demande.getObjectifDecisionne().getType();
    }
    return NaturesDecisions.estdeTypeOd(type);
  }
}

/* Location:
 * Qualified Name:     OutilAsp
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */