package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.EreAspSuiteIDE;
import fr.unedic.cali.asu.dom.EreAsrSuiteIDE;
import fr.unedic.cali.asu.dom.EreInscriptionDemandeurEmploi;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCaa14P01;
import fr.unedic.cali.dom.affectation.ProduitAsuCaa14P02;
import fr.unedic.cali.outilsfonctionnels.ConstructionCSOIA;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;

public class OutilSimulationCalculEstimationSimplifiee
  implements OutilFonctionnel
{
  public static final String TYPE_SIMULATION_ARE_CGE = "ARE CGE";
  public static final String TYPE_SIMULATION_ASR = "ASR";
  public static final String TYPE_SIMULATION_ASP = "ASP";
  private static final String SITUATION_EMPLOI_ARCE = "CEN";
  private static final String SUFFIXE_REF_EXTERNE = "001";
  private static final int DIX = 10;
  private static final int LONGUEUR_COMPLETION = 4;
  private static final String CHAINE_ZERO = "0";
  private static final String CHAINE_UN = "1";
  private static final String CHAINE_DEUX = "2";
  private static final String CHAINE_TROIS = "3";
  private static final String CHAINE_QUATRE = "4";
  private static final String CHAINE_CINQ = "5";
  private static final String CHAINE_SIX = "6";
  private static final String CHAINE_SEPT = "7";
  private static final String CHAINE_HUIT = "8";
  private static final String CHAINE_NEUF = "9";
  private static final Damj DATE_DEBUT_ASR_2009 = ProduitAsuCaa14P01.getInstance().getPeriodeValidite().getDebut();
  private static final Damj DATE_DEBUT_ASP_2011 = ProduitAsuCaa14P02.getInstance().getPeriodeValidite().getDebut();
  
  public static ArrayList determinerListeSimulations(Contexte p_contexte)
  {
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\n\t\t******** Début Détermination des types de simulations possibles ********\n" });
    
    ArrayList liste = new ArrayList();
    liste.add("ARE CGE");
    
    boolean licenciementEconomique = false;
    DomLiquidationAssurance dom = (DomLiquidationAssurance)p_contexte.getDonnees();
    Individu individu = (Individu)dom.getIndividu();
    ContratTravail contratTravail = getFaitGenerateur(individu).getContrat();
    if (contratTravail != null)
    {
      licenciementEconomique = contratTravail.getCodeMotifFin() == 1;
      if (licenciementEconomique) {
        if (contratTravail.getDateRuptureContratTravail().estApresOuCoincideAvec(DATE_DEBUT_ASP_2011))
        {
          liste.add("ASP");
        }
        else if (contratTravail.getDateRuptureContratTravail().estApresOuCoincideAvec(DATE_DEBUT_ASR_2009))
        {
          liste.add("ASR");
        }
        else
        {
          String libelleLog = "\n\t\t******** Type de simulation ASR non valide avec une FCT au " + contratTravail.getDateRuptureContratTravail().toString() + " ********\n";
          
          OutilTrace.ecrireTrace(Niveau.WARN, new Object[] { libelleLog });
        }
      }
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\n\t\t******** Fin Détermination des types de simulations possibles ********\n" });
    
    return liste;
  }
  
  public static void alimenterDonneesSimulation(Contexte p_contexte, String p_typeSimulation)
  {
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\n\t\t******** Début Alimentation des données de simulation ********\n" });
    
    DomLiquidationAssurance dom = (DomLiquidationAssurance)p_contexte.getDonnees();
    Individu individu = (Individu)dom.getIndividu();
    
    ActiviteSalarie activiteSalarie = getFaitGenerateur(individu);
    Damj dateIDE = activiteSalarie.getDateFin().lendemain();
    DemandeAssuranceSpec demande;
    DemandeAssuranceSpec demande;
    if (p_typeSimulation.equals("ARE CGE"))
    {
      demande = creerDemandeAsu(individu, dateIDE);
    }
    else if (p_typeSimulation.equals("ASP"))
    {
      DemandeAssuranceSpec demande = creerDemandeAsp(individu, dateIDE);
      
      activiteSalarie.getContrat().setCodeMotifFin(44);
    }
    else
    {
      demande = creerDemandeAsr(individu, dateIDE);
      
      activiteSalarie.getContrat().setCodeMotifFin(42);
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\n\t\t******** Alimentation des données de simulation (demande créée) ********\n" });
    
    individu.ajouterDemande(demande);
    
    String typePEC = "";
    String sousTypePEC = "";
    String situationEmploi = "";
    if ((p_typeSimulation.equals("ASR")) || (p_typeSimulation.equals("ASP")))
    {
      typePEC = "2";
      sousTypePEC = "6";
    }
    if (p_typeSimulation.equals("ASP")) {
      situationEmploi = "CSP";
    }
    int idPec = creerPriseEnCharge(individu, dateIDE, Damj.FIN_DES_TEMPS, typePEC, sousTypePEC, situationEmploi);
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\n\t\t******** Alimentation des données de simulation (PEC créée) ********\n" });
    
    FormulaireAsu formulaire = ((Demande)demande).createFormulaireAsu();
    formulaire.setIdPec(idPec);
    formulaire.setReferenceExterne(entierVersChaineCompletee(idPec) + "001");
    formulaire.setDateDepot(dateIDE);
    
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\n\t\t******** Fin Alimentation des données de simulation ********\n" });
    
    dom.setDemande(demande);
    dom.setIdDemande(demande.getIdentifiant());
    
    reinitialiserDom(dom);
  }
  
  private static DemandeAssuranceSpec creerDemandeAsu(Individu p_individu, Damj p_dateIde)
  {
    Demande demande = new Demande();
    EvenementReferenceExamenSpec ere = new EreInscriptionDemandeurEmploi();
    ere.setDateEvenement(p_dateIde);
    demande.setEvenementReferenceExamen(ere);
    demande.setDemandeur(p_individu);
    
    return demande;
  }
  
  private static int creerPriseEnCharge(IndividuSpec p_individu, Damj p_dateDebut, Damj p_dateFin, String p_type, String p_sousType, String p_situationEmploi)
  {
    ChronologiePeriodes listePec;
    ChronologiePeriodes listePec;
    if (p_individu.getChronologiePecFusionneesFinCI() == null) {
      listePec = new ChronologiePeriodes();
    } else {
      listePec = (ChronologiePeriodes)p_individu.getChronologiePecFusionneesFinCI();
    }
    ObjetChronoPeriodePriseEnCharge periode = new ObjetChronoPeriodePriseEnCharge(new Periode(p_dateDebut));
    if (p_dateFin != null) {
      periode.setDateFin(p_dateFin);
    }
    periode.setCategorie("1");
    periode.setTypePec(p_type);
    periode.setSousType(p_sousType);
    periode.setSituationEmploi(p_situationEmploi);
    
    setDemandeurEmploiEtActualise(periode);
    
    int nbPecExistantes = listePec.getTaille();
    periode.setIdentifiantPec((nbPecExistantes + 1) * 10);
    
    listePec.ajouter(periode);
    
    p_individu.setChronologiePecFusionneesFinCI(listePec);
    ChronologiePeriodes listePecNonFiltres;
    ChronologiePeriodes listePecNonFiltres;
    if (p_individu.getChronologiePecNonFusionneesFinCI() == null) {
      listePecNonFiltres = new ChronologiePeriodes();
    } else {
      listePecNonFiltres = (ChronologiePeriodes)p_individu.getChronologiePecNonFusionneesFinCI();
    }
    ObjetChronoPeriodePriseEnChargeSansFiltre periodeNonFiltre = new ObjetChronoPeriodePriseEnChargeSansFiltre(new Periode(p_dateDebut));
    if (p_dateFin != null) {
      periodeNonFiltre.setDateFin(p_dateFin);
    }
    periodeNonFiltre.setCategorie("1");
    
    periodeNonFiltre.setTypePec(p_type);
    periodeNonFiltre.setSousType(p_sousType);
    
    setDemandeurEmploiEtActualise(periodeNonFiltre);
    
    int nbPecNonFiltresExistantes = listePecNonFiltres.getTaille();
    periodeNonFiltre.setIdentifiantPec((nbPecNonFiltresExistantes + 1) * 10);
    
    listePecNonFiltres.ajouter(periodeNonFiltre);
    
    p_individu.setChronologiePecNonFusionneesFinCI(listePecNonFiltres);
    
    return periode.getIdentifiantPec();
  }
  
  private static void setDemandeurEmploiEtActualise(ObjetChronoPeriodePriseEnCharge p_pec)
  {
    boolean demandeurEmploi = false;
    boolean actualise = false;
    String situationEmploi = "CEN";
    if (p_pec.getTypePec().equals("")) {
      p_pec.setTypePec("1");
    }
    if (p_pec.getSousType().equals("")) {
      p_pec.setSousType("1");
    }
    if (((p_pec.getTypePec().equals("1")) && (p_pec.getSousType().equals("1"))) || ((p_pec.getTypePec().equals("1")) && (p_pec.getSousType().equals("2"))) || ((p_pec.getTypePec().equals("1")) && (p_pec.getSousType().equals("3"))) || ((p_pec.getTypePec().equals("2")) && (p_pec.getSousType().equals("1"))) || ((p_pec.getTypePec().equals("2")) && (p_pec.getSousType().equals("2"))) || ((p_pec.getTypePec().equals("2")) && (p_pec.getSousType().equals("5"))) || ((p_pec.getTypePec().equals("1")) && (p_pec.getSousType().equals("7")) && (situationEmploi.equals("CEN"))))
    {
      demandeurEmploi = true;
      actualise = true;
    }
    else if (((p_pec.getTypePec().equals("1")) && (p_pec.getSousType().equals("4"))) || ((p_pec.getTypePec().equals("1")) && (p_pec.getSousType().equals("5"))) || ((p_pec.getTypePec().equals("1")) && (p_pec.getSousType().equals("9"))) || ((p_pec.getTypePec().equals("2")) && (p_pec.getSousType().equals("4"))) || (p_pec.getTypePec().equals("3")) || (p_pec.getTypePec().equals("6")) || ((p_pec.getTypePec().equals("1")) && (p_pec.getSousType().equals("7")) && (!situationEmploi.equals("CEN"))))
    {
      demandeurEmploi = false;
      actualise = false;
    }
    else if (p_pec.getTypePec().equals("4"))
    {
      demandeurEmploi = true;
      actualise = false;
    }
    else if (((p_pec.getTypePec().equals("1")) && (p_pec.getSousType().equals("6"))) || ((p_pec.getTypePec().equals("2")) && (p_pec.getSousType().equals("6"))))
    {
      demandeurEmploi = false;
      actualise = true;
    }
    else if (((p_pec.getTypePec().equals("1")) && (p_pec.getSousType().equals("8"))) || ((p_pec.getTypePec().equals("2")) && (p_pec.getSousType().equals("8"))))
    {
      demandeurEmploi = false;
      actualise = true;
    }
    p_pec.setDemandeurEmploi(demandeurEmploi);
    p_pec.setActualise(actualise);
  }
  
  private static String entierVersChaineCompletee(int p_int)
  {
    String string = "" + p_int;
    while (string.length() < 4) {
      string = "0" + string;
    }
    return string;
  }
  
  private static Demande creerDemandeAsr(Individu p_individu, Damj p_dateIde)
  {
    Demande demande = new Demande();
    demande.setEvenementReferenceExamen(new EreAsrSuiteIDE());
    demande.getEvenementReferenceExamen().setDateDeclenchementExamen(p_dateIde);
    demande.getEvenementReferenceExamen().setDateEvenement(p_dateIde);
    FormulaireAsu formulaireAsu = demande.createFormulaireAsu();
    formulaireAsu.setDateDepot(p_dateIde);
    formulaireAsu.setDateCreationDal(p_dateIde);
    formulaireAsu.setMotifEnvoi(ConstructionCSOIA.getCSOIADepuisTypeExamen("ASU_16"));
    demande.setEstFormulaireCharge(true);
    demande.setDemandeur(p_individu);
    
    return demande;
  }
  
  private static Demande creerDemandeAsp(Individu p_individu, Damj p_dateIde)
  {
    Demande demande = new Demande();
    demande.setEvenementReferenceExamen(new EreAspSuiteIDE());
    demande.getEvenementReferenceExamen().setDateDeclenchementExamen(p_dateIde);
    demande.getEvenementReferenceExamen().setDateEvenement(p_dateIde);
    FormulaireAsu formulaireAsu = demande.createFormulaireAsu();
    formulaireAsu.setDateDepot(p_dateIde);
    formulaireAsu.setDateCreationDal(p_dateIde);
    formulaireAsu.setMotifEnvoi(ConstructionCSOIA.getCSOIADepuisTypeExamen("ASU_24"));
    demande.setEstFormulaireCharge(true);
    demande.setDemandeur(p_individu);
    
    return demande;
  }
  
  private static void reinitialiserDom(DomLiquidationAssurance p_dom)
  {
    p_dom.setResultatAvantDroitPrecedent(null);
    p_dom.setResultatExecutionCalculDroitPrecedent(null);
    p_dom.setEstRepriseContextuelle(false);
    p_dom.setEtudeDerniereFct(true);
    p_dom.setContinuerEtudeFctEre(true);
  }
  
  public static ActiviteSalarie getFaitGenerateur(IndividuSpec p_individu)
  {
    ActiviteSalarie faitGenerateur = null;
    
    Chronologie listePAS = p_individu.getChronoPeriodePasseProfessionnel();
    listePAS.setComparateur(new ComparateurTemporelsSurDateFin());
    faitGenerateur = (ActiviteSalarie)listePAS.premierElement();
    return faitGenerateur;
  }
}

/* Location:
 * Qualified Name:     OutilSimulationCalculEstimationSimplifiee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */