package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.RejetSpec;
import fr.unedic.cali.dom.affectation.LigneAsuFds12;
import fr.unedic.cali.dom.affectation.LigneAsuSpe02;
import fr.unedic.cali.dom.affectation.LigneAsuSsp07;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAntecedentSurDemande;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreReexamenSurDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreAttributionEnCoursIndemnisationPourDate;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.Damj;

public final class OutilVerificationContexteEre
{
  public static void verifierExistanteAreFdd(DemandeSpec pDemande, Damj dateRecherche)
    throws CoucheLogiqueException
  {
    IndividuSpec individu = pDemande.getDemandeur();
    boolean demandeFddTrouvee = false;
    
    ChronologieDebuts listeDemandes = individu.getChronoDemandeAssurance();
    listeDemandes.iterer();
    while ((listeDemandes.encoreSuivant()) && (!demandeFddTrouvee))
    {
      DemandeAssuranceSpec demande = (DemandeAssuranceSpec)listeDemandes.elementSuivant();
      if ((demande.estUneDemandeAreFdd()) && ((demande.getDossierExamen() instanceof RejetSpec)) && (demande.getDateRecherche().estAvantOuCoincideAvec(dateRecherche)))
      {
        DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)demande.getDossierExamen();
        boolean affiliationOK = (dossierExamen.getConditionQuantiteAffiliation() != null) && (dossierExamen.getConditionQuantiteAffiliation().estSatisfait());
        if (!affiliationOK) {
          demandeFddTrouvee = true;
        }
      }
    }
    if ((!demandeFddTrouvee) && (!estContexteAntecedentAreSpectacleEpuise(pDemande.getDemandeur()))) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_ABSENCE_ARE_FDD");
    }
  }
  
  private static boolean estContexteAntecedentAreSpectacleEpuise(IndividuSpec individu)
  {
    boolean contexteAntecedentAreSpectacleEpuise = false;
    
    FiltreET filtreAntecedentAre = new FiltreET();
    filtreAntecedentAre.ajouterFiltre(new FiltreAntecedentSurDemande());
    filtreAntecedentAre.ajouterFiltre(new FiltreDecisionARESurDecision());
    filtreAntecedentAre.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
    
    AttributionAssuranceSpec antecedentAsu = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(individu.getChronoDemandesNonTriees(), Damj.FIN_DES_TEMPS, filtreAntecedentAre);
    
    boolean antecedentNulOK = (antecedentAsu == null) && (individu.getDernierJourIndemnisableAreSpe() != null);
    if ((antecedentNulOK) || ((antecedentAsu != null) && (((Demande)antecedentAsu.getDemande()).getSaisieAntecedent().getContexteDemande() != null) && (((Demande)antecedentAsu.getDemande()).getSaisieAntecedent().getContexteDemande().intValue() == 4))) {
      contexteAntecedentAreSpectacleEpuise = true;
    }
    return contexteAntecedentAreSpectacleEpuise;
  }
  
  public static void verifierPresenceReliquatAre(DemandeSpec demande, Damj dateRecherche)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionAssurancePrecedente = ((DemandeAssuranceSpec)demande).rechercherAttributionPrecedenteDuMemeType();
    if (attributionAssurancePrecedente != null)
    {
      DemandeAssuranceSpec demandeAssurancePrecedente = (DemandeAssuranceSpec)attributionAssurancePrecedente.getDemande();
      try
      {
        if ((demandeAssurancePrecedente.estUneDemandeAre()) && (donnerPresenceReliquat(attributionAssurancePrecedente, dateRecherche))) {
          GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PRESENCE_RELIQUAT_ARE");
        }
      }
      catch (ApplicativeException ex)
      {
        throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle(), ex);
      }
    }
  }
  
  public static void verifierPresenceReliquatAps(DemandeSpec demande, Damj dateRecherche)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionAssurancePrecedente = ((DemandeAssuranceSpec)demande).rechercherAttributionPrecedenteDuMemeType();
    if (attributionAssurancePrecedente != null)
    {
      DemandeAssuranceSpec demandeAssurancePrecedente = (DemandeAssuranceSpec)attributionAssurancePrecedente.getDemande();
      try
      {
        if ((demandeAssurancePrecedente != null) && (demandeAssurancePrecedente.estUneDemandeAps()) && (donnerPresenceReliquat(attributionAssurancePrecedente, dateRecherche))) {
          GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PRESENCE_RELIQUAT_APS");
        }
      }
      catch (ApplicativeException ex)
      {
        throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle(), ex);
      }
    }
  }
  
  public static void verifierPresenceReliquatAtOuAfd(DemandeSpec demande, Damj dateRecherche)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionAssurancePrecedente = ((DemandeAssuranceSpec)demande).rechercherAttributionPrecedenteDuMemeType();
    try
    {
      if ((attributionAssurancePrecedente != null) && (attributionAssurancePrecedente.getProduit().getLigne().getNomUnique().equals(LigneAsuFds12.getInstance().getNomUnique())) && (donnerPresenceReliquat(attributionAssurancePrecedente, dateRecherche))) {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PRESENCE_RELIQUAT_AT_AFD");
      }
    }
    catch (ApplicativeException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle(), ex);
    }
  }
  
  public static void verifierDroitAreEnCours(DemandeSpec demande, Damj dateRecherche)
    throws CoucheLogiqueException
  {
    try
    {
      FiltreET filtreAttributionEnCours = new FiltreET();
      filtreAttributionEnCours.ajouterFiltre(new FiltreNegation(new FiltreDemandePourERE("ASU_31")));
      filtreAttributionEnCours.ajouterFiltre(new FiltreAttributionStandardAssurance(true, true, false, false, null));
      filtreAttributionEnCours.ajouterFiltre(new FiltreAttributionEnCoursIndemnisationPourDate(dateRecherche));
      AttributionSpec attributionAssuranceEnCours = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getDemandeur().getChronoDemandesNonTriees(), demande, filtreAttributionEnCours);
      if (attributionAssuranceEnCours != null)
      {
        DemandeAssuranceSpec demandeAssuranceEnCours = (DemandeAssuranceSpec)attributionAssuranceEnCours.getDemande();
        if (demandeAssuranceEnCours.estUneDemandeAre()) {
          GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PRESENCE_DROIT_ARE_EN_COURS", new String[] { dateRecherche.toString() });
        }
      }
    }
    catch (ApplicativeException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle(), ex);
    }
  }
  
  public static void verifierDroitApsEnCours(DemandeSpec demande, Damj dateRecherche)
    throws CoucheLogiqueException
  {
    try
    {
      FiltreET filtreAttributionEnCours = new FiltreET();
      filtreAttributionEnCours.ajouterFiltre(new FiltreAttributionStandardAssurance(true, true, false, false, null));
      filtreAttributionEnCours.ajouterFiltre(new FiltreAttributionEnCoursIndemnisationPourDate(dateRecherche));
      AttributionSpec attributionAssuranceEnCours = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getDemandeur().getChronoDemandesNonTriees(), demande, filtreAttributionEnCours);
      if ((attributionAssuranceEnCours != null) && (attributionAssuranceEnCours.getProduit().getLigne().getNomUnique().equals(LigneAsuSsp07.getInstance().getNomUnique()))) {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PRESENCE_DROIT_APS_EN_COURS", new String[] { dateRecherche.toString() });
      }
    }
    catch (ApplicativeException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle(), ex);
    }
  }
  
  public static void verifierDroitAtOuAfdEnCours(DemandeSpec demande, Damj dateRecherche)
    throws CoucheLogiqueException
  {
    try
    {
      FiltreET filtreAttributionEnCours = new FiltreET();
      filtreAttributionEnCours.ajouterFiltre(new FiltreAttributionStandardAssurance(true, true, false, false, null));
      filtreAttributionEnCours.ajouterFiltre(new FiltreAttributionEnCoursIndemnisationPourDate(dateRecherche));
      AttributionSpec attributionAssuranceEnCours = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getDemandeur().getChronoDemandesNonTriees(), demande, filtreAttributionEnCours);
      if (attributionAssuranceEnCours != null)
      {
        DemandeAssuranceSpec demandeAssuranceEnCours = (DemandeAssuranceSpec)attributionAssuranceEnCours.getDemande();
        if (demandeAssuranceEnCours.estUneDemandeAtAfd()) {
          GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PRESENCE_DROIT_AT_AFD_EN_COURS", new String[] { dateRecherche.toString() });
        }
      }
    }
    catch (ApplicativeException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle(), ex);
    }
  }
  
  public static void verifierAttributionPrecedentePourInstallationAreFdd(DemandeSpec demande)
    throws ApplicativeException
  {
    AttributionAssuranceSpec derniereAttributionAsu = ((DemandeAssuranceSpec)demande).rechercherAttributionPrecedenteDuMemeType();
    if (derniereAttributionAsu == null) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_AUCUN_DROIT_PRECEDENT_TROUVE");
    }
    LigneSpec ligneDerniereAttribution = derniereAttributionAsu.getProduit().getLigne();
    if (!ligneDerniereAttribution.equals(LigneAsuSpe02.getInstance())) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ATTR_PREC_NON_SPECT_POUR_ARE_FDD");
    }
    Damj djiParEpuisement = ((ProduitAsuSpec)derniereAttributionAsu.getProduit()).recupererDJIParEpuisement(demande, derniereAttributionAsu, true);
    if (djiParEpuisement == null) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ATTR_PREC_NON_ETEINT_PAR_EPUIS");
    }
  }
  
  private static boolean donnerPresenceReliquat(AttributionAssuranceSpec attributionAssurancePrecedente, Damj dateRecherche)
    throws ApplicativeException
  {
    boolean presenceReliquat = false;
    
    Quantite qteReliquat = ((ProduitAsuSpec)attributionAssurancePrecedente.getProduit()).determinerReliquatHorsMaintien(attributionAssurancePrecedente, dateRecherche.veille());
    if ((qteReliquat != null) && (qteReliquat.getValeurEntiere() > 0)) {
      presenceReliquat = true;
    }
    return presenceReliquat;
  }
}

/* Location:
 * Qualified Name:     OutilVerificationContexteEre
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */