package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreRevisionAre14;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreAttributionPourRsod;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourNatureDecision;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.Damj;
import java.util.Iterator;

public class RechercherDemandeMaintien
{
  public static DemandeMaintien rechercherDemandeMaintien(IndividuSpec individu, AttributionAssuranceSpec attribution)
  {
    DemandeMaintien demandeARetourne = null;
    if (individu == null) {
      return null;
    }
    Iterator iteratorDemandes = individu.getChronoDemandeMaintien().iterer();
    while ((iteratorDemandes.hasNext()) && (demandeARetourne == null))
    {
      DemandeMaintien demandeMaintien = (DemandeMaintien)iteratorDemandes.next();
      if ((demandeMaintien.getClassementAdministratif() == null) && (demandeMaintien.getDemandeMaintenue() != null) && (((Demande)demandeMaintien.getDemandeMaintenue()).getAttribution() != null))
      {
        String rsodMaintenu = ((Demande)demandeMaintien.getDemandeMaintenue()).getAttribution().getRsod();
        if ((attribution.getRsod() != null) && (attribution.getRsod().equals(rsodMaintenu))) {
          demandeARetourne = demandeMaintien;
        }
      }
    }
    return demandeARetourne;
  }
  
  public static AttributionSpec rechercherAttributionAssurancePrecedentePourMaintien(DemandeMaintien demande)
    throws ApplicativeException
  {
    DemandeAssuranceSpec demandeMaintenue = demande.getDemandeMaintenue();
    FiltreET filtres = new FiltreET();
    if ((demandeMaintenue != null) && ((demandeMaintenue.getDossierExamen() instanceof AttributionSpec)))
    {
      AttributionSpec attribution = (AttributionSpec)demandeMaintenue.getDossierExamen();
      String rsodMaintenu = attribution.getRsod();
      filtres.ajouterFiltre(new FiltreAttributionPourRsod(rsodMaintenu));
    }
    filtres.ajouterFiltre(new FiltreAttributionStandardAssurance(true, true, true, false, demande));
    AttributionSpec attributionARE = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getDemandeur().getChronoDemandesNonTriees(), demande.getDateDepot().lendemain(), filtres);
    if (attributionARE == null) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_MNT_CTX_ATTRIBUTION_ARE_INEXISTANTE", new Object[] { demande.getDateDepot() });
    }
    return attributionARE;
  }
  
  public static DemandeAssuranceSpec rechercherDemandeMaintenu(DemandeMaintien demandeMaintien)
  {
    AttributionSpec attributionARE;
    AttributionSpec attributionARE;
    if (demandeMaintien.getRsodMaintenu() != null)
    {
      FiltreET filtreOdAsu = new FiltreET();
      FiltreOU filtreRevisionOuOdOuNovationSortie = new FiltreOU();
      filtreRevisionOuOdOuNovationSortie.ajouterFiltre(new FiltreOuvertureDroitStandardAssurance(true, true, true, false, demandeMaintien));
      filtreRevisionOuOdOuNovationSortie.ajouterFiltre(new FiltreRevisionAre14(false));
      filtreRevisionOuOdOuNovationSortie.ajouterFiltre(new FiltreDecisionPourNatureDecision(48));
      filtreOdAsu.ajouterFiltre(filtreRevisionOuOdOuNovationSortie);
      filtreOdAsu.ajouterFiltre(new FiltreAttributionPourRsod(demandeMaintien.getRsodMaintenu()));
      attributionARE = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demandeMaintien.getDemandeur().getChronoDemandesNonTriees(), Damj.FIN_DES_TEMPS, filtreOdAsu);
    }
    else
    {
      attributionARE = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demandeMaintien.getChronologieDemandesAssuranceSansCourante(), demandeMaintien.getDateDepot().lendemain(), new FiltreOuvertureDroitStandardAssurance(true, true, false, false, demandeMaintien));
    }
    if (attributionARE != null) {
      return (DemandeAssuranceSpec)attributionARE.getDemande();
    }
    return null;
  }
  
  public static DemandeAssuranceSpec rechercherDemandeMaintenuePortantPji(DemandeMaintien demandeMaintien)
  {
    AttributionSpec attributionARE;
    AttributionSpec attributionARE;
    if (demandeMaintien.getRsodMaintenu() != null)
    {
      attributionARE = rechercherAttributionAsuRsod(demandeMaintien.getDemandeur(), demandeMaintien.getRsodMaintenu());
    }
    else
    {
      FiltreET filtreOdAsu = new FiltreET();
      filtreOdAsu.ajouterFiltre(new FiltreOuvertureDroitStandardAssurance(true, true, false, false, null));
      attributionARE = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demandeMaintien.getDemandeur().getChronoDemandesNonTriees(), demandeMaintien.getDateDepot().lendemain(), filtreOdAsu);
      
      String rsodAttribMaintenue = attributionARE.getRsod();
      
      attributionARE = rechercherAttributionAsuRsod(demandeMaintien.getDemandeur(), rsodAttribMaintenue);
    }
    if (attributionARE != null) {
      return (DemandeAssuranceSpec)attributionARE.getDemande();
    }
    return null;
  }
  
  private static AttributionSpec rechercherAttributionAsuRsod(IndividuSpec individu, String rsod)
  {
    FiltreET filtreAttributionAsu = new FiltreET();
    filtreAttributionAsu.ajouterFiltre(new FiltreAttributionStandardAssurance(true, true, false, false, null));
    filtreAttributionAsu.ajouterFiltre(new FiltreAttributionPourRsod(rsod));
    AttributionSpec attributionARE = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(individu.getChronoDemandesNonTriees(), Damj.FIN_DES_TEMPS, filtreAttributionAsu);
    
    return attributionARE;
  }
}

/* Location:
 * Qualified Name:     RechercherDemandeMaintien
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */