package fr.unedic.cali.asu.outilsfonctionnels.liquidationauto;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMotifEchec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ResultatServiceDemande;
import fr.unedic.util.services.Contexte;

public class OutilLiquidationAutomatiqueDemandeConversionFinDroit
  extends OutilLiquidationAutomatiqueAbstrait
{
  public void demarerLiquidationAutomatique(DemandeSpec demande, Contexte contexte)
  {
    DemandeAssuranceSpec demandeAssurance = (DemandeAssuranceSpec)demande;
    if (fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeFinDroitAsr(demande))
    {
      DemandeAssuranceSpec demandeAsrPrec = OutilAsr.getDemandeAsrPrecedente(demande, demande.getDateRecherche());
      fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.copieDonneesForcees(demandeAsrPrec, demandeAssurance);
    }
    else if (fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeFinDroitAsp(demande))
    {
      DemandeAssuranceSpec demandeAspPrec = (DemandeAssuranceSpec)OutilAsp.getInstance().rechercherDemandeAspLiee(demande);
      fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.copieDonneesForcees(demandeAspPrec, demandeAssurance);
    }
    sauvegarderEtatDemandes(demande.getDemandeur());
    try
    {
      ResultatServiceDemande resultatLiquidation = liquiderDemande(demande, true);
      
      traiterResultatLiquidationDemandeConversionFinDroit(resultatLiquidation, contexte);
    }
    catch (Exception e)
    {
      OutilFonctionnelTraitementsErreurs outilTraitementErreurs = OutilFonctionnelTraitementsErreurs.getInstance();
      outilTraitementErreurs.nettoyerDemande(demande);
      OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { e });
    }
    demande.supprimerDossiersAffectations();
  }
  
  private void traiterResultatLiquidationDemandeConversionFinDroit(ResultatServiceDemande pResultat, Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = (Demande)pResultat.getDemande();
    
    boolean demandeAValider = trouverSiDemandeAValider(demande);
    if (demandeAValider)
    {
      validerDecision(demande, contexte);
    }
    else
    {
      OutilFonctionnelTraitementsErreurs outilTraitementErreurs = OutilFonctionnelTraitementsErreurs.getInstance();
      outilTraitementErreurs.nettoyerDemande(demande);
    }
  }
  
  private boolean trouverSiDemandeAValider(Demande pDemande)
  {
    DossierExamenSpec dossierExamen = pDemande.getDossierExamen();
    DecisionSpec decision = (DecisionSpec)pDemande.getDossierExamen();
    
    boolean estUneAttribution = detecterSiAttribution(decision);
    boolean demandeAValider = estUneAttribution;
    if (!estUneAttribution) {
      if (pDemande.estUneDemandeFinDroitAtp())
      {
        demandeAValider = true;
      }
      else
      {
        int motifEchec = OutilMotifEchec.retournerPremierMotifEchec(dossierExamen.getListConditionsAttribution());
        if (motifEchec == 801) {
          demandeAValider = true;
        }
      }
    }
    return demandeAValider;
  }
  
  private boolean detecterSiAttribution(DecisionSpec decision)
  {
    int natureDecision = decision.getNatureDecision();
    boolean estUneAttribution;
    switch (natureDecision)
    {
    case 10: 
    case 11: 
    case 12: 
    case 15: 
    case 26: 
    case 32: 
    case 40: 
      estUneAttribution = true;
      break;
    default: 
      estUneAttribution = false;
    }
    return estUneAttribution;
  }
}

/* Location:
 * Qualified Name:     OutilLiquidationAutomatiqueDemandeConversionFinDroit
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */