package fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ConditionChomageInvolontaireSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.EntretienLiquidationSimplifiee;
import fr.unedic.cali.asu.dom.SituationDemandeur;
import fr.unedic.cali.asu.outilsfonctionnels.GestionDemandeDv122eJour;
import fr.unedic.cali.asu.parcours.DomLiquidationSimplifiee;
import fr.unedic.cali.asu.produits.liquidation.dom.ParametreLiquidationSimplifiee;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ClassementAdministratif;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.OutilAttribution;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreDemandeDecisionneeOuClasseeSP;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreRepriseSurDecisions;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.List;

public class DeterminationSituationDemandeur
{
  public static final int ID_PEC_PRIMO_DEMANDEUR = 10;
  public static final int NATURE_DECISION_SP = 99;
  public static final BigDecimal RELIQUAT_ZERO = BigDecimal.ZERO;
  
  public void rechercherSituationdemandeur(DomLiquidationSimplifiee dom)
    throws ApplicativeException
  {
    IndividuSpec individu = dom.getIndividu();
    SituationDemandeur situationDemandeur = new SituationDemandeur();
    
    dom.setSituationDemandeur(situationDemandeur);
    DemandeSpec demande = dom.getDemande();
    
    situationDemandeur.setDateNaissance(individu.getDateNaissance());
    if (demande == null)
    {
      Object[] params = { genererTripletteIdentifiantIndividu(dom.getContexteService()) };
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_LS_DEMANDE_INTROUVABLE", params);
    }
    ObjetChronoPeriodePriseEnCharge pecRecherchee = OutillagePEC.getPeriodePEC(individu, demande.getFormulaire().getIdPec());
    if (pecRecherchee == null)
    {
      Object[] params = { String.valueOf(demande.getFormulaire().getIdPec()), genererTripletteIdentifiantIndividu(dom.getContexteService()) };
      
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_LS_PEC_INTROUVABLE", params);
    }
    situationDemandeur.setDateInscription(pecRecherchee.getDateDebut());
    if (demande.getFormulaire().getIdPec() != 10) {
      dom.setEstPrimoDemandeur(false);
    } else {
      dom.setEstPrimoDemandeur(true);
    }
    if (!dom.isEstPrimoDemandeur())
    {
      ObjetChronoPeriodePriseEnCharge pecPrecedente = OutillagePEC.getPECDemandeurEmploiPrecedente(individu, demande.getFormulaire().getIdPec());
      if (pecPrecedente == null)
      {
        Object[] params = { String.valueOf(demande.getFormulaire().getIdPec()), genererTripletteIdentifiantIndividu(dom.getContexteService()) };
        
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_LS_PEC_PRECEDENTE_INTROUVABLE", params);
      }
      reinscription(situationDemandeur, individu, dom, pecPrecedente);
    }
  }
  
  protected void reinscription(SituationDemandeur situationDemandeur, IndividuSpec individu, DomLiquidationSimplifiee dom, ObjetChronoPeriodePriseEnCharge pec)
    throws ApplicativeException
  {
    Demande demande = (Demande)dom.getDemande();
    
    Damj dateInscription = situationDemandeur.getDateInscription();
    
    situationDemandeur.setDateDerniereCessation(pec.getDateFin());
    
    alimenterDernierePeriodeGaec(situationDemandeur, individu, dateInscription);
    
    alimenterDernierDvRepriseIPR(situationDemandeur, individu, dateInscription);
    
    alimenterDerniereDecision(situationDemandeur, individu, demande);
    
    Periode pra = recherchePeriodePra(situationDemandeur, individu, demande, situationDemandeur.getDateFinDernierePeriodeGaec());
    
    int nombreJoursAffiliation = CalculAffiliation.calculerAffiliation(individu, pra);
    
    situationDemandeur.setNombreJourQuantiteTravail(nombreJoursAffiliation);
    
    alimenterReliquat(situationDemandeur, demande, dateInscription, dom.getEntretien());
  }
  
  protected void alimenterDernierePeriodeGaec(SituationDemandeur situationDemandeur, IndividuSpec individu, Damj date)
    throws ApplicativeException
  {
    Chronologie chronoAS = RechercherDernierSinistre.determinerChronologieActivitesRechercheDernierSinistre(individu);
    TravailSpec derniereFct = RechercherDernierSinistre.rechercherDernierSinistre(date, chronoAS);
    if (derniereFct != null)
    {
      situationDemandeur.setDateDebutDernierePeriodeGaec(derniereFct.getDateDebut());
      situationDemandeur.setDateFinDernierePeriodeGaec(derniereFct.getDateFin());
      if (derniereFct.getEntreprise() != null) {
        situationDemandeur.setLibelleEmployeur(derniereFct.getEntreprise().getLibelleEntreprise());
      }
    }
  }
  
  protected void alimenterDerniereDecision(SituationDemandeur situationDemandeur, IndividuSpec individu, Demande demande)
  {
    FiltreET filtreDemandePrecedente = new FiltreET();
    filtreDemandePrecedente.ajouterFiltre(new FiltreDemandeDecisionneeOuClasseeSP());
    filtreDemandePrecedente.ajouterFiltre(new FiltreNegation(new FiltreDemandePourERE("ASU_06")));
    DemandeSpec demandePrecedente = OutilRecherche.rechercherDemandePrecedente(individu.getChronoDemandesNonTriees(), demande, filtreDemandePrecedente);
    if (demandePrecedente != null)
    {
      int natureDecisionDerniereDecision = 0;
      boolean estDerniereDecisionSP = false;
      Damj dateDecision = demandePrecedente.getDateRecherche();
      if ((demandePrecedente.getClassementAdministratif() != null) && (demandePrecedente.getClassementAdministratif().getTypeClassement().equalsIgnoreCase("SP")))
      {
        natureDecisionDerniereDecision = 99;
        estDerniereDecisionSP = true;
      }
      else
      {
        DecisionSpec decisionSpec = (DecisionSpec)demandePrecedente.getListeDossiersExamen().get(0);
        natureDecisionDerniereDecision = decisionSpec.getNatureDecision();
        
        Damj dateAttrib = decisionSpec.getDateAttribution();
        if (dateAttrib != null) {
          dateDecision = dateAttrib;
        }
        situationDemandeur.setDateAttributionDerniereDecision(dateDecision);
        situationDemandeur.setProduitDerniereDecision(decisionSpec.getDossierAffecte().getProduit().getLibelleCourt());
        if ((decisionSpec instanceof AttributionAssuranceSpec))
        {
          AttributionAssuranceSpec attributionAssurance = (AttributionAssuranceSpec)decisionSpec;
          if (2 == attributionAssurance.getCompetenceAdministrative()) {
            estDerniereDecisionSP = true;
          }
        }
      }
      situationDemandeur.setNatureDecisionDerniereDecision(natureDecisionDerniereDecision);
      situationDemandeur.setEstDerniereDecisionSP(estDerniereDecisionSP);
    }
  }
  
  private static Periode recherchePeriodePra(SituationDemandeur situationDemandeur, IndividuSpec individu, Demande demande, Damj derniereFctConnue)
    throws CoucheLogiqueException
  {
    Damj dateFGDAsuPrecedent = demande.getDateFaitGenerateurOdPrecedente();
    Damj dateDebutPra = null;
    
    Damj dateFinPra = calculerDateFinPra(derniereFctConnue, situationDemandeur, dateFGDAsuPrecedent);
    
    ParametreLiquidationSimplifiee parametre = Parametres.determinerPraEligible(situationDemandeur, dateFinPra, individu);
    if (parametre == null)
    {
      Object[] params = { situationDemandeur.getDateFinDernierePeriodeGaec() };
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_LS_PARAM_INTROUVABLE", params);
    }
    dateDebutPra = calculerDateDebutPra(parametre, dateFinPra, dateFGDAsuPrecedent);
    
    int nombreMoisPra = parametre.getNombreMoisPRA();
    
    situationDemandeur.setDateFgdAsuPrecedent(dateFGDAsuPrecedent);
    situationDemandeur.setNombreMoisPra(nombreMoisPra);
    situationDemandeur.setDateDebutQuantiteTravail(dateDebutPra);
    situationDemandeur.setDateFinQuantiteTravail(dateFinPra);
    
    return new Periode(dateDebutPra, dateFinPra);
  }
  
  protected void alimenterReliquat(SituationDemandeur situationDemandeur, Demande demande, Damj dateInscription, EntretienLiquidationSimplifiee entretien)
    throws ApplicativeException
  {
    if (situationDemandeur.isEstDerniereDecisionSP())
    {
      situationDemandeur.setReliquat(RELIQUAT_ZERO);
      situationDemandeur.setEtatReliquat(1);
    }
    else
    {
      AttributionAssuranceSpec attributionAssurancePrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), dateInscription.lendemain(), new FiltreAttributionStandardAssurance(true, true, true, false, demande));
      if (attributionAssurancePrecedente != null)
      {
        situationDemandeur.setProduitReliquat(attributionAssurancePrecedente.getProduit());
        
        Demande demandePrecedente = (Demande)attributionAssurancePrecedente.getDemande();
        if ((demandePrecedente.estUneDemandeAtp()) || (demandePrecedente.estUneDemandeAsr()))
        {
          situationDemandeur.setReliquat(RELIQUAT_ZERO);
          situationDemandeur.setEtatReliquat(1);
        }
        else
        {
          boolean estPriseEncompteObjectifReprise = estPriseEncompteObjectifReprise(demande, entretien, situationDemandeur);
          if (!estPriseEncompteObjectifReprise)
          {
            situationDemandeur.setReliquat(RELIQUAT_ZERO);
            situationDemandeur.setEtatReliquat(1);
          }
          else
          {
            attributionAssurancePrecedente.setDemandeSuivantePourTraitementReliquat(demande);
            ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionAssurancePrecedente, demande.getDateRecherche().veille(), true, true);
            
            determinerContexteExamenDepuisResultatCalcul(resultatCalcul, situationDemandeur);
            if (resultatCalcul.getEtatAttribution() == 4) {
              situationDemandeur.setDateReliquatDechu(rechercheDateFinDelaiDecheance(demande));
            }
            recupererQuantiteReliquat(situationDemandeur, resultatCalcul);
            traiterCasParticulier(situationDemandeur, dateInscription, attributionAssurancePrecedente, resultatCalcul);
          }
        }
      }
      else
      {
        situationDemandeur.setEtatReliquat(1);
      }
    }
  }
  
  protected void recupererQuantiteReliquat(SituationDemandeur situationDemandeur, ResultatExecutionCalculSpec resultatCalcul)
  {
    if ((resultatCalcul.isResultatAvantNul()) || ((!resultatCalcul.isResultatAvantNul()) && (resultatCalcul.getEtatResultatAvant() != 9) && (resultatCalcul.getReliquatAREAvecMaintien() != null))) {
      situationDemandeur.setReliquat(new BigDecimal(resultatCalcul.getReliquatAREAvecMaintien().getValeurEntiere()));
    }
  }
  
  protected void traiterCasParticulier(SituationDemandeur situationDemandeur, Damj dateInscription, AttributionAssuranceSpec attributionAssurancePrecedente, ResultatExecutionCalculSpec resultatCalcul)
  {
    if (casSpectacle2016ApresDateLimite(attributionAssurancePrecedente, dateInscription))
    {
      situationDemandeur.setEtatReliquat(2);
      situationDemandeur.setCauseNonValidite(2);
    }
  }
  
  private boolean casSpectacle2016ApresDateLimite(AttributionAssuranceSpec attributionAssurancePrecedente, Damj ide)
  {
    boolean retour = false;
    if (OutilAttribution.getInstance().estProduitAttributionEgal(attributionAssurancePrecedente, "ASU_SPE02_05"))
    {
      Damj dateLimiteIndemnisationAttribPrecedente = null;
      ConstitutionDateLimiteIndemnisation cep = ((Attribution)attributionAssurancePrecedente).getConstitutionElementsActifs().getConstitutionDateLimiteIndemnisation();
      if (cep != null) {
        dateLimiteIndemnisationAttribPrecedente = cep.getDateLimiteIndemnisation();
      }
      if ((dateLimiteIndemnisationAttribPrecedente != null) && (ide.estApres(dateLimiteIndemnisationAttribPrecedente))) {
        retour = true;
      }
    }
    return retour;
  }
  
  private boolean estPriseEncompteObjectifReprise(Demande demande, EntretienLiquidationSimplifiee entretien, SituationDemandeur situationDemandeur)
    throws CoucheLogiqueException
  {
    boolean estPriseEncompteObjectifReprise = true;
    Damj dateDernierSinistre = null;
    if (entretien != null) {
      dateDernierSinistre = entretien.getDateFinContrat();
    }
    if (dateDernierSinistre == null) {
      dateDernierSinistre = situationDemandeur.getDateFinDernierePeriodeGaec();
    }
    if (dateDernierSinistre != null)
    {
      LigneAsuCge01 ligneCasGeneral = LigneAsuCge01.getInstance();
      ProduitAsuSpec produitCgeActif = (ProduitAsuSpec)ligneCasGeneral.getProduitActif(dateDernierSinistre);
      if (produitCgeActif != null) {
        estPriseEncompteObjectifReprise = produitCgeActif.determinePriseEnCompteObjectifReprise(demande);
      } else {
        estPriseEncompteObjectifReprise = false;
      }
    }
    return estPriseEncompteObjectifReprise;
  }
  
  private Damj rechercheDateFinDelaiDecheance(Demande demande)
  {
    AttributionSpec attributionPrecedente = demande.rechercherAttributionPrecedenteDuMemeType();
    
    return ((ProduitAsuSpec)attributionPrecedente.getProduit()).getDateFinDelaiDecheance(attributionPrecedente, demande);
  }
  
  private void determinerContexteExamenDepuisResultatCalcul(ResultatExecutionCalculSpec resultatCalcul, SituationDemandeur situationDemandeur)
  {
    if (resultatCalcul.getEtatAttribution() == 3)
    {
      situationDemandeur.setEtatReliquat(3);
      situationDemandeur.setCauseNonValidite(resultatCalcul.getEtatAttribution());
    }
    else
    {
      situationDemandeur.setEtatReliquat(2);
      situationDemandeur.setCauseNonValidite(resultatCalcul.getEtatAttribution());
    }
  }
  
  protected void alimenterDernierDvRepriseIPR(SituationDemandeur situationDemandeur, IndividuSpec individu, Damj date)
    throws ApplicativeException
  {
    FiltreET filtreRepriseIPR = new FiltreET();
    FiltreDemandePourERE filtreERE = new FiltreDemandePourERE("ASU_04");
    FiltreRepriseSurDecisions filtreReprise = new FiltreRepriseSurDecisions();
    filtreRepriseIPR.ajouterFiltre(filtreERE);
    filtreRepriseIPR.ajouterFiltre(filtreReprise);
    
    DecisionSpec repriseIPR = OutilRecherche.rechercherDecisionPrecedente(individu.getChronoDemandeAssurance(), date.lendemain(), filtreRepriseIPR);
    if (repriseIPR != null)
    {
      DemandeAssuranceSpec demandeDV = GestionDemandeDv122eJour.retrouverDemandePortantDv(repriseIPR.getDemande());
      ConditionChomageInvolontaireSpec capa = ((DossierExamenAssuranceSpec)demandeDV.getDossierExamen()).getConditionChomageInvolontaire();
      
      String idFct = capa.getIdentifiantActivitePortantDV();
      ActiviteSalarie fct = (ActiviteSalarie)individu.rechercherPeriodePasseProfessionnel(idFct);
      if (fct != null) {
        situationDemandeur.setDateDVprecedantRepriseIPR(fct.getDateFin());
      }
    }
  }
  
  public static Damj calculerDateFinPra(Damj derniereFctConnue, SituationDemandeur situationDemandeur, Damj dateFGDAsuPrecedent)
  {
    Damj dateFinPra = null;
    
    boolean fgdApresFct = (derniereFctConnue != null) && (dateFGDAsuPrecedent != null) && (derniereFctConnue.estApres(dateFGDAsuPrecedent));
    boolean pasDeFgd = (derniereFctConnue != null) && (dateFGDAsuPrecedent == null);
    if ((fgdApresFct) || (pasDeFgd)) {
      dateFinPra = derniereFctConnue;
    } else {
      dateFinPra = situationDemandeur.getDateInscription().veille();
    }
    return dateFinPra;
  }
  
  public static Damj calculerDateDebutPra(ParametreLiquidationSimplifiee parametre, Damj dateFinPra, Damj dateFGDAsuPrecedent)
  {
    Damj dateDebutPra = null;
    int nombreMoisPra = parametre.getNombreMoisPRA();
    if (parametre.getDateDebutPra() != null)
    {
      dateDebutPra = parametre.getDateDebutPra();
    }
    else
    {
      dateDebutPra = dateFinPra.deplacerVersArriere(new DureeCalendaire(0, nombreMoisPra));
      if (dateFGDAsuPrecedent != null) {
        dateDebutPra = Damj.max(dateFGDAsuPrecedent.lendemain(), dateDebutPra);
      }
    }
    return dateDebutPra;
  }
  
  public static String genererTripletteIdentifiantIndividu(ContexteService contexteService)
  {
    StringBuffer sb = new StringBuffer();
    sb.append(contexteService.getAssedicAllocataire());
    sb.append(" ");
    sb.append(contexteService.getRsin());
    sb.append(" ");
    sb.append(contexteService.getCxala());
    
    return sb.toString();
  }
}

/* Location:
 * Qualified Name:     DeterminationSituationDemandeur
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */