package fr.unedic.cali.asu.outilsfonctionnels.prechargement;

import fr.unedic.archi.commun.exception.TechniqueException;
import fr.unedic.archi.logique.persistance.GestionnairePersistance;
import fr.unedic.archi.logique.persistance.Requete;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.outilsfonctionnels.OutilTraitementReliquat;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.affectation.LigneAsuSpe02;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P05;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P06;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.persistance.util.ContextePersistance;
import fr.unedic.cali.dom.pivot.Decision;
import fr.unedic.cali.outilsfonctionnels.ConstructionCSOIA;
import fr.unedic.util.services.ApplicativeRuntimeException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class OutilLectureContexteExamen
  implements OutilFonctionnel
{
  private static final int DELAI_BORNAGE_DATE_EXAMEN = 2;
  private static final int DUREE_NON_ELIGIBILITE_DDE_EXP_SUR_SPECTACLE = 14;
  
  public static OutilLectureContexteExamen getInstance()
  {
    return new OutilLectureContexteExamen();
  }
  
  public Decision recupererAttributionPrecedente(List<Decision> listeDecisionPivot, Damj dateRecherche)
  {
    Decision attributionPrecedente = null;
    for (Decision courante : listeDecisionPivot)
    {
      ProduitSpec produit = recupererProduit(courante);
      if ((!estEnReexamen(courante)) && (courante.getDateEffetDecision().estAvant(dateRecherche)) && (estProduitAsu(produit)) && (estAttributionRACouSP(courante)))
      {
        attributionPrecedente = courante;
        break;
      }
    }
    return attributionPrecedente;
  }
  
  private boolean estAttributionRACouSP(Decision decision)
  {
    return NaturesDecisions.estdeTypeAttribution(decision.getNatureDecision());
  }
  
  public Damj rechercheDateFgdOd(List<Decision> listeDecisionPivot, Damj dateRecherche)
  {
    Damj dateFgdOdPrecedente = null;
    for (Decision courante : listeDecisionPivot)
    {
      ProduitSpec produit = recupererProduit(courante);
      int natureDecision = courante.getNatureDecision();
      if ((courante.getDateEffetDecision().estAvant(dateRecherche)) && (estProduitAsu(produit)) && (NaturesDecisions.estdeTypeOd(natureDecision)))
      {
        dateFgdOdPrecedente = courante.getDateFctFG();
        break;
      }
    }
    return dateFgdOdPrecedente;
  }
  
  public Damj rechercheDateFctDernierRejetDvPostFgd(List<Decision> listeDecisionPivot, Damj dateRecherche, Damj dateFGDOdPrecedente)
  {
    Damj dateFctDernierRejetDv = null;
    Damj borneDebutRecherche;
    Damj borneDebutRecherche;
    if (dateFGDOdPrecedente == null) {
      borneDebutRecherche = Damj.NUIT_DES_TEMPS;
    } else {
      borneDebutRecherche = dateFGDOdPrecedente.lendemain();
    }
    Periode periodeRecherche = new Periode(borneDebutRecherche, dateRecherche.veille());
    for (Decision courante : listeDecisionPivot)
    {
      ProduitSpec produit = recupererProduit(courante);
      if ((courante.getDateEffetDecision().estContenueDans(periodeRecherche)) && (estProduitAsu(produit)) && (estRejetDv(courante)) && (!estUneDemandeIPR(courante)))
      {
        if (estReprise(courante.getReferenceExterneDemande()))
        {
          dateFctDernierRejetDv = courante.getDateFctFG().veille(); break;
        }
        dateFctDernierRejetDv = courante.getDateFctFG();
        
        break;
      }
    }
    dateFctDernierRejetDv = gererCasOdEstExamenIpr(dateFGDOdPrecedente, dateFctDernierRejetDv);
    return dateFctDernierRejetDv;
  }
  
  private Damj gererCasOdEstExamenIpr(Damj dateFGDOdPrecedente, Damj dateFctDernierRejetDv)
  {
    Damj dateARetourner = dateFctDernierRejetDv;
    if ((dateFctDernierRejetDv != null) && (dateFGDOdPrecedente != null) && (dateFctDernierRejetDv.estAvantOuCoincideAvec(dateFGDOdPrecedente))) {
      dateARetourner = null;
    }
    return dateARetourner;
  }
  
  public boolean recherchePresenceReliquatValide(AttributionSpec attribution, Damj dateRecherche)
    throws CoucheLogiqueException
  {
    boolean estReliquatValide = false;
    if (attribution != null)
    {
      AttributionSpec derniereAttributionAssurance = attribution;
      
      Boolean reliquatValide = AppelCalculParLiquidationAsu.determinerReliquatValide(derniereAttributionAssurance, dateRecherche);
      if ((reliquatValide != null) && (reliquatValide.booleanValue()))
      {
        estReliquatValide = reliquatValide.booleanValue();
        if ((!estProduitAttributionSpectacle2016(derniereAttributionAssurance)) && ((attribution instanceof AttributionAssuranceSpec)))
        {
          Periode delaiDecheance = OutilTraitementReliquat.getDelaiDecheance((AttributionAssuranceSpec)derniereAttributionAssurance);
          estReliquatValide = dateRecherche.estContenueDans(delaiDecheance);
        }
      }
    }
    return estReliquatValide;
  }
  
  protected boolean estProduitAttributionSpectacle2016(AttributionSpec derniereAttributionAssurance)
  {
    boolean retour = false;
    if ((derniereAttributionAssurance.getProduit().getCode() == ProduitAsuSpe02P05.getInstance().getCode()) || (derniereAttributionAssurance.getProduit().getCode() == ProduitAsuSpe02P06.getInstance().getCode())) {
      retour = true;
    }
    return retour;
  }
  
  public boolean estReliquatSpectacle(Decision decision, boolean estReliquatValide)
  {
    boolean estProduitSpectacle = false;
    if ((estReliquatValide) && (decision != null))
    {
      ProduitSpec produit = recupererProduit(decision);
      if (ProduitAbstrait.estDuType(6, produit)) {
        estProduitSpectacle = true;
      }
    }
    return estProduitSpectacle;
  }
  
  public boolean recherchePresenceDemandeAttenteDecision(List<Decision> listeDecisionPivot)
  {
    boolean existeAttenteDecision = false;
    for (Decision courante : listeDecisionPivot) {
      if ((estDemandeAsu(courante)) && (estAttenteDecision(courante)))
      {
        existeAttenteDecision = true;
        break;
      }
    }
    return existeAttenteDecision;
  }
  
  public Damj recupererDateExamenDerniereDemandeAssurance(List<Decision> listeDecisionPivot, Damj dateRecherche)
  {
    Damj dateDerniereDecision = null;
    for (Decision courante : listeDecisionPivot)
    {
      ProduitSpec produit = recupererProduit(courante);
      if ((estProduitAsu(produit)) && (estDemandeEligible(courante)) && (courante.getDateEffetDecision().estAvant(dateRecherche)))
      {
        dateDerniereDecision = courante.getDateExamen();
        break;
      }
    }
    Damj dateBorne = bornerDateExamen(dateRecherche);
    if (dateDerniereDecision != null) {
      dateDerniereDecision = Damj.max(dateDerniereDecision, dateBorne);
    }
    return dateDerniereDecision;
  }
  
  public List<Decision> filtrerDemandeClasserOuNonAssurance(List<Decision> listeDecision)
  {
    List<Decision> listeARetourner = new ArrayList();
    for (Decision courante : listeDecision) {
      if ((!estDemandeClassee(courante)) && (estGammeAsu(courante))) {
        listeARetourner.add(courante);
      }
    }
    return listeARetourner;
  }
  
  private boolean estGammeAsu(Decision decision)
  {
    ProduitSpec produit = recupererProduit(decision);
    boolean estGammeAsu;
    boolean estGammeAsu;
    if (produit != null) {
      estGammeAsu = estProduitAsu(produit);
    } else {
      estGammeAsu = estDemandeAsu(decision);
    }
    return estGammeAsu;
  }
  
  private boolean estDemandeClassee(Decision decision)
  {
    return (decision.getClassementAdministratif() != null) && (!"".equals(decision.getClassementAdministratif()));
  }
  
  private boolean estUneDemandeIPR(Decision decision)
  {
    return "Y".equals(decision.getTypeExamen());
  }
  
  private boolean estReprise(String referenceExterne)
  {
    fr.unedic.cali.asu.dom.Demande demandeRejetDv = chargerDemandeAssurance(referenceExterne);
    return NaturesDecisions.estdeTypeReprise(demandeRejetDv.getObjectifDecisionne().getSousType());
  }
  
  private boolean estDemandeEligible(Decision decision)
  {
    List<String> typeExamenExclu = new ArrayList();
    typeExamenExclu.add("T6");
    typeExamenExclu.add("T1");
    typeExamenExclu.add("T4");
    return (!typeExamenExclu.contains(decision.getTypeExamen())) && (!estEnReexamen(decision));
  }
  
  private boolean estEnReexamen(Decision decision)
  {
    return "R".equals(decision.getCodeReexamen());
  }
  
  private boolean estAttenteDecision(Decision decision)
  {
    return (decision.getNatureDecision() == 0) && ((decision.getClassementAdministratif() == null) || ("".equals(decision.getClassementAdministratif())));
  }
  
  private boolean estDemandeAsu(Decision decision)
  {
    return ConstructionCSOIA.estGammeAsu(decision.getTypeExamen());
  }
  
  private ProduitSpec recupererProduit(Decision decision)
  {
    ProduitSpec produit = null;
    if ((decision.getCodeProduit() != null) && (!"".equals(decision.getCodeProduit()))) {
      produit = Parametres.getProduit(decision.getCodeProduit());
    }
    return produit;
  }
  
  private boolean estProduitAsu(ProduitSpec produit)
  {
    return (produit != null) && (GammeAsu.getInstance().getNomUnique().equals(produit.getLigne().getGamme().getNomUnique()));
  }
  
  private boolean estRejetDv(Decision decision)
  {
    boolean estRejet = NaturesDecisions.estdeTypeRejet(decision.getNatureDecision());
    List<Integer> listeEchecCap09 = new ArrayList();
    listeEchecCap09.add(Integer.valueOf(91));
    listeEchecCap09.add(Integer.valueOf(92));
    listeEchecCap09.add(Integer.valueOf(93));
    listeEchecCap09.add(Integer.valueOf(94));
    return (estRejet) && (listeEchecCap09.contains(Integer.valueOf(decision.getMotifRejet())));
  }
  
  protected boolean verifierPresenceDemandeRechargement(Damj dateDerniereAttribution, Damj dateEtude, List<Decision> decisions)
  {
    return verifierPresenceTypeDemandeRecherche(dateDerniereAttribution, dateEtude, decisions, ConstructionCSOIA.getCSOIADepuisTypeExamen("ASU_29"));
  }
  
  protected boolean verifierPresenceDemandeFinDroit(Damj dateDerniereAttribution, Damj dateEtude, List<Decision> decisions)
  {
    return verifierPresenceTypeDemandeRecherche(dateDerniereAttribution, dateEtude, decisions, ConstructionCSOIA.getCSOIADepuisTypeExamen("ASU_08"));
  }
  
  protected boolean verifierPresenceTypeDemandeRecherche(Damj dateDerniereAttribution, Damj dateEtude, List<Decision> decisions, String typeDemande)
  {
    boolean resultat = false;
    Periode periodeRecherche = new Periode(dateDerniereAttribution.lendemain(), dateEtude);
    for (Decision decisionCourante : decisions) {
      if ((periodeRecherche.contient(decisionCourante.getDateEffetDecision())) && (typeDemande.equals(decisionCourante.getTypeExamen())))
      {
        resultat = true;
        break;
      }
    }
    return resultat;
  }
  
  public boolean estUnDroitAMoinsDe15JoursDuTerme(AttributionSpec attribution, Damj dateEtude)
  {
    boolean resultat = false;
    if ((attribution != null) && (attribution.getCalendrierExecutionCalcul() != null) && (attribution.getCalendrierExecutionCalcul().getDernierJourIndemnisable() != null))
    {
      Damj djiTheorique = attribution.getCalendrierExecutionCalcul().getDernierJourIndemnisable();
      resultat = new Periode(djiTheorique.deplacerVersArriere(new DureeCalendaire(0, 0, 14)), djiTheorique).contient(dateEtude);
    }
    return resultat;
  }
  
  public boolean verifierAbsenceDemandeFinDroit(AttributionSpec attribution, Damj dateEtude, List<Decision> decisions)
  {
    boolean resultat = false;
    if (attribution != null)
    {
      ProduitSpec produit = attribution.getProduitExecution();
      if (ProduitAbstrait.estDuType(8, produit)) {
        resultat = !verifierPresenceDemandeRechargement(attribution.getDateAttribution(), dateEtude, decisions);
      } else if (LigneAsuSpe02.getInstance().getNomUnique().equals(produit.getLigne().getNomUnique())) {
        resultat = !verifierPresenceDemandeFinDroit(attribution.getDateAttribution(), dateEtude, decisions);
      }
    }
    return resultat;
  }
  
  public fr.unedic.cali.asu.dom.Demande chargerDemandeAssurance(String referenceExterne)
  {
    demande = null;
    GestionnairePersistance gestionnaire = null;
    Requete requete = null;
    try
    {
      gestionnaire = ContextePersistance.getGestionnairePersistance();
      requete = gestionnaire.getRequete("getDemandeAsuParRefext", fr.unedic.cali.asu.dom.pc.DemandePC.class);
      
      Map parameters = new HashMap();
      String cxass = (String)gestionnaire.getObjetFonctionnel("numassedic");
      Long cxala = (Long)gestionnaire.getObjetFonctionnel("numalloc");
      parameters.put("numassedic", cxass);
      parameters.put("numalloc", cxala);
      parameters.put("referenceExterne", referenceExterne);
      
      Collection res = (Collection)requete.executer(parameters);
      
      Iterator iterator = res.iterator();
      fr.unedic.cali.asu.dom.pc.DemandePC demandePC;
      if (iterator.hasNext()) {
        demandePC = (fr.unedic.cali.asu.dom.pc.DemandePC)iterator.next();
      }
      return (fr.unedic.cali.asu.dom.Demande)demandePC.createOM();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_DOM_MANAGER", "Erreur lors de l'appel du DomManager : chargerDemandeAssurance()", e);
    }
    finally
    {
      try
      {
        if (requete != null) {
          requete.liberer();
        }
      }
      catch (TechniqueException e)
      {
        throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_DOM_MANAGER", "Erreur lors de l'appel du DomManager : chargerDemandeAssurance()", e);
      }
    }
  }
  
  public fr.unedic.cali.ari.dom.Demande chargerDemandeAri(String demandeId)
  {
    demande = null;
    GestionnairePersistance gestionnaire = null;
    Requete requete = null;
    try
    {
      gestionnaire = ContextePersistance.getGestionnairePersistance();
      requete = gestionnaire.getRequete("getDemandeAriParId", fr.unedic.cali.ari.dom.pc.DemandePC.class);
      
      Map parameters = new HashMap();
      String cxass = (String)gestionnaire.getObjetFonctionnel("numassedic");
      Long cxala = (Long)gestionnaire.getObjetFonctionnel("numalloc");
      parameters.put("numassedic", cxass);
      parameters.put("numalloc", cxala);
      parameters.put("demandeid", Long.valueOf(demandeId));
      
      Collection res = (Collection)requete.executer(parameters);
      
      Iterator iterator = res.iterator();
      fr.unedic.cali.ari.dom.pc.DemandePC demandePC;
      if (iterator.hasNext()) {
        demandePC = (fr.unedic.cali.ari.dom.pc.DemandePC)iterator.next();
      }
      return (fr.unedic.cali.ari.dom.Demande)demandePC.createOM();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_DOM_MANAGER", "Erreur lors de l'appel du DomManager : chargerDemandeAri()", e);
    }
    finally
    {
      try
      {
        if (requete != null) {
          requete.liberer();
        }
      }
      catch (TechniqueException e)
      {
        throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_DOM_MANAGER", "Erreur lors de l'appel du DomManager : chargerDemandeAri()", e);
      }
    }
  }
  
  private Damj bornerDateExamen(Damj dateRecherche)
  {
    Damj retour = dateRecherche;
    if ((dateRecherche.getMois() == 2) && (dateRecherche.getJour() == 29)) {
      retour = retour.veille();
    }
    retour = retour.deplacerVersArriere(new DureeCalendaire(2));
    return retour;
  }
}

/* Location:
 * Qualified Name:     OutilLectureContexteExamen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */