package fr.unedic.cali.asu.outilsfonctionnels.strategies;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.OdAssuranceSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionAssurance;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import java.util.Collection;
import java.util.Iterator;

public class StrategieDroitOptionApresARE14
  implements StrategieDroitOptionSpec
{
  public boolean estDroitOptionReadmissionPossible(Demande demande)
  {
    boolean retour = false;
    ActiviteSalarie fctRetenue = null;
    
    int sousTypeReprise = 3;
    for (Iterator iter = demande.getListeObjectifsExamen().iterator(); iter.hasNext();)
    {
      ObjectifExamen objectif = (ObjectifExamen)iter.next();
      if (objectif.getNumeroOrdre() == 1) {
        sousTypeReprise = objectif.getSousType();
      }
    }
    boolean aspDcPapDc = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 9);
    if ((estSousTypeAccepte(sousTypeReprise)) && (!aspDcPapDc)) {
      if (demande.getAttribution() != null) {
        fctRetenue = traitementReprise(demande);
      } else {
        fctRetenue = traitementRejetDV(demande);
      }
    }
    if ((fctRetenue != null) && (estApprenti(fctRetenue))) {
      retour = true;
    }
    return retour;
  }
  
  private boolean estSousTypeAccepte(int sousType)
  {
    return (sousType == 14) || (sousType == 15) || (sousType == 47) || (sousType == 48);
  }
  
  public boolean estDetectionAutoDroitOption(Demande demande)
  {
    ActiviteSalarie fctRetenue = null;
    boolean estApprenti = false;
    
    fr.unedic.cali.dom.AttributionAssuranceSpec attributionPrecedente = (fr.unedic.cali.dom.AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, new FiltreAttributionAssurance(false, true, false, true, demande));
    if (attributionPrecedente != null)
    {
      ValidationProduit validationProduit = ((DossierAffectation)attributionPrecedente.getOuvertureDroit().getDossierAffecte()).getValidationProduit();
      if (validationProduit != null) {
        fctRetenue = validationProduit.getPeriodeValidationProduit();
      }
    }
    if ((fctRetenue != null) && (estApprenti(fctRetenue))) {
      estApprenti = true;
    }
    return estApprenti;
  }
  
  private ActiviteSalarie traitementReprise(Demande demande)
  {
    ActiviteSalarie fctRetenue = null;
    ValidationProduit validationProduit = ((DossierAffectation)demande.getAttribution().getOuvertureDroit().getDossierAffecte()).getValidationProduit();
    if (validationProduit != null) {
      fctRetenue = validationProduit.getPeriodeValidationProduit();
    }
    return fctRetenue;
  }
  
  private ActiviteSalarie traitementRejetDV(Demande demande)
  {
    ActiviteSalarie fctRetenue = null;
    
    fr.unedic.cali.dom.AttributionAssuranceSpec attributionPrecedente = (fr.unedic.cali.dom.AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, new FiltreAttributionAssurance(false, true, false, true, demande));
    
    ValidationProduit validationProduit = ((DossierAffectation)attributionPrecedente.getOuvertureDroit().getDossierAffecte()).getValidationProduit();
    if (validationProduit != null) {
      fctRetenue = validationProduit.getPeriodeValidationProduit();
    }
    return fctRetenue;
  }
  
  public static boolean estApprenti(ActiviteSalarie fctRetenue)
  {
    boolean retour = false;
    int typeContrat = fctRetenue.getContratTypeParticulier();
    switch (typeContrat)
    {
    case 1: 
    case 2: 
    case 19: 
      retour = true;
      break;
    }
    return retour;
  }
}

/* Location:
 * Qualified Name:     StrategieDroitOptionApresARE14
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */