package fr.unedic.cali.asu.outilsfonctionnels.strategies;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionISLR;
import fr.unedic.cali.autresdoms.ga.dom.Indemnite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteMonnaie;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class StrategieIslrAvantMEP08SI1
  extends ConstitutionISLR
  implements StrategieIslrSpec
{
  public QuantiteEuro calculeISLR(Collection p_listeIndemnites, int p_codeMotifRuptureCT, int p_categorieEmploiParticulier, Damj p_dateFaitGenerateurOuDernierSinistre)
    throws CoucheLogiqueException
  {
    QuantiteEuro retourISLR = new QuantiteEuro("0");
    if (p_listeIndemnites == null) {
      return retourISLR;
    }
    BigDecimal montantTOT = null;
    BigDecimal montantI = null;
    BigDecimal montantL = null;
    BigDecimal montantE = null;
    BigDecimal montantSL = null;
    BigDecimal montantC = null;
    BigDecimal montantT = null;
    BigDecimal montantRe = null;
    BigDecimal montantRs = null;
    BigDecimal montantFm = null;
    BigDecimal montantRi = null;
    BigDecimal montantRmat = null;
    BigDecimal montantRmar = null;
    BigDecimal montantRj = null;
    BigDecimal montantRvrp = null;
    BigDecimal montantRpnac = null;
    BigDecimal montantRapp = null;
    BigDecimal montantRaut = null;
    
    BigDecimal montantFCDouFMIouCNE = null;
    
    boolean presenceIndemnitesRuptureSpecifiquesHormisVRP = false;
    for (Iterator it = p_listeIndemnites.iterator(); it.hasNext();)
    {
      Indemnite indemnite = (Indemnite)it.next();
      int typeIndemnite = Integer.valueOf(indemnite.getTypeIndemnite()).intValue();
      if (indemnite.getMontant() != null) {
        switch (typeIndemnite)
        {
        case 1: 
          break;
        case 5: 
          montantTOT = indemnite.getMontant().getValeurMontant();
          break;
        case 7: 
          montantI = indemnite.getMontant().getValeurMontant();
          break;
        case 6: 
          montantE = indemnite.getMontant().getValeurMontant();
          break;
        case 3: 
          montantC = indemnite.getMontant().getValeurMontant();
          break;
        case 4: 
          montantT = indemnite.getMontant().getValeurMontant();
          break;
        case 101: 
          montantL = indemnite.getMontant().getValeurMontant();
          break;
        case 102: 
          montantSL = indemnite.getMontant().getValeurMontant();
          break;
        case 105: 
          if (p_codeMotifRuptureCT == 17) {
            montantRe = indemnite.getMontant().getValeurMontant();
          } else if (p_codeMotifRuptureCT == 18) {
            montantRs = indemnite.getMontant().getValeurMontant();
          }
          presenceIndemnitesRuptureSpecifiquesHormisVRP = true;
          break;
        case 106: 
          if (p_codeMotifRuptureCT == 11) {
            montantFm = indemnite.getMontant().getValeurMontant();
          }
          presenceIndemnitesRuptureSpecifiquesHormisVRP = true;
          break;
        case 107: 
          if (p_codeMotifRuptureCT == 26) {
            montantRi = indemnite.getMontant().getValeurMontant();
          }
          presenceIndemnitesRuptureSpecifiquesHormisVRP = true;
          break;
        case 108: 
          if (p_categorieEmploiParticulier == 22) {
            montantRmat = indemnite.getMontant().getValeurMontant();
          } else if (p_categorieEmploiParticulier == 37) {
            montantRmar = indemnite.getMontant().getValeurMontant();
          }
          presenceIndemnitesRuptureSpecifiquesHormisVRP = true;
          break;
        case 109: 
          if (p_categorieEmploiParticulier == 36) {
            montantRj = indemnite.getMontant().getValeurMontant();
          }
          presenceIndemnitesRuptureSpecifiquesHormisVRP = true;
          break;
        case 110: 
          if (p_categorieEmploiParticulier == 46) {
            montantRvrp = indemnite.getMontant().getValeurMontant();
          }
          break;
        case 111: 
          montantRpnac = indemnite.getMontant().getValeurMontant();
          presenceIndemnitesRuptureSpecifiquesHormisVRP = true;
          break;
        case 112: 
          montantRapp = indemnite.getMontant().getValeurMontant();
          presenceIndemnitesRuptureSpecifiquesHormisVRP = true;
          break;
        case 113: 
          montantRaut = indemnite.getMontant().getValeurMontant();
          presenceIndemnitesRuptureSpecifiquesHormisVRP = true;
          break;
        case 103: 
        case 104: 
        case 122: 
          montantFCDouFMIouCNE = indemnite.getMontant().getValeurMontant();
          presenceIndemnitesRuptureSpecifiquesHormisVRP = true;
          break;
        default: 
          if (Log.isTraceActive(ConstitutionISLR.class, Niveau.DEBUG)) {
            Log.ecritTrace(Niveau.DEBUG, ConstitutionISLR.class, "calculeISLR", "Type indemnite non traité: " + indemnite.getTypeIndemnite());
          }
          break;
        }
      }
    }
    BigDecimal valeurZero = new BigDecimal("0");
    if (montantI != null)
    {
      if (montantTOT != null)
      {
        if ((!presenceIndemnitesRuptureSpecifiquesHormisVRP) && (montantRvrp == null) && (montantL == null) && (montantSL == null) && (montantC == null) && (montantT != null)) {
          retourISLR = new QuantiteEuro(montantT);
        } else {
          retourISLR = new QuantiteEuro(valeurZero.max(montantTOT.subtract(montantI)));
        }
      }
      else {
        retourISLR = new QuantiteEuro("0");
      }
    }
    else
    {
      if (montantRpnac != null)
      {
        if (montantT != null) {
          retourISLR = new QuantiteEuro(montantT);
        } else {
          retourISLR = new QuantiteEuro("0");
        }
      }
      else if (montantRapp != null)
      {
        if (montantT != null) {
          retourISLR = new QuantiteEuro(montantT);
        } else {
          retourISLR = new QuantiteEuro("0");
        }
      }
      else if (montantRe != null) {
        retourISLR = calculeISLRUnitaireStandard(montantE, montantTOT, montantRe);
      } else if (montantRs != null) {
        retourISLR = calculeISLRUnitaireStandard(montantE, montantTOT, montantRs);
      } else if (montantFm != null) {
        retourISLR = calculeISLRUnitaireStandard(montantE, montantTOT, montantFm);
      } else if (montantRi != null) {
        retourISLR = calculeISLRUnitaireStandard(montantE, montantTOT, montantRi);
      } else if (montantRmat != null) {
        retourISLR = calculeISLRUnitaireCasAssistanteMaternelle(montantE, montantTOT, montantRmat);
      } else if (montantRmar != null) {
        retourISLR = calculeISLRUnitaireStandard(montantE, montantTOT, montantRmar);
      } else if (montantRj != null) {
        retourISLR = calculeISLRUnitaireStandard(montantE, montantTOT, montantRj);
      } else if (montantFCDouFMIouCNE != null) {
        retourISLR = calculeISLRPourFCDouFMIouCNE(montantTOT, montantFCDouFMIouCNE);
      } else if (montantRaut != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CEPA05_AUTRES_INDEMNITES_LEGALES");
      }
      if (montantRvrp != null) {
        if (montantT != null) {
          retourISLR = new QuantiteEuro(montantT);
        } else {
          retourISLR = new QuantiteEuro("0");
        }
      }
      if (!presenceIndemnitesRuptureSpecifiquesHormisVRP)
      {
        if ((montantTOT != null) && (montantTOT.intValue() > 0)) {
          if (montantE == null) {
            retourISLR = new QuantiteEuro(montantTOT);
          } else {
            retourISLR = new QuantiteEuro(valeurZero.max(montantTOT.subtract(montantE)));
          }
        }
        if ((montantL != null) || (montantSL != null) || (montantC != null) || (montantT != null)) {
          retourISLR = determinerMontantIslrSurValeursMontantsLSLCT(montantE, montantL, montantSL, montantC, montantT, p_dateFaitGenerateurOuDernierSinistre);
        }
      }
    }
    return retourISLR;
  }
}

/* Location:
 * Qualified Name:     StrategieIslrAvantMEP08SI1
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */