package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.LigneAsuSpe02;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P05;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class AffectationDemandeASUSpectacleClauseRattrapage
  extends ParcoursAffectationDemandeAssurance
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = getDemande(contexte);
    DossierAffectation dossierAffectation = preTraitementAffectationDemandeAsu(demande);
    
    Chronologie chronoPeriodesParticipantesRechercherDernierSinistre = RechercherDernierSinistre.determinerChronologieActivitesRechercheDernierSinistre(demande);
    
    boolean estDernierSinistreTrouve = rechercherDernierSinistre(demande, chronoPeriodesParticipantesRechercherDernierSinistre);
    ActiviteSalarie fctRetenueForcee = (ActiviteSalarie)demande.getDonneesTemporaires().getPeriodeFctARetenir();
    if (estDernierSinistreTrouve)
    {
      TravailSpec dernierSinistre = dossierAffectation.getSinistre();
      
      boolean estDernierSinistreAvantApplicationSpe16 = estDernierSinistreAvantApplicationSpe16(dernierSinistre.getDateFin());
      if (estDernierSinistreAvantApplicationSpe16) {
        recupererDecorReglementaireAvantApplicationSpe16(demande, dossierAffectation, dernierSinistre);
      } else {
        recupererDecorReglementaire(dossierAffectation);
      }
      ProduitAsuSpec produitDernierSinistre = recupererProduitSpectacle(dossierAffectation.getDecorReglementaire());
      fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit validationProduit;
      fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit validationProduit;
      if (fctRetenueForcee != null) {
        validationProduit = (fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit)produitDernierSinistre.obtenirValidationProduit(fctRetenueForcee, demande.getDemandeur(), demande, false);
      } else {
        validationProduit = (fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit)produitDernierSinistre.obtenirValidationProduit((ActiviteSalarie)dernierSinistre, demande.getDemandeur(), demande, false);
      }
      dossierAffectation.setValidationProduit(validationProduit);
      if (!dossierAffectation.getValidationProduit().isEstProduitValide())
      {
        dossierAffectation.setProduitSecours(produitDernierSinistre);
        dossierAffectation.setCodeProduitSecours(produitDernierSinistre.getCode());
      }
    }
    else
    {
      ProduitAsuSpec produit = determinerProduitParDefaut(demande);
      dossierAffectation.setProduitSecours(produit);
      dossierAffectation.setCodeProduitSecours(produit.getCode());
    }
    return new Resultat(0);
  }
  
  private ProduitAsuSpec recupererProduitSpectacle(DecorReglementaire decor)
  {
    return (ProduitAsuSpec)decor.determinerProduitEffectifDeLaLigne(LigneAsuSpe02.getInstance());
  }
  
  private void recupererDecorReglementaireAvantApplicationSpe16(Demande demande, DossierAffectation dossierAffectation, TravailSpec dernierSinistre)
    throws CoucheLogiqueException
  {
    ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
    conteneur.setDateRecherche(demande.getDateExamen());
    conteneur.setDateFinContrat(demande.getDateExamen());
    conteneur.setBesoinCritereQualif(true);
    conteneur.setDernierSinistre(dernierSinistre);
    conteneur.setDemande(demande);
    dossierAffectation.setDecorReglementaire(ConstitutionDecorReglementaire.recupererDecor(conteneur));
  }
  
  private boolean estDernierSinistreAvantApplicationSpe16(Damj dateFinDernierSinistre)
  {
    Damj dateDebutSpectacle16 = ProduitAsuSpe02P05.getInstance().getPeriodeValidite().getDebut();
    return dateDebutSpectacle16.estApres(dateFinDernierSinistre);
  }
  
  protected void bornerPraFaitGenerateurOdPrecedente(Periode pra, Damj dateFaitGenerateurOdPrecedente)
  {
    if ((dateFaitGenerateurOdPrecedente != null) && (pra.getDebut().estAvantOuCoincideAvec(dateFaitGenerateurOdPrecedente))) {
      pra.setDebut(dateFaitGenerateurOdPrecedente.lendemain());
    }
  }
}

/* Location:
 * Qualified Name:     AffectationDemandeASUSpectacleClauseRattrapage
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */