package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.fabriques.FabriqueAffectationDemandeAsp;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.asu.outilsfonctionnels.ControleAlertesBloquantesReglementsNonGeres;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieAffectationDemandeAspSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.ProduitAsuCaa14P03;
import fr.unedic.cali.dom.affectation.ProduitAsuCva10P03;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutilActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteNonSalariee;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeHorsChamp;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesCertifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesDeclarees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSpec;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.util.List;

public abstract class AffectationDemandeCvaCaa
  extends AffectationDemandeASUClassique
{
  protected abstract ProduitAsuSpec recupererProduitActif();
  
  protected abstract ProduitAsuSpec affecterProduitCaa(Damj paramDamj)
    throws CoucheLogiqueException;
  
  protected abstract ProduitAsuSpec affecterProduitCva(Damj paramDamj)
    throws CoucheLogiqueException;
  
  protected abstract boolean verifierAncienneteSuffisante(DemandeAssuranceSpec paramDemandeAssuranceSpec, TravailSpec paramTravailSpec, Damj paramDamj)
    throws CoucheLogiqueException;
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    getDemande(contexte).getDemandeur().desactiverExclusionChronoPasseProPourLiquidationFCTRevision();
    affecterDemandeCvaCaa(contexte);
    getDemande(contexte).getDemandeur().reactiverExclusionChronoPasseProPourLiquidationFCTRevision();
    
    miseAJourChronoExclusionPasseProPourLiquidationFCTRevision(contexte);
    
    OutilTrace.tracerFinParcours();
    
    return new Resultat(0);
  }
  
  private void affecterDemandeCvaCaa(Contexte contexte)
    throws ApplicativeException
  {
    Demande demandeAssuranceExistante = getDemande(contexte);
    DossierAffectation dossierAffectation = preTraitementAffectationDemandeAsu(demandeAssuranceExistante);
    if ((demandeAssuranceExistante.getDonneesDemandeAssociee() != null) && (demandeAssuranceExistante.getDonneesDemandeAssociee().getDemandeAssociee() != null)) {
      demandeAssuranceExistante.removeDonneesDemandeAssociee();
    }
    Chronologie chronoPeriodesParticipantesRechercherDernierSinistre = RechercherDernierSinistre.determinerChronologieActivitesRechercheDernierSinistre(demandeAssuranceExistante);
    
    boolean estDernierSinistre = rechercherDernierSinistre(demandeAssuranceExistante, chronoPeriodesParticipantesRechercherDernierSinistre);
    
    TravailSpec dernierSinistre = dossierAffectation.getSinistre();
    
    dossierAffectation.setJustificationAffectation(1);
    if (estDernierSinistre)
    {
      verifierDernierSinistreEnConflit(dernierSinistre);
      
      verifierDernierAuAtteste(dernierSinistre);
      
      leverAlertes(dernierSinistre, demandeAssuranceExistante);
      
      boolean dernierSinistreNeProposePasDecor = false;
      if (dossierAffectation.getDecorReglementaire() == null)
      {
        dossierAffectation.setDecorReglementaire(ConstitutionDecorReglementaire.recupererDecor((DossierAffectation)demandeAssuranceExistante.getDossierAffectation()));
        dernierSinistreNeProposePasDecor = true;
      }
      if (!dernierSinistreNeProposePasDecor) {
        lancerAlerteDernierSinistreProposeDecor(dossierAffectation);
      }
    }
    DureeCalendaire delaiAllongementExistant = new DureeCalendaire();
    
    ProduitAsuSpec produit = determinerProduitRelatifAuSinistre(dernierSinistre, dossierAffectation);
    if (((dernierSinistre instanceof ActiviteSalarie)) && (!produit.contientReglement(((ActiviteSalarie)dernierSinistre).getReglement()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ERR_ASP_REGLEMENT_NON_GERE", new Object[] { ((ActiviteSalarie)dernierSinistre).getReglement().getLibelleCourt() });
    }
    determinerDelaiRecherche(dossierAffectation, delaiAllongementExistant, produit);
    
    verifierExistanceDernierAu(dossierAffectation, estDernierSinistre);
    if (estDernierSinistre)
    {
      Chronologie chronoPeriodesParticipantesValidationProduit = RechercherDernierSinistre.determinerChronologieActivitesRechercheDernierSinistre(demandeAssuranceExistante);
      
      validerProduit(demandeAssuranceExistante, chronoPeriodesParticipantesValidationProduit, produit);
    }
    if (dossierAffectation.getProduit() == null) {
      dossierAffectation.setProduitSecours(produit);
    }
  }
  
  private void verifierDernierSinistreEnConflit(TravailSpec dernierSinistre)
    throws CoucheLogiqueException
  {
    if (dernierSinistre.estEnConflit()) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A6MB1");
    }
  }
  
  public Damj determinerDateRechercheDecor(TravailSpec dernierSinistre, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    Damj dateRechercheDecor = demande.getDateExamen();
    if (dernierSinistre != null)
    {
      dateRechercheDecor = dernierSinistre.getDateFin();
      if ((dernierSinistre instanceof ActiviteSalarie))
      {
        ActiviteSalarie activite = (ActiviteSalarie)dernierSinistre;
        if ((activite.getDateEngagementProcedureLicenciement() != null) && (activite.getDateEngagementProcedureLicenciement().estApresOuCoincideAvec(recupererProduitActif().getPeriodeValidite().getDebut()))) {
          dateRechercheDecor = activite.getDateEngagementProcedureLicenciement();
        }
      }
    }
    return dateRechercheDecor;
  }
  
  protected void leverAlertes(TravailSpec dernierSinistre, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    if ((dernierSinistre instanceof ActiviteSalarie))
    {
      ActiviteSalarie activite = (ActiviteSalarie)dernierSinistre;
      if (activite.getDateEngagementProcedureLicenciement() != null)
      {
        if (activite.getDateEngagementProcedureLicenciement().estAvant(recupererProduitActif().getPeriodeValidite().getDebut())) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("PR_CALI_L_ALERTE_A6MB7", new Object[] { recupererProduitActif().getPeriodeValidite().getDebut() });
        }
      }
      else if (activite.getDateFin().estAvant(recupererProduitActif().getPeriodeValidite().getDebut())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("PR_CALI_L_ALERTE_A6MB8", new Object[] { recupererProduitActif().getPeriodeValidite().getDebut() });
      }
    }
  }
  
  protected void validerProduit(DemandeAssuranceSpec demandeAsuCourante, Chronologie chronoPeriodesParticipantes, ProduitAsuSpec produitDernierSinistre)
    throws ApplicativeException
  {
    DossierAffectation dossierAffectationCourant = (DossierAffectation)demandeAsuCourante.getDossierAffectation();
    
    TravailSpec periodeFctForcee = demandeAsuCourante.getDonneesTemporaires().getPeriodeFctARetenir();
    if (periodeFctForcee != null) {
      gestionFctForcee(periodeFctForcee, dossierAffectationCourant, demandeAsuCourante);
    } else {
      validerProduitFct(demandeAsuCourante, dossierAffectationCourant.getSinistre());
    }
  }
  
  protected boolean validerProduitFct(DemandeAssuranceSpec demandeAsuCourante, TravailSpec periodeFct)
    throws ApplicativeException
  {
    boolean produitAffecte = false;
    
    DossierAffectation dossierAffectationCourant = (DossierAffectation)demandeAsuCourante.getDossierAffectation();
    
    ProduitAsuSpec produitRelatifFctCourante = determinerProduitRelatifAuSinistre(periodeFct, dossierAffectationCourant);
    
    verifierPeriodeCertifieEnConflit(periodeFct);
    
    leverAlerteEtudeMandataire(demandeAsuCourante, periodeFct);
    if ((periodeFct instanceof ActiviteSalarie))
    {
      verifierPopulationsNonTraitees((ActiviteSalarie)periodeFct);
      ControleAlertesBloquantesReglementsNonGeres.controleFctEtudiee((ActiviteSalarie)periodeFct);
      
      ValidationProduit validationProduit = (ValidationProduit)produitRelatifFctCourante.obtenirValidationProduit((ActiviteSalarie)periodeFct, demandeAsuCourante.getDemandeur(), demandeAsuCourante, false);
      if ((validationProduit != null) && (validationProduit.isEstProduitValide()))
      {
        dossierAffectationCourant.setJustificationAffectation(1);
        validationProduit.setProduitValide(produitRelatifFctCourante);
        produitAffecte = true;
        
        dossierAffectationCourant.setValidationProduit(validationProduit);
      }
      else
      {
        traiterValidationProduitKO(validationProduit, dossierAffectationCourant, produitRelatifFctCourante, demandeAsuCourante, periodeFct);
        
        produitAffecte = false;
        
        verifierReglesNonConnuesPeriodesPraLaPlusLongue(demandeAsuCourante, (ActiviteSalarie)periodeFct);
      }
      if (((validationProduit == null) || (!validationProduit.isEstProduitValide())) && ((dossierAffectationCourant.getSinistre() instanceof ActiviteSalarie)) && (((Demande)demandeAsuCourante).getContexteAffiliationValide() != null))
      {
        validationProduit = new ValidationProduit();
        validationProduit.setPeriodeValidationProduit((ActiviteSalarie)dossierAffectationCourant.getSinistre());
        dossierAffectationCourant.setValidationProduit(validationProduit);
      }
    }
    return produitAffecte;
  }
  
  protected void traiterValidationProduitKO(ValidationProduit validationProduit, DossierAffectation dossierAffectationCourant, ProduitAsuSpec produitRelatifFctCourante, DemandeAssuranceSpec demandeAsuCourante, TravailSpec periodeFct)
    throws ApplicativeException
  {
    if (validationProduit != null) {
      dossierAffectationCourant.setValidationProduit(validationProduit);
    }
    validationProduit = (ValidationProduit)produitRelatifFctCourante.obtenirValidationProduit((ActiviteSalarie)periodeFct, demandeAsuCourante.getDemandeur(), demandeAsuCourante, true);
    if ((validationProduit != null) && (validationProduit.isEstProduitValide()))
    {
      FiltresTemporel listeFiltresDernierePNA = new FiltresTemporel();
      listeFiltresDernierePNA.ajouterFiltre(new FiltreFinAvantOuCoincideAvecDate(periodeFct.getDateFin()));
      listeFiltresDernierePNA.ajouterFiltre(new FiltrePeriodesAttestees(false));
      Chronologie listePNA = demandeAsuCourante.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(listeFiltresDernierePNA);
      
      Temporel periodeNonAttesteeRetenue = listePNA.dernierElement();
      
      Damj dateFCTDamj = periodeNonAttesteeRetenue.getDateFin();
      String dateFCTString = "ouverte";
      if (!dateFCTDamj.equals(Damj.FIN_DES_TEMPS)) {
        dateFCTString = "du " + dateFCTDamj.formater();
      }
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB5", new String[] { dateFCTString });
    }
    else if (validationProduit != null)
    {
      dossierAffectationCourant.setValidationProduit(validationProduit);
    }
    verifierOriginePeriodesPraLaPlusLongue(demandeAsuCourante, (ActiviteSalarie)periodeFct);
  }
  
  protected ProduitAsuSpec determinerProduitRelatifAuSinistre(TravailSpec sinistre, DossierAffectation dossierAffectationCourant)
    throws CoucheLogiqueException
  {
    Damj dateRechercheDecor = determinerDateRechercheDecor(sinistre, dossierAffectationCourant.getDemande());
    
    return affecterProduit(dateRechercheDecor, sinistre, (DemandeAssuranceSpec)dossierAffectationCourant.getDemande());
  }
  
  protected ProduitAsuSpec affecterProduit(Damj dateRechercheDecor, TravailSpec dernierSinistre, DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    boolean estProduitReglementaireCva = (dateRechercheDecor != null) && (dernierSinistre != null) && (verifierAncienneteSuffisante(demande, dernierSinistre, dateRechercheDecor));
    
    boolean estDernierSinistrePap = ((dernierSinistre instanceof ActiviteSalarie)) && (OutilActiviteSalarie.getInstance().estAeMotifRupturePap((ActiviteSalarie)dernierSinistre));
    
    ProduitAsuSpec produitCaa14P03 = ProduitAsuCaa14P03.getInstance();
    ProduitAsuSpec produitCva10P03 = ProduitAsuCva10P03.getInstance();
    GammeAsu gameAsu = GammeAsu.getInstance();
    
    boolean estProduitAspCgeActif = (gameAsu.getProduitsActifs(dateRechercheDecor).contains(produitCaa14P03)) || (gameAsu.getProduitsActifs(dateRechercheDecor).contains(produitCva10P03));
    
    FabriqueAffectationDemandeAsp fabrique = new FabriqueAffectationDemandeAsp();
    CritereStrategie criteres = new CritereStrategie();
    criteres.setDatePivot(demande.getDateExamen());
    StrategieAffectationDemandeAspSpec strategie = (StrategieAffectationDemandeAspSpec)fabrique.getStrategie(criteres);
    
    boolean affectationProduitCgePossible = strategie.produitCgeAutorise((Demande)demande);
    ProduitAsuSpec produit;
    ProduitAsuSpec produit;
    if (estProduitReglementaireCva) {
      produit = trouverProduitPourProduitReglementaireCva(estProduitAspCgeActif, affectationProduitCgePossible, dateRechercheDecor, demande, estDernierSinistrePap);
    } else {
      produit = trouverProduitPourProduitReglementaireCaa(estProduitAspCgeActif, affectationProduitCgePossible, dateRechercheDecor, demande, estDernierSinistrePap);
    }
    return produit;
  }
  
  protected ProduitAsuSpec trouverProduitPourProduitReglementaireCaa(boolean estProduitAspCgeActif, boolean affectationProduitCgePossible, Damj dateRechercheDecor, DemandeAssuranceSpec demande, boolean estDernierSinistrePap)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produit;
    if (affectationProduitCgePossible)
    {
      ProduitAsuSpec produit = affecterProduitCge(dateRechercheDecor, demande);
      if (estDernierSinistrePap) {
        ajouterContexteDemande(demande, "PAPARE");
      } else {
        ajouterContexteDemande(demande, "ASPARE");
      }
    }
    else
    {
      produit = affecterProduitCaa(dateRechercheDecor);
    }
    return produit;
  }
  
  private void ajouterContexteDemande(DemandeAssuranceSpec demande, String contexteRelatifAuProduit)
  {
    ContexteDemande contexte = new ContexteDemande();
    contexte.setTypeContexteDemande(contexteRelatifAuProduit);
    if (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, contexteRelatifAuProduit)) {
      demande.ajouterContexteDemande(contexte);
    }
  }
  
  protected ProduitAsuSpec trouverProduitPourProduitReglementaireCva(boolean estProduitAspCgeActif, boolean affectationProduitCgePossible, Damj dateRechercheDecor, DemandeAssuranceSpec demande, boolean estDernierSinistrePap)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produit;
    if ((estProduitAspCgeActif) && (affectationProduitCgePossible))
    {
      ProduitAsuSpec produit = affecterProduitCge(dateRechercheDecor, demande);
      if (estDernierSinistrePap) {
        ajouterContexteDemande(demande, "PAPDC");
      } else {
        ajouterContexteDemande(demande, "ASPDC");
      }
    }
    else
    {
      produit = affecterProduitCva(dateRechercheDecor);
    }
    return produit;
  }
  
  protected ProduitAsuSpec affecterProduitCge(Damj pDateRechercheDecor, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
    
    conteneur.setDemande(demande);
    conteneur.setDateRecherche(pDateRechercheDecor);
    conteneur.setDateFinContrat(pDateRechercheDecor);
    DecorReglementaire decor = ConstitutionDecorReglementaire.recupererDecor(conteneur);
    return (ProduitAsuSpec)decor.getProduitParDefaut();
  }
  
  protected abstract void verifierDernierAuAtteste(TravailSpec paramTravailSpec)
    throws CoucheLogiqueException;
  
  protected void verifierExistanceDernierAu(DossierAffectation dossierAffectation, boolean estDernierSinistre)
    throws CoucheLogiqueException
  {
    if ((!seulementChronoActivitesHorsChampDansDelai(dossierAffectation.getDemande())) && (!estDernierSinistre)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A6MB5", new String[] { dossierAffectation.getDemande().getDateExamen().toString() });
    }
  }
  
  public static boolean seulementChronoActivitesHorsChampDansDelai(DemandeSpec demande)
  {
    FiltrePeriodesSurFiltresExclusifs filtresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    
    FiltresTemporel filtresTravailSalarieNonSalarie = new FiltresTemporel();
    filtresTravailSalarieNonSalarie.ajouterFiltre(new FiltrePeriodesCertifiees());
    filtresExclusifs.ajouterFiltre(filtresTravailSalarieNonSalarie);
    
    FiltresTemporel filtresDeclareTravail = new FiltresTemporel();
    filtresDeclareTravail.ajouterFiltre(new FiltrePeriodesDeclarees());
    filtresDeclareTravail.ajouterFiltre(new FiltreTravailSpec());
    filtresExclusifs.ajouterFiltre(filtresDeclareTravail);
    
    Chronologie chronoActivitesParticipantes = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtresExclusifs);
    
    chronoActivitesParticipantes = chronoActivitesParticipantes.copier(new FiltreFinAvantOuCoincideAvecDate(demande.getDateExamen()));
    
    Chronologie chronoActivitesParticipantesDansDelai = null;
    
    DelaiRechercheProduit periodeDelaiForclusion = ((DossierAffectation)demande.getDossierAffectation()).getDelaiRecherche();
    if (periodeDelaiForclusion != null) {
      chronoActivitesParticipantesDansDelai = chronoActivitesParticipantes.copier(new FiltreFinDansBornes(periodeDelaiForclusion));
    }
    Chronologie chronoActivitesHorsChampDansDelai = null;
    
    filtresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    FiltreTemporel filtreActiviteSalarieHorsChamp = new FiltrePeriodeActiviteSalarieeHorsChamp();
    filtresExclusifs.ajouterFiltre(filtreActiviteSalarieHorsChamp);
    FiltreTemporel filtreActiviteNonSalarie = new FiltrePeriodeActiviteNonSalariee();
    filtresExclusifs.ajouterFiltre(filtreActiviteNonSalarie);
    if (chronoActivitesParticipantesDansDelai != null) {
      chronoActivitesHorsChampDansDelai = chronoActivitesParticipantesDansDelai.copier(filtresExclusifs);
    }
    return (chronoActivitesParticipantesDansDelai != null) && (chronoActivitesHorsChampDansDelai != null) && (chronoActivitesParticipantesDansDelai.getTaille() > 0) && (chronoActivitesParticipantesDansDelai.getTaille() == chronoActivitesHorsChampDansDelai.getTaille());
  }
  
  private void miseAJourChronoExclusionPasseProPourLiquidationFCTRevision(Contexte contexte)
  {
    Demande demande = getDemande(contexte);
    TravailSpec dernierSinistre = ((DossierAffecte)demande.getDossierAffectation()).getSinistre();
    if ((dernierSinistre != null) && (OutilActiviteSalarie.getInstance().estAeCSPouPAP(dernierSinistre)) && (!demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().contientElement(dernierSinistre))) {
      demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().ajouter(dernierSinistre);
    }
  }
}

/* Location:
 * Qualified Name:     AffectationDemandeCvaCaa
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */