package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.affectation.parametres.CriteresQualification;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.DomQualificationPeriode;
import fr.unedic.cali.parcours.ParcoursServiceAbstrait;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.Hashtable;
import java.util.List;
import java.util.StringTokenizer;

public class EnregistrerQualificationPeriode
  extends ParcoursServiceAbstrait
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (getIndividu(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "L'allocataire demandeur est obligatoire");
    }
  }
  
  public Resultat demarrerParcours(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (Log.isTraceActive(EnregistrerQualificationPeriode.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, EnregistrerQualificationPeriode.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, EnregistrerQualificationPeriode.class, "demarrer", "\t\t******** Début Parcours EnregistrerQualificationPeriode ********\n");
    }
    ResultatEnregistrerQualificationPeriode resultat = new ResultatEnregistrerQualificationPeriode();
    resultat.setEtat(1);
    
    IndividuSpec individu = getIndividu(p_contexte);
    
    individu.setIndicateurEnregistrerQualifPeriodes(true);
    
    Hashtable idPeriodeBooleen = getIdPeriodeBooleen(p_contexte);
    
    DecorReglementaire decor = AccesDecorReglementaire.getInstance().getDecorParId(getIdDecor(p_contexte));
    
    Damj dateFinDernierSinistre = ((DomQualificationPeriode)p_contexte.getDonnees()).getDateFinDernierSinistre();
    
    CriteresQualification criteresQualification = new CriteresQualification(decor, dateFinDernierSinistre, false, false);
    
    AccesDecorReglementaire.getInstance().positionnerCriteresQualifSurPas(criteresQualification, (Individu)individu);
    
    ChronologiePeriodes chronoPeriodeActivite = new ChronologiePeriodes();
    individu.getChronoPeriodePasseProfessionnelLiquidation().copieElements(chronoPeriodeActivite);
    
    ChronologiePeriodes chronoPeriodeActiviteSalariee = null;
    if (chronoPeriodeActivite != null) {
      chronoPeriodeActiviteSalariee = (ChronologiePeriodes)chronoPeriodeActivite.copier(new FiltreActiviteSalarie());
    }
    List listePeriodesQualifiees = miseAJourQualificationPeriode(chronoPeriodeActiviteSalariee, idPeriodeBooleen);
    
    individu.remplacerCollectionActiviteSalarie(listePeriodesQualifiees);
    
    resultat.setChronoPeriodeActiviteQualifiee(chronoPeriodeActiviteSalariee);
    resultat.setEtat(0);
    if (Log.isTraceActive(EnregistrerQualificationPeriode.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, EnregistrerQualificationPeriode.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, EnregistrerQualificationPeriode.class, "demarrer", "\t\t******** Résultat Parcours EnregistrerQualificationPeriode ********\n" + resultat);
      
      Log.ecritTrace(Niveau.DEBUG, EnregistrerQualificationPeriode.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, EnregistrerQualificationPeriode.class, "demarrer", "\t\t******** Fin Parcours EnregistrerQualificationPeriode ********\n");
    }
    return resultat;
  }
  
  private Hashtable getIdPeriodeBooleen(Contexte p_contexte)
  {
    return ((DomQualificationPeriode)p_contexte.getDonnees()).getIdPeriodeBooleen();
  }
  
  private String getIdDecor(Contexte p_contexte)
  {
    return ((DomQualificationPeriode)p_contexte.getDonnees()).getIdDecor();
  }
  
  protected List miseAJourQualificationPeriode(ChronologiePeriodes p_chronoPeriodeActivite, Hashtable p_idPeriodeAQualifier)
    throws CoucheLogiqueException
  {
    List listePeriodesQualifiees = new ArrayList();
    if (p_chronoPeriodeActivite != null)
    {
      p_chronoPeriodeActivite.iterer();
      while (p_chronoPeriodeActivite.encoreSuivant())
      {
        ActiviteSalarie periodeActiviteAQualifier = (ActiviteSalarie)p_chronoPeriodeActivite.elementSuivant();
        
        String valeurBooleen = (String)p_idPeriodeAQualifier.get(periodeActiviteAQualifier.getIdentifiant());
        if (valeurBooleen != null)
        {
          StringTokenizer tokenizer = new StringTokenizer(valeurBooleen, "|");
          
          String stringEstLiquidable = tokenizer.nextToken();
          boolean estLiquidable = new Boolean(stringEstLiquidable).booleanValue();
          
          String stringEstFctPrincipale = tokenizer.nextToken();
          boolean estFctPrincipale = new Boolean(stringEstFctPrincipale).booleanValue();
          
          periodeActiviteAQualifier.setEstLiquidable(estLiquidable);
          periodeActiviteAQualifier.setEstFctPrincipale(estFctPrincipale);
          
          listePeriodesQualifiees.add(periodeActiviteAQualifier);
        }
      }
    }
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_INCOHENCE_BASE_PERIODE");
    
    return listePeriodesQualifiees;
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu p_individu)
  {
    return 2;
  }
  
  protected void alimenterAgregatGaec(Individu p_individu, String p_idDemande)
  {
    p_individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(2);
  }
  
  protected void controlerPostTraitement(Individu p_individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(p_individu.getDonneesChargementGaec().getAppelGaecReduit(), 2);
  }
}

/* Location:
 * Qualified Name:     EnregistrerQualificationPeriode
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */