package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.dom.FormulaireAsuTemporaire;
import fr.unedic.cali.asu.outilsfonctionnels.ControlePrescription;
import fr.unedic.cali.autresdoms.cohab.sigma.demande.dom.spec.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDemandesGammeAsu;
import fr.unedic.cali.parcours.DomCreationFormulaires;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ResultatCreationFormulaires;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

public class FabriquerFormulairesCali
  extends ParcoursCali
{
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    ResultatCreationFormulaires resultat = new ResultatCreationFormulaires();
    
    Collection collectionFormulairesCali = new ArrayList();
    
    DomCreationFormulaires dom = (DomCreationFormulaires)p_contexte.getDonnees();
    Collection collectionDemandesCojac = dom.getCollectionDemandesCojac();
    IndividuSpec individu = dom.getIndividu();
    
    Chronologie chronoDemandesAsu = individu.getChronoDemandeAssurance();
    
    FormulaireAsu formulaireAsu = null;
    Iterator iterDemandesCojac = collectionDemandesCojac.iterator();
    while (iterDemandesCojac.hasNext())
    {
      formulaireAsu = creerFormulaireAsu((DemandeSpec)iterDemandesCojac.next(), chronoDemandesAsu);
      collectionFormulairesCali.add(formulaireAsu);
    }
    resultat.setCollectionFormulairesCali(collectionFormulairesCali);
    return resultat;
  }
  
  protected FormulaireAsu creerFormulaireAsu(DemandeSpec p_demandeCojac, Chronologie p_chronologieDemandes)
    throws ApplicativeException
  {
    FormulaireAsu formulaireAsu = null;
    
    FormulaireAsu formulaireExistant = controlePreexistenceFormulaire(p_demandeCojac.getIdentifiantDemande(), p_demandeCojac.getDateDepot(), p_chronologieDemandes);
    if (formulaireExistant != null) {
      formulaireAsu = formulaireExistant;
    } else {
      formulaireAsu = new FormulaireAsuTemporaire();
    }
    formulaireAsu.setDateDepot(p_demandeCojac.getDateDepot());
    formulaireAsu.setMotifEnvoi(p_demandeCojac.getTypeExamen());
    formulaireAsu.setIdPec(p_demandeCojac.getIdentifiantPec());
    formulaireAsu.setReferenceExterne(p_demandeCojac.getIdentifiantDemande());
    formulaireAsu.setPresenceAe(p_demandeCojac.getPresenceAE());
    formulaireAsu.setDemandeLiquidable(p_demandeCojac.getEtatLiquidable());
    formulaireAsu.setRefusFNE(p_demandeCojac.getRefusFNE());
    formulaireAsu.setDroitAuCongeReclassement(p_demandeCojac.isDroitCongeReclassement());
    formulaireAsu.setPareCrpCtpPropose(p_demandeCojac.getPropositionCrpCtp());
    
    formulaireAsu.setDateCreationDal(p_demandeCojac.getDateDemande());
    
    formulaireAsu.setReferenceExterneDemandeLiee(p_demandeCojac.getReferenceRejetDV());
    formulaireAsu.setDeploiementInstruction(p_demandeCojac.getDeploiementDalInstruction());
    
    formulaireAsu.setNomGamme(p_demandeCojac.getGamme());
    formulaireAsu.setNomLigne(p_demandeCojac.getLigne());
    formulaireAsu.setNomProduit(p_demandeCojac.getProduit());
    
    return formulaireAsu;
  }
  
  private FormulaireAsu controlePreexistenceFormulaire(String p_identifiantDal, Damj p_dateDepotRecue, Chronologie p_chronologieDemandes)
    throws ApplicativeException
  {
    FormulaireAsu formulaire = null;
    Demande demandeAsu = null;
    boolean dejaClasse = false;
    boolean formulaireTrouve = false;
    if (p_chronologieDemandes != null)
    {
      Chronologie chronoDemandesAssurance = p_chronologieDemandes.copier(new FiltreDemandesGammeAsu());
      chronoDemandesAssurance.iterer();
      while ((!formulaireTrouve) && (chronoDemandesAssurance.encoreSuivant()) && (!formulaireTrouve))
      {
        demandeAsu = (Demande)chronoDemandesAssurance.elementSuivant();
        FormulaireAsu formulaireTest = (FormulaireAsu)demandeAsu.getFormulaire();
        String idDal = formulaireTest.getReferenceExterne();
        if (idDal.equals(p_identifiantDal))
        {
          formulaireTrouve = true;
          formulaire = formulaireTest;
        }
      }
    }
    if (formulaire != null)
    {
      formulaire.setDateDepot(p_dateDepotRecue);
      dejaClasse = demandeAsu.getClassementAdministratif() != null;
      if (!dejaClasse) {
        ControlePrescription.controlerPrescription(formulaire);
      }
    }
    return formulaire;
  }
}

/* Location:
 * Qualified Name:     FabriquerFormulairesCali
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */