package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.AppelGaecReduit;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.DomQualificationPeriode;
import fr.unedic.cali.parcours.ParcoursServiceAbstrait;
import fr.unedic.cali.parcours.ResultatServicePrestation;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.Collection;

public class LireDemandeAssuranceMutualise
  extends ParcoursServiceAbstrait
{
  private static final int RESULTAT_CONTEXTE_IMPOSSIBLE_A_DETERMINER = 0;
  
  public Resultat demarrerParcours(Contexte p_contexte)
    throws ApplicativeException
  {
    ResultatLireDemandeAssuranceMutualise resultat = new ResultatLireDemandeAssuranceMutualise();
    resultat.setEtat(0);
    
    lireDemandeAssurance(p_contexte, resultat);
    
    Damj dateFinDernierSinistre = lireContexteExamen(p_contexte, resultat);
    
    ajouterDateFinDernierSinistre(p_contexte, dateFinDernierSinistre);
    
    lireQualificationPeriode(p_contexte, resultat);
    
    return resultat;
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu p_individu)
  {
    return 2;
  }
  
  protected void alimenterAgregatGaec(Individu p_individu, String p_idDemande)
  {
    boolean besoinChargementTotalGaec = false;
    boolean estSurPecAnnuleeOuFusionee = false;
    
    DemandeSpec demande = p_individu.rechercherDemande(p_idDemande);
    
    besoinChargementTotalGaec = demande.getEvenementReferenceExamen().verifierBesoinChargementTotalGaec();
    if (!besoinChargementTotalGaec) {
      estSurPecAnnuleeOuFusionee = OutillagePEC.demandeSurPecAnnuleeOuFusionneeOuHorsPec(p_individu, demande);
    }
    if (p_individu != null)
    {
      Collection typePeriodesGaec = new ArrayList();
      if ((besoinChargementTotalGaec) || (estSurPecAnnuleeOuFusionee))
      {
        p_individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(2);
      }
      else
      {
        typePeriodesGaec.add("9");
        p_individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(1);
        p_individu.getDonneesChargementGaec().getAgregatGaec().setTypePeriodesGaec(typePeriodesGaec);
      }
    }
  }
  
  protected void controlerPostTraitement(Individu p_individu)
    throws AccesDonneesGaecException
  {
    AppelGaecReduit gaecReduit = p_individu.getDonneesChargementGaec().getAppelGaecReduit();
    
    String idDemande = p_individu.getDonneesChargementGaec().getAgregatGaec().getIdDemande();
    DemandeSpec demande = p_individu.rechercherDemande(idDemande);
    
    boolean besoinChargementTotalGaec = demande.getEvenementReferenceExamen().verifierBesoinChargementTotalGaec();
    
    boolean estSurPecAnnuleeOuFusionee = OutillagePEC.demandeSurPecAnnuleeOuFusionneeOuHorsPec(p_individu, demande);
    if ((besoinChargementTotalGaec) || (estSurPecAnnuleeOuFusionee))
    {
      controlerModeAppel(gaecReduit, 2);
    }
    else
    {
      controlerTypePeriode(gaecReduit.getTypePeriodes(), "9");
      controlerModeAppel(gaecReduit, 1);
    }
  }
  
  private Damj lireContexteExamen(Contexte p_contexte, ResultatLireDemandeAssuranceMutualise p_resultat)
    throws ApplicativeException
  {
    Damj dateFinDernierSinistre = null;
    Parcours parcoursLectureContexteDemande = new ParcoursLectureContexteExamen();
    Parcours parcoursContexteParticulier = new ParcoursDeterminationContexteParticulier();
    try
    {
      parcoursContexteParticulier.effectuerParcours(p_contexte);
      
      ResultatContexteExamen resultatLireContexteDemande = (ResultatContexteExamen)parcoursLectureContexteDemande.demarrer(p_contexte);
      p_resultat.setResultatLireContexteDemande(resultatLireContexteDemande);
      if ((resultatLireContexteDemande != null) && (resultatLireContexteDemande.getDernierSinistre() != null)) {
        dateFinDernierSinistre = resultatLireContexteDemande.getDernierSinistre().getDateFin();
      }
    }
    catch (ApplicativeException ex)
    {
      String code = ex.getCode();
      if ((code.equalsIgnoreCase("HG_PR_CALI_L_DETERMINATION_ETAT_DROIT_IMP_NEUTRA")) || (code.equals("HG_PR_CALI_L_DATE_RECHERCHE_DERNIER_SINISTRE_CSR")))
      {
        ResultatContexteExamen resultatContexteExamen = new ResultatContexteExamen();
        resultatContexteExamen.setContexteExamen(0);
        p_resultat.setResultatLireContexteDemande(resultatContexteExamen);
      }
      else
      {
        throw ex;
      }
    }
    return dateFinDernierSinistre;
  }
  
  private void lireDemandeAssurance(Contexte p_contexte, ResultatLireDemandeAssuranceMutualise p_resultat)
    throws ApplicativeException
  {
    Parcours parcoursLectureDemandeAssurance = new LireDemandePrestationAssurance();
    ResultatServicePrestation resultatLireDemandeAssurance = (ResultatServicePrestation)parcoursLectureDemandeAssurance.demarrer(p_contexte);
    p_resultat.setResultatLireDemandeAssurance(resultatLireDemandeAssurance);
    if (!resultatLireDemandeAssurance.estSatisfait()) {
      p_resultat.setEtat(1);
    }
  }
  
  private void lireQualificationPeriode(Contexte p_contexte, ResultatLireDemandeAssuranceMutualise p_resultat)
    throws ApplicativeException
  {
    Parcours parcoursLectureQualificationPeriode = new LireQualificationPeriode();
    ResultatLireQualificationPeriode resultatLireQualificationPeriode = (ResultatLireQualificationPeriode)parcoursLectureQualificationPeriode.demarrer(p_contexte);
    p_resultat.setResultatLireQualificationPeriode(resultatLireQualificationPeriode);
    if (!resultatLireQualificationPeriode.estSatisfait()) {
      p_resultat.setEtat(1);
    }
    if (getIndividu(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "L'allocataire demandeur est obligatoire");
    }
  }
  
  private void ajouterDateFinDernierSinistre(Contexte p_contexte, Damj p_dateFinDernierSinistre)
  {
    DomQualificationPeriode dom = (DomQualificationPeriode)p_contexte.getDonnees();
    dom.setDateFinDernierSinistre(p_dateFinDernierSinistre);
  }
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    IndividuSpec individu = getIndividu(p_contexte);
    DomLiquidationDemande dom = (DomLiquidationDemande)p_contexte.getDonnees();
    if (dom.getDemandeSpec() == null)
    {
      DemandeAssuranceSpec demandeAssuranceCourante = (DemandeAssuranceSpec)individu.rechercherDemande(dom.getIdDemande());
      dom.setDemande(demandeAssuranceCourante);
      if (demandeAssuranceCourante == null) {
        throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "Une demande est obligatoire pour ce produit.", null);
      }
    }
  }
}

/* Location:
 * Qualified Name:     LireDemandeAssuranceMutualise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */