package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.affectation.parametres.CriteresQualification;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.outilsaffiliation.CalculAffiliationSimplifie;
import fr.unedic.cali.asu.outilsfonctionnels.examenfileau.ConstructionDemande;
import fr.unedic.cali.asu.outilsfonctionnels.examenfileau.ConstructionPeriodeExamenFilEau;
import fr.unedic.cali.asu.outilsfonctionnels.examenfileau.ControleFctExamenFilEau;
import fr.unedic.cali.asu.outilsfonctionnels.examenfileau.EtudeDemandeExamenFilEau;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltreDemandeAfd;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltreDemandeAps;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltreDemandeAsuFdd;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltreRejetPourAffiInsuffisante;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.StatistiqueExamenAuFilEau;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.LigneAsuSpe02;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.ExamenAuFilEauManager;
import fr.unedic.cali.outilsfonctionnels.OutilExamenFilEau;
import fr.unedic.cali.outilsfonctionnels.OutilFluxSigma;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.RechercherPeriodeIndemnisation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateDeclenchementExamenApresOuCoincideDate;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateDeclenchementExamenAvantOuCoincideDate;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDecisionNonEnReexamen;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDemandesAss;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreODValidee;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionsSuivantesSurDecisions;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreOuvertureDroitSurDecision;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreReexamenSurDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionPourCompetence;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class ParcoursExamenFilEau
  extends ParcoursCali
{
  private int nombreExamenMene;
  private boolean estExamenTermine;
  private DemandeSpec demandeAInstaller;
  private StatistiqueExamenAuFilEau statEfe = null;
  private static final boolean RESULTAT_SATISFAIT = true;
  private static final boolean RESULTAT_NON_SATISFAIT = false;
  private static final int DUREE_CREATION_ATTENTE_60JOURS_DNJ = 60;
  public static final String PARAM_DATE_FIN_DJN = "paramDateFinDNJ";
  
  public ParcoursExamenFilEau()
  {
    nombreExamenMene = 0;
    estExamenTermine = false;
    demandeAInstaller = null;
  }
  
  protected void setDemandeAInstaller(DemandeSpec demandeAInstaller)
  {
    this.demandeAInstaller = demandeAInstaller;
  }
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    ResultatExamenAuFilEau resultatRetourne = new ResultatExamenAuFilEau(0);
    
    DomExamenAuFilEau dom = (DomExamenAuFilEau)contexte.getDonnees();
    if (dom.isExamenAutomatique()) {
      statEfe = ExamenAuFilEauManager.initialiserStatistique(dom.getDateEvenementDeclencheur(), dom.getNatureEvenementDeclencheur());
    }
    ChronologiePeriodes periodeIndemnisees = RechercherPeriodeIndemnisation.getListePeriodesIndemnisation(dom.getIndividu());
    
    boolean resultatExamenFct = false;
    while (!estExamenTermine) {
      try
      {
        boolean resultatPreCondition = verifierPreConditions(contexte, periodeIndemnisees);
        
        resultatRetourne.setChronoPefe(((DomExamenAuFilEau)contexte.getDonnees()).getChronoPefe());
        if (resultatPreCondition)
        {
          dom.setEcrireStat(true);
          
          resultatExamenFct = examinerFct(contexte);
          if (!resultatExamenFct) {
            resultatRetourne.setEtat(1);
          }
          resultatRetourne.setChronoDemandes(((DomExamenAuFilEau)contexte.getDonnees()).getChronoDemandes());
        }
        else
        {
          resultatRetourne.setEtat(1);
        }
        postTraitement(contexte, resultatPreCondition, resultatExamenFct);
      }
      catch (CoucheLogiqueException e)
      {
        traiterAlertes(contexte, e);
      }
    }
    if ((dom.isExamenAutomatique()) && (dom.isEcrireStat())) {
      ExamenAuFilEauManager.ajouterStatistiqueSurIndividu(dom.getIndividu(), statEfe);
    }
    OutilTrace.tracerFinParcours();
    return resultatRetourne;
  }
  
  protected boolean verifierPreConditions(Contexte contexte, ChronologiePeriodes chronoPeriodesIndemnisees)
    throws CoucheLogiqueException
  {
    DomExamenAuFilEau dom = (DomExamenAuFilEau)contexte.getDonnees();
    String[] params = new String[1];
    
    boolean resultat = true;
    
    params[0] = dom.getDateEvenement().toString();
    
    ControleFctExamenFilEau outil = ControleFctExamenFilEau.getInstance();
    if (!outil.verifierEligibilitePeriodeIndemnisee(chronoPeriodesIndemnisees, dom.getDateEvenement()))
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_EFE_FCT_HORS_INDEMNISATION", params);
    }
    else
    {
      if (!outil.verifierFctEstDansGaec(dom.getIndividu(), dom.getDateEvenement())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_EFE_FCT_ABSENTE_DANS_GAEC", params);
      }
      if (!verifierChaineDemandeFdd(dom.getIndividu(), dom.getDateEvenement())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_EFE_IMPOSSIBLE_CHAINE_FDD_INCOMPLETE");
      }
      if (!outil.verifierFctEstNonLieeDroitAre(dom.getIndividu(), dom.getDateEvenement())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_EFE_FCT_LIEE_DECISION", params);
      }
      if (!outil.verifierFctEstAvantDja(dom.getIndividu(), dom.getDateEvenement())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_EFE_FCT_EST_AVANT_DJA", params);
      }
      ConstructionPeriodeExamenFilEau constructionPefe = new ConstructionPeriodeExamenFilEau(dom.getIndividu());
      ChronologiePeriodes chronoPefe = constructionPefe.getChronologiePeriodeExamenFilEau();
      dom.setChronoPefe(chronoPefe);
      if (!outil.verifierFctEstDansPEFE(chronoPefe, dom.getDateEvenement())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_EFE_FCT_HORS_PEFE", params);
      }
    }
    return resultat;
  }
  
  protected boolean examinerFct(Contexte contexte)
    throws ApplicativeException
  {
    boolean resultat = false;
    
    DomExamenAuFilEau dom = (DomExamenAuFilEau)contexte.getDonnees();
    Individu individu = (Individu)dom.getIndividu();
    
    nombreExamenMene += 1;
    
    ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
    conteneur.setDateRecherche(dom.getDateEvenement());
    DecorReglementaire decorReglementaire = AccesDecorReglementaire.getInstance().getDecor(conteneur);
    
    CriteresQualification critereQualification = new CriteresQualification(decorReglementaire, dom.getDateEvenement(), false, false);
    
    AccesDecorReglementaire.getInstance().positionnerCriteresQualifSurPas(critereQualification, individu);
    
    boolean effectuerAffiliationSimplifiee = dom.isCalculAffiliationSimplifieeActif();
    boolean affiliationSimplifieeSuffisante = true;
    if (effectuerAffiliationSimplifiee) {
      affiliationSimplifieeSuffisante = CalculAffiliationSimplifie.estAffiliationMinimaleValidee(individu, dom.getDateEvenement());
    }
    if (dom.isExamenAutomatique()) {
      ExamenAuFilEauManager.mettreAJourStatistiqueFct(statEfe, dom.getDateEvenement(), nombreExamenMene, affiliationSimplifieeSuffisante);
    }
    if (affiliationSimplifieeSuffisante)
    {
      EtudeDemandeExamenFilEau ofEtudeDemande = EtudeDemandeExamenFilEau.getInstance();
      
      resultat = affiliationSimplifiee(ofEtudeDemande, dom, individu, contexte);
    }
    return resultat;
  }
  
  private boolean affiliationSimplifiee(EtudeDemandeExamenFilEau ofEtudeDemande, DomExamenAuFilEau dom, Individu individu, Contexte contexte)
    throws ApplicativeException
  {
    Damj fct = dom.getDateEvenement().lendemain();
    
    List<String> listeDesExamens = determinerListeDesExamensEFE();
    boolean resultat = false;
    boolean continuerExamen = true;
    ConstructionDemande ofConstructionDemande = null;
    Iterator<String> iterExamen = listeDesExamens.iterator();
    
    DemandeAssuranceSpec demandeTemporaire = null;
    while ((iterExamen.hasNext()) && (continuerExamen))
    {
      String typeExamen = (String)iterExamen.next();
      
      ofConstructionDemande = new ConstructionDemande(fct, typeExamen);
      demandeTemporaire = (DemandeAssuranceSpec)ofConstructionDemande.installerDemande(contexte);
      if (demandeTemporaire == null)
      {
        resultat = false;
        continuerExamen = false;
      }
      else
      {
        try
        {
          resultat = etudierDemande(ofEtudeDemande, dom, resultat, demandeTemporaire);
        }
        finally
        {
          individu.supprimerDemande(demandeTemporaire);
        }
      }
    }
    return resultat;
  }
  
  private boolean etudierDemande(EtudeDemandeExamenFilEau ofEtudeDemande, DomExamenAuFilEau dom, boolean resultat, DemandeAssuranceSpec demandeTemporaire)
    throws ApplicativeException
  {
    boolean resultatIntermediaire = resultat;
    
    ofEtudeDemande.lancerEtudeDemande(demandeTemporaire);
    if (dom.isExamenManuel()) {
      dom.getChronoDemandes().ajouter((DemandeAssuranceSpec)demandeTemporaire.copie());
    }
    int resultatDemandeLiquidee = ofEtudeDemande.donnerResultatLiquidation(demandeTemporaire);
    if (resultatDemandeLiquidee == 0)
    {
      resultatIntermediaire = true;
      
      demandeAInstaller = ((DemandeAssuranceSpec)demandeTemporaire.copie());
    }
    else if ((resultatDemandeLiquidee == 1) || (resultatDemandeLiquidee == 2))
    {
      resultatIntermediaire = false;
    }
    return resultatIntermediaire;
  }
  
  protected void postTraitement(Contexte contexte, boolean resultatPreConditions, boolean resultatExamenFct)
    throws ApplicativeException
  {
    DomExamenAuFilEau dom = (DomExamenAuFilEau)contexte.getDonnees();
    IndividuSpec individu = dom.getIndividu();
    if ((!resultatPreConditions) || (!resultatExamenFct))
    {
      Damj dateFct = OutilExamenFilEau.getDateFctApresOuCoincideAvec(individu, dom.getDateEvenement().lendemain());
      if (dateFct == null) {
        estExamenTermine = true;
      } else {
        etudierFct(dom, individu, dateFct);
      }
    }
    else
    {
      estExamenTermine = true;
      if (dom.isExamenAutomatique()) {
        ExamenAuFilEauManager.mettreAJourStatistiqueResultat(statEfe, 1);
      }
      if (!dom.isModeSimulationActif()) {
        OutilFluxSigma.notifierSigmaPourCreationDemandeExamenFilEau(individu, dom.getDateEvenement(), getTypeDalACreer());
      }
    }
  }
  
  private void etudierFct(DomExamenAuFilEau dom, IndividuSpec individu, Damj dateFct)
    throws ApplicativeException
  {
    dom.setDateEvenement(dateFct);
    
    int nbreFctATraiter = nombreExamenMene + 1;
    if (nbreFctATraiter > dom.getNombreMaximumFctATraiter())
    {
      estExamenTermine = true;
      if (dom.isExamenAutomatique()) {
        ExamenAuFilEauManager.mettreAJourStatistiqueResultat(statEfe, 2);
      }
      if (!dom.isModeSimulationActif()) {
        OutilFluxSigma.notifierSigmaPourCreationAttenteExamenFilEau(individu, dom.getDateEvenement(), "2");
      }
    }
  }
  
  protected void traiterAlertes(Contexte contexte, CoucheLogiqueException exception)
    throws ApplicativeException
  {
    estExamenTermine = true;
    
    DomExamenAuFilEau dom = (DomExamenAuFilEau)contexte.getDonnees();
    if (exception.getCode().equals("ASU_PR_CALI_L_ALERTE_A11MB14"))
    {
      Damj dateFinDnj = (Damj)exception.getParametres().get("paramDateFinDNJ");
      
      Periode periodeDNJaFCT = new Periode(dateFinDnj, dom.getDateEvenement());
      if ((!dom.isModeSimulationActif()) && (periodeDNJaFCT.getDuree() > 60)) {
        OutilFluxSigma.notifierSigmaPourCreationAttenteExamenFilEau(dom.getIndividu(), dateFinDnj, "1");
      }
    }
    if ((dom.isExamenAutomatique()) && (dom.isEcrireStat()))
    {
      ExamenAuFilEauManager.mettreAJourStatistiqueResultat(statEfe, 3);
      
      ExamenAuFilEauManager.ajouterStatistiqueSurIndividu(dom.getIndividu(), statEfe);
    }
    throw exception;
  }
  
  protected String getTypeDalACreer()
    throws ApplicativeException
  {
    String typeDalACreer = null;
    if (demandeAInstaller == null)
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_EFE_DEMANDE_A_INSTALLER_NULL");
    }
    else
    {
      String nomLigne = demandeAInstaller.getDossierAffectation().getProduit().getLigne().getNomUnique();
      if ((nomLigne.equals("ASU_CGE01")) || (nomLigne.equals("ASU_CSA06")) || (nomLigne.equals("ASU_CSR04")) || (nomLigne.equals("ASU_SPE02"))) {
        typeDalACreer = "71";
      } else if (nomLigne.equals("ASU_SSP07")) {
        typeDalACreer = "R2";
      } else if (nomLigne.equals("ASU_FDS12")) {
        typeDalACreer = "R5";
      }
      if (typeDalACreer == null)
      {
        String[] params = new String[1];
        params[0] = nomLigne;
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_EFE_TYPE_DAL_A_CREER_NULL", params);
      }
    }
    return typeDalACreer;
  }
  
  private boolean verifierChaineDemandeFdd(IndividuSpec individu, Damj borneFct)
  {
    FiltresTemporel filtreAsuFddAvantFctPefe = new FiltresTemporel();
    filtreAsuFddAvantFctPefe.ajouterFiltre(new FiltreDemandeAsuFdd());
    filtreAsuFddAvantFctPefe.ajouterFiltre(new FiltreDateDeclenchementExamenAvantOuCoincideDate(borneFct));
    filtreAsuFddAvantFctPefe.ajouterFiltre(new FiltreDecisionNonEnReexamen());
    Chronologie demandesAsuFddAvantFctPefe = individu.getChronoDemandeAssurance().copier(filtreAsuFddAvantFctPefe);
    
    FiltresTemporel filtreAreFddRejetPourAffiAvantFctPefe = new FiltresTemporel();
    filtreAreFddRejetPourAffiAvantFctPefe.ajouterFiltre(new FiltreRejetPourAffiInsuffisante());
    Chronologie demandesAreFddPourRejetAffiAvantFctPefe = demandesAsuFddAvantFctPefe.copier(filtreAreFddRejetPourAffiAvantFctPefe);
    boolean resultat;
    boolean resultat;
    if (demandesAreFddPourRejetAffiAvantFctPefe.estVide()) {
      resultat = rechercheAntecedent(individu);
    } else {
      resultat = (rechercheFDDSpectacleSurODCRA(demandesAreFddPourRejetAffiAvantFctPefe, borneFct)) || (rechercheRejetAffi(individu, demandesAreFddPourRejetAffiAvantFctPefe, demandesAsuFddAvantFctPefe, borneFct));
    }
    return resultat;
  }
  
  protected boolean rechercheAntecedent(IndividuSpec individu)
  {
    boolean boolChaineDemandeFdd = false;
    FiltreOU filtreAntecedent = new FiltreOU();
    filtreAntecedent.ajouterFiltre(new FiltreDemandePourERE("ASU_22"));
    filtreAntecedent.ajouterFiltre(new FiltreDemandePourERE("SOL_20"));
    FiltreET filtreAntecedentAre = new FiltreET();
    filtreAntecedentAre.ajouterFiltre(filtreAntecedent);
    filtreAntecedentAre.ajouterFiltre(new FiltreDecisionARESurDecision());
    filtreAntecedentAre.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
    filtreAntecedentAre.ajouterFiltre(new FiltreDecisionPourCompetence(1, 0));
    
    AttributionAssuranceSpec antecedentAsu = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(individu.getChronoDemandesNonTriees(), Damj.FIN_DES_TEMPS, filtreAntecedentAre);
    
    boolean saisieAntecedant = (antecedentAsu != null) && (((Demande)antecedentAsu.getDemande()).getSaisieAntecedent().getContexteDemande() != null) && (((Demande)antecedentAsu.getDemande()).getSaisieAntecedent().getContexteDemande().intValue() == 4);
    if (((antecedentAsu == null) && (individu.getDernierJourIndemnisableAreSpe() != null)) || (saisieAntecedant)) {
      boolChaineDemandeFdd = true;
    }
    return boolChaineDemandeFdd;
  }
  
  protected boolean rechercheFDDSpectacleSurODCRA(Chronologie demandesAreFddPourRejetAffiAvantFctPefe, Damj borneFct)
  {
    boolean boolChaineDemandeFdd = false;
    Demande derniereDemandeAreFddRejetAffiAvantFctPefe = (Demande)demandesAreFddPourRejetAffiAvantFctPefe.dernierElement();
    if (derniereDemandeAreFddRejetAffiAvantFctPefe.getDossierAffectation().getProduit().getLigne().getNomUnique().equals(LigneAsuSpe02.getInstance().getNomUnique()))
    {
      FiltreET filtreEt = new FiltreET();
      filtreEt.ajouterFiltre(new FiltreDemandePourERE("ASU_31"));
      filtreEt.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
      filtreEt.ajouterFiltre(new FiltreOuvertureDroitSurDecision());
      filtreEt.ajouterFiltre(new FiltreDecisionsSuivantesSurDecisions(derniereDemandeAreFddRejetAffiAvantFctPefe.getDateExamen().veille()));
      DecisionSpec odCRA = OutilRecherche.rechercherDecisionPrecedente(derniereDemandeAreFddRejetAffiAvantFctPefe.getDemandeur().getChronoDemandeAssurance(), borneFct.lendemain(), filtreEt);
      if (odCRA != null) {
        boolChaineDemandeFdd = true;
      }
    }
    return boolChaineDemandeFdd;
  }
  
  protected boolean rechercheRejetAffi(IndividuSpec individu, Chronologie demandesAreFddPourRejetAffiAvantFctPefe, Chronologie demandesAsuFddAvantFctPefe, Damj borneFct)
  {
    Demande derniereDemandeAreFddRejetAffiAvantFctPefe = (Demande)demandesAreFddPourRejetAffiAvantFctPefe.dernierElement();
    boolean boolChaineDemandeFdd = false;
    if (derniereDemandeAreFddRejetAffiAvantFctPefe.estMigree())
    {
      boolChaineDemandeFdd = true;
    }
    else
    {
      FiltresTemporel filtreApsOuAfdFddApresRejetAreFddPourAffiAvantFctPefe = new FiltresTemporel();
      FiltrePeriodesSurFiltresExclusifs filtreApsOuAfd = new FiltrePeriodesSurFiltresExclusifs();
      filtreApsOuAfd.ajouterFiltre(new FiltreDemandeAps());
      filtreApsOuAfd.ajouterFiltre(new FiltreDemandeAfd());
      filtreApsOuAfd.ajouterFiltre(new FiltreDecisionNonEnReexamen());
      filtreApsOuAfdFddApresRejetAreFddPourAffiAvantFctPefe.ajouterFiltre(new FiltreDateDeclenchementExamenApresOuCoincideDate(derniereDemandeAreFddRejetAffiAvantFctPefe.getDateDeclenchementExamen()));
      
      filtreApsOuAfdFddApresRejetAreFddPourAffiAvantFctPefe.ajouterFiltre(filtreApsOuAfd);
      Chronologie demandesApsOuAfdFddApresRejetArePourAffiFDDAvantFctPefe = demandesAsuFddAvantFctPefe.copier(filtreApsOuAfdFddApresRejetAreFddPourAffiAvantFctPefe);
      
      FiltresTemporel filtreOdApsFddApresRejetAreFddPourAffiAvantFctPefe = new FiltresTemporel();
      filtreOdApsFddApresRejetAreFddPourAffiAvantFctPefe.ajouterFiltre(new FiltreODValidee());
      filtreOdApsFddApresRejetAreFddPourAffiAvantFctPefe.ajouterFiltre(new FiltreDemandeAps());
      Chronologie demandesOdApsFddApresRejetArePourAffiFddAvantFctPefe = demandesApsOuAfdFddApresRejetArePourAffiFDDAvantFctPefe.copier(filtreOdApsFddApresRejetAreFddPourAffiAvantFctPefe);
      if (!demandesOdApsFddApresRejetArePourAffiFddAvantFctPefe.estVide())
      {
        boolChaineDemandeFdd = true;
      }
      else
      {
        FiltresTemporel filtreRejetApsFddPourAffiApresRejetAreFddPourAffiAvantFctPefe = new FiltresTemporel();
        filtreRejetApsFddPourAffiApresRejetAreFddPourAffiAvantFctPefe.ajouterFiltre(new FiltreRejetPourAffiInsuffisante());
        filtreRejetApsFddPourAffiApresRejetAreFddPourAffiAvantFctPefe.ajouterFiltre(new FiltreDemandeAps());
        Chronologie demandesRejetApsFddPourAffiApresRejetAreFddAvantFctPefe = demandesApsOuAfdFddApresRejetArePourAffiFDDAvantFctPefe.copier(filtreRejetApsFddPourAffiApresRejetAreFddPourAffiAvantFctPefe);
        if (!demandesRejetApsFddPourAffiApresRejetAreFddAvantFctPefe.estVide())
        {
          FiltresTemporel filtreRejetPourAffiOuOdAfdFddApresRejetAPSPourAffiFddAvantFctPefe = new FiltresTemporel();
          FiltrePeriodesSurFiltresExclusifs filtreOdOuRejetAfdPourAffi = new FiltrePeriodesSurFiltresExclusifs();
          filtreOdOuRejetAfdPourAffi.ajouterFiltre(new FiltreODValidee());
          filtreOdOuRejetAfdPourAffi.ajouterFiltre(new FiltreRejetPourAffiInsuffisante());
          filtreOdOuRejetAfdPourAffi.ajouterFiltre(new FiltreDemandeAfd());
          filtreRejetPourAffiOuOdAfdFddApresRejetAPSPourAffiFddAvantFctPefe.ajouterFiltre(filtreOdOuRejetAfdPourAffi);
          filtreRejetPourAffiOuOdAfdFddApresRejetAPSPourAffiFddAvantFctPefe.ajouterFiltre(new FiltreDemandeAfd());
          filtreRejetPourAffiOuOdAfdFddApresRejetAPSPourAffiFddAvantFctPefe.ajouterFiltre(new FiltreDateDeclenchementExamenApresOuCoincideDate(((Demande)demandesRejetApsFddPourAffiApresRejetAreFddAvantFctPefe.premierElement()).getDateDeclenchementExamen()));
          
          Chronologie demandesRejetPourAffiOuOdAfdFddApresRejetApsPourAffiFddAvantFctPefe = demandesApsOuAfdFddApresRejetArePourAffiFDDAvantFctPefe.copier(filtreRejetPourAffiOuOdAfdFddApresRejetAPSPourAffiFddAvantFctPefe);
          if (!demandesRejetPourAffiOuOdAfdFddApresRejetApsPourAffiFddAvantFctPefe.estVide())
          {
            boolChaineDemandeFdd = true;
          }
          else
          {
            FiltresTemporel filtreOdAssApresRejetAPSPourAffiFddAvantFctPefe = new FiltresTemporel();
            filtreOdAssApresRejetAPSPourAffiFddAvantFctPefe.ajouterFiltre(new FiltreDateDeclenchementExamenAvantOuCoincideDate(borneFct));
            filtreOdAssApresRejetAPSPourAffiFddAvantFctPefe.ajouterFiltre(new FiltreDemandesAss());
            filtreOdAssApresRejetAPSPourAffiFddAvantFctPefe.ajouterFiltre(new FiltreODValidee());
            filtreOdAssApresRejetAPSPourAffiFddAvantFctPefe.ajouterFiltre(new FiltreDateDeclenchementExamenApresOuCoincideDate(((Demande)demandesRejetApsFddPourAffiApresRejetAreFddAvantFctPefe.premierElement()).getDateDeclenchementExamen()));
            
            Chronologie demandesAssApresRejetApsPourAffiFddAvantFctPefe = individu.getChronoDemandeSolidarite().copier(filtreOdAssApresRejetAPSPourAffiFddAvantFctPefe);
            if (!demandesAssApresRejetApsPourAffiFddAvantFctPefe.estVide()) {
              boolChaineDemandeFdd = true;
            }
          }
        }
      }
    }
    return boolChaineDemandeFdd;
  }
  
  protected List<String> determinerListeDesExamensEFE()
  {
    List<String> listeDesExamens = new ArrayList();
    listeDesExamens.add("ASU_13");
    return listeDesExamens;
  }
}

/* Location:
 * Qualified Name:     ParcoursExamenFilEau
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */