package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.fabriques.FabriqueVerificationDonneesSaisieAntecedent;
import fr.unedic.cali.asu.liquidation.antecedent.VerificationDonneesSaisieAntecedentSpec;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilReferenceExterne;
import fr.unedic.cali.asu.outilsfonctionnels.OutilVerificationPreconditionsAntecedent;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenAntecedentSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.LigneAsuCsa06;
import fr.unedic.cali.dom.affectation.LigneAsuExp03;
import fr.unedic.cali.dom.affectation.LigneAsuFds12;
import fr.unedic.cali.dom.affectation.LigneAsuSpe02;
import fr.unedic.cali.dom.affectation.LigneAsuSsp07;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.AppelCalcul;
import fr.unedic.cali.outilsfonctionnels.OutilComparateurDecision;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.OutilVerificationPreconditions;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ResultatServiceDemande;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.List;
import org.apache.commons.lang.StringUtils;

public class ParcoursInstallationAntecedent
  extends ParcoursLiquidationAssuranceClassique
{
  public Resultat demarrerTraitement(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    DemandeSpec demandeCourante = getDemande(contexte);
    
    ResultatLiquidationAssurance resultatLiquidation = new ResultatLiquidationAssurance(2);
    
    initialiserCoordEuropeenne(contexte);
    
    initialisationPasseProfessionnelLiquidation(contexte);
    
    verifierContexte(demandeCourante);
    if (demandeCourante.estDecisionnee()) {
      sauvegarderDonneesAvantReexamen(contexte);
    }
    detectionContexteParticulier(contexte);
    
    controlerDonneesForcees(contexte);
    
    initialiserDemande(contexte);
    
    Damj dateExamen = determinerDateExamen(contexte);
    
    verifierPreconditions(contexte);
    
    chargermentListePNDSIndividu(demandeCourante, dateExamen);
    
    affecterProduit(contexte);
    
    determinerContextesLiquidation(contexte);
    
    positionnerObjectif(contexte);
    
    creerGrapheDecision(contexte);
    
    creerGrapheReliquatDroit(contexte);
    
    controlerDonneesForceesPostLiquidation(contexte);
    
    determinationReferenceExterne(contexte);
    
    alimenterDecisionsReexamen(contexte, resultatLiquidation);
    
    resultatLiquidation.setDemande(demandeCourante);
    
    OutilTrace.tracerFinParcours();
    return resultatLiquidation;
  }
  
  protected void initialiserDemande(Contexte contexte)
  {
    Demande demande = (Demande)getDemande(contexte);
    DossierAffectation dossierAffectation = new DossierAffecte(1);
    
    demande.setDossierAffectation(dossierAffectation);
    
    demande.viderListeObjectifsExamen();
    
    demande.setListeMotifsReexamen(null);
  }
  
  private void initialiserCoordEuropeenne(Contexte contexte)
  {
    Demande demande = (Demande)getDemande(contexte);
    if (demande.getSaisieAntecedent() != null)
    {
      int typeCoordinationEuropeenne = demande.getSaisieAntecedent().getTypeCoordinationEuropeenne();
      
      demande.getDonneesTemporaires().setTypeCoordinationEuropeenne(typeCoordinationEuropeenne);
    }
  }
  
  protected void controlerDonneesForcees(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = (Demande)getDemande(contexte);
    Damj dateTraitement = getContexteService(contexte).getDateTraitement();
    
    VerificationDonneesSaisieAntecedentSpec outilVerification = FabriqueVerificationDonneesSaisieAntecedent.getOutilVerificationDonneesSaisies(demande);
    outilVerification.verifierDonneesForcees(demande, dateTraitement);
  }
  
  protected void controlerDonneesForceesPostLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = (Demande)getDemande(contexte);
    
    VerificationDonneesSaisieAntecedentSpec outilVerification = FabriqueVerificationDonneesSaisieAntecedent.getOutilVerificationDonneesSaisies(demande);
    outilVerification.verifierDonneesForceesPostLiquidation(demande);
  }
  
  protected void verifierPreconditions(Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demandePrestationsCourante = (Demande)getDemande(contexte);
    
    OutilVerificationPreconditionsAntecedent.getInstance().verifierPreconditions(demandePrestationsCourante);
    
    EvenementReferenceExamenAntecedentSpec ereAntecedent = (EvenementReferenceExamenAntecedentSpec)demandePrestationsCourante.getEvenementReferenceExamen();
    
    AttributionSpec attributionPrecedente = demandePrestationsCourante.rechercherAttributionPrecedenteDuMemeType();
    if (ereAntecedent.verifierPremiereDemandeIndividu(demandePrestationsCourante))
    {
      if (attributionPrecedente != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_ANTECEDENT_PRESENCE_DROIT_PRECEDENT");
      }
    }
    else if (!"0".equals(demandePrestationsCourante.getSaisieAntecedent().getMontantReadmissionRetenu()))
    {
      if (demandePrestationsCourante.getSaisieAntecedent().getCodeProduit().intValue() != 1) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ANTECEDENT_READ_COMPOSITE_NON_ARE");
      }
      if (("1".equals(demandePrestationsCourante.getSaisieAntecedent().getMontantReadmissionRetenu())) && ((attributionPrecedente == null) || (!ProduitAbstrait.estDuType(6, attributionPrecedente.getProduit())))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ANTECEDENT_READ_COMPOSITE_CPA");
      } else if (attributionPrecedente != null) {
        demandePrestationsCourante.setDemandeOrigine((DemandeAssuranceSpec)attributionPrecedente.getDemande());
      }
    }
  }
  
  protected void detectionContexteParticulier(Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demandePrestationsCourante = (Demande)getDemande(contexte);
    if (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandePrestationsCourante, "ARESJASPDC")) {
      demandePrestationsCourante.clearCollectionContexteDemande();
    }
    if ((demandePrestationsCourante.getSaisieAntecedent() != null) && ((demandePrestationsCourante.getSaisieAntecedent().estAntecedentAsp()) || (demandePrestationsCourante.getSaisieAntecedent().estAntecedentMayotte()) || (demandePrestationsCourante.getSaisieAntecedent().estClauseRattrapage()))) {
      DetectionContexteParticulierLiquidation.getInstance().determinerContexteParticulierLiquidationAssurance(demandePrestationsCourante);
    }
  }
  
  protected void affecterProduit(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = (Demande)getDemande(contexte);
    DossierAffectation dossierAffectation = (DossierAffectation)demande.getDossierAffectation();
    SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
    
    ActiviteSalarie fctRetenue = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantFCTRetenue());
    
    TravailSpec faitGenerateur = (TravailSpec)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantFaitGenerateur());
    
    dossierAffectation.setSinistre(faitGenerateur);
    
    DecorReglementaire decorReglementaire = recupererDecorReglementaire(demande, dossierAffectation);
    dossierAffectation.setDecorReglementaire(decorReglementaire);
    
    ProduitSpec produit = determinerProduit(decorReglementaire, saisieAntecedent, dossierAffectation);
    
    String nomReglementApplicable = saisieAntecedent.getNomReglementApplicable();
    Reglement reglement;
    Reglement reglement;
    if (!StringUtils.isEmpty(nomReglementApplicable)) {
      reglement = Parametres.getReglement(nomReglementApplicable, produit);
    } else {
      reglement = fctRetenue.getReglement();
    }
    ValidationProduit validationProduit = new ValidationProduit();
    validationProduit.setProduitValide(produit);
    validationProduit.setPeriodeValidationProduit(fctRetenue);
    validationProduit.setReglementApplicable(reglement);
    
    dossierAffectation.setValidationProduit(validationProduit);
    dossierAffectation.setProduitSecours(produit);
    if (ProduitAbstrait.estDuType(7, produit.getCode())) {
      DetectionContexteParticulierLiquidation.getInstance().detectionContexteEnCoursPmvs(demande, faitGenerateur, saisieAntecedent.getDateAttribution());
    }
  }
  
  protected DecorReglementaire recupererDecorReglementaire(Demande demande, DossierAffectation dossierAffectation)
    throws CoucheLogiqueException
  {
    DecorReglementaire decorReglementaire;
    DecorReglementaire decorReglementaire;
    if (demande.getSaisieAntecedent().getContexteDemande().intValue() == 8)
    {
      Damj dateDjc = demande.getSaisieAntecedent().getDateDernierJourCalcule();
      Damj datePECApresDJC = recupererPremierJourPECApresDJCAntecedent(demande.getDemandeur(), dateDjc);
      decorReglementaire = recupererDecorReglementaireDate(demande, datePECApresDJC);
    }
    else
    {
      decorReglementaire = ConstitutionDecorReglementaire.recupererDecor(dossierAffectation);
    }
    return decorReglementaire;
  }
  
  protected DecorReglementaire recupererDecorReglementaireDate(Demande demande, Damj date)
    throws CoucheLogiqueException
  {
    ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
    conteneur.setDateRecherche(date);
    conteneur.setDateFinContrat(date);
    conteneur.setDernierSinistre(demande.getSaisieAntecedent().getPeriodeFGD());
    
    conteneur.setBesoinCritereQualif(true);
    conteneur.setDemande(demande);
    return ConstitutionDecorReglementaire.recupererDecor(conteneur);
  }
  
  protected Damj recupererPremierJourPECApresDJCAntecedent(IndividuSpec individu, Damj dateDjc)
    throws CoucheLogiqueException
  {
    Damj datePECApresDJC = OutillagePEC.getPremierJourPECDemandeurMayotteExclu(individu, dateDjc);
    if (datePECApresDJC == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_ANTECEDENT_AUCUNE_PEC_APRES_DJC");
    }
    return datePECApresDJC;
  }
  
  private ProduitSpec determinerProduit(DecorReglementaire decorReglementaire, SaisieAntecedent saisieAntecedent, DossierAffectation dossierAffectation)
    throws CoucheLogiqueException
  {
    ProduitSpec produit = null;
    
    int codeProduitSaisie = saisieAntecedent.getCodeProduit().intValue();
    
    Damj dateRechercheProduit = saisieAntecedent.getPeriodeFGD().getDateFin();
    if (1 == codeProduitSaisie)
    {
      produit = decorReglementaire.determinerProduitEffectifDeLaLigne(LigneAsuCge01.getInstance());
    }
    else if (2 == codeProduitSaisie)
    {
      produit = decorReglementaire.determinerProduitEffectifDeLaLigne(LigneAsuSpe02.getInstance());
    }
    else if (3 == codeProduitSaisie)
    {
      produit = LigneAsuSsp07.getInstance().getProduitActif(dateRechercheProduit);
    }
    else if (4 == codeProduitSaisie)
    {
      produit = LigneAsuFds12.getInstance().getProduitActif(dateRechercheProduit);
    }
    else if (5 == codeProduitSaisie)
    {
      produit = decorReglementaire.determinerProduitEffectifDeLaLigne(LigneAsuCsa06.getInstance());
    }
    else if (9 == codeProduitSaisie)
    {
      produit = decorReglementaire.determinerProduitEffectifDeLaLigne(LigneAsuExp03.getInstance());
    }
    else if (12 == codeProduitSaisie)
    {
      AffectationDemandeAsp affectation = new AffectationDemandeAsp();
      produit = affectation.determinerProduitRelatifAuSinistre(saisieAntecedent.getPeriodeFGD(), dossierAffectation);
    }
    else
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_ANTECEDENT_AUCUN_PRODUIT_ACTIF", new Object[] { Integer.valueOf(codeProduitSaisie) });
    }
    if (produit == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_ANTECEDENT_AUCUN_PRODUIT_ACTIF_DATE");
    }
    return produit;
  }
  
  protected void positionnerObjectif(Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)getDemande(contexte);
    DossierAffectation dossierAffectation = (DossierAffectation)demande.getDossierAffectation();
    ProduitAsuSpec produit = (ProduitAsuSpec)dossierAffectation.getValidationProduit().getProduitValide();
    
    ObjectifExamen objectifExamen = (ObjectifExamen)produit.creerObjectifExamen(10, null);
    if (objectifExamen == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBJECTIF_IMPOSSIBLE", new Object[] { produit.getLibelleCourt() });
    } else {
      objectifExamen.setEtat(23);
    }
    demande.setObjectifCourant(objectifExamen);
    demande.ajouterObjectifExamen(objectifExamen);
  }
  
  protected void creerGrapheDecision(Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)getDemande(contexte);
    DossierAffectation dossierAffectation = (DossierAffectation)demande.getDossierAffectation();
    ProduitAsuSpec produit = (ProduitAsuSpec)dossierAffectation.getValidationProduit().getProduitValide();
    if (demande.getDonneesDemandeAssociee() != null) {
      demande.removeDonneesDemandeAssociee();
    }
    produit.creerGrapheDemandeAntecedent(contexte);
    
    ((DecisionSpec)demande.getDossierExamen()).setNatureDecision(38);
    if ((demande.getSaisieAntecedent().getContexteDemande() != null) && ((5 == demande.getSaisieAntecedent().getContexteDemande().intValue()) || (7 == demande.getSaisieAntecedent().getContexteDemande().intValue()))) {
      ((DecisionSpec)demande.getDossierExamen()).setNatureDecision(39);
    }
  }
  
  protected void creerGrapheReliquatDroit(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = (Demande)getDemande(contexte);
    if ((demande.getListContexteDemande() == null) || (!OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demande.getListContexteDemande(), "ARESJASPDC")))
    {
      AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)demande.getDossierExamen();
      
      alimenterTrancheExecutable(contexte);
      
      AppelCalcul.alimenterGrapheAntecedentCalcul(attribution);
    }
  }
  
  protected void determinationReferenceExterne(Contexte contexte)
    throws CoucheLogiqueException
  {
    DemandeSpec demande = ((DomLiquidationDemande)contexte.getDonnees()).getDemandeSpec();
    DossierExamenSpec dossierExamenCourant = (DossierExamenSpec)demande.getListeDossiersExamen().get(0);
    if ((((DomLiquidationDemande)contexte.getDonnees()).getDemandeAvantReexamen() == null) || (((DomLiquidationDemande)contexte.getDonnees()).getReferenceExterneAvantReexamen() == null)) {
      OutilReferenceExterne.determinationReferenceExterneAdmission(contexte);
    } else {
      ((OdSpec)dossierExamenCourant).setReferenceExterne(((DomLiquidationDemande)contexte.getDonnees()).getReferenceExterneAvantReexamen());
    }
  }
  
  protected void alimenterDecisionsReexamen(Contexte contexte, ResultatServiceDemande resultat)
    throws CoucheLogiqueException
  {
    if (((DomLiquidationDemande)contexte.getDonnees()).getDemandeAvantReexamen() != null)
    {
      ArrayList listeDifferences = new ArrayList();
      listeDifferences.add(OutilComparateurDecision.creerDifferenceSystematique());
      resultat.setListeDifferencesReexamen(listeDifferences);
    }
  }
  
  protected void traitementPostLiquidation(Contexte contexte)
    throws CoucheLogiqueException
  {
    DomLiquidationDemande domCourant = (DomLiquidationDemande)contexte.getDonnees();
    DemandeSpec demandeCourante = domCourant.getDemandeSpec();
    demandeCourante.setDemandeLiquidee(false);
  }
  
  private void alimenterTrancheExecutable(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    if ((demande.getAttribution() != null) && (demande.getAttribution().getProduit() != null))
    {
      ProduitAsuSpec produit = (ProduitAsuSpec)demande.getAttribution().getProduit();
      produit.constituerTranchesExecutables(contexte);
    }
  }
}

/* Location:
 * Qualified Name:     ParcoursInstallationAntecedent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */