package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.outilsfonctionnels.ControlePrescription;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.DetectionTypeChomage;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.Collection;
import java.util.Iterator;

public class ParcoursLiquidationAssuranceRevision
  extends ParcoursLiquidationAssurance
{
  protected void controlerDonneesSecteurPublic(IndividuSpec individu, DemandeAssuranceSpec demande)
    throws ContexteException
  {}
  
  public Resultat demarrerTraitement(Contexte contexte)
    throws ApplicativeException
  {
    ResultatLiquidationAssurance resultatLiquidation = new ResultatLiquidationAssurance(2);
    OutilTrace.tracerDebutParcours();
    
    DemandeSpec demandeCourante = getDemande(contexte);
    
    verifierContexte(demandeCourante);
    
    initialiserRegimeEuropeen((Demande)demandeCourante);
    
    initialisationPasseProfessionnelLiquidation(contexte);
    if (demandeCourante.estDecisionnee()) {
      sauvegarderDonneesAvantReexamen(contexte);
    }
    Damj dateExamen = determinerDateExamen(contexte);
    if (dateExamen == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_DATE_EXAMEN_NON_DETERMINEE");
    }
    verifierPreconditions(contexte);
    
    determinationContexteParticulier(contexte);
    
    constaterContexteInitial(contexte);
    
    chargermentListePNDSIndividu(demandeCourante, dateExamen);
    
    boolean prescritpionOk = ControlePrescription.controlerPrescription(demandeCourante.getFormulaire());
    if (!prescritpionOk) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_DAL_PRESCRITE");
    }
    rechercheDecorReglementaire(contexte);
    
    affecterProduit(contexte);
    
    determinerContexteExamen(contexte);
    
    determinerContextesLiquidation(contexte);
    
    controlerDonneesForcees(contexte);
    
    liquiderDemande(contexte);
    
    controlerDonneesForceesPostLiquidation(contexte);
    
    alimenterDecisionsReexamen(contexte, resultatLiquidation);
    
    verifierPostContexte(getDemande(contexte));
    
    resultatLiquidation.setDemande(getDemandeAsu(contexte));
    
    determinerCREMModificationLiquidation(contexte, resultatLiquidation);
    
    OutilTrace.tracerFinParcours();
    return resultatLiquidation;
  }
  
  protected void chargermentListePNDSIndividu(DemandeSpec demandeCourante, Damj dateExamen)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec odPourRevision = ((DemandeAssuranceSpec)demandeCourante).rechercherOuvertureDroitPrecedenteDuMemeType();
    if (odPourRevision != null) {
      super.chargermentListePNDSIndividu(odPourRevision.getDemande(), odPourRevision.getDateExamen());
    }
  }
  
  private void initialiserRegimeEuropeen(Demande demande)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionAssurancePrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, new FiltreAttributionStandardAssurance(true, true, false, true, demande));
    if (attributionAssurancePrecedente != null)
    {
      AttributionAssuranceSpec attribMaitre = (AttributionAssuranceSpec)attributionAssurancePrecedente.getOuvertureDroit();
      if (attribMaitre != null) {
        demande.getDonneesTemporaires().setTypeCoordinationEuropeenne(((Demande)attribMaitre.getDemande()).getDonneesTemporaires().getTypeCoordinationEuropeenne());
      }
    }
  }
  
  private void rechercheDecorReglementaire(Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)getDemande(contexte);
    
    ActiviteSalarie periode = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(demande.getDonneesTemporaires().getIdentifiantPeriodeActiviteConserveePerdue());
    if (periode == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A6MB3");
    }
    if ((periode.getPeriode().getFin() != null) && (periode.getPeriode().getFin().coincideAvec(Damj.FIN_DES_TEMPS))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PER_ACT_PERDUE_OUVERTE");
    }
    int codeMotifFin = periode.getCodeMotifFin();
    int contexteDemission = periode.getContrat().getContexteDemission();
    if (!DetectionTypeChomage.estChomageLegitime(codeMotifFin, contexteDemission)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A6MB4");
    }
    if (!estAttesteeAEOuEquivalent(periode)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PER_ACT_ORIGINE_PERIODE_INVALIDE");
    }
  }
  
  private boolean estAttesteeAEOuEquivalent(ActiviteSalarie periode)
  {
    return new FiltrePeriodesAttestees().accepter(periode);
  }
  
  protected void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    super.determinerContextesLiquidation(contexte);
    if ((getDom(contexte).getAttributionPrecedente() == null) || (!getDom(contexte).getAttributionPrecedente().estMaintenue())) {
      switch (getDom(contexte).getContexteExamen())
      {
      case 1: 
      case 2: 
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_BLOQUANTE_A10MB2");
        break;
      }
    }
  }
  
  protected void liquiderDemande(Contexte contexte)
    throws ApplicativeException
  {
    determinerOrdreObjectifs(contexte);
    
    traiterObjectifs(contexte);
  }
  
  protected void determinerOrdreObjectifs(Contexte contexte)
    throws ApplicativeException
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)getDemandeAsu(contexte).getDossierAffectation().getProduit();
    produit.determinerOrdreObjectifs(contexte);
  }
  
  private void traiterObjectifs(Contexte contexte)
    throws ApplicativeException
  {
    Demande demandeCourante = getDemandeAsu(contexte);
    
    ObjectifExamen objectifCourant = demandeCourante.getObjectifParNumeroOrdre(1);
    
    boolean traitementFini = false;
    while (!traitementFini)
    {
      lancerParcoursObjectif(contexte, objectifCourant);
      if (objectifCourant.getEtat() == 21)
      {
        proposerRevision(contexte);
        objectifCourant.setEtat(23);
        traitementFini = true;
      }
      else
      {
        ObjectifExamen objectifNonTraite = verifierExistenceObjectifNonTraite(contexte);
        if (objectifNonTraite == null)
        {
          proposerEchec(contexte);
          traitementFini = true;
        }
        else
        {
          objectifCourant = objectifNonTraite;
        }
      }
    }
    getDemandeAsu(contexte).setObjectifCourant(null);
  }
  
  private void proposerRevision(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = getDemandeAsu(contexte);
    
    ((DecisionSpec)demande.getDossierExamen()).setNatureDecision(getDemandeAsu(contexte).getObjectifCourant().getSousType());
    
    alimenterTranchesExecutables(contexte);
    
    demande.setListeMotifsReexamen(null);
  }
  
  private void proposerEchec(Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demande = getDemandeAsu(contexte);
    
    demande.setListeMotifsReexamen(null);
    
    DossierExamenSpec dossierExamen = demande.getDossierAffectation().getDossierExamen();
    ((DossierExamenAssuranceSpec)dossierExamen).setContributionParticuliere(null);
    
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    demande.setDemandeOrigine((DemandeAssuranceSpec)dom.getAttributionPrecedente().getDemande());
    
    Collection listeObjectifs = demande.getListeObjectifsExamen();
    for (Iterator iter = listeObjectifs.iterator(); iter.hasNext();)
    {
      ObjectifExamen objectif = (ObjectifExamen)iter.next();
      if (objectif.getType() == 4)
      {
        demande.getDossierAffectationAdmission().getDossierExamen().changerEtat(29);
        ((DecisionSpec)demande.getDossierAffectationAdmission().getDossierExamen()).setNatureDecision(29);
      }
    }
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu individu)
  {
    return 0;
  }
  
  protected void alimenterAgregatGaec(Individu individu, String idDemande)
  {
    individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(0);
  }
  
  protected void controlerPostTraitement(Individu individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(individu.getDonneesChargementGaec().getAppelGaecReduit(), 0);
  }
  
  protected void positionnerPasseProRevisionAvecExclusionFctReviseesAre14(Demande pDemande) {}
  
  protected void activerChronoPasseProPourLiquidationRevision(IndividuSpec pIndividu) {}
  
  protected void desactiverChronoPasseProPourLiquidationRevision(IndividuSpec pIndividu) {}
}

/* Location:
 * Qualified Name:     ParcoursLiquidationAssuranceRevision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */