package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.SituationDemandeur;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationauto.OutilFonctionnelTraitementsErreurs;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.CalculAffiliation;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.ComparateurDecision;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.DeterminationContexte;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.LiquidationSimplifiee;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.DeterminationSituationDemandeur;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.OutilLiquidationSimplifiee;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.OutilPeriodesAffiliation;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.OutilRecherchePra;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesEntreeOutilLiquidationSimplifiee;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesEntreeOutilPeriodesAffiliation;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesEntreeOutilRecherchePra;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesSortieOutilLiquidationSimplifiee;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesSortieOutilRecherchePra;
import fr.unedic.cali.autresdoms.d12i.dom.DonneesNPDE;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.Entretien;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilDeterminationDateExamen;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursLiquidation;
import fr.unedic.cali.parcours.ParcoursServiceAbstrait;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJoursCalendaires;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.List;

public class ParcoursLiquidationSimplifieeFlux
  extends ParcoursServiceAbstrait
{
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    IndividuSpec individuCourant = getIndividu(contexte);
    if (individuCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Individu absent du contexte");
    }
  }
  
  private void traitementPreLiquidationSimplifiee(Demande demande)
    throws ApplicativeException
  {
    demande.setDemandeLiquidee(true);
    OutilDeterminationDateExamen.getInstance().determinerDateExamen(demande);
  }
  
  private void traitementPostLiquidationSimplifiee(Demande demande)
  {
    demande.setDemandeLiquidee(false);
  }
  
  public Resultat demarrerParcours(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours(Niveau.DEBUG);
    
    ResultatLiquidationSimplifiee resultat = new ResultatLiquidationSimplifiee();
    resultat.setEtat(1);
    
    DomLiquidationSimplifiee dom = (DomLiquidationSimplifiee)contexte.getDonnees();
    Demande demande = (Demande)dom.getDemande();
    resultat.setDomLiquidationSimplifiee(dom);
    traitementPreLiquidationSimplifiee(demande);
    
    DonneesEntreeOutilPeriodesAffiliation donneesAffi = new DonneesEntreeOutilPeriodesAffiliation();
    DonneesEntreeOutilRecherchePra donneesPra = new DonneesEntreeOutilRecherchePra();
    DonneesEntreeOutilLiquidationSimplifiee donneesLiquidation = new DonneesEntreeOutilLiquidationSimplifiee();
    
    DeterminationSituationDemandeur situationDemandeur = new DeterminationSituationDemandeur();
    situationDemandeur.rechercherSituationdemandeur(dom);
    
    alimenterEntretien(dom, donneesAffi);
    if (verifierPreconditions(dom))
    {
      liquiderEnSimplifiee(dom, donneesAffi, donneesPra, donneesLiquidation);
      
      liquiderDemande(dom);
      if (comparerDecisions(dom))
      {
        dom.setNotifierCourrier(true);
        
        demande.setEstInstallationNPDEsurTransaction(true);
        valider(contexte);
      }
    }
    else
    {
      OutilFonctionnelTraitementsErreurs.getInstance().creerTraceCrem(demande, contexte);
    }
    traitementPostLiquidationSimplifiee(demande);
    
    resultat.setEtat(0);
    
    OutilTrace.tracerFinParcours(Niveau.DEBUG);
    
    return resultat;
  }
  
  protected void valider(Contexte contexte)
    throws ApplicativeException
  {
    ((DomLiquidationSimplifiee)contexte.getDonnees()).setEnvoieSigma(false);
    ((DomLiquidationSimplifiee)contexte.getDonnees()).setAppelGestionnaireReexecution(false);
    new LiquidationSimplifiee().valider(contexte);
  }
  
  private boolean comparerDecisions(DomLiquidationSimplifiee dom)
  {
    boolean decisionsIdentiques = true;
    if (ComparateurDecision.comparerDecision(dom) == "D")
    {
      dom.getDemande().annulerDecisions();
      decisionsIdentiques = false;
    }
    return decisionsIdentiques;
  }
  
  private void alimenterDonneesEntreeAffi(DonneesEntreeOutilPeriodesAffiliation donneesAffi, DomLiquidationSimplifiee dom)
  {
    Demande demande = (Demande)dom.getDemande();
    SituationDemandeur situation = dom.getSituationDemandeur();
    DonneesNPDE donneesD12i = demande.getDonneesNPDE();
    donneesAffi.setPresenceFormation(donneesD12i.isEstPresenceFormation());
    
    List<Temporel> periodesD12i = donneesD12i.getListePeriodeAffiliationDeclaree();
    
    Chronologie chrono = new ChronologiePeriodes();
    if (periodesD12i != null)
    {
      Iterator<Temporel> it = periodesD12i.iterator();
      while (it.hasNext())
      {
        Temporel periode = (Temporel)it.next();
        if ((estPeriodeTerminee(periode)) && (estPeriodeTermineeApresDernierFaitGenerateurDeDroit(periode, situation.getDateFgdAsuPrecedent()))) {
          chrono.ajouter(periode);
        }
      }
    }
    donneesAffi.setChronoPeriodesDeclarees(chrono);
  }
  
  private boolean estPeriodeTerminee(Temporel periode)
  {
    return (periode.getDateFin() != null) && (!periode.getDateFin().coincideAvec(Damj.FIN_DES_TEMPS));
  }
  
  private boolean estPeriodeTermineeApresDernierFaitGenerateurDeDroit(Temporel periode, Damj dateDernierFaitGenerateur)
  {
    return (dateDernierFaitGenerateur == null) || ((periode.getDateFin() != null) && (periode.getDateFin().estApres(dateDernierFaitGenerateur)));
  }
  
  private void alimenterEntretien(DomLiquidationSimplifiee dom, DonneesEntreeOutilPeriodesAffiliation donneesAffi)
  {
    Demande demande = (Demande)dom.getDemande();
    
    alimenterDonneesEntreeAffi(donneesAffi, dom);
    demande.setEntretien(OutilPeriodesAffiliation.recupererInformationsEntretien(donneesAffi));
  }
  
  private boolean verifierPreconditions(DomLiquidationSimplifiee dom)
    throws ApplicativeException
  {
    DeterminationContexte determinationContexte = new DeterminationContexte();
    return determinationContexte.determinerContexte(dom) == "S";
  }
  
  private void alimenterDonneesEntreePra(DonneesEntreeOutilRecherchePra donneesPra, DomLiquidationSimplifiee dom)
    throws ApplicativeException
  {
    Demande demande = (Demande)dom.getDemande();
    SituationDemandeur situation = dom.getSituationDemandeur();
    
    donneesPra.setDateInscription(situation.getDateInscription());
    donneesPra.setDernierDeclare(demande.getEntretien().getDateFinContrat());
    donneesPra.setDvPrecedantRepriseIPR(situation.getDateDVprecedantRepriseIPR());
    donneesPra.setEtatReliquat(situation.getEtatReliquat());
    donneesPra.setFgdAsuPrecedent(situation.getDateFgdAsuPrecedent());
    donneesPra.setDerniereFctPeriodeGAEC(situation.getDateFinDernierePeriodeGaec());
  }
  
  private void alimenterDonneesEntreeOutilLiquidation(DonneesEntreeOutilLiquidationSimplifiee donneesLiquidation, DonneesEntreeOutilPeriodesAffiliation donneesAffi, DonneesSortieOutilRecherchePra donneesSortiePra, DomLiquidationSimplifiee dom)
  {
    Demande demande = (Demande)dom.getDemande();
    SituationDemandeur situation = dom.getSituationDemandeur();
    
    donneesLiquidation.setAffiRequise(donneesSortiePra.getAffiRequise());
    donneesLiquidation.setDerniereCi(situation.getDateDerniereCessation());
    donneesLiquidation.setDernierePeriodeGaec(situation.getDateDebutDernierePeriodeGaec());
    donneesLiquidation.setEstPrimo(dom.isEstPrimoDemandeur());
    donneesLiquidation.setEtatReliquat(situation.getEtatReliquat());
    
    boolean produitGerantIccp = false;
    ProduitAsuSpec produit = (ProduitAsuSpec)situation.getProduitReliquat();
    if (produit != null) {
      produitGerantIccp = produit.estProduitGerantIccpEnContexteRepriseSimplifiee();
    }
    donneesLiquidation.setEstProduitGerantIccpEnContexteRepriseSimplifiee(produitGerantIccp);
    donneesLiquidation.setAffiDeclare(demande.getEntretien().getQuantiteAffiliation().getValeurEntiere());
    donneesLiquidation.setDateInscription(situation.getDateInscription());
    donneesLiquidation.setPresenceFormation(donneesAffi.isPresenceFormation());
  }
  
  private void liquiderEnSimplifiee(DomLiquidationSimplifiee dom, DonneesEntreeOutilPeriodesAffiliation donneesAffi, DonneesEntreeOutilRecherchePra donneesPra, DonneesEntreeOutilLiquidationSimplifiee donneesLiquidation)
    throws ApplicativeException
  {
    alimenterDonneesEntreePra(donneesPra, dom);
    Damj finPra = OutilRecherchePra.recupererDateFinPra(donneesPra);
    DureeCalendaire age = dom.getIndividu().getAgeALaDate(finPra);
    
    donneesPra.setDateFinPra(finPra);
    donneesPra.setAgeALaFct(age);
    DonneesSortieOutilRecherchePra donneesSortiePra = OutilRecherchePra.recupererPra(donneesPra);
    
    donneesAffi.setPra(donneesSortiePra.getPra());
    Demande demande = (Demande)dom.getDemande();
    
    OutilPeriodesAffiliation.calculerAffiliationDeclaree(demande.getEntretien(), donneesAffi);
    
    Chronologie gaec = CalculAffiliation.determinerPeriodesParticipantesAvecDeclare(dom.getIndividu(), donneesSortiePra.getPra(), dom.getSituationDemandeur().getDateInscription());
    
    donneesAffi.setChronoPeriodesGAEC(gaec);
    donneesLiquidation.setAffiTotale(OutilPeriodesAffiliation.calculerAffiliationTotale(donneesAffi));
    
    alimenterDonneesEntreeOutilLiquidation(donneesLiquidation, donneesAffi, donneesSortiePra, dom);
    DonneesSortieOutilLiquidationSimplifiee sortieLiquidation = OutilLiquidationSimplifiee.liquider(donneesLiquidation);
    
    dom.setNatureDecisionAttendue(sortieLiquidation.getNatureDecision());
    dom.setCodeMotifEchecANotifier(String.valueOf(sortieLiquidation.getCodeMotifRejet()));
    
    ProduitAsuSpec produit = (ProduitAsuSpec)dom.getSituationDemandeur().getProduitReliquat();
    if ((produit != null) && (produit.estProduitGerantIccpEnContexteRepriseSimplifiee()) && (sortieLiquidation.getJoursIccpConservatoire() != null) && (sortieLiquidation.getJoursIccpConservatoire().getValeur().compareTo(BigDecimal.ZERO) > 0))
    {
      ((Demande)dom.getDemande()).getDonneesTemporaires().setSaisieCasGeneralDonneesTemporaire(true);
      ((Demande)dom.getDemande()).getDonneesTemporaires().setQuantiteJoursDiffereIccpConservatoire(sortieLiquidation.getJoursIccpConservatoire());
    }
  }
  
  private void liquiderDemande(DomLiquidationSimplifiee dom)
    throws ApplicativeException
  {
    DemandeSpec demande = dom.getDemande();
    
    demande.setModeLiquidation("S");
    
    DomLiquidationDemande domContexte = null;
    Contexte contexteParcours = null;
    ParcoursLiquidation parcoursLiquidationDemande = null;
    
    domContexte = demande.getGamme().creerDomLiquidationDemande();
    domContexte.setDemande(demande);
    domContexte.setIdDemande(demande.getIdentifiant());
    domContexte.setIndividu(demande.getDemandeur());
    domContexte.setContexteService(demande.getDemandeur().getContexteService());
    contexteParcours = new Contexte();
    contexteParcours.setDonnees(domContexte);
    
    parcoursLiquidationDemande = demande.getGamme().getParcoursLiquidation(demande);
    parcoursLiquidationDemande.effectuerParcours(contexteParcours);
    
    dom.setDemandeStandard(demande);
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu individu)
  {
    return 2;
  }
  
  protected void alimenterAgregatGaec(Individu individu, String idDemande)
  {
    if (individu != null) {
      individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(2);
    }
  }
  
  protected void controlerPostTraitement(Individu individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(individu.getDonneesChargementGaec().getAppelGaecReduit(), 2);
  }
}

/* Location:
 * Qualified Name:     ParcoursLiquidationSimplifieeFlux
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */