package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.calcul.dom.CalendrierExecutionCalcul;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ElementBaseActiviteReduite;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.dom.cge01.AttributionAssuranceCgeSpec;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.mnt.dom.Accord;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionEESSI;
import fr.unedic.cali.asu.outilsfonctionnels.OutilTranchesExecutables;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsRevisions;
import fr.unedic.cali.asu.outilsfonctionnels.RechercherDemandeMaintien;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.AttributionGen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.DureeReglementaireSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.FinancementSpec;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.RecuperationElementActiviteReduite;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.RecuperationElementIndemnisation;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvantSpec;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.ConventionGestion;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.Prescription;
import fr.unedic.cali.dom.QuantiteDroit;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.ApplicativeRuntimeException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.UniteDuree;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public abstract class Attribution
  extends AttributionGen
  implements AttributionAssuranceCgeSpec
{
  private static final long serialVersionUID = 1L;
  protected transient ElementBaseIndemnisation ebiAttribution = null;
  protected transient ElementBaseActiviteReduite ebacAttribution = null;
  private transient boolean isUnJourDiffereConsomme = false;
  private transient Damj pjiEffectif;
  protected transient MaintienEuropeen maintienEuropeen;
  public static final transient int DUREE_PROLONGATION_THEORIQUE = 182;
  private transient Quantite dureeProlongationTheorique = null;
  private transient ElementChomageSansRupture elementChomageSansRupture = null;
  protected transient DemandeSpec demandeSuivantePourTraitementReliquat;
  private Collection<CarencePrefixeAFixer> listeCarencesForcees = null;
  
  public Attribution(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Attribution() {}
  
  public Attribution(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    Attribution copieAttribution = (Attribution)copie;
    super.copieElements(copieAttribution);
    copieAttribution.setUnJourDiffereConsomme(isUnJourDiffereConsomme());
    copieAttribution.setPjiEffectif(getPjiEffectif());
    copieAttribution.setReferenceExterne(getReferenceExterne());
    copieAttribution.setTopRenoncement(estTopeeRenoncement());
    copieAttribution.setNbJoursActiviteCourrierASS(getNbJoursActiviteCourrierASS());
    copieAttribution.setDemandeSuivantePourTraitementReliquat(getDemandeSuivantePourTraitementReliquat());
    copieAttribution.setCumulMoisActiviteReduite(getCumulMoisActiviteReduite());
    
    copieAttribution.clearCollectionTranchesExecutables();
    Iterator<TrancheExecutable> iter = getListTranchesExecutables().iterator();
    while (iter.hasNext())
    {
      TrancheExecutable element = (TrancheExecutable)iter.next();
      copieAttribution.ajouterTranchesExecutables((TrancheExecutable)element.copie());
    }
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public boolean estDemandeSuiteExamenFilEau()
  {
    return ((Demande)getDemande()).estUneDemandeEfe();
  }
  
  public boolean estMaintenue()
  {
    DemandeMaintien demandeMaintien = RechercherDemandeMaintien.rechercherDemandeMaintien(getDemande().getDemandeur(), this);
    return (demandeMaintien != null) && ((demandeMaintien.getDossierExamen() instanceof Accord)) && (!demandeMaintien.estEnReExamen());
  }
  
  public boolean estTopeeRenoncement()
  {
    return isTopRenoncement();
  }
  
  public int getCompetenceAdministrative()
  {
    return getCompetence().getCompetenceAdministrative();
  }
  
  public int getCompetenceFinanciere()
  {
    return getCompetence().getCompetenceFinanciere();
  }
  
  public AttributionSpec getAttributionMaitre()
  {
    switch (getNatureDecision())
    {
    case 11: 
    case 26: 
      int montantRetenu = getConstitutionProduitResultant().getTypeMontantRetenu();
      if (1 == montantRetenu) {
        return this;
      }
      if (getAttributionPrecedente() != null) {
        return getAttributionPrecedente().getAttributionMaitre();
      }
    case 10: 
    case 12: 
    case 32: 
    case 35: 
    case 38: 
    case 39: 
    case 40: 
      return this;
    case 3: 
    case 13: 
    case 15: 
    case 27: 
    case 34: 
    case 46: 
      return getAttributionPrecedente().getAttributionMaitre();
    }
    return null;
  }
  
  public Damj getDateFaitGenerateur()
  {
    Damj dateRetour = null;
    if (getFaitGenerateur() != null) {
      dateRetour = getFaitGenerateur().getDateFaitGenerateur();
    }
    return dateRetour;
  }
  
  public Quantite getDureeIndemnisationTheorique()
  {
    return getDureeTheorique();
  }
  
  public Quantite getDureeTheorique()
  {
    ConstitutionDurees constitutionDurees = getConstitutionDurees();
    if (constitutionDurees != null)
    {
      DureeIndemnisation dureeIndemnisation = constitutionDurees.getDureeIndemnisation();
      if (dureeIndemnisation != null) {
        return dureeIndemnisation.getDureeTheorique();
      }
    }
    return null;
  }
  
  public Quantite getDureeIndemnisationInitiale()
  {
    if ((getConstitutionDurees() != null) && (getConstitutionDurees().getDureeIndemnisation() != null)) {
      return getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    }
    return null;
  }
  
  public Quantite getDureeInitiale()
  {
    AttributionSpec attributionMaitre = getOuvertureDroitCapitalRetenu();
    if (attributionMaitre == this)
    {
      if ((getConstitutionElementsActifs().getConstitutionDurees() != null) && (getConstitutionElementsActifs().getConstitutionDurees().getDureeIndemnisation() != null)) {
        return getConstitutionElementsActifs().getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
      }
      return null;
    }
    return ((AttributionAssuranceSpec)attributionMaitre).getDureeInitiale();
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
  {
    controleTrancheExecutableActivee();
    if (ebiAttribution == null) {
      ebiAttribution = RecuperationElementIndemnisation.recupererElementBaseIndemnisation(this);
    }
    return (ElementBaseIndemnisation)ebiAttribution.copie();
  }
  
  public void supprimerCacheElementBaseIndemnisation()
  {
    ebiAttribution = null;
  }
  
  protected void controleTrancheExecutableActivee()
  {
    if ((!OutilTranchesExecutables.estUnProduitSpectacle(getProduitMontantRetenu())) && (((ProduitAsuSpec)getProduit()).estTrancheActivee(getDemande()))) {
      throw new UnsupportedOperationException("L'EBI est désactivé pour le produit : " + getProduit().getNomUnique());
    }
  }
  
  public void setElementBaseIndemnisation(ElementBaseIndemnisation elementBaseIndemnisation)
  {
    ebiAttribution = elementBaseIndemnisation;
  }
  
  public ElementBaseActiviteReduite getElementBaseActiviteReduite()
  {
    if (ebacAttribution == null) {
      ebacAttribution = RecuperationElementActiviteReduite.recupererElementBaseActiviteReduite(this);
    }
    return ebacAttribution;
  }
  
  public FormuleMontantSpec getFormuleMontant(String code)
  {
    FormuleMontantSpec formuleRetour = ((ProduitAsuSpec)getProduitExecution()).getFormuleMontant(code);
    
    Demande demande = (Demande)getDemande();
    if ((demande.getDonneesDemandeAssociee() != null) && (demande.getDonneesDemandeAssociee().getDemandeAssociee() != null))
    {
      if (String.valueOf(2).equals(getConstitutionMontantsBruts().getTypeMontantRetenuDroitCourant())) {
        formuleRetour.setFormuleMontantApplicable(2);
      } else {
        formuleRetour.setFormuleMontantApplicable(1);
      }
      if (demande.getDonneesDemandeAssociee().getDemandeAssociee().getAttribution() != null) {
        formuleRetour.setFormuleMontantDroitAssocie(demande.getDonneesDemandeAssociee().getDemandeAssociee().getAttribution().getFormuleMontant("2"));
      }
    }
    return formuleRetour;
  }
  
  public Collection<CarencePrefixeAFixer> getListeCarences()
  {
    if (listeCarencesForcees != null) {
      return listeCarencesForcees;
    }
    Collection<CarencePrefixeAFixer> collection = new ArrayList();
    ConstitutionDelais constitutionDelais = getConstitutionDelais();
    if (constitutionDelais != null) {
      collection = getConstitutionDelais().getListeCarencesAAppliquer();
    }
    return collection;
  }
  
  public void ajouterCarencesForcees(CarencePrefixeAFixer carence)
  {
    if (listeCarencesForcees == null) {
      listeCarencesForcees = new ArrayList();
    }
    if (carence != null) {
      listeCarencesForcees.add(carence);
    }
  }
  
  public void supprimerCarencesForcees()
  {
    listeCarencesForcees = null;
  }
  
  public ConventionGestionSpec getConventionGestion()
  {
    ConventionGestionSpec conventionGestion = null;
    if (getCompetence().getConventionGestion() != null)
    {
      ConventionGestionSpec conventionGestionOrigine = getCompetence().getConventionGestion();
      conventionGestion = new ConventionGestion(conventionGestionOrigine.getNumeroConventionGestion(), conventionGestionOrigine.getCodeAffectation(), conventionGestionOrigine.isEstAideArce(), conventionGestionOrigine.isEstAideAdr(), conventionGestionOrigine.isEstAideCongeNonPaye(), conventionGestionOrigine.isEstAideFinDroit(), conventionGestionOrigine.isEstAideAllocationDeces(), conventionGestionOrigine.getSignataire(), conventionGestionOrigine.estPrecompteCRC(), conventionGestionOrigine.getDebutValidite(), conventionGestionOrigine.getFinValidite(), conventionGestionOrigine.getLibelleAffectation(), conventionGestionOrigine.estIdExterneObligatoire());
    }
    return conventionGestion;
  }
  
  public Damj getTermePrcActiviteConservee()
  {
    Damj termePrcSjr = null;
    ConstitutionSjr constitutionSjr = getConstitutionSjr();
    if ((constitutionSjr != null) && (constitutionSjr.getSjrip() != null)) {
      termePrcSjr = constitutionSjr.getSjrip().getDateEffet();
    }
    return termePrcSjr;
  }
  
  public boolean isCapitalRetenuCourant()
  {
    return true;
  }
  
  public boolean isMontantRetenuCourant()
  {
    return true;
  }
  
  public boolean isUnJourDiffereConsomme()
  {
    return isUnJourDiffereConsomme;
  }
  
  public void setUnJourDiffereConsomme(boolean isUnJourDiffereConsomme)
  {
    this.isUnJourDiffereConsomme = isUnJourDiffereConsomme;
  }
  
  public boolean estEnReexamen()
  {
    return getDemande().estEnReExamen();
  }
  
  public boolean estExecutable()
  {
    String typeExamen = getDemande().getEvenementReferenceExamen().getTypeExamen();
    boolean contexteRevisionEnRejetDv = OutilsRevisions.estContexteAttributionEnCoursRevisionAre14AvecRejetDv((Demande)getDemande());
    return (estNonClassementAdministratifValide()) && (!estEnReexamen()) && (!estNeutralise()) && (estValidee()) && (!((DemandeAssuranceSpec)getDemande()).estUneDemandeFinDroit()) && (!((DemandeAssuranceSpec)getDemande()).estUneDemandeFinancement()) && (getCompetence().getCompetenceAdministrative() == 1) && (!estTopeeRenoncement()) && (!((Demande)getDemande()).isEstNonExecutable()) && ((!"ASU_29".equals(typeExamen)) || (getDemande().getDatePremiereValidation() != null)) && (!contexteRevisionEnRejetDv);
  }
  
  private boolean estNonClassementAdministratifValide()
  {
    return (getDemande().getClassementAdministratif() == null) || (((getDemande().getClassementAdministratif() instanceof Prescription)) && (!((Prescription)getDemande().getClassementAdministratif()).isValidite()));
  }
  
  public boolean estMigree()
  {
    return getDemande().estMigree();
  }
  
  public boolean estMigreeEnSimplifiee()
  {
    return getDemande().estMigreeEnSimplifiee();
  }
  
  public boolean estNeutralise()
  {
    return getDemande().estNeutraliseeCalcul();
  }
  
  public boolean estPjiEffectif()
  {
    return pjiEffectif != null;
  }
  
  public Collection getAttributionLiees()
  {
    return null;
  }
  
  public Damj getDateExamen()
  {
    return getDemande().getDateExamen();
  }
  
  public Damj getDateFinAbonnement()
  {
    return getDemande().getDateFinAbonnement();
  }
  
  public IndividuSpec getDemandeur()
  {
    return getDemande().getDemandeur();
  }
  
  public GammeSpec getGamme()
  {
    return getDemande().getGamme();
  }
  
  public String getIdentifiantDemande()
  {
    return getDemande().getIdentifiant();
  }
  
  public Damj getPji()
  {
    Damj pji = null;
    if (pjiEffectif != null) {
      pji = pjiEffectif;
    } else if (getConstitutionPointDepartIndemnisation() != null) {
      pji = getConstitutionPointDepartIndemnisation().getPji();
    }
    return pji;
  }
  
  public Damj getPjiEffectif()
  {
    return pjiEffectif;
  }
  
  public ProduitSpec getProduit()
  {
    return getDossierAffecte().getProduit();
  }
  
  public String getTypeExamen()
  {
    return getDemande().getEvenementReferenceExamen().getTypeExamen();
  }
  
  public void setPjiEffectif(Damj pjiEffectif)
  {
    this.pjiEffectif = pjiEffectif;
  }
  
  public void setReexecutee(boolean estReexecute)
  {
    getDemande().setReexecutee(estReexecute);
  }
  
  public boolean estDemandeSuiteFinDeDroit()
  {
    Demande demande = (Demande)getDemande();
    return demande.estDemandeSuiteFinDeDroit();
  }
  
  public boolean isTopContratsRemuneresBaseSmic()
  {
    Sjrip sjrip = getConstitutionSjr().getSjrip();
    if ((sjrip != null) && (sjrip.getPrc() != null)) {
      return sjrip.getPrc().isTopContratsDeTypeParticulier();
    }
    return false;
  }
  
  public Sjc getSJC()
  {
    ConstitutionSjc constitutionSjc = getConstitutionSjc();
    Sjc sjcTemporaire;
    Sjc sjcTemporaire;
    if ((constitutionSjc != null) && (constitutionSjc.getSjcip() != null))
    {
      sjcTemporaire = constitutionSjc.getSjci();
    }
    else
    {
      ConstitutionSjr constitutionSjr = getConstitutionSjr();
      
      sjcTemporaire = new Sjc(BigDecimal.ZERO, constitutionSjr.getSjrip().getDateEffet(), constitutionSjr.getSjrip().getContexteParticulierSjr());
    }
    return sjcTemporaire;
  }
  
  public Reglement getRegime()
  {
    Reglement reglementApplicable = null;
    ReglementApplicableSpec reglement = getReglementApplicable();
    if (reglement != null) {
      reglementApplicable = reglement.getReglement();
    }
    return reglementApplicable;
  }
  
  public String getNomReglementApplicable()
  {
    String nomRetour = null;
    Reglement regime = getRegime();
    if (regime != null) {
      nomRetour = regime.getNomReglement();
    }
    return nomRetour;
  }
  
  public List<QuantiteDroit> getListeDurees()
  {
    ArrayList<QuantiteDroit> listeDurees = new ArrayList();
    if ((getConstitutionDurees() != null) && (getConstitutionDurees().getDureeIndemnisation() != null)) {
      listeDurees.add(((ProduitAsuSpec)getProduit()).creerDureeCalcul(this));
    }
    Demande demande = (Demande)getDemande();
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demande))
    {
      DureeProlongation dureeProlongation = new DureeProlongation();
      listeDurees.add(dureeProlongation.creerDureeCalcul());
    }
    else
    {
      Quantite dureePostPrime = getDureePostPrime();
      if (dureePostPrime != null)
      {
        DureePostPrime dureePostPrimeObjet = new DureePostPrime();
        dureePostPrimeObjet.creerDureeCalcul(dureePostPrime.getValeurEntiere());
      }
    }
    return listeDurees;
  }
  
  public Damj getDateLimiteIndemnisation()
  {
    Damj dateLimiteIndem = null;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "ARECOURCSP"))
    {
      dateLimiteIndem = getConstitutionDateLimiteIndemnisation().getDateLimiteIndem();
    }
    else
    {
      ConstitutionDateLimiteIndemnisation constitutionDateLimiteIndemnisation = getConstitutionDateLimiteIndemnisationAttributionOrigine();
      if (constitutionDateLimiteIndemnisation != null) {
        dateLimiteIndem = constitutionDateLimiteIndemnisation.getDateLimiteIndem();
      }
    }
    return dateLimiteIndem;
  }
  
  public String getContexteDateLimiteIndemnisation()
  {
    String contexteDateLimiteIndemnisation = null;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "ARECOURCSP"))
    {
      contexteDateLimiteIndemnisation = getConstitutionDateLimiteIndemnisation().getContexteDateLimiteIndemnisation();
    }
    else
    {
      ConstitutionDateLimiteIndemnisation constitutionDateLimiteIndemnisation = getConstitutionDateLimiteIndemnisationAttributionOrigine();
      if (constitutionDateLimiteIndemnisation != null)
      {
        contexteDateLimiteIndemnisation = constitutionDateLimiteIndemnisation.getContexteDateLimiteIndemnisation();
        if ((contexteDateLimiteIndemnisation == null) && (constitutionDateLimiteIndemnisation.getDateLimiteIndem() != null))
        {
          boolean estTypeProduitCsp = ProduitAbstrait.estDuType(2, getProduit());
          if (estTypeProduitCsp) {
            contexteDateLimiteIndemnisation = "IDEASP";
          }
          ContexteDemande contexteDemande = (ContexteDemande)OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent((Demande)getDemande(), 2);
          if ((contexteDemande != null) && (getDateLimiteIndemnisation().coincideAvec(contexteDemande.getDateFinJustifContexte()))) {
            contexteDateLimiteIndemnisation = "CRSPMVS";
          }
        }
      }
    }
    return contexteDateLimiteIndemnisation;
  }
  
  protected abstract ConstitutionDateLimiteIndemnisation getConstitutionDateLimiteIndemnisationAttributionOrigine();
  
  public Quantite getDureeProlongationTheorique()
  {
    Demande demande = (Demande)getDemande();
    if ((dureeProlongationTheorique == null) && (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demande))) {
      dureeProlongationTheorique = new Quantite(new BigDecimal(Integer.toString(182)), UniteDuree.JOUR);
    }
    return dureeProlongationTheorique;
  }
  
  public ElementChomageSansRupture getElementChomageSansRupture()
  {
    if ((elementChomageSansRupture == null) && (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(getDemande()))) {
      elementChomageSansRupture = new ElementChomageSansRupture(this);
    }
    return elementChomageSansRupture;
  }
  
  public ElementChomageSansRupture getElementChomageSansRuptureAttributionPrecedente()
  {
    ElementChomageSansRupture retour = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if ((attributionPrecedente instanceof Attribution)) {
      retour = ((Attribution)attributionPrecedente).getElementChomageSansRupture();
    }
    return retour;
  }
  
  public MontantAsuSpec getMontantRecalcule(Damj dateRecalcul)
    throws CoucheLogiqueException
  {
    return recalculerMontantAttribution(dateRecalcul);
  }
  
  protected MontantAsuSpec recalculerMontantAttribution(Damj dateRecalcul)
    throws CoucheLogiqueException
  {
    GammeAsuSpec gamme = (GammeAsuSpec)getGamme();
    
    DonneesEntreesRecuperationMontant donneesEntrees = gamme.mapperDonneesEntreesRecuperationMontant(this);
    donneesEntrees.setDateCalculMontant(dateRecalcul);
    
    return DeterminationMontant.determinerMontant(donneesEntrees);
  }
  
  public void setCalendrierExecutionAvant(CalendrierExecutionAvantSpec calendrierAvant)
  {
    DomManager.supprimer(super.getCalendrierExecutionAvant(), calendrierAvant);
    super.setCalendrierExecutionAvant(calendrierAvant);
  }
  
  public void setCalendrierExecutionCalcul(CalendrierExecutionCalculSpec calendrier)
  {
    DomManager.supprimer(super.getCalendrierExecutionCalcul(), calendrier);
    super.setCalendrierExecutionCalcul(calendrier);
  }
  
  public void marquerGraphePersistant()
  {
    verifierCoherenceReferenceExterne();
    Demande demande = (Demande)getDemande();
    if ((demande != null) && (demande.getObjectifSatisfait() == null)) {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_TECHNIQUE_GRAPHE_INCOHERENT", "Erreur technique : Il n'existe pas d'objectif satisfait alors que nous avons une attribution");
    }
    super.marquerGraphePersistant();
    
    DomManager.persisterEnProfondeur(super.getCalendrierExecutionCalcul());
    DomManager.persisterEnProfondeur(super.getCalendrierExecutionAvant());
    
    DomManager.persisterEnProfondeur(super.getCollectionTranchesExecutables());
  }
  
  protected void verifierCoherenceReferenceExterne()
  {
    if ((getReferenceExterne() == null) && (!"ASU_21".equals(getDemande().getEvenementReferenceExamen().getTypeExamen()))) {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_TECHNIQUE_GRAPHE_INCOHERENT", "Erreur technique : Le RSOD (reference externe) sur l'attribution est null");
    }
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    return (ProduitAsuSpec)getDossierAffecte().getProduit();
  }
  
  public boolean estDemandeExpresse()
  {
    return ((Demande)getDemande()).estUneDemandeExpresse();
  }
  
  public DemandeSpec getDemandeSuivantePourTraitementReliquat()
  {
    return demandeSuivantePourTraitementReliquat;
  }
  
  public void setDemandeSuivantePourTraitementReliquat(DemandeSpec demandeSuivantePourTraitementReliquat)
  {
    this.demandeSuivantePourTraitementReliquat = demandeSuivantePourTraitementReliquat;
  }
  
  public abstract Damj getDateFaitGenerateurDroit();
  
  public String determinerCodeSousProduitPourSigma()
  {
    if ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "AREENTRCSP")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "ARECOURCSP"))) {
      return OutilAsp.getInstance().recupererProduitReglementaire(getDemande()).determinerCodeSousProduitPourSigma(this);
    }
    return ((ProduitAsuSpec)getProduit()).determinerCodeSousProduitPourSigma(this);
  }
  
  public Quantite getDureeIndemnisationEffective()
  {
    ConstitutionDurees constitutionDurees = getConstitutionDurees();
    if ((constitutionDurees != null) && (constitutionDurees.getDureeIndemnisation() != null)) {
      return constitutionDurees.getDureeIndemnisation().getDureeEffective();
    }
    return null;
  }
  
  public Damj getPremierJourIndemnisable()
  {
    return getConstitutionPointDepartIndemnisation().getPji();
  }
  
  public boolean estPresenceDiffere()
  {
    ConstitutionDelais constitutionDelais = getConstitutionDelais();
    boolean presenceDiffere = false;
    if (constitutionDelais != null) {
      presenceDiffere = constitutionDelais.getNbJoursCarenceDiffere() != 0;
    }
    return presenceDiffere;
  }
  
  public BigDecimal getSeuilMensuelPansConservees()
  {
    ConditionActiviteConservee conditionActiviteConservee = getConditionActiviteConservee();
    if (conditionActiviteConservee != null) {
      return conditionActiviteConservee.getSeuilMensuelPansConditionActiviteConservee();
    }
    return null;
  }
  
  public int getBassinEmploi()
  {
    Attribution attributionOrigine = (Attribution)getOuvertureDroit();
    return attributionOrigine.getConditionFaitGenerateur().getCodeBassinCtp();
  }
  
  public AttributionAssuranceSpec getAttributionFinancement()
  {
    Attribution attributionOrigine = (Attribution)getOuvertureDroit();
    
    Demande demandeOrigine = (Demande)attributionOrigine.getDemande();
    
    FinancementSpec attributionFinancement = null;
    if (demandeOrigine.getDonneesDemandeAssociee() != null)
    {
      Demande demandeFinancement = demandeOrigine.getDonneesDemandeAssociee().getDemandeAssociee();
      if ((demandeFinancement != null) && ((demandeFinancement.getAttribution() instanceof FinancementSpec))) {
        attributionFinancement = (FinancementSpec)demandeFinancement.getAttribution();
      }
      if ((attributionFinancement != null) && ("E".equalsIgnoreCase(attributionFinancement.getNatureFinancement()))) {
        return null;
      }
    }
    return (AttributionAssuranceSpec)attributionFinancement;
  }
  
  public MaintienEuropeen getMaintienEuropeen()
  {
    if (maintienEuropeen == null) {
      maintienEuropeen = MaintienEuropeen.getInstanceMaintienEuropeen(this);
    }
    return maintienEuropeen;
  }
  
  public BigDecimal getNbJoursIccp()
  {
    ConstitutionDelais constitutionDelais = getConstitutionDelais();
    BigDecimal jours = null;
    if (constitutionDelais != null) {
      jours = new BigDecimal(constitutionDelais.getNbJoursCarenceICCP());
    }
    return jours;
  }
  
  public DemandeSpec getDemandeMontantRetenu()
  {
    return getDemande();
  }
  
  public Damj getDateEffetDecision()
  {
    return getDateAttribution();
  }
  
  public int getTypeMontantRetenu()
  {
    return 1;
  }
  
  public int getTypeCapitalRetenu()
  {
    return 1;
  }
  
  public AttributionAssuranceSpec rechercherAttributionPrecedenteDuMemeType()
  {
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente == null) {
      attributionPrecedente = super.rechercherAttributionPrecedenteDuMemeType();
    }
    return attributionPrecedente;
  }
  
  public fr.unedic.cali.asu.dom.OdAssuranceSpec rechercherOuvertureDroitPrecedenteDuMemeType()
  {
    fr.unedic.cali.asu.dom.OdAssuranceSpec odAssuranceSpec = (fr.unedic.cali.asu.dom.OdAssuranceSpec)getOuvertureDroit();
    if ((odAssuranceSpec == null) || (getAttributionPrecedente() == null)) {
      odAssuranceSpec = super.rechercherOuvertureDroitPrecedenteDuMemeType();
    }
    return odAssuranceSpec;
  }
  
  public CalendrierExecutionCalculSpec getCalendrierExecutionCalcul()
  {
    if ((((Demande)getDemande()).estUneDemandeFinDroit()) && (getDemande().estDecisionnee()) && (!getDemande().estEnReExamen()))
    {
      DemandeAssuranceSpec demande = (DemandeAssuranceSpec)OutilFinDroit.rechercherDemandePrecedenteCorrespondante(getDemande());
      CalendrierExecutionCalculSpec calendrier = null;
      if ((demande != null) && (demande.getAttribution().getCalendrierExecutionCalcul() != null)) {
        calendrier = ((CalendrierExecutionCalcul)demande.getAttribution().getCalendrierExecutionCalcul()).dupliquerEtatAuDji();
      }
      return calendrier;
    }
    return super.getCalendrierExecutionCalcul();
  }
  
  public Collection getListePensionInvalidite()
  {
    return getConstitutionMontantsBruts().getListePensionInvalidite();
  }
  
  public boolean notifierEESSI()
  {
    return OutilGestionEESSI.getInstance().estAttributionAssuranceFrontaliere(this);
  }
  
  public AttributionAssuranceSpec getAttributionAssociee()
  {
    Demande demande = (Demande)getDemande();
    if ((demande.getDonneesDemandeAssociee() != null) && (demande.getDonneesDemandeAssociee().getDemandeAssociee() != null) && (demande.getDonneesDemandeAssociee().getDemandeAssociee().getAttribution() != null))
    {
      Demande demandeAssociee = demande.getDonneesDemandeAssociee().getDemandeAssociee();
      return demandeAssociee.getAttribution();
    }
    return null;
  }
  
  public Quantite getMontantJournalierBrut()
  {
    switch (getNatureDecision())
    {
    case 11: 
    case 26: 
      return getConstitutionProduitResultant().getMontantJournalierBrut();
    }
    return getConstitutionMontantsBruts().getMontantJournalierBrut();
  }
  
  public List<TrancheExecutable> getListTranchesExecutables()
  {
    for (Iterator<TrancheExecutable> iter = super.getListTranchesExecutables().iterator(); iter.hasNext();)
    {
      TrancheExecutable element = (TrancheExecutable)iter.next();
      element.setAttribution(this);
    }
    return super.getListTranchesExecutables();
  }
  
  public Collection<TrancheExecutable> getCollectionTranchesExecutables()
  {
    return getListTranchesExecutables();
  }
  
  public void clearCollectionTranchesExecutables()
  {
    for (Iterator<TrancheExecutable> iter = getCollectionTranchesExecutables().iterator(); iter.hasNext();)
    {
      TrancheExecutable element = (TrancheExecutable)iter.next();
      DomManager.supprimer(element);
    }
    super.clearCollectionTranchesExecutables();
  }
  
  public void remplacerCollectionTranchesExecutables(Collection collectionACopier)
  {
    for (Iterator<TrancheExecutable> iter = getCollectionTranchesExecutables().iterator(); iter.hasNext();)
    {
      TrancheExecutable element = (TrancheExecutable)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionTranchesExecutables(collectionACopier);
  }
  
  public void setListeTranchesExecutables(Collection<TrancheExecutable> listeTranchesExecutables)
  {
    remplacerCollectionTranchesExecutables(listeTranchesExecutables);
  }
  
  public DemandeMaintien getDemandeMaintien()
  {
    return getDemandeAssurance().getDemandeMaintien();
  }
  
  public SalaireJournalierSpec getSalaireJournalierInitial()
  {
    Sjr sjrTemporaire = null;
    ConstitutionSjr constitutionSjr = getConstitutionSjr();
    if (constitutionSjr != null) {
      sjrTemporaire = constitutionSjr.getSjri();
    }
    return sjrTemporaire;
  }
  
  public SalaireJournalierSpec getSalaireJournalierConserve()
  {
    return getSJC();
  }
  
  public Boolean estAvecPrecompteCRC()
  {
    Boolean crc = null;
    CompetenceSpec competence = getCompetence();
    if ((competence.getCompetenceAdministrative() == 2) && (((Competence)competence).isEstPCRCForce())) {
      crc = Boolean.TRUE;
    }
    return crc;
  }
  
  public BigDecimal getCoefficientSaisonnier()
  {
    BigDecimal coefficientSaisonnier = BigDecimal.ONE;
    ConstitutionCoefficientSaisonnier constitutionCoefficientSaisonnier = getConstitutionCoefficientSaisonnier();
    if (constitutionCoefficientSaisonnier != null) {
      coefficientSaisonnier = constitutionCoefficientSaisonnier.getCoefficientSaisonnierRetenu();
    }
    return coefficientSaisonnier;
  }
  
  public int getNatureCoefficientSaisonnier()
  {
    ConstitutionCaractereSaisonnier constitutionCaractereSaisonnier = getConstitutionCaractereSaisonnier();
    if (constitutionCaractereSaisonnier != null) {
      return constitutionCaractereSaisonnier.getTypeCaractereSaisonnierRetenu();
    }
    return -1;
  }
  
  public boolean a3ansActiviteEn5ans()
  {
    boolean retour = false;
    if (getConstitutionCaractereSaisonnier() != null)
    {
      DureeCalendaire ageALAttribution = new DureeCalendaire(50);
      if (((Demande)getDemande()).getDonneesTemporaires().isCaractereSaisonnierForce())
      {
        if (((Demande)getDemande()).getDonneesTemporaires().getTypeCaractereSaisonnierForce() == 1) {
          if (ageALAttribution.compareTo(getDemandeur().getAgeALaDate(getDemande().getDateDeclenchementExamen())) > 0) {
            retour = true;
          } else {
            retour = getConstitutionCaractereSaisonnier().isActivite3Sur5();
          }
        }
      }
      else {
        retour = getConstitutionCaractereSaisonnier().isActivite3Sur5();
      }
    }
    return retour;
  }
  
  public BigDecimal getCoefficientTempsPartiel()
  {
    BigDecimal valeurCoefficientTempsPartiel = null;
    ConstitutionCoefficientTempsPartiel constitutionCoefficientTempsPartiel = getConstitutionCoefficientTempsPartiel();
    if (constitutionCoefficientTempsPartiel != null) {
      valeurCoefficientTempsPartiel = constitutionCoefficientTempsPartiel.getCoefficientTempsPartielRetenu();
    }
    if (valeurCoefficientTempsPartiel == null) {
      valeurCoefficientTempsPartiel = BigDecimal.ONE;
    }
    return valeurCoefficientTempsPartiel;
  }
  
  public boolean estSjrBaseSmic()
  {
    return isTopContratsRemuneresBaseSmic();
  }
  
  public int getCategorieEmploiA2B()
  {
    return getConstitutionSjr().getCodeEmploiA2b();
  }
  
  public Quantite getMontantPreavis()
  {
    Quantite retour = null;
    ConstitutionMontantsBruts constitutionMontantsBruts = getConstitutionMontantsBruts();
    if (constitutionMontantsBruts != null) {
      retour = constitutionMontantsBruts.getMontantJournalierPreavis();
    }
    return retour;
  }
  
  public Quantite getCapitalAServir()
  {
    Quantite retour = null;
    ConstitutionMontantsBruts constitutionMontantsBruts = getConstitutionMontantsBruts();
    if (constitutionMontantsBruts != null) {
      retour = constitutionMontantsBruts.getCapitalInitialBrut();
    }
    return retour;
  }
  
  public ReglementApplicableSpec getReglementApplicableMontantRetenu()
  {
    return getReglementApplicable();
  }
  
  public void viderCacheElementsChomageSansRupture()
  {
    elementChomageSansRupture = null;
  }
  
  public ProduitSpec getProduitExecution()
  {
    ProduitSpec produitRetour = getProduit();
    
    int codeProduitExecutable = ((DossierAffectation)getDossierAffecte()).getCodeProduitExecutable();
    if (codeProduitExecutable == 0)
    {
      Demande demande = (Demande)getDemande();
      if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 6)) {
        produitRetour = OutilAsp.getInstance().recupererProduitReglementaire(getDemande());
      }
    }
    else
    {
      produitRetour = Parametres.getProduit(codeProduitExecutable);
    }
    return produitRetour;
  }
  
  public boolean estDemandeDrv()
  {
    return "ASU_27".equals(getDemande().getEvenementReferenceExamen().getTypeExamen());
  }
  
  public Damj getDateDebutDelaiDecheance()
  {
    return getOuvertureDroit().getDateAttribution();
  }
  
  public Quantite getDureeTheoriquePourDelaiDecheance()
  {
    return ((AttributionAssuranceSpec)getOuvertureDroit()).getDureeTheorique();
  }
  
  public Quantite getDureePostPrime()
  {
    ConstitutionDurees constitutionDurees = getConstitutionDurees();
    if (constitutionDurees != null)
    {
      DureeIndemnisation dureeIndemnisation = constitutionDurees.getDureeIndemnisation();
      if (dureeIndemnisation != null) {
        return dureeIndemnisation.getDureePostPrimeCspConstitutionDurees();
      }
    }
    return null;
  }
  
  public DureeReglementaireSpec getDureeReglementaire()
  {
    return getConstitutionDurees().getDureeIndemnisation();
  }
}

/* Location:
 * Qualified Name:     Attribution
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */