package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.CarenceSpec;
import fr.unedic.cali.asu.dom.ObjetChronoPeriodeConcreteCarenceForcee;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.CarencePrefixeAFixerGen;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.parcours.ContexteParcoursCali;
import fr.unedic.cali.util.ObjetChronoPeriodeConcreteCarence;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;

public abstract class CarencePrefixeAFixer
  extends CarencePrefixeAFixerGen
  implements ObjetPersistantSpec, CarenceSpec
{
  public static final Unite UNITE_DEFAUT = Unite.get("jour");
  private transient ObjetChronoPeriode m_periodeOrigine;
  private transient Quantite m_reliquat;
  private transient boolean m_reliquatCarence;
  private transient ObjetChronoPeriode m_periodeOrigineReliquat;
  
  public CarencePrefixeAFixer(int p_jours)
  {
    setQuantiteInitial(new Quantite(String.valueOf(p_jours), UNITE_DEFAUT));
  }
  
  public CarencePrefixeAFixer(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public CarencePrefixeAFixer() {}
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  /**
   * @deprecated
   */
  public void marquerGraphePersistant() {}
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    CarencePrefixeAFixer copie = (CarencePrefixeAFixer)p_copie;
    if (getPeriodeApplicationCarence() != null) {
      copie.setPeriodeApplicationCarence(new Periode(getPeriodeApplicationCarence().getDebut(), getPeriodeApplicationCarence().getFin()));
    }
    copie.setReliquat(getReliquat());
    copie.setOrigine(getOrigine());
    copie.setDateFinPeriodeOrigine(getDateFinPeriodeOrigine());
    copie.setIdentifiantPeriodeOrigine(getIdentifiantPeriodeOrigine());
    copie.setQuantiteInitial(getQuantiteInitial());
    copie.setReliquatCarence(isReliquatCarence());
    copie.setOrigineReliquat(getOrigineReliquat());
  }
  
  public ObjetChronoPeriode getOrigineReliquat()
  {
    return m_periodeOrigineReliquat;
  }
  
  public void setOrigineReliquat(ObjetChronoPeriode p_periodeOrigineReliquat)
  {
    m_periodeOrigineReliquat = p_periodeOrigineReliquat;
  }
  
  public ObjetChronoPeriode getOrigine()
  {
    if (m_periodeOrigine == null)
    {
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      if (getIdentifiantPeriodeOrigine() != null) {
        if (getIdentifiantPeriodeOrigine().trim().equals("CarenceForcee")) {
          m_periodeOrigine = new ObjetChronoPeriodeConcreteCarenceForcee(getDateFinPeriodeOrigine(), getDateFinPeriodeOrigine());
        } else {
          m_periodeOrigine = ((ObjetChronoPeriode)individuCourant.rechercherPeriodePasseProfessionnel(getIdentifiantPeriodeOrigine().trim()));
        }
      }
      if ((m_periodeOrigine == null) && (getDateFinPeriodeOrigine() != null)) {
        m_periodeOrigine = new ObjetChronoPeriodeConcreteCarence(getDateFinPeriodeOrigine(), getDateFinPeriodeOrigine());
      }
    }
    return m_periodeOrigine;
  }
  
  public void setOrigine(ObjetChronoPeriode p_periodeOrigine)
  {
    m_periodeOrigine = p_periodeOrigine;
    if (p_periodeOrigine != null)
    {
      if ((p_periodeOrigine instanceof TravailSpec)) {
        setIdentifiantPeriodeOrigine(((TravailSpec)p_periodeOrigine).getIdentifiant());
      }
      setDateFinPeriodeOrigine(p_periodeOrigine.getDateFin());
    }
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public Quantite getReliquat()
  {
    return m_reliquat;
  }
  
  public void setReliquat(Quantite p_reliquat)
  {
    m_reliquat = p_reliquat;
  }
  
  public boolean isReliquatCarence()
  {
    return m_reliquatCarence;
  }
  
  public void setReliquatCarence(boolean p_reliquatCarence)
  {
    m_reliquatCarence = p_reliquatCarence;
  }
}

/* Location:
 * Qualified Name:     CarencePrefixeAFixer
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */