package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.ConditionFaitGenerateurGen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.parcours.ContexteParcoursCali;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteAffiliation;
import java.math.BigDecimal;

public class ConditionFaitGenerateur
  extends ConditionFaitGenerateurGen
  implements FaitGenerateurSpec
{
  private transient ActiviteSalarie m_periodeFaitGenerateur = null;
  private static final long serialVersionUID = 4961721735145626148L;
  
  public ConditionFaitGenerateur(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public ConditionFaitGenerateur() {}
  
  public boolean estSatisfait()
  {
    return getEtat() == 0;
  }
  
  public void setEtatSatisfait(boolean p_etatSatisfait)
  {
    if (p_etatSatisfait) {
      setEtat(0);
    } else {
      setEtat(1);
    }
  }
  
  public void setPeriodeFaitGenerateur(ActiviteSalarie p_periodeFaitGenerateur)
  {
    m_periodeFaitGenerateur = p_periodeFaitGenerateur;
    if (p_periodeFaitGenerateur != null)
    {
      setIdentifiantPeriodeFaitGenerateur(p_periodeFaitGenerateur.getIdentifiant());
      setMotifFinPeriode(p_periodeFaitGenerateur.getMotifFin());
      setDateFaitGenerateur(p_periodeFaitGenerateur.getDateFin());
      setDateEngagementProcedure(p_periodeFaitGenerateur.getDateEngagementProcedureLicenciement());
      setCodeBassinCtp(p_periodeFaitGenerateur.getEntreprise().getCodeBassinCTP());
    }
  }
  
  public ActiviteSalarie getPeriodeFaitGenerateur()
  {
    if (m_periodeFaitGenerateur == null)
    {
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      
      m_periodeFaitGenerateur = ((ActiviteSalarie)individuCourant.rechercherPeriodePasseProfessionnel(getIdentifiantPeriodeFaitGenerateur()));
    }
    return m_periodeFaitGenerateur;
  }
  
  public BigDecimal getRefusFne()
  {
    if ((getPeriodeFaitGenerateur() != null) && (getPeriodeFaitGenerateur().getContrat() != null)) {
      return getPeriodeFaitGenerateur().getContrat().getRefusFne();
    }
    return null;
  }
  
  public Quantite getNombreJoursFaitGenerateur()
  {
    if (getPeriodeFaitGenerateur() != null) {
      return new Quantite(getPeriodeFaitGenerateur().getDuree(), UniteAffiliation.JOUR);
    }
    return null;
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  /**
   * @deprecated
   */
  public void marquerGraphePersistant() {}
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ConditionFaitGenerateur copie = (ConditionFaitGenerateur)p_copie;
    copie.setDateEvenement(getDateEvenement());
    copie.setAgeIndividuDateFG(getAgeIndividuDateFG());
    copie.setDateFaitGenerateur(getDateFaitGenerateur());
    copie.setIdentifiantPeriodeFaitGenerateur(getIdentifiantPeriodeFaitGenerateur());
    copie.setMotifFinPeriode(getMotifFinPeriode());
    copie.setCodeMotifEchec(getCodeMotifEchec());
    copie.setEtat(getEtat());
    copie.setDateEngagementProcedure(getDateEngagementProcedure());
    copie.setPeriodeFaitGenerateur(getPeriodeFaitGenerateur());
    copie.setRefusAdhesionFne(getRefusAdhesionFne());
    copie.setCodeBassinCtp(getCodeBassinCtp());
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
}

/* Location:
 * Qualified Name:     ConditionFaitGenerateur
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */