package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.cge01.liquidation.dom.spec.ConstitutionDelaisSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilCarence;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.ConstitutionDelaisGen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.ConstitutionDroitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

public class ConstitutionDelais
  extends ConstitutionDelaisGen
  implements ConstitutionDroitSpec, ConstitutionDelaisSpec
{
  private static final long serialVersionUID = 5655254439781196369L;
  private transient QuantiteEuro montantICCPOrigine;
  private transient QuantiteEuro cumulMontantICCPA4Origine;
  private transient ActiviteSalarie activitePresenceAutreTransaction;
  private transient String identifiantFCTRetenueICCP;
  private transient Damj pjiTheorique;
  private transient Damj dateDebutDernierDelaiAttente;
  
  public ConstitutionDelais(DomPCSpec pc)
  {
    super(pc);
  }
  
  public ConstitutionDelais() {}
  
  public QuantiteEuro getCumulMontantICCPA4Origine()
  {
    return cumulMontantICCPA4Origine;
  }
  
  public void setCumulMontantICCPA4Origine(QuantiteEuro cumulMontantICCPA4Origine)
  {
    this.cumulMontantICCPA4Origine = cumulMontantICCPA4Origine;
  }
  
  public QuantiteEuro getMontantICCPOrigine()
  {
    return montantICCPOrigine;
  }
  
  public void setMontantICCPOrigine(QuantiteEuro montantICCPOrigine)
  {
    this.montantICCPOrigine = montantICCPOrigine;
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    ConstitutionDelais copieConstitutionDelais = (ConstitutionDelais)copie;
    
    copieConstitutionDelais.setPeriodeReference91jours(getPeriodeReference91jours() != null ? new Periode(getPeriodeReference91jours().getDebut(), getPeriodeReference91jours().getFin()) : null);
    
    Collection<CarencePrefixeAFixer> collectionCarences = getCollectionCarences();
    for (CarencePrefixeAFixer element : collectionCarences) {
      if (element != null) {
        copieConstitutionDelais.ajouterCarences((CarencePrefixeAFixer)element.copie());
      }
    }
    copieConstitutionDelais.setDebutCarenceDiffere(getDebutCarenceDiffere());
    copieConstitutionDelais.setDebutCarenceICCP(getDebutCarenceICCP());
    copieConstitutionDelais.setDebutCarenceISLR(getDebutCarenceISLR());
    copieConstitutionDelais.setNbJoursCarenceDiffere(getNbJoursCarenceDiffere());
    copieConstitutionDelais.setNbJoursCarenceICCP(getNbJoursCarenceICCP());
    copieConstitutionDelais.setNbJoursCarenceISLR(getNbJoursCarenceISLR());
    copieConstitutionDelais.setTermeCarenceDiffere(getTermeCarenceDiffere());
    copieConstitutionDelais.setTermeCarenceICCP(getTermeCarenceICCP());
    copieConstitutionDelais.setTermeCarenceISLR(getTermeCarenceISLR());
    copieConstitutionDelais.setDebutPMC(getDebutPMC());
    copieConstitutionDelais.setTermePMC(getTermePMC());
    copieConstitutionDelais.setNbJoursPMC(getNbJoursPMC());
    copieConstitutionDelais.setTypePmc(getTypePmc());
    copieConstitutionDelais.setMontantICCPOrigine(getMontantICCPOrigine());
    copieConstitutionDelais.setCumulMontantICCPA4Origine(getCumulMontantICCPA4Origine());
    copieConstitutionDelais.setActivitePresenceAutreTransaction(getActivitePresenceAutreTransaction());
    copieConstitutionDelais.setPresenceTransaction(isPresenceTransaction());
    copieConstitutionDelais.setPjiTheorique(getPjiTheorique());
    
    copieConstitutionDelais.setDebutCarencePreavisLegal(getDebutCarencePreavisLegal());
    copieConstitutionDelais.setTermeCarencePreavisLegal(getTermeCarencePreavisLegal());
    copieConstitutionDelais.setNbJoursCarencePreavisLegal(getNbJoursCarencePreavisLegal());
    copieConstitutionDelais.setIdentifiantFCTRetenueICCP(getIdentifiantFCTRetenueICCP());
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public ActiviteSalarie getActivitePresenceAutreTransaction()
  {
    return activitePresenceAutreTransaction;
  }
  
  public void setActivitePresenceAutreTransaction(ActiviteSalarie activitePresenceAutreTransaction)
  {
    this.activitePresenceAutreTransaction = activitePresenceAutreTransaction;
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getCollectionCarences());
  }
  
  public Collection getListeCarencesAAppliquer()
  {
    Collection<CarencePrefixeAFixer> toutesLesCarences = new ArrayList();
    
    List<CarencePrefixeAFixer> listeCarences = getListCarences();
    for (CarencePrefixeAFixer carence : listeCarences) {
      if (!OutilCarence.estCarenceDeType(carence, "PMC_I")) {
        toutesLesCarences.add(carence);
      }
    }
    return Collections.unmodifiableCollection(toutesLesCarences);
  }
  
  public Damj getPjiTheorique()
  {
    return pjiTheorique;
  }
  
  public void setPjiTheorique(Damj pjiTheorique)
  {
    this.pjiTheorique = pjiTheorique;
  }
  
  public void setDateDebutDernierDelaiAttente(Damj dateDebutDernierDelaiAttente)
  {
    this.dateDebutDernierDelaiAttente = dateDebutDernierDelaiAttente;
  }
  
  public Damj getDateDebutDernierDelaiAttente()
  {
    return dateDebutDernierDelaiAttente;
  }
  
  public void remplacerCollectionCarences(Collection collectionACopier)
  {
    Collection<CarencePrefixeAFixer> listeCarences = collectionACopier;
    for (CarencePrefixeAFixer element : listeCarences) {
      DomManager.supprimer(element);
    }
    super.remplacerCollectionCarences(collectionACopier);
  }
  
  public String getIdentifiantFCTRetenueICCP()
  {
    return identifiantFCTRetenueICCP;
  }
  
  public void setIdentifiantFCTRetenueICCP(String identifiantFCTRetenueICCP)
  {
    this.identifiantFCTRetenueICCP = identifiantFCTRetenueICCP;
  }
}

/* Location:
 * Qualified Name:     ConstitutionDelais
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */