package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.DecisionGen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConditionsAttributionSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public abstract class Decision
  extends DecisionGen
  implements DecisionAssuranceSpec
{
  private static final long serialVersionUID = 1L;
  
  public Decision(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Decision() {}
  
  public Decision(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    Decision copieDecision = (Decision)copie;
    super.copieElements(copieDecision);
    copieDecision.setNatureDecision(getNatureDecision());
    copieDecision.setValidee(estValidee());
    copieDecision.setInvestigationFraude(isInvestigationFraude());
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public ConditionsAttributionSpec getConditionsAttributionActives()
  {
    ObjectifExamen objectifCourant = recupererObjectifActif();
    
    int typeObjectif = objectifCourant.getType();
    switch (typeObjectif)
    {
    case 2: 
    case 5: 
    case 6: 
      return getConditionsAttributionReprise();
    case 4: 
      return getConditionsAttributionRevision();
    }
    return getConditionsAttributionAdmission();
  }
  
  public ConstitutionElementsSpec getConstitutionElementsActifs()
  {
    ObjectifExamen objectifCourant = recupererObjectifActif();
    
    int typeObjectif = objectifCourant.getType();
    switch (typeObjectif)
    {
    case 2: 
    case 5: 
    case 6: 
      return getConstitutionElementsReprise();
    case 4: 
      return getConstitutionElementsRevision();
    }
    return getConstitutionElementsAdmission();
  }
  
  public ObjectifExamen recupererObjectifActif()
  {
    ObjectifExamen objectifCourant = ((Demande)getDemande()).getObjectifCourant();
    if (objectifCourant == null) {
      objectifCourant = ((Demande)getDemande()).getObjectifDecisionne();
    }
    return objectifCourant;
  }
  
  public boolean estValidee()
  {
    return isValidee();
  }
  
  public Chronologie getListeActiviteConservee()
  {
    Chronologie chronoActiviteConservee = new ChronologiePeriodes();
    
    Collection<SjrActiviteConservee> listeActiviteConservees = getCollectionSjrActiviteConservee();
    if (listeActiviteConservees != null)
    {
      Iterator<SjrActiviteConservee> iteratorActiviteConservee = listeActiviteConservees.iterator();
      while (iteratorActiviteConservee.hasNext())
      {
        SjrActiviteConservee activiteConserveCourante = (SjrActiviteConservee)iteratorActiviteConservee.next();
        
        TravailSpec activiteConservee = activiteConserveCourante.getPeriodeActiviteConservee();
        if (activiteConservee != null) {
          chronoActiviteConservee.ajouter(activiteConservee);
        }
      }
    }
    return chronoActiviteConservee;
  }
  
  public Chronologie getListeActiviteConserveePerdues()
  {
    Chronologie chronoActiviteConservee = new ChronologiePeriodes();
    
    Collection<SjrActiviteConservee> listeActiviteConserveePerdue = getCollectionSjrActiviteConserveePerdue();
    if (listeActiviteConserveePerdue != null)
    {
      Iterator<SjrActiviteConservee> iteratorActiviteConservee = listeActiviteConserveePerdue.iterator();
      while (iteratorActiviteConservee.hasNext())
      {
        SjrActiviteConservee activiteConserveCourante = (SjrActiviteConservee)iteratorActiviteConservee.next();
        
        TravailSpec activiteConservee = activiteConserveCourante.getPeriodeActiviteConservee();
        if (activiteConservee != null) {
          chronoActiviteConservee.ajouter(activiteConservee);
        }
      }
    }
    return chronoActiviteConservee;
  }
  
  public Collection<SjrActiviteConservee> getCollectionSjrActiviteConservee()
  {
    Collection<SjrActiviteConservee> listeActiviteConserveePerdue = null;
    if ((getConstitutionSjc() != null) && (getConstitutionSjc().getSjcip() != null)) {
      listeActiviteConserveePerdue = getConstitutionSjc().getSjcip().getCollectionSjrActiviteConservee();
    } else if (getConditionActiviteConservee() != null) {
      listeActiviteConserveePerdue = getConditionActiviteConservee().getCollectionSjrActiviteConservee();
    }
    return listeActiviteConserveePerdue;
  }
  
  public Collection<SjrActiviteConservee> getCollectionSjrActiviteConserveePerdue()
  {
    Collection<SjrActiviteConservee> listeActiviteConserveePerdue = null;
    if ((getConstitutionSjc() != null) && (getConstitutionSjc().getSjcip() != null)) {
      listeActiviteConserveePerdue = getConstitutionSjc().getSjcip().getCollectionSjrActiviteConserveePerdue();
    } else if (getConditionActiviteConservee() != null) {
      listeActiviteConserveePerdue = getConditionActiviteConservee().getCollectionSjrActiviteConserveePerdue();
    }
    return listeActiviteConserveePerdue;
  }
  
  public List<TravailSpec> getListeActiviteConserveePerduesRevisees()
  {
    List<TravailSpec> listActiviteConservee = new ArrayList();
    Collection<SjrActiviteConservee> listeActiviteConserveePerdue = getCollectionSjrActiviteConserveePerdue();
    if (listeActiviteConserveePerdue != null)
    {
      Iterator<SjrActiviteConservee> it = listeActiviteConserveePerdue.iterator();
      while (it.hasNext())
      {
        SjrActiviteConservee sjrActiviteConservee = (SjrActiviteConservee)it.next();
        if ("R".equals(sjrActiviteConservee.getTypeActiviteConservee())) {
          listActiviteConservee.add(sjrActiviteConservee.getPeriodeActiviteConservee());
        }
      }
    }
    return listActiviteConservee;
  }
  
  public int getCompetenceAdministrative()
  {
    return getCompetence().getCompetenceAdministrative();
  }
  
  public int getCompetenceFinanciere()
  {
    return getCompetence().getCompetenceFinanciere();
  }
  
  public ConditionQuantiteAffiliationSpec getConditionAffiliation()
  {
    ConditionQuantiteAffiliationSpec condition = null;
    if (getConditionsAttributionAdmission() != null) {
      condition = getConditionsAttributionAdmission().getConditionQuantiteAffiliation();
    }
    return condition;
  }
  
  public String determinerCodeSousProduitPourSigma()
  {
    return null;
  }
}

/* Location:
 * Qualified Name:     Decision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */