package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.AccesseurDroitsSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ConditionMontantNonNulSpec;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.ConditionValiditeReliquatSpec;
import fr.unedic.cali.asu.dom.ContributionParticuliereAbstrait;
import fr.unedic.cali.asu.dom.ContributionParticuliereSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.DossierExamenGen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.util.Collection;
import java.util.List;

public abstract class DossierExamen
  extends DossierExamenGen
  implements DossierExamenAssuranceSpec
{
  private static final long serialVersionUID = 1L;
  private transient AttributionAssuranceSpec attributionPrecedente;
  private transient AccesseurDroits accesseurDroits;
  
  public DossierExamen(DomPCSpec pc)
  {
    super(pc);
  }
  
  public DossierExamen() {}
  
  public DossierExamen(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  protected void copie(DossierExamen source)
  {
    if (source == null) {
      return;
    }
    if (source.getConditionsAttributionAdmission() == null) {
      source.setConditionsAttributionAdmission(new ConditionsAttributionAdmission());
    }
    source.getConditionsAttributionAdmission().copieElements(getConditionsAttributionAdmission());
    if (source.getConstitutionElementsAdmission() == null) {
      source.setConstitutionElementsAdmission(new ConstitutionElementsAdmission());
    }
    source.getConstitutionElementsAdmission().copieElements(getConstitutionElementsAdmission());
    if (source.getConditionsAttributionReprise() == null) {
      source.setConditionsAttributionReprise(new ConditionsAttributionReprise());
    }
    source.getConditionsAttributionReprise().copieElements(getConditionsAttributionReprise());
    if (source.getConstitutionElementsReprise() == null) {
      source.setConstitutionElementsReprise(new ConstitutionElementsReprise());
    }
    source.getConstitutionElementsReprise().copieElements(getConstitutionElementsReprise());
    if (source.getConditionsAttributionRevision() == null) {
      source.setConditionsAttributionRevision(new ConditionsAttributionRevision());
    }
    source.getConditionsAttributionRevision().copieElements(getConditionsAttributionRevision());
    if (source.getConstitutionElementsRevision() == null) {
      source.setConstitutionElementsRevision(new ConstitutionElementsRevision());
    }
    source.getConstitutionElementsRevision().copieElements(getConstitutionElementsRevision());
    if (source.getCompetence() != null) {
      setCompetence((Competence)source.getCompetence().copie());
    }
    if (getCompetenceSousJacente() != null) {
      setCompetenceSousJacente((Competence)getCompetenceSousJacente().copie());
    }
    setContexteDdeExpresse(source.getContexteDdeExpresse());
    if (source.getContributionParticuliere() != null) {
      setContributionParticuliere((ContributionParticuliere)source.getContributionParticuliere().copie());
    }
    setAttributionPrecedente(source.getAttributionPrecedente());
    
    setDossierAffecte(source.getDossierAffecte());
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    DossierExamen copieDossierExamen = (DossierExamen)copie;
    if (getConditionsAttributionAdmission() == null) {
      setConditionsAttributionAdmission(new ConditionsAttributionAdmission());
    }
    getConditionsAttributionAdmission().copieElements(copieDossierExamen.getConditionsAttributionAdmission());
    if (getConstitutionElementsAdmission() == null) {
      setConstitutionElementsAdmission(new ConstitutionElementsAdmission());
    }
    getConstitutionElementsAdmission().copieElements(copieDossierExamen.getConstitutionElementsAdmission());
    if (getConditionsAttributionReprise() == null) {
      setConditionsAttributionReprise(new ConditionsAttributionReprise());
    }
    getConditionsAttributionReprise().copieElements(copieDossierExamen.getConditionsAttributionReprise());
    if (getConstitutionElementsReprise() == null) {
      setConstitutionElementsReprise(new ConstitutionElementsReprise());
    }
    getConstitutionElementsReprise().copieElements(copieDossierExamen.getConstitutionElementsReprise());
    if (getConditionsAttributionRevision() == null) {
      setConditionsAttributionRevision(new ConditionsAttributionRevision());
    }
    getConditionsAttributionRevision().copieElements(copieDossierExamen.getConditionsAttributionRevision());
    if (getConstitutionElementsRevision() == null) {
      setConstitutionElementsRevision(new ConstitutionElementsRevision());
    }
    getConstitutionElementsRevision().copieElements(copieDossierExamen.getConstitutionElementsRevision());
    if (getCompetence() != null) {
      copieDossierExamen.setCompetence((Competence)getCompetence().copie());
    }
    if (getCompetenceSousJacente() != null) {
      copieDossierExamen.setCompetenceSousJacente((Competence)getCompetenceSousJacente().copie());
    }
    copieDossierExamen.setContexteDdeExpresse(getContexteDdeExpresse());
    if (getContributionParticuliere() != null) {
      copieDossierExamen.setContributionParticuliere((ContributionParticuliere)getContributionParticuliere().copie());
    }
    copieDossierExamen.setDateEvenement(getDateEvenement());
    copieDossierExamen.setAttributionPrecedente(getAttributionPrecedente());
    
    copieDossierExamen.setDateFinPerteActiviteConservee(getDateFinPerteActiviteConservee());
    copieDossierExamen.setMotifFinPerteActiviteConservee(getMotifFinPerteActiviteConservee());
  }
  
  public void setAttributionPrecedente(AttributionAssuranceSpec decisionPrecedente)
  {
    attributionPrecedente = decisionPrecedente;
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getCompetence());
    DomManager.persisterEnProfondeur(super.getContributionParticuliere());
    DomManager.persisterEnProfondeur(super.getConditionsAttributionAdmission());
    DomManager.persisterEnProfondeur(super.getConditionsAttributionReprise());
    DomManager.persisterEnProfondeur(super.getConstitutionElementsAdmission());
    DomManager.persisterEnProfondeur(super.getConstitutionElementsReprise());
    DomManager.persisterEnProfondeur(super.getConditionsAttributionRevision());
    DomManager.persisterEnProfondeur(super.getConstitutionElementsRevision());
    DomManager.persisterEnProfondeur(super.getCompetenceSousJacente());
  }
  
  public boolean estDroitSaisonnier()
  {
    if (getConstitutionCaractereSaisonnier() != null)
    {
      int caractereSaisonnier = getConstitutionCaractereSaisonnier().getTypeCaractereSaisonnierRetenu();
      switch (caractereSaisonnier)
      {
      case 1: 
      case 2: 
        return true;
      }
      return false;
    }
    return false;
  }
  
  public ConstitutionCaractereSaisonnier getConstitutionCaractereSaisonnier()
  {
    return getConstitutionElementsAdmission().getConstitutionCaractereSaisonnier();
  }
  
  public boolean estRejetDV()
  {
    if ((getConditionChomageInvolontaire() != null) && (!getConditionChomageInvolontaire().estSatisfait())) {
      return true;
    }
    return false;
  }
  
  public ConditionChomageInvolontaire getConditionChomageInvolontaire()
  {
    return getConditionsAttributionActives().getConditionChomageInvolontaire();
  }
  
  public abstract fr.unedic.cali.asu.produits.liquidation.dom.spec.ConditionsAttributionSpec getConditionsAttributionActives();
  
  public ConditionsAttributionReprise getConditionsAttributionReprise()
  {
    if (super.getConditionsAttributionReprise() == null) {
      super.setConditionsAttributionReprise(new ConditionsAttributionReprise());
    }
    return super.getConditionsAttributionReprise();
  }
  
  public AccesseurDroitsSpec getAccesseurDroits()
  {
    return accesseurDroits != null ? accesseurDroits : new AccesseurDroits(this);
  }
  
  public AttributionAssuranceSpec getAttributionPrecedente()
  {
    if (((Demande)getDemande()).getDemandeOrigine() != null) {
      setAttributionPrecedente(((Demande)getDemande()).getDemandeOrigine().getAttribution());
    }
    return attributionPrecedente;
  }
  
  public ConditionQuantiteAffiliationSpec getConditionQuantiteAffiliation()
  {
    return getConditionsAttributionAdmission().getConditionQuantiteAffiliation();
  }
  
  public FaitGenerateurSpec getFaitGenerateur()
  {
    return getConditionFaitGenerateur();
  }
  
  public FaitGenerateurSpec getConditionFaitGenerateur()
  {
    return getConditionsAttributionAdmission().getConditionFaitGenerateur();
  }
  
  public abstract JustificationAffiliationSpec getJustificationAffiliation();
  
  public ReglementApplicableSpec getReglementApplicable()
  {
    return getConstitutionReglementApplicable();
  }
  
  public ReglementApplicableSpec getConstitutionReglementApplicable()
  {
    return getConstitutionElementsActifs().getConstitutionReglementApplicable();
  }
  
  public void setContributionParticuliere(ContributionParticuliereSpec contributionParticuliere)
  {
    DomManager.supprimer(getContributionParticuliere(), contributionParticuliere);
    super.setContributionParticuliere((ContributionParticuliereAbstrait)contributionParticuliere);
  }
  
  public DossierExamenSpec changerEtat(int typeDossierExamen)
    throws CoucheLogiqueException
  {
    DossierExamen nouveauDossier = null;
    switch (typeDossierExamen)
    {
    case 0: 
      nouveauDossier = new Examen();
      break;
    case 10: 
    case 32: 
    case 40: 
      nouveauDossier = new Od();
      break;
    case 11: 
    case 26: 
      nouveauDossier = new Readmission();
      break;
    case 16: 
    case 28: 
    case 33: 
      nouveauDossier = new Rejet();
      break;
    case 3: 
      nouveauDossier = new Reprise();
      break;
    case 50: 
      nouveauDossier = new RepriseSecteurPublic();
      break;
    case 47: 
    case 48: 
      nouveauDossier = new Novation();
      break;
    case 30: 
      nouveauDossier = new Revision();
      break;
    case 45: 
      nouveauDossier = new RevisionAdmission();
      break;
    case 29: 
      nouveauDossier = new Echec();
      break;
    case 35: 
      nouveauDossier = new OdAssociee();
      break;
    case 46: 
      nouveauDossier = new RepriseAssociee();
      break;
    case 36: 
      nouveauDossier = new NonFinancement();
      break;
    case 38: 
      nouveauDossier = new Antecedent();
      break;
    case 39: 
      nouveauDossier = new Poursuite();
      break;
    case 49: 
      nouveauDossier = new PoursuiteIndemnisation();
      break;
    case 1: 
    case 2: 
    case 4: 
    case 5: 
    case 6: 
    case 7: 
    case 8: 
    case 9: 
    case 12: 
    case 13: 
    case 14: 
    case 15: 
    case 17: 
    case 18: 
    case 19: 
    case 20: 
    case 21: 
    case 22: 
    case 23: 
    case 24: 
    case 25: 
    case 27: 
    case 31: 
    case 34: 
    case 37: 
    case 41: 
    case 42: 
    case 43: 
    case 44: 
    default: 
      throw new UnsupportedOperationException("Impossible de changer l'etat du dossier d'examen vers le nouvel etat : " + typeDossierExamen);
    }
    nouveauDossier.copie(this);
    return nouveauDossier;
  }
  
  public Damj getDateAttribution()
  {
    if (getConstitutionDateAttribution() != null) {
      return getConstitutionDateAttribution().getDateAttribution();
    }
    return null;
  }
  
  public ConstitutionDateAttribution getConstitutionDateAttribution()
  {
    return getConstitutionElementsActifs().getConstitutionDateAttribution();
  }
  
  public abstract ConstitutionElementsSpec getConstitutionElementsActifs();
  
  public DemandeSpec getDemande()
  {
    if (getDossierAffecte() == null) {
      return null;
    }
    return getDossierAffecte().getDemande();
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public ConstitutionProduitResultant getConstitutionProduitResultant()
  {
    return getConstitutionElementsAdmission().getConstitutionProduitResultant();
  }
  
  public ConstitutionElementsAdmission getConstitutionElementsAdmission()
  {
    if (super.getConstitutionElementsAdmission() == null) {
      super.setConstitutionElementsAdmission(new ConstitutionElementsAdmission());
    }
    return super.getConstitutionElementsAdmission();
  }
  
  public ConstitutionDurees getConstitutionDurees()
  {
    return getConstitutionElementsActifs().getConstitutionDurees();
  }
  
  public Quantite getDureeRestanteAImputerFinCSP()
  {
    return getConstitutionElementsActifs().getConstitutionDurees().getDureeIndemnisation().getDureeRestantAImputer();
  }
  
  public ConstitutionSjc getConstitutionSjc()
  {
    return getConstitutionElementsActifs().getConstitutionSjc();
  }
  
  public ConstitutionDelais getConstitutionDelais()
  {
    return getConstitutionElementsActifs().getConstitutionDelais();
  }
  
  public ConstitutionPointDepartIndemnisation getConstitutionPointDepartIndemnisation()
  {
    return getConstitutionElementsActifs().getConstitutionPointDepartIndemnisation();
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public ConstitutionQuantiteAffiliation getConstitutionQuantiteAffiliation()
  {
    return getConstitutionElementsAdmission().getConstitutionQuantiteAffiliation();
  }
  
  public ConstitutionSjr getConstitutionSjr()
  {
    return getConstitutionElementsActifs().getConstitutionSjr();
  }
  
  public ConstitutionSjr createConstitutionSjr()
  {
    return getConstitutionElementsActifs().createConstitutionSjr();
  }
  
  public ConditionChomageInvolontaire createConditionChomageInvolontaire()
  {
    return getConditionsAttributionActives().createConditionChomageInvolontaire();
  }
  
  public ConstitutionCaractereSaisonnier createConstitutionCaractereSaisonnier()
  {
    return getConstitutionElementsAdmission().createConstitutionCaractereSaisonnier();
  }
  
  public ConstitutionCoefficientSaisonnier createConstitutionCoefficientSaisonnier()
  {
    return getConstitutionElementsAdmission().createConstitutionCoefficientSaisonnier();
  }
  
  public ConstitutionQuantiteAffiliation createConstitutionQuantiteAffiliation()
  {
    return getConstitutionElementsAdmission().createConstitutionQuantiteAffiliation();
  }
  
  public ConditionQuantiteAffiliation createConditionQuantiteAffiliation()
  {
    return getConditionsAttributionAdmission().createConditionQuantiteAffiliation();
  }
  
  public ConditionActiviteConservee createConditionActiviteConservee()
  {
    return getConditionsAttributionActives().createConditionActiviteConservee();
  }
  
  public ConstitutionPointDepartIndemnisation createConstitutionPointDepartIndemnisation()
  {
    return getConstitutionElementsActifs().createConstitutionPointDepartIndemnisation();
  }
  
  public ConstitutionDateAttribution createConstitutionDateAttribution()
  {
    return getConstitutionElementsActifs().createConstitutionDateAttribution();
  }
  
  public ConstitutionDelais createConstitutionDelais()
  {
    return getConstitutionElementsActifs().createConstitutionDelais();
  }
  
  public ConditionChomageTotal createConditionChomageTotal()
  {
    return getConditionsAttributionAdmission().createConditionChomageTotal();
  }
  
  public ConditionFaitGenerateur createConditionFaitGenerateur()
  {
    return getConditionsAttributionAdmission().createConditionFaitGenerateur();
  }
  
  public ConditionsAttributionAdmission getConditionsAttributionAdmission()
  {
    if (super.getConditionsAttributionAdmission() == null) {
      super.setConditionsAttributionAdmission(new ConditionsAttributionAdmission());
    }
    return super.getConditionsAttributionAdmission();
  }
  
  public ConstitutionElementsReprise getConstitutionElementsReprise()
  {
    if (super.getConstitutionElementsReprise() == null) {
      super.setConstitutionElementsReprise(new ConstitutionElementsReprise());
    }
    return super.getConstitutionElementsReprise();
  }
  
  public ConditionsAttributionRevision getConditionsAttributionRevision()
  {
    if (super.getConditionsAttributionRevision() == null) {
      super.setConditionsAttributionRevision(new ConditionsAttributionRevision());
    }
    return super.getConditionsAttributionRevision();
  }
  
  public ConstitutionElementsRevision getConstitutionElementsRevision()
  {
    if (super.getConstitutionElementsRevision() == null) {
      super.setConstitutionElementsRevision(new ConstitutionElementsRevision());
    }
    return super.getConstitutionElementsRevision();
  }
  
  public ConstitutionMontantsBruts getConstitutionMontantsBruts()
  {
    return getConstitutionElementsActifs().getConstitutionMontantsBruts();
  }
  
  public ConstitutionCoefficientSaisonnier getConstitutionCoefficientSaisonnier()
  {
    return getConstitutionElementsAdmission().getConstitutionCoefficientSaisonnier();
  }
  
  public ConstitutionCoefficientTempsPartiel getConstitutionCoefficientTempsPartiel()
  {
    return getConstitutionElementsAdmission().getConstitutionCoefficientTempsPartiel();
  }
  
  public ConditionRechercheEmploi getConditionRechercheEmploi()
  {
    return getConditionsAttributionActives().getConditionRechercheEmploi();
  }
  
  public ConditionAge getConditionAge()
  {
    return getConditionsAttributionActives().getConditionAge();
  }
  
  public ConditionCumulPrestationFamiliale getConditionCumulPrestationFamiliale()
  {
    return getConditionsAttributionActives().getConditionCumulPrestationFamiliale();
  }
  
  public ConditionMontantNonNulSpec getConditionMontantNonNul()
  {
    return getConditionsAttributionActives().getConditionMontantNonNul();
  }
  
  public ConditionActiviteConservee getConditionActiviteConservee()
  {
    return getConditionsAttributionActives().getConditionActiviteConservee();
  }
  
  public ConditionChomageTotal getConditionChomageTotal()
  {
    return getConditionsAttributionAdmission().getConditionChomageTotal();
  }
  
  public ConditionValiditeReliquatSpec getConditionValiditeReliquat()
  {
    return getConditionsAttributionReprise().getConditionValiditeReliquat();
  }
  
  public ConstitutionProduitResultant createConstitutionProduitResultant()
  {
    return getConstitutionElementsAdmission().createConstitutionProduitResultant();
  }
  
  public void setCompetence(CompetenceSpec competence)
  {
    DomManager.supprimer(super.getCompetence(), competence);
    super.setCompetence((Competence)competence);
  }
  
  public void setCompetenceSousJacente(CompetenceSpec competenceSousJacente)
  {
    DomManager.supprimer(super.getCompetenceSousJacente(), competenceSousJacente);
    super.setCompetenceSousJacente((Competence)competenceSousJacente);
  }
  
  public List getListConditionsAttribution()
  {
    return getConditionsAttributionActives().getListeConditionsAttribution();
  }
  
  public void setDossierAffecte(DossierAffectationSpec dossierAffectation)
  {
    super.setDossierAffecte(dossierAffectation);
    if ((dossierAffectation != null) && (dossierAffectation.getDossierExamen() != this)) {
      dossierAffectation.setDossierExamen(this);
    }
  }
  
  public CompetenceSpec getCompetence()
  {
    if (estCompetencePersistee()) {
      return super.getCompetence();
    }
    CompetenceSpec competenceAdministrativeParDefaut = new Competence();
    competenceAdministrativeParDefaut.setCompetenceFinanciere(1);
    competenceAdministrativeParDefaut.setCompetenceAdministrative(1);
    setCompetence(competenceAdministrativeParDefaut);
    return competenceAdministrativeParDefaut;
  }
  
  public boolean estCompetencePersistee()
  {
    return super.getCompetence() != null;
  }
  
  public Damj getDateEvenement()
  {
    return getDateAttribution();
  }
  
  public ConstitutionSjc createConstitutionSjc()
  {
    return getConstitutionElementsAdmission().createConstitutionSjc();
  }
  
  public ReglementApplicableSpec createConstitutionReglementApplicable()
  {
    return getConstitutionElementsActifs().createConstitutionReglementApplicable();
  }
  
  public ConstitutionDateLimiteIndemnisation createConstitutionDateLimiteIndemnisation()
  {
    return getConstitutionElementsActifs().createConstitutionDateLimiteIndemnisation();
  }
  
  public ConstitutionDateLimiteIndemnisation getConstitutionDateLimiteIndemnisation()
  {
    return getConstitutionElementsActifs().getConstitutionDateLimiteIndemnisation();
  }
  
  public ConditionAnciennete createConditionAnciennete()
  {
    return getConditionsAttributionAdmission().createConditionAnciennete();
  }
  
  public ConditionAnciennete getConditionAnciennete()
  {
    return getConditionsAttributionAdmission().getConditionAnciennete();
  }
  
  public ConditionDureeNonNulle getConditionDureeNonNulle()
  {
    return getConditionsAttributionActives().getConditionDureeNonNulle();
  }
  
  public ConditionDureeNonNulle createConditionDureeNonNulle()
  {
    return getConditionsAttributionActives().createConditionDureeNonNulle();
  }
  
  public ConditionCSRAccordCP getConditionCSRAccordCP()
  {
    return getConditionsAttributionActives().getConditionCSRAccordCP();
  }
  
  public boolean isEstSinistreOuCalamiteNaturelle()
  {
    return getConditionCSRAccordCP().isEstSinistreOuCalamiteNaturelle();
  }
  
  public abstract Collection getListePlafonnementAffiliation();
  
  public DemandeAssuranceSpec getDemandeAssurance()
  {
    return (DemandeAssuranceSpec)getDemande();
  }
  
  public AttributionAssuranceSpec rechercherAttributionPrecedenteDuMemeType()
  {
    return getDemandeAssurance().rechercherAttributionPrecedenteDuMemeType();
  }
  
  public OdAssuranceSpec rechercherOuvertureDroitPrecedenteDuMemeType()
  {
    return getDemandeAssurance().rechercherOuvertureDroitPrecedenteDuMemeType();
  }
  
  public fr.unedic.cali.asu.dom.ConditionsAttributionSpec getListConditionAttributionObjectifAdmission()
  {
    return getConditionsAttributionAdmission();
  }
  
  public fr.unedic.cali.asu.dom.ConditionsAttributionSpec getListConditionAttributionObjectifReprise()
  {
    return getConditionsAttributionReprise();
  }
  
  public void setCompetence(Competence competence)
  {
    DomManager.supprimer(super.getCompetence(), competence);
    super.setCompetence(competence);
  }
  
  public void setContributionParticuliere(ContributionParticuliereAbstrait contributionParticuliere)
  {
    DomManager.supprimer(super.getContributionParticuliere(), contributionParticuliere);
    super.setContributionParticuliere(contributionParticuliere);
  }
  
  public void setConditionsAttributionAdmission(ConditionsAttributionAdmission conditionsAttributionAdmission)
  {
    DomManager.supprimer(super.getConditionsAttributionAdmission(), conditionsAttributionAdmission);
    super.setConditionsAttributionAdmission(conditionsAttributionAdmission);
  }
  
  public void setConditionsAttributionReprise(ConditionsAttributionReprise conditionsAttributionReprise)
  {
    DomManager.supprimer(super.getConditionsAttributionReprise(), conditionsAttributionReprise);
    super.setConditionsAttributionReprise(conditionsAttributionReprise);
  }
  
  public void setConstitutionElementsAdmission(ConstitutionElementsAdmission constitutionElementsAdmission)
  {
    DomManager.supprimer(super.getConstitutionElementsAdmission(), constitutionElementsAdmission);
    super.setConstitutionElementsAdmission(constitutionElementsAdmission);
  }
  
  public void setConstitutionElementsReprise(ConstitutionElementsReprise constitutionElementsReprise)
  {
    DomManager.supprimer(super.getConstitutionElementsReprise(), constitutionElementsReprise);
    super.setConstitutionElementsReprise(constitutionElementsReprise);
  }
  
  public void setConditionsAttributionRevision(ConditionsAttributionRevision conditionsAttributionRevision)
  {
    DomManager.supprimer(super.getConditionsAttributionRevision(), conditionsAttributionRevision);
    super.setConditionsAttributionRevision(conditionsAttributionRevision);
  }
  
  public void setConstitutionElementsRevision(ConstitutionElementsRevision constitutionElementsRevision)
  {
    DomManager.supprimer(super.getConstitutionElementsRevision(), constitutionElementsRevision);
    super.setConstitutionElementsRevision(constitutionElementsRevision);
  }
  
  public void setCompetenceSousJacente(Competence competenceSousJacente)
  {
    DomManager.supprimer(super.getCompetenceSousJacente(), competenceSousJacente);
    super.setCompetenceSousJacente(competenceSousJacente);
  }
}

/* Location:
 * Qualified Name:     DossierExamen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */