package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ElementChomageSansRuptureSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class ElementChomageSansRupture
  implements ElementChomageSansRuptureSpec
{
  private Demande m_demandeCourante = null;
  private Damj m_dateMaxIndemnisation = null;
  private Damj m_dateRepriseActivite = null;
  private Periode m_periodeDeSuspension = null;
  private Boolean m_estDecisionProlongation;
  private Boolean m_estSinistreOuCalamiteNaturelle;
  private Boolean m_estAccordCp;
  
  public ElementChomageSansRupture(Attribution p_attribution)
  {
    m_demandeCourante = ((Demande)p_attribution.getDemande());
    ContexteDemandeSpec contexte = OutilGestionContexteDemande.trouverContexteDemandeAssurance(m_demandeCourante, new String[] { "RUPCTRSUSP", "CSRSUSP" });
    if (contexte != null) {
      m_periodeDeSuspension = ((ContexteDemande)contexte).getPeriodeJustifContexte();
    }
    if (m_periodeDeSuspension == null)
    {
      TravailSpec periodeFinSuspension = OutilsChomageSansRCT.trouverPeriodeDeSuspension(m_demandeCourante);
      m_periodeDeSuspension = periodeFinSuspension.getPeriode();
    }
    if ((p_attribution.getConstitutionDurees() != null) && (p_attribution.getConstitutionDurees().getDureeIndemnisation() != null))
    {
      if (p_attribution.getConstitutionDurees().getDureeIndemnisation().getDateMaxiIndemnisationCsr() != null) {
        m_dateMaxIndemnisation = p_attribution.getConstitutionDurees().getDureeIndemnisation().getDateMaxiIndemnisationCsr();
      }
      m_estDecisionProlongation = new Boolean(p_attribution.getConstitutionDurees().getDureeIndemnisation().isEstAccordPlusDe182jCsr());
    }
    if (p_attribution.getConditionCSRAccordCP() != null)
    {
      m_estSinistreOuCalamiteNaturelle = new Boolean(p_attribution.getConditionCSRAccordCP().isEstSinistreOuCalamiteNaturelle());
      m_estAccordCp = new Boolean(p_attribution.getConditionCSRAccordCP().estSatisfait());
    }
  }
  
  public ElementChomageSansRupture(TrancheExecutable p_tranche, Demande p_demande)
  {
    m_dateMaxIndemnisation = p_tranche.getDateMaxIndemnisation();
    m_dateRepriseActivite = p_tranche.getDateRepriseActivite();
    m_periodeDeSuspension = new Periode(p_tranche.getDateDebutPeriodeSuspension(), p_tranche.getDateFinPeriodeSuspension());
    m_estSinistreOuCalamiteNaturelle = Boolean.valueOf(p_tranche.isEstSinistreOuCalamite());
    m_estAccordCp = Boolean.valueOf(p_tranche.isEstAccordCp());
    m_estDecisionProlongation = Boolean.valueOf(p_tranche.isEstDecisionProlongation());
    m_demandeCourante = p_demande;
  }
  
  public Damj getDateMaxIndeminisation()
  {
    return m_dateMaxIndemnisation;
  }
  
  public Damj getDateRepriseActivite()
  {
    if ((m_dateRepriseActivite == null) && 
      (m_periodeDeSuspension != null)) {
      m_dateRepriseActivite = m_periodeDeSuspension.getFin().lendemain();
    }
    return m_dateRepriseActivite;
  }
  
  public boolean getDecisionProlongation()
    throws CoucheLogiqueException
  {
    if (m_estDecisionProlongation != null) {
      return m_estDecisionProlongation.booleanValue();
    }
    throw new CoucheLogiqueException("");
  }
  
  public boolean estSinistreOuCalamite()
  {
    if (m_estSinistreOuCalamiteNaturelle != null) {
      return m_estSinistreOuCalamiteNaturelle.booleanValue();
    }
    throw new UnsupportedOperationException("La donnée n'a pas été initialisée");
  }
  
  public boolean estUnContexteDeRupturePendantSuspension()
  {
    return OutilsChomageSansRCT.estDemandeEnContexteDeRuptureDeContratEnCoursDeSuspension(m_demandeCourante);
  }
  
  public boolean estDemandeEnContexteDeChomageEnCoursDeSuspension()
  {
    return OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(m_demandeCourante);
  }
  
  public boolean estAccordCp()
  {
    if (m_estAccordCp != null) {
      return m_estAccordCp.booleanValue();
    }
    throw new UnsupportedOperationException("La donnée n'a pas été initialisée");
  }
  
  public Damj getDateDebutPeriodeSuspension()
  {
    if (m_periodeDeSuspension != null) {
      return m_periodeDeSuspension.getDebut();
    }
    return null;
  }
  
  public Damj getDateFinPeriodeSuspension()
  {
    if (m_periodeDeSuspension != null) {
      return m_periodeDeSuspension.getFin();
    }
    return null;
  }
  
  public void setEstAccordCp(Boolean p_estAccordCp)
  {
    m_estAccordCp = p_estAccordCp;
  }
  
  public void setEstSinistreOuCalamiteNaturelle(Boolean p_estSinistreOuCalamiteNaturelle)
  {
    m_estSinistreOuCalamiteNaturelle = p_estSinistreOuCalamiteNaturelle;
  }
  
  public boolean estUneDemandeSuiteARuptureDuContrat()
  {
    return false;
  }
}

/* Location:
 * Qualified Name:     ElementChomageSansRupture
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */