package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.ParcoursObjectifAdmission;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.ObjectifExamenAdmissionGen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ObjectifExamenSpec;
import fr.unedic.cali.asu.produits.liquidation.parcours.ConstitutionCapitalAvecDureeEffective;
import fr.unedic.cali.asu.produits.liquidation.parcours.ConstitutionDateAttribution;
import fr.unedic.cali.asu.produits.liquidation.parcours.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.parcours.ConstitutionReglementApplicable;
import fr.unedic.cali.asu.produits.liquidation.parcours.DeterminationConditionAge;
import fr.unedic.cali.asu.produits.liquidation.parcours.DeterminationConditionCumulPrestationFamiliale;
import fr.unedic.cali.asu.produits.liquidation.parcours.DeterminationConditionMontantProduitNonNul;
import fr.unedic.cali.asu.produits.liquidation.parcours.DeterminationConditionRechercheEmploi;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.parcours.ParcoursTraitementSatisfait;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import java.util.List;

public class ObjectifExamenAdmission
  extends ObjectifExamenAdmissionGen
  implements ObjectifExamenSpec
{
  private static final long serialVersionUID = 5774469774122080700L;
  protected transient List<ContexteDemandeSpec> listeContextesDemande = null;
  
  public ObjectifExamenAdmission(DomPCSpec pc)
  {
    super(pc);
  }
  
  public ObjectifExamenAdmission() {}
  
  public ObjectifExamenAdmission(List<ContexteDemandeSpec> contexteDemande)
  {
    listeContextesDemande = contexteDemande;
  }
  
  public Parcours creerParcoursObjectif()
  {
    return new ParcoursObjectifAdmission();
  }
  
  public ObjectifExamen getObjectifSauvegarde()
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public int getType()
  {
    return 1;
  }
  
  public ObjetMetierSpec copie()
  {
    ObjectifExamenAdmission copie = new ObjectifExamenAdmission();
    copieElements(copie);
    return copie;
  }
  
  public void marquerGraphePersistant() {}
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public Parcours creerParcoursCapitalAvecDureeEffective()
  {
    return new ConstitutionCapitalAvecDureeEffective();
  }
  
  public Parcours creerParcoursCaractereSaisonnier()
  {
    return null;
  }
  
  public Parcours creerParcoursCoefficientSaisonnier()
  {
    return null;
  }
  
  public Parcours creerParcoursCoefficientTempsPartiel()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionAge()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(listeContextesDemande, "ARESJREV")) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionAge();
  }
  
  public Parcours creerParcoursConditionChomageInvolontaire()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionChomageTotal()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionCumulActiviteConservee()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionCumulAvantageVieillesse()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionCumulPrestationFamiliale()
  {
    if ((OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(listeContextesDemande, "ARESJASPDC")) || (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(listeContextesDemande, "ARESJREV")) || (OutilGestionContexteDemande.estContextePresentDansRegroupement(listeContextesDemande, 7))) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionCumulPrestationFamiliale();
  }
  
  public Parcours creerParcoursConditionFaitGenerateur()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionMontant()
  {
    if ((OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(listeContextesDemande, "ARESJASPDC")) || (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(listeContextesDemande, "ARESJREV"))) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionMontantProduitNonNul();
  }
  
  public Parcours creerParcoursConditionQuantiteAffiliation()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionDureeNonNulle()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionRechercheEmploi()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(listeContextesDemande, "ARESJREV")) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionRechercheEmploi();
  }
  
  public Parcours creerParcoursDateAttribution()
  {
    return new ConstitutionDateAttribution();
  }
  
  public Parcours creerParcoursDelaisReports()
  {
    return null;
  }
  
  public Parcours creerParcoursDeterminationCompetenceFinanceAdmDroitResultant()
  {
    return null;
  }
  
  public Parcours creerParcoursDeterminationCompetencesFinanceAdmDroitCourant()
  {
    return null;
  }
  
  public Parcours creerParcoursDureeEffective()
  {
    return null;
  }
  
  public Parcours creerParcoursDureesReglementaires()
  {
    return null;
  }
  
  public Parcours creerParcoursPointDeDepart()
  {
    return new ConstitutionPointDepartIndemnisation();
  }
  
  public Parcours creerParcoursProduitResultant()
  {
    return null;
  }
  
  public Parcours creerParcoursQuantiteAffiliation()
  {
    return null;
  }
  
  public Parcours creerParcoursReglementApplicable()
  {
    return new ConstitutionReglementApplicable();
  }
  
  public Parcours creerParcoursSalaireJournalierConserve()
  {
    return null;
  }
  
  public Parcours creerParcoursSalaireJournalierDeReference()
  {
    return null;
  }
  
  public Parcours creerParcoursMontantsBruts()
  {
    return null;
  }
  
  public Parcours creerParcoursDateLimiteIndemnisation()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionAnciennete()
  {
    return null;
  }
  
  public Parcours creerParcoursRevisionAutomatique()
  {
    return null;
  }
  
  public Parcours creerParcoursLiquidationDemandeAssociee()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionCsrAccordCp()
  {
    return new ParcoursTraitementSatisfait();
  }
  
  public Parcours creerParcoursCondition28JSuspension()
  {
    return new ParcoursTraitementSatisfait();
  }
  
  public Parcours creerParcoursConditionValiditeReliquat()
  {
    return null;
  }
  
  public Parcours creerParcoursDetectionContributionParticuliere(Demande demande)
  {
    return null;
  }
  
  public Parcours creerParcoursCapitalDroitCourant()
  {
    return null;
  }
  
  public Parcours creerParcoursMontantsEffectifs()
  {
    return null;
  }
  
  public Parcours creerParcoursNouvelleRevisionAutomatique()
  {
    return null;
  }
  
  public Parcours creerParcoursConstitutionDureePostPrime()
  {
    return null;
  }
}

/* Location:
 * Qualified Name:     ObjectifExamenAdmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */