package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.OdAssocieeGen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.AttributionAssocieeSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.FinancementSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class OdAssociee
  extends OdAssocieeGen
  implements FinancementSpec, AttributionAssocieeSpec
{
  private static final long serialVersionUID = 1065122603095007284L;
  
  public OdAssociee(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public OdAssociee() {}
  
  public OdAssociee(Damj p_dateEvenement)
  {
    super(p_dateEvenement);
  }
  
  public OdAssociee(Damj p_dateEvenement, DossierExamen p_dossierExamen)
  {
    super(p_dateEvenement);
    copie(p_dossierExamen);
  }
  
  protected void copie(Attribution p_source)
  {
    if (p_source == null) {
      return;
    }
    super.copie(p_source);
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    Od copie = (Od)p_copie;
    super.copieElements(copie);
  }
  
  public ObjetMetierSpec copie()
  {
    Od copie = new Od();
    copieElements(copie);
    return copie;
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public boolean estExecutable()
  {
    return false;
  }
  
  public String getNatureFinancement()
  {
    if ((getConstitutionDurees() != null) && (getConstitutionDurees().getDureeIndemnisation().getDureeEffective().getValeurEntiere() == 0)) {
      return "E";
    }
    if (getCompetenceFinanciere() == 2) {
      return "E";
    }
    return "P";
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
  {
    controleTrancheExecutableActivee();
    if (ebiAttribution == null) {
      if ((getConstitutionProduitResultant() != null) && (isMontantRetenuPrecedent()))
      {
        int montantRetenu = getConstitutionProduitResultant().getTypeMontantRetenu();
        ebiAttribution = ((ElementBaseIndemnisation)((ProduitAsuSpec)getProduit()).recupererElementBaseIndemnisationPourReadmissionAvecMontantRetenuPrecedent(getNatureDecision(), montantRetenu, getDemande(), this));
      }
      else
      {
        ebiAttribution = super.getElementBaseIndemnisation();
      }
    }
    ebiAttribution.setListePensionInvalidite(getListePensionInvalidite());
    
    return ebiAttribution;
  }
  
  public boolean isMontantRetenuCourant()
  {
    return !isMontantRetenuPrecedent();
  }
  
  private boolean isMontantRetenuPrecedent()
  {
    boolean estMontantRetenuCourant = false;
    if ((getConstitutionProduitResultant() != null) && ((getConstitutionProduitResultant().getTypeMontantRetenu() == 2) || (getConstitutionProduitResultant().getTypeMontantRetenu() == 3))) {
      estMontantRetenuCourant = true;
    }
    return estMontantRetenuCourant;
  }
  
  public BigDecimal getSJRRetenu()
  {
    BigDecimal sjrRetenu = null;
    if (isMontantRetenuCourant()) {
      sjrRetenu = getConstitutionSjr().getSjrrp().getSalaire();
    } else {
      sjrRetenu = getConstitutionProduitResultant().getSjrrpProduitPrecedent().getSalaire();
    }
    return sjrRetenu;
  }
  
  public DemandeSpec getDemandeMontantRetenu()
  {
    DemandeSpec demandeRetenu = null;
    if (getConstitutionProduitResultant() != null)
    {
      int montantRetenu = getConstitutionProduitResultant().getTypeMontantRetenu();
      if ((getAttributionPrecedente() != null) && ((2 == montantRetenu) || (3 == montantRetenu))) {
        demandeRetenu = getAttributionPrecedente().getDemandeMontantRetenu();
      } else {
        demandeRetenu = getDemande();
      }
    }
    else
    {
      demandeRetenu = super.getDemandeMontantRetenu();
    }
    return demandeRetenu;
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    DemandeSpec demandeRetenu = getDemandeMontantRetenu();
    return (ProduitAsuSpec)demandeRetenu.getDossierAffectation().getProduit();
  }
  
  public FormuleMontantSpec getFormuleMontant(String p_code)
  {
    FormuleMontantSpec formuleRetour = null;
    if (getConstitutionProduitResultant() != null)
    {
      int montantRetenu = getConstitutionProduitResultant().getTypeMontantRetenu();
      if ((getAttributionPrecedente() != null) && ((2 == montantRetenu) || (3 == montantRetenu))) {
        formuleRetour = getAttributionPrecedente().getProduitMontantRetenu().getFormuleMontant(p_code);
      } else {
        formuleRetour = super.getFormuleMontant(p_code);
      }
    }
    else
    {
      formuleRetour = super.getFormuleMontant(p_code);
    }
    return formuleRetour;
  }
}

/* Location:
 * Qualified Name:     OdAssociee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */