package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesDureeDroit;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesPRA;
import fr.unedic.cali.dom.spec.PraSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;

public class Pra
  extends Periode
  implements ObjetMetierSpec, PraSpec
{
  private static final int ORDRE_DEFAUT = 1;
  private static final long serialVersionUID = 451523066347525549L;
  private static final Periode PERIODE_VALIDITE_TOUJOURS = new Periode(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS);
  private Hashtable<Unite, Quantite> listeQuantitesAffiliationRequises = new Hashtable();
  private Hashtable<Unite, Quantite> listeQuantitesAssimilationMaximales = new Hashtable();
  private Quantite dureeInitiale = null;
  private String article3;
  private int ordreQuantiteAppartenance;
  private int ordreReglementApplicable;
  private CleAccesPRA cleAcces;
  private Collection<DureeDroitPourPRA> listeDureeDroitPourPRA = new ArrayList();
  private String contexte;
  private Periode periodeValidite = PERIODE_VALIDITE_TOUJOURS;
  
  private Pra() {}
  
  public Pra(String reglement)
  {
    CleAccesPRA cle = new CleAccesPRA(reglement);
    setCleAcces(cle);
    setOrdreReglementApplicable(1);
    setOrdreQuantiteAppartenance(1);
  }
  
  public Pra(String reglement, int duree, int ordreReglementApplicable, int ordreQuantiteAppartenance)
  {
    CleAccesPRA cle = new CleAccesPRA(reglement);
    setCleAcces(cle);
    setDureeInitiale(new Quantite(duree, Unite.get("mois")));
    setOrdreReglementApplicable(ordreReglementApplicable);
    setOrdreQuantiteAppartenance(ordreQuantiteAppartenance);
  }
  
  public Pra(String reglement, int[] codeAge, int duree, int ordreReglementApplicable, int ordreQuantiteAppartenance)
  {
    CleAccesPRA cle = new CleAccesPRA(reglement, codeAge);
    setCleAcces(cle);
    setDureeInitiale(new Quantite(duree, Unite.get("mois")));
    setOrdreReglementApplicable(ordreReglementApplicable);
    setOrdreQuantiteAppartenance(ordreQuantiteAppartenance);
  }
  
  public Pra(String reglement, int[] codeAge, int duree, int ordreReglementApplicable, int ordreQuantiteAppartenance, String contexte)
  {
    CleAccesPRA cle = new CleAccesPRA(reglement, codeAge, contexte);
    setCleAcces(cle);
    setDureeInitiale(new Quantite(duree, Unite.get("mois")));
    setOrdreReglementApplicable(ordreReglementApplicable);
    setOrdreQuantiteAppartenance(ordreQuantiteAppartenance);
    setContexte(contexte);
  }
  
  public Pra(String reglement, int[] codeAge, int duree, int ordreReglementApplicable, int ordreQuantiteAppartenance, int codeNombreTrimestre)
  {
    CleAccesPRA cle = new CleAccesPRA(reglement, codeAge, codeNombreTrimestre);
    setCleAcces(cle);
    setDureeInitiale(new Quantite(duree, Unite.get("mois")));
    setOrdreReglementApplicable(ordreReglementApplicable);
    setOrdreQuantiteAppartenance(ordreQuantiteAppartenance);
  }
  
  public Pra(Damj date, int n)
  {
    super(date, n);
  }
  
  public Pra(Damj date1, Damj date2)
  {
    super(date1, date2);
  }
  
  public Pra(Damj date, DureeCalendaire duree, int sens)
  {
    super(date, duree, sens);
  }
  
  public Pra(Periode periodeReference)
  {
    super(periodeReference.getDebut(), periodeReference.getFin());
  }
  
  public String getArticle3()
  {
    return article3;
  }
  
  public Quantite getDureeInitiale()
  {
    return dureeInitiale;
  }
  
  public Quantite getQuantiteAffiliationRequise(Unite unite)
  {
    return (Quantite)getListeQuantitesAffiliationRequises().get(unite);
  }
  
  public Quantite getQuantiteAssimilationMaximale(Unite unite)
  {
    return (Quantite)getListeQuantitesAssimilationMaximales().get(unite);
  }
  
  public Hashtable<Unite, Quantite> getListeQuantitesAffiliationRequises()
  {
    return listeQuantitesAffiliationRequises;
  }
  
  public Hashtable<Unite, Quantite> getListeQuantitesAssimilationMaximales()
  {
    return listeQuantitesAssimilationMaximales;
  }
  
  public void setArticle3(String article3)
  {
    this.article3 = article3;
  }
  
  public void setDureeInitiale(Quantite dureeInitiale)
  {
    this.dureeInitiale = dureeInitiale;
  }
  
  public void setListeQuantitesAffiliationRequises(Hashtable<Unite, Quantite> listeQuantitesAffiliationRequises)
  {
    this.listeQuantitesAffiliationRequises = listeQuantitesAffiliationRequises;
  }
  
  public void setListeQuantitesAssimilationMaximales(Hashtable<Unite, Quantite> listeQuantitesAssimilationMaximales)
  {
    this.listeQuantitesAssimilationMaximales = listeQuantitesAssimilationMaximales;
  }
  
  public String toString()
  {
    return "PRA [" + getDebut() + " - " + getFin() + "]";
  }
  
  public ObjetMetierSpec copie()
  {
    Pra copie = new Pra();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copieSpec)
  {
    Pra copie = (Pra)copieSpec;
    
    copie.setListeQuantitesAffiliationRequises(getListeQuantitesAffiliationRequises());
    copie.setListeQuantitesAssimilationMaximales(getListeQuantitesAssimilationMaximales());
    copie.setArticle3(getArticle3());
    copie.setDebut(getDebut());
    copie.setDureeInitiale(getDureeInitiale());
    copie.setFin(getFin());
    
    copie.setOrdreQuantiteAppartenance(getOrdreQuantiteAppartenance());
    copie.setOrdreReglementApplicable(getOrdreReglementApplicable());
    copie.setContexte(getContexte());
    copie.setPeriodeValidite(getPeriodeValidite());
    if (getCleAcces() != null) {
      copie.setCleAcces(new CleAccesPRA(getCleAcces().getNomReglement(), getCleAcces().getCodeAge()));
    }
    if (listeDureeDroitPourPRA != null)
    {
      Iterator<DureeDroitPourPRA> it = listeDureeDroitPourPRA.iterator();
      while (it.hasNext()) {
        copie.ajouterDureeDroit(((DureeDroitPourPRA)it.next()).copie());
      }
    }
  }
  
  public boolean estApplicable(CleAccesPRA cle)
  {
    return (cle != null) && (cleAcces.equals(cle)) && ((cle.getDateRecherche() == null) || (getPeriodeValidite().contient(cle.getDateRecherche())));
  }
  
  public CleAccesPRA getCleAcces()
  {
    return cleAcces;
  }
  
  public void setCleAcces(CleAccesPRA cleAcces)
  {
    this.cleAcces = cleAcces;
  }
  
  public int getOrdreQuantiteAppartenance()
  {
    return ordreQuantiteAppartenance;
  }
  
  public void setOrdreQuantiteAppartenance(int ordreQuantiteAppartenance)
  {
    this.ordreQuantiteAppartenance = ordreQuantiteAppartenance;
  }
  
  public int getOrdreReglementApplicable()
  {
    return ordreReglementApplicable;
  }
  
  public void setOrdreReglementApplicable(int ordreReglementApplicable)
  {
    this.ordreReglementApplicable = ordreReglementApplicable;
  }
  
  public void ajouterDureeDroit(DureeDroitPourPRA dureeDroit)
  {
    listeDureeDroitPourPRA.add(dureeDroit);
  }
  
  public DureeDroitPourPRA getDureeDroit(CleAccesDureeDroit cle)
  {
    DureeDroitPourPRA dureeDroit = null;
    
    Iterator<DureeDroitPourPRA> it = listeDureeDroitPourPRA.iterator();
    while (it.hasNext())
    {
      DureeDroitPourPRA dureeCourante = (DureeDroitPourPRA)it.next();
      if (dureeCourante.estApplicable(cle)) {
        if (dureeDroit == null) {
          dureeDroit = dureeCourante;
        } else if (dureeDroit.getOrdre() > dureeCourante.getOrdre()) {
          dureeDroit = dureeCourante;
        }
      }
    }
    return dureeDroit;
  }
  
  public String getContexte()
  {
    return contexte;
  }
  
  public void setContexte(String contexte)
  {
    this.contexte = contexte;
  }
  
  public void setPeriodeValidite(Periode periodeValidite)
  {
    this.periodeValidite = periodeValidite;
  }
  
  public Periode getPeriodeValidite()
  {
    return periodeValidite;
  }
}

/* Location:
 * Qualified Name:     Pra
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */