package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.PrcGen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.NonConformiteException;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.util.Iterator;

public abstract class Prc
  extends PrcGen
  implements ObjetPersistantSpec
{
  public static final String FORMULE_CALCUL_DIVISEUR_RG_A1_A2 = "N - (ni + na)";
  public static final String FORMULE_CALCUL_DIVISEUR_A3 = "Maximum de (N - n; D0)";
  public static final String FORMULE_CALCUL_DIVISEUR_A4 = "Maximum de (N - (n + j); H / 10; D0)";
  public static final String FORMULE_CALCUL_DIVISEUR_A5 = "Maximum de (N - (n + j); D0)";
  protected transient Chronologie m_chronoActiviteSalarie = new ChronologiePeriodes();
  protected transient Chronologie m_chronoPeriodesDeductibles = new ChronologiePeriodes();
  protected transient Chronologie m_listeJustificationDiviseurPeriodesParticipantes = null;
  private transient Chronologie m_chronoActiviteSalarieParticipantSr = new ChronologiePeriodes();
  private transient JustificationPrc m_justification;
  
  protected Prc() {}
  
  public Prc(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public Prc(Damj p_dateDebut, Damj p_dateFin)
  {
    super(p_dateDebut, p_dateFin);
  }
  
  public Prc(Periode p_periode)
  {
    super(p_periode);
  }
  
  protected boolean ajouterActiviteSalarie(ActiviteSalarie p_activiteSalarie)
  {
    boolean ajoutOk = true;
    if (p_activiteSalarie == null) {
      throw new IllegalArgumentException("L'argument à ajouter est null.");
    }
    try
    {
      m_chronoActiviteSalarie.ajouter(p_activiteSalarie);
    }
    catch (NonConformiteException ex)
    {
      if (Log.isTraceActive(Prc.class, Niveau.DEBUG)) {
        Log.ecritTrace(Niveau.DEBUG, Prc.class, "ajouterActiviteSalarie", ex);
      }
      ajoutOk = false;
    }
    return ajoutOk;
  }
  
  protected boolean ajouterPeriodeDeductible(ObjetChronoPeriode p_periodeDeductible)
  {
    boolean ajoutOk = true;
    if (p_periodeDeductible == null) {
      throw new IllegalArgumentException("L'argument à ajouter est null.");
    }
    try
    {
      m_chronoPeriodesDeductibles.ajouter(p_periodeDeductible);
    }
    catch (NonConformiteException ex)
    {
      if (Log.isTraceActive(Prc.class, Niveau.DEBUG)) {
        Log.ecritTrace(Niveau.DEBUG, Prc.class, "ajouterPeriodeDeductible", ex);
      }
      ajoutOk = false;
    }
    return ajoutOk;
  }
  
  public boolean ajouterActiviteSalarieParticipantSr(ActiviteSalarie p_activiteSalarie)
  {
    boolean ajoutOk = true;
    if (p_activiteSalarie == null) {
      throw new IllegalArgumentException("L'argument à ajouter est null.");
    }
    try
    {
      getChronoActiviteSalarieParticipantSr().ajouter(p_activiteSalarie);
    }
    catch (NonConformiteException ex)
    {
      if (Log.isTraceActive(Prc.class, Niveau.DEBUG)) {
        Log.ecritTrace(Niveau.DEBUG, Prc.class, "ajouterActiviteSalarieParticipantSr", ex);
      }
      ajoutOk = false;
    }
    return ajoutOk;
  }
  
  public String toString()
  {
    StringBuffer chaineRetour = new StringBuffer();
    chaineRetour.append(super.toString() + "\n");
    chaineRetour.append("Prip : " + getPrip() + "\n");
    chaineRetour.append("Srip : " + getSrip() + "\n");
    chaineRetour.append("Diviseur (D) : " + getDiviseur() + "\n");
    chaineRetour.append("Durée Prc (N) : " + getDureePrc() + "\n");
    chaineRetour.append("n : " + getNombreJourDeductible() + "\n");
    chaineRetour.append("na : " + getNombreJourAbsence() + "\n");
    chaineRetour.append("ni : " + getNombreJourInappartenance() + "\n");
    chaineRetour.append("H : " + getNombreHeuresTotal() + "\n");
    chaineRetour.append("h : " + getNombreHeuresA4ouA5() + "\n");
    if (!getChronoActiviteSalarie().estVide()) {
      chaineRetour.append("Chrono périodes activités salariées : " + getChronoActiviteSalarie() + "\n");
    }
    if (!getChronoPeriodesDeductibles().estVide()) {
      chaineRetour.append("Chrono périodes déductibles : " + getChronoPeriodesDeductibles() + "\n");
    }
    chaineRetour.append("Top contrats type particulier : " + isTopContratsDeTypeParticulier() + "\n");
    
    return chaineRetour.toString();
  }
  
  public void setDateDebut(Damj p_dateDebut)
  {
    setPeriode(new Periode(p_dateDebut, getDateFin()));
  }
  
  public void setDateFin(Damj p_dateFin)
  {
    setPeriode(new Periode(getDateDebut(), p_dateFin));
  }
  
  public void jdoPostLoad() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete() {}
  
  public void marquerGraphePersistant() {}
  
  public void jdoPreStore() {}
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    Prc copie = (Prc)p_copie;
    if (getPeriode() != null) {
      copie.setPeriode(new Periode(getPeriode().getDebut(), getPeriode().getFin()));
    }
    if (getChronoActiviteSalarie() != null)
    {
      Iterator iter = getChronoActiviteSalarie().iterer();
      while (iter.hasNext())
      {
        ActiviteSalarie element = (ActiviteSalarie)iter.next();
        copie.ajouterActiviteSalarie(element);
      }
    }
    if (getChronoPeriodesDeductibles() != null)
    {
      Iterator iter = getChronoPeriodesDeductibles().iterer();
      while (iter.hasNext())
      {
        ObjetChronoPeriode element = (ObjetChronoPeriode)iter.next();
        copie.ajouterPeriodeDeductible(element);
      }
    }
    if (getPrip() != null) {
      copie.setPrip(new Periode(getPrip().getDebut(), getPrip().getFin()));
    }
    copie.setDiviseur(getDiviseur());
    copie.setDureePrc(getDureePrc());
    copie.setNombreHeuresTotal(getNombreHeuresTotal());
    copie.setNombreJourAbsence(getNombreJourAbsence());
    copie.setNombreJourDeductible(getNombreJourDeductible());
    copie.setSrip(getSrip());
    copie.setDroitCongesA4ouA5(getDroitCongesA4ouA5());
    copie.setNombreHeuresA4ouA5(getNombreHeuresA4ouA5());
    copie.setNombreJourInappartenance(getNombreJourInappartenance());
    copie.setNombreJourTravailEffectif(getNombreJourTravailEffectif());
    copie.setTopContratsDeTypeParticulier(isTopContratsDeTypeParticulier());
    if (getJustification() != null) {
      copie.setJustification((JustificationPrc)getJustification().copie());
    }
    copie.setEstSripReduit(isEstSripReduit());
  }
  
  public Chronologie getChronoActiviteSalarie()
  {
    return m_chronoActiviteSalarie;
  }
  
  public Chronologie getChronoPeriodesDeductibles()
  {
    return m_chronoPeriodesDeductibles;
  }
  
  public Chronologie getChronoActiviteSalarieParticipantSr()
  {
    return m_chronoActiviteSalarieParticipantSr;
  }
  
  public void viderChronologies()
  {
    m_chronoActiviteSalarie.vider();
    m_chronoPeriodesDeductibles.vider();
  }
  
  public JustificationPrc getJustification()
  {
    if (m_justification == null) {
      m_justification = new JustificationPrc(getPeriode());
    }
    return m_justification;
  }
  
  public void setJustification(JustificationPrc p_justification)
  {
    m_justification = p_justification;
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
}

/* Location:
 * Qualified Name:     Prc
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */