package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.ReadmissionGen;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.ReadmissionSpec;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitDelegueSpec;
import fr.unedic.cali.dom.affectation.ProduitSecurisationProfessionnelleSpec;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class Readmission
  extends ReadmissionGen
  implements ReadmissionSpec
{
  private static final long serialVersionUID = 699573461090044586L;
  
  public Readmission(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Readmission() {}
  
  public Readmission(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public Readmission(Damj dateEvenement, DossierExamen dossierExamen)
  {
    super(dateEvenement, dossierExamen);
  }
  
  public ObjetMetierSpec copie()
  {
    Readmission copie = new Readmission();
    copieElements(copie);
    return copie;
  }
  
  protected void copie(DossierExamen pSource)
  {
    super.copie(pSource);
    if ((pSource instanceof Od))
    {
      Od source = (Od)pSource;
      List listeSourceTrancheExecutable = source.getListTranchesExecutables();
      if (listeSourceTrancheExecutable != null)
      {
        List<TrancheExecutable> listeCibleTrancheExecutable = new ArrayList();
        Iterator itSource = listeSourceTrancheExecutable.iterator();
        while (itSource.hasNext())
        {
          TrancheExecutable trancheCourante = (TrancheExecutable)itSource.next();
          listeCibleTrancheExecutable.add((TrancheExecutable)trancheCourante.copie());
        }
        setListeTranchesExecutables(listeCibleTrancheExecutable);
      }
    }
  }
  
  public void copieElements(ObjetMetierSpec pCopie)
  {
    Readmission copie = (Readmission)pCopie;
    super.copieElements(copie);
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public List getListeDurees()
  {
    switch (getNatureDecision())
    {
    case 11: 
    case 26: 
      return getListeDureesProduitResultant();
    }
    return super.getListeDurees();
  }
  
  private List getListeDureesProduitResultant()
  {
    ArrayList listeDurees = new ArrayList();
    if (getConstitutionProduitResultant() != null) {
      listeDurees.add(((ProduitAsuSpec)getProduit()).creerDureeCalcul(this));
    }
    Demande demande = (Demande)getDemande();
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demande))
    {
      DureeProlongation dureeProlongation = new DureeProlongation();
      listeDurees.add(dureeProlongation.creerDureeCalcul());
    }
    return listeDurees;
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
  {
    controleTrancheExecutableActivee();
    if (ebiAttribution == null)
    {
      int montantRetenu = getConstitutionProduitResultant().getTypeMontantRetenu();
      if ((isMontantRetenuCourant()) || (getNatureDecision() == 12)) {
        ebiAttribution = super.getElementBaseIndemnisation();
      } else {
        ebiAttribution = ((ElementBaseIndemnisation)((ProduitAsuSpec)getProduit()).recupererElementBaseIndemnisationPourReadmissionAvecMontantRetenuPrecedent(getNatureDecision(), montantRetenu, getDemande(), this));
      }
      if (((getDemande() != null) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "ARECOURCSP"))) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "AREENTRCSP"))) {
        ebiAttribution.setProduitAreActif(getProduit());
      } else if ((getProduit() instanceof ProduitSecurisationProfessionnelleSpec)) {
        ebiAttribution.setProduitAreActif(((ProduitSecurisationProfessionnelleSpec)getProduit()).recupererProduitAreActif(this));
      }
    }
    if (getCompetence().getCompetenceAdministrative() == 2)
    {
      if (((Competence)getCompetence()).isEstPCRCForce()) {
        ebiAttribution.setAvecPrecompteCRC(Boolean.TRUE);
      }
    }
    else {
      ebiAttribution.setAvecPrecompteCRC(null);
    }
    ebiAttribution.setEstProduitGerantPensionInvalidite(Boolean.valueOf(((ProduitAsuSpec)getProduit()).estProduitGerantPensionInvalidite(getDemande())));
    
    ebiAttribution.setListePensionInvalidite(getListePensionInvalidite());
    
    return (ElementBaseIndemnisation)ebiAttribution.copie();
  }
  
  public DemandeSpec getDemandeMontantRetenu()
  {
    DemandeSpec demandeRetenu = null;
    
    int montantRetenu = getConstitutionElementsAdmission().getConstitutionProduitResultant().getTypeMontantRetenu();
    if ((1 == montantRetenu) || (getAttributionPrecedente() == null)) {
      demandeRetenu = getDemande();
    } else {
      demandeRetenu = getAttributionPrecedente().getDemandeMontantRetenu();
    }
    return demandeRetenu;
  }
  
  public Quantite getDureeIndemnisationInitiale()
  {
    Quantite dureeEffective = null;
    ConstitutionProduitResultant constitutionProduitResultant = getConstitutionProduitResultant();
    if (constitutionProduitResultant != null) {
      dureeEffective = constitutionProduitResultant.getDureeEffective();
    }
    return dureeEffective;
  }
  
  public Quantite getDureeIndemnisationTheorique()
  {
    return getDureeTheorique();
  }
  
  public Quantite getDureeTheorique()
  {
    switch (getNatureDecision())
    {
    case 11: 
    case 26: 
      return getConstitutionProduitResultant().getDureeTheorique();
    }
    return getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
  }
  
  public FormuleMontantSpec getFormuleMontant(String p_code)
  {
    FormuleMontantSpec formuleRetour = null;
    
    int montantRetenu = getConstitutionElementsAdmission().getConstitutionProduitResultant().getTypeMontantRetenu();
    if ((1 == montantRetenu) || (getAttributionPrecedente() == null)) {
      formuleRetour = super.getFormuleMontant(p_code);
    } else {
      formuleRetour = getAttributionPrecedente().getProduitMontantRetenu().getFormuleMontant(p_code);
    }
    Demande demande = (Demande)getDemande();
    if ((demande.getDonneesDemandeAssociee() != null) && (demande.getDonneesDemandeAssociee().getDemandeAssociee() != null))
    {
      if (String.valueOf(2).equals(getConstitutionMontantsBruts().getTypeMontantRetenuDroitCourant())) {
        formuleRetour.setFormuleMontantApplicable(2);
      } else {
        formuleRetour.setFormuleMontantApplicable(1);
      }
      if (demande.getDonneesDemandeAssociee().getDemandeAssociee().getAttribution() != null) {
        formuleRetour.setFormuleMontantDroitAssocie(demande.getDonneesDemandeAssociee().getDemandeAssociee().getAttribution().getFormuleMontant("2"));
      }
    }
    return formuleRetour;
  }
  
  public AttributionSpec getAttributionMaitre()
  {
    if ((getNatureDecision() == 11) || (getNatureDecision() == 26))
    {
      int capitalRetenu = getConstitutionProduitResultant().getTypeCapitalRetenu();
      if (1 == capitalRetenu) {
        return this;
      }
      if (getAttributionPrecedente() != null) {
        return getAttributionPrecedente().getAttributionMaitre();
      }
    }
    return this;
  }
  
  public AttributionAssuranceSpec getAttributionMaitrePourRevision()
  {
    return this;
  }
  
  public MontantAsuSpec getMontantRecalcule(Damj p_dateRecalcul)
    throws CoucheLogiqueException
  {
    switch (getNatureDecision())
    {
    case 11: 
      if (getAttributionPrecedente() != null) {
        return getAttributionPrecedente().getMontantRecalcule(p_dateRecalcul);
      }
      return null;
    case 26: 
      if (getConstitutionProduitResultant().getTypeMontantRetenu() == 1) {
        return recalculerMontantAttribution(p_dateRecalcul);
      }
      if (getAttributionPrecedente() != null) {
        return getAttributionPrecedente().getMontantRecalcule(p_dateRecalcul);
      }
      if (((Demande)getDemande()).estEnContexteDroitAnterieurSecteurPublicValide())
      {
        MontantBaseSpec montantRecalcule = ((ProduitAsuSpec)getProduit()).obtenirMontantDroitPrecedentSecteurPublicProduitResultant((Demande)getDemande(), this, getDemandeur());
        return (MontantAsuSpec)montantRecalcule;
      }
      return null;
    }
    return recalculerMontantAttribution(p_dateRecalcul);
  }
  
  public ProduitDelegueSpec getProduitDelegueMontantRetenu()
  {
    DemandeSpec demandeRetenu = getDemandeMontantRetenu();
    return ((ProduitAbstrait)demandeRetenu.getDossierAffectation().getProduit()).getProduitDelegue();
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    DemandeSpec demandeRetenu = getDemandeMontantRetenu();
    return (ProduitAsuSpec)demandeRetenu.getDossierAffectation().getProduit();
  }
  
  public boolean isMontantRetenuCourant()
  {
    boolean estMontantRetenuCourant = false;
    if (getConstitutionProduitResultant().getTypeMontantRetenu() == 1) {
      estMontantRetenuCourant = true;
    }
    return estMontantRetenuCourant;
  }
  
  public Quantite getDureeIndemnisationEffective()
  {
    switch (getNatureDecision())
    {
    case 11: 
    case 26: 
      return getConstitutionProduitResultant().getDureeEffective();
    }
    if ((getConstitutionDurees() != null) && (getConstitutionDurees().getDureeIndemnisation() != null)) {
      return getConstitutionDurees().getDureeIndemnisation().getDureeEffective();
    }
    return null;
  }
  
  public int getTypeMontantRetenu()
  {
    switch (getNatureDecision())
    {
    case 11: 
    case 26: 
      return getConstitutionProduitResultant().getTypeMontantRetenu();
    }
    return super.getTypeMontantRetenu();
  }
  
  public int getTypeCapitalRetenu()
  {
    switch (getNatureDecision())
    {
    case 11: 
    case 26: 
      return getConstitutionProduitResultant().getTypeCapitalRetenu();
    }
    return super.getTypeCapitalRetenu();
  }
  
  public OdAssuranceSpec getOuvertureDroitCapitalRetenu()
  {
    OdAssuranceSpec ouvertureDeDroit = this;
    if ((getNatureDecision() == 11) || (getNatureDecision() == 26))
    {
      int capitalRetenu = getTypeCapitalRetenu();
      if (1 != capitalRetenu)
      {
        AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
        if (attributionPrecedente == null) {
          attributionPrecedente = getDemandeAssurance().rechercherOuvertureDroitPrecedenteDuMemeType();
        }
        if (attributionPrecedente != null) {
          ouvertureDeDroit = attributionPrecedente.getOuvertureDroitCapitalRetenu();
        }
      }
    }
    return ouvertureDeDroit;
  }
  
  public Collection getListePensionInvalidite()
  {
    switch (getNatureDecision())
    {
    case 11: 
      return getConstitutionProduitResultant().getListePensionInvalidite();
    case 12: 
    case 26: 
      return getConstitutionMontantsBruts().getListePensionInvalidite();
    }
    return null;
  }
  
  public SalaireJournalierSpec getSalaireJournalierInitial()
  {
    Demande demande = (Demande)getDemande();
    SalaireJournalierSpec salaireJournalierRetenu = null;
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      salaireJournalierRetenu = super.getSalaireJournalierInitial();
    } else if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      salaireJournalierRetenu = new Sjr(demande.getDonneesTemporaires().getSjrSP().getValeur(), demande.getDonneesTemporaires().getTermePrcSp(), null);
    } else {
      salaireJournalierRetenu = getAttributionPrecedente().getSalaireJournalierInitial();
    }
    return salaireJournalierRetenu;
  }
  
  public BigDecimal getCoefficientSaisonnier()
  {
    Demande demande = (Demande)getDemande();
    BigDecimal coefficientSaisonnier = BigDecimal.ONE;
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      coefficientSaisonnier = super.getCoefficientSaisonnier();
    } else if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      coefficientSaisonnier = demande.getDonneesTemporaires().getCoefficientSaisonnierSp();
    } else {
      coefficientSaisonnier = getAttributionPrecedente().getCoefficientSaisonnier();
    }
    return coefficientSaisonnier;
  }
  
  public int getNatureCoefficientSaisonnier()
  {
    Demande demande = (Demande)getDemande();
    int natureCoefficientSaisonnier = -1;
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      natureCoefficientSaisonnier = super.getNatureCoefficientSaisonnier();
    } else if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      natureCoefficientSaisonnier = demande.getDonneesTemporaires().getTypeCaractereSaisonnierForce();
    } else {
      natureCoefficientSaisonnier = getAttributionPrecedente().getNatureCoefficientSaisonnier();
    }
    return natureCoefficientSaisonnier;
  }
  
  public boolean a3ansActiviteEn5ans()
  {
    Demande demande = (Demande)getDemande();
    boolean a3ansActiviteEn5ans = false;
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      a3ansActiviteEn5ans = super.a3ansActiviteEn5ans();
    } else if (!demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      a3ansActiviteEn5ans = getAttributionPrecedente().a3ansActiviteEn5ans();
    }
    return a3ansActiviteEn5ans;
  }
  
  public BigDecimal getCoefficientTempsPartiel()
  {
    Demande demande = (Demande)getDemande();
    BigDecimal coefficientSaisonnier = new BigDecimal("1");
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      coefficientSaisonnier = super.getCoefficientTempsPartiel();
    } else if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      coefficientSaisonnier = demande.getDonneesTemporaires().getCoefficientTempsPartielSp();
    } else {
      coefficientSaisonnier = getAttributionPrecedente().getCoefficientTempsPartiel();
    }
    return coefficientSaisonnier;
  }
  
  public boolean estSjrBaseSmic()
  {
    Demande demande = (Demande)getDemande();
    boolean sjrBaseSmic = false;
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      sjrBaseSmic = super.estSjrBaseSmic();
    } else if (!demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      sjrBaseSmic = getAttributionPrecedente().estSjrBaseSmic();
    }
    return sjrBaseSmic;
  }
  
  public int getCategorieEmploiA2B()
  {
    Demande demande = (Demande)getDemande();
    int categorieA2B = 0;
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      categorieA2B = super.getCategorieEmploiA2B();
    } else if (!demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      categorieA2B = getAttributionPrecedente().getCategorieEmploiA2B();
    }
    return categorieA2B;
  }
  
  public Quantite getCapitalAServir()
  {
    Quantite capitalAServir = null;
    boolean estCapitalCourantRetenu = getTypeCapitalRetenu() == 1;
    if (estCapitalCourantRetenu) {
      capitalAServir = super.getCapitalAServir();
    } else {
      capitalAServir = getConstitutionProduitResultant().getCapitalMax();
    }
    return capitalAServir;
  }
  
  public ReglementApplicableSpec getReglementApplicableMontantRetenu()
  {
    ReglementApplicableSpec reglement = null;
    
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      reglement = super.getReglementApplicableMontantRetenu();
    } else if (((Demande)getDemande()).estEnContexteDroitAnterieurSecteurPublicValide()) {
      reglement = super.getReglementApplicableMontantRetenu();
    } else {
      reglement = getAttributionPrecedente().getReglementApplicableMontantRetenu();
    }
    return reglement;
  }
}

/* Location:
 * Qualified Name:     Readmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */