package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseActiviteReduite;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.RepriseGen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.SjcipSpec;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.novation.OutilConstitutionSjc;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.novation.OutilConstitutionSjr;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSecurisationProfessionnelleSpec;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.List;

public class Reprise
  extends RepriseGen
  implements RepriseSpec
{
  public static final String MONTANT_RETENU_ASP = "1";
  public static final String MONTANT_RETENU_ARE_SOUS_JACENT = "2";
  private static final long serialVersionUID = -8856563166773337337L;
  
  public Reprise(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Reprise() {}
  
  public Reprise(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public Reprise(Damj dateEvenement, DossierExamenSpec dossierExamen)
  {
    super(dateEvenement);
    copie((DossierExamen)dossierExamen);
  }
  
  public ObjetMetierSpec copie()
  {
    Reprise copie = new Reprise();
    copieElements(copie);
    return copie;
  }
  
  public String getSituationParticuliere()
  {
    String situationParticuliere = "";
    if (getAttributionPrecedente() != null) {
      situationParticuliere = getAttributionPrecedente().getSituationParticuliere();
    }
    return situationParticuliere;
  }
  
  public boolean isInvestigationFraude()
  {
    if (getAttributionPrecedente() == null) {
      return false;
    }
    return getAttributionPrecedente().isInvestigationFraude();
  }
  
  public String getRsod()
  {
    String rsod = "0";
    if (getAttributionPrecedente() != null) {
      rsod = getAttributionPrecedente().getRsod();
    }
    return rsod;
  }
  
  public String getRsrp()
  {
    return getReferenceExterne();
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public JustificationAffiliationSpec getJustificationAffiliation()
  {
    return null;
  }
  
  public boolean isTopContratsRemuneresBaseSmic()
  {
    boolean estApprenti = false;
    if (getAttributionPrecedente() != null) {
      estApprenti = getAttributionPrecedente().isTopContratsRemuneresBaseSmic();
    }
    return estApprenti;
  }
  
  public ReglementApplicableSpec getConstitutionReglementApplicable()
  {
    ReglementApplicableSpec reglement = null;
    if (getAttributionPrecedente() != null) {
      reglement = getAttributionPrecedente().getReglementApplicable();
    }
    return reglement;
  }
  
  public ConstitutionSjr getConstitutionSjr()
  {
    ConstitutionSjr constitutionSjr = getConstitutionElementsActifs().getConstitutionSjr();
    if (constitutionSjr == null)
    {
      constitutionSjr = getConstitutionElementsActifs().createConstitutionSjr();
      if (constitutionSjr.getSjrip() == null) {
        constitutionSjr.createSjrip();
      }
      OutilConstitutionSjr.alimenterSjr(constitutionSjr, (ProduitAsuSpec)getProduit(), this);
    }
    return constitutionSjr;
  }
  
  public ConstitutionSjc getConstitutionSjc()
  {
    ConstitutionSjc constitutionSjc = getConstitutionElementsActifs().getConstitutionSjc();
    if (constitutionSjc == null)
    {
      constitutionSjc = getConstitutionElementsActifs().createConstitutionSjc();
      
      SjcipSpec sjcip = constitutionSjc.createSjcip();
      OutilConstitutionSjc.alimenterSjcPourReprise(this, constitutionSjc, sjcip, (ProduitAsuSpec)getProduit());
    }
    return constitutionSjc;
  }
  
  public ElementBaseActiviteReduite getElementBaseActiviteReduite()
  {
    return getAttributionPrecedente().getElementBaseActiviteReduite();
  }
  
  public ConstitutionCoefficientSaisonnier getConstitutionCoefficientSaisonnier()
  {
    BigDecimal coefficient = BigDecimal.ONE;
    ConstitutionCoefficientSaisonnier constitutionCoefficient = getConstitutionElementsReprise().getConstitutionCoefficientSaisonnier();
    if ((getAttributionPrecedente() != null) && (constitutionCoefficient == null))
    {
      if (((ProduitAsuSpec)getAttributionPrecedente().getProduit()).estTrancheActivee(getAttributionPrecedente().getDemande()))
      {
        TrancheExecutable trancheExecutable = (TrancheExecutable)((Attribution)getAttributionPrecedente()).getListTranchesExecutables().get(0);
        coefficient = trancheExecutable.getCoefficientSaisonnier();
      }
      else
      {
        coefficient = getAttributionPrecedente().getElementBaseIndemnisation().getCoefficientSaisonnier();
      }
      if (coefficient != null)
      {
        constitutionCoefficient = getConstitutionElementsActifs().createConstitutionCoefficientSaisonnier();
        constitutionCoefficient.setCoefficientSaisonnierRetenu(coefficient);
      }
    }
    return constitutionCoefficient;
  }
  
  public ConstitutionCoefficientTempsPartiel getConstitutionCoefficientTempsPartiel()
  {
    BigDecimal coefficient = BigDecimal.ONE;
    ConstitutionCoefficientTempsPartiel constitutionCoefficient = getConstitutionElementsReprise().getConstitutionCoefficientTempsPartiel();
    if ((getAttributionPrecedente() != null) && (constitutionCoefficient == null))
    {
      if (((ProduitAsuSpec)getAttributionPrecedente().getProduit()).estTrancheActivee(getAttributionPrecedente().getDemande()))
      {
        TrancheExecutable trancheExecutable = (TrancheExecutable)((Attribution)getAttributionPrecedente()).getListTranchesExecutables().get(0);
        coefficient = trancheExecutable.getCoefficientTempsPartiel();
      }
      else
      {
        coefficient = getAttributionPrecedente().getElementBaseIndemnisation().getCoefficientTempsPartiel();
      }
      constitutionCoefficient = getConstitutionElementsActifs().createConstitutionCoefficientTempsPartiel();
      constitutionCoefficient.setCoefficientTempsPartielRetenu(coefficient);
    }
    return constitutionCoefficient;
  }
  
  public ConstitutionCaractereSaisonnier getConstitutionCaractereSaisonnier()
  {
    ConstitutionCaractereSaisonnier caractereSaisonnier = null;
    if (getAttributionPrecedente() != null)
    {
      caractereSaisonnier = getConstitutionElementsActifs().createConstitutionCaractereSaisonnier();
      
      int typeCaractereSaisonnierRetenu = 0;
      boolean estActivite3Sur5 = false;
      if (((ProduitAsuSpec)getAttributionPrecedente().getProduit()).estTrancheActivee(getAttributionPrecedente().getDemande()))
      {
        TrancheExecutable tranche = (TrancheExecutable)((Attribution)getAttributionPrecedente()).getListTranchesExecutables().get(0);
        typeCaractereSaisonnierRetenu = tranche.getNatureCoefficientSaisonnier();
        estActivite3Sur5 = tranche.isA3ansActiviteEn5ans();
      }
      else
      {
        ElementBaseIndemnisation elementBaseIndemnisation = getElementBaseIndemnisation();
        typeCaractereSaisonnierRetenu = elementBaseIndemnisation.getTypeCaractereSaisonnierRetenu();
        estActivite3Sur5 = elementBaseIndemnisation.isConditionCaractereSaisonnierParRythme();
      }
      if ((typeCaractereSaisonnierRetenu == 2) || (typeCaractereSaisonnierRetenu == 1)) {
        caractereSaisonnier.setCaractereSaisonnierRetenu(true);
      }
      if (typeCaractereSaisonnierRetenu == -1) {
        caractereSaisonnier.setTypeCaractereSaisonnierRetenu(0);
      } else {
        caractereSaisonnier.setTypeCaractereSaisonnierRetenu(typeCaractereSaisonnierRetenu);
      }
      caractereSaisonnier.setActivite3Sur5(estActivite3Sur5);
    }
    return caractereSaisonnier;
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
  {
    controleTrancheExecutableActivee();
    if (ebiAttribution == null)
    {
      ElementBaseIndemnisation ebiAttributionPrecedente = null;
      ((Demande)getAttributionPrecedente().getDemande()).desactiverTrancheExecutable();
      ebiAttributionPrecedente = getAttributionPrecedente().getElementBaseIndemnisation();
      ((Demande)getAttributionPrecedente().getDemande()).reactiverTrancheExecutable();
      
      ebiAttribution = new ElementBaseIndemnisation();
      ebiAttributionPrecedente.copieElements(ebiAttribution);
      if ((OutilDemande.estUneDemandeFinDroitAsp(getDemande())) && (getConstitutionElementsReprise().getConstitutionSjr() != null) && (getConstitutionElementsReprise().getConstitutionSjr().getSjrip() != null))
      {
        ebiAttribution.setSjr(getConstitutionElementsReprise().getConstitutionSjr().getSjri());
        if (getConstitutionElementsReprise().getConstitutionSjc() != null) {
          ebiAttribution.setSjc(getConstitutionElementsReprise().getConstitutionSjc().getSjci());
        }
      }
      majProduitActif();
      
      Quantite dureePostPrime = getDureePostPrime();
      if ((dureePostPrime != null) && (dureePostPrime.getValeurEntiere() == 0)) {
        ebiAttribution.setEstDureePostPrimeEpuisee(true);
      }
    }
    return (ElementBaseIndemnisation)ebiAttribution.copie();
  }
  
  private void majProduitActif()
  {
    if ((getDemande() != null) && (estDemandeEnContexteAreASP((Demande)getDemande()))) {
      ebiAttribution.setProduitAreActif(getProduit());
    } else if ((getProduit() instanceof ProduitSecurisationProfessionnelleSpec)) {
      ebiAttribution.setProduitAreActif(((ProduitSecurisationProfessionnelleSpec)getProduit()).recupererProduitAreActif(this));
    }
  }
  
  public AttributionSpec getAttributionMaitre()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionMaitre();
    }
    return null;
  }
  
  public AttributionAssuranceSpec getAttributionOrigine()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionOrigine();
    }
    return null;
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getProduitMontantRetenu();
    }
    return null;
  }
  
  public FormuleMontantSpec getFormuleMontant(String code)
  {
    Demande demandePrecedente = (Demande)getAttributionPrecedente().getDemande();
    if ((estDemandeEnContexteAreASP((Demande)getDemande())) || ((estDemandeEnContexteAreASP(demandePrecedente)) && (!estDemandeEnContexteAreASP((Demande)getDemande())))) {
      return super.getFormuleMontant(code);
    }
    return getAttributionPrecedente().getFormuleMontant(code);
  }
  
  private boolean estDemandeEnContexteAreASP(Demande demande)
  {
    return (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "AREENTRCSP")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP"));
  }
  
  public Damj getDateFaitGenerateurDroit()
  {
    return getAttributionPrecedente().getDateFaitGenerateurDroit();
  }
  
  public MaintienEuropeen getMaintienEuropeen()
  {
    if (maintienEuropeen == null) {
      if (getAttributionPrecedente() != null) {
        if (getAttributionPrecedente().getMaintienEuropeen() == null) {
          maintienEuropeen = MaintienEuropeen.getInstanceMaintienEuropeen(this);
        } else {
          maintienEuropeen = getAttributionPrecedente().getMaintienEuropeen();
        }
      }
    }
    return maintienEuropeen;
  }
  
  public boolean estMaintenue()
  {
    if (getOuvertureDroit().getNatureDecision() == 38) {
      return ((fr.unedic.cali.asu.dom.OdAssuranceSpec)getOuvertureDroit()).estMaintenue();
    }
    return super.estMaintenue();
  }
  
  public BigDecimal getSeuilMensuelPansConservees()
  {
    return getAttributionPrecedente().getSeuilMensuelPansConservees();
  }
  
  public Damj getTermePrcActiviteConservee()
  {
    return getAttributionPrecedente().getTermePrcActiviteConservee();
  }
  
  public Collection getListePlafonnementAffiliation()
  {
    return (getAttributionPrecedente() instanceof Attribution) ? ((Attribution)getAttributionPrecedente()).getListePlafonnementAffiliation() : null;
  }
  
  public DemandeSpec getDemandeMontantRetenu()
  {
    return getAttributionPrecedente().getDemandeMontantRetenu();
  }
  
  public int getTypeMontantRetenu()
  {
    return getAttributionPrecedente().getTypeMontantRetenu();
  }
  
  public int getTypeCapitalRetenu()
  {
    throw new UnsupportedOperationException("HG_PR_L_METHODE_NON_IMPLEMENTEE_ATTRIBUTION");
  }
  
  public fr.unedic.cali.dom.OdAssuranceSpec getOuvertureDroit()
  {
    fr.unedic.cali.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroit();
    }
    return ouvertureDeDroit;
  }
  
  public fr.unedic.cali.asu.dom.OdAssuranceSpec getOuvertureDroitCapitalRetenu()
  {
    fr.unedic.cali.asu.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente == null) {
      attributionPrecedente = getDemandeAssurance().rechercherOuvertureDroitPrecedenteDuMemeType();
    }
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroitCapitalRetenu();
    }
    return ouvertureDeDroit;
  }
  
  public boolean estDemandeSuiteFinDeDroit()
  {
    return (getAttributionPrecedente() != null) && (getAttributionPrecedente().estDemandeSuiteFinDeDroit());
  }
  
  public Collection getListePensionInvalidite()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getListePensionInvalidite();
    }
    return null;
  }
  
  public AttributionAssuranceSpec getAttributionAssociee()
  {
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if ((attributionPrecedente instanceof Attribution)) {
      return ((Attribution)attributionPrecedente).getAttributionAssociee();
    }
    return null;
  }
  
  public SalaireJournalierSpec getSalaireJournalierInitial()
  {
    if (OutilDemande.estUneDemandeFinDroitAsp(getDemande()))
    {
      ConstitutionSjr constitutionSjr = getConstitutionElementsReprise().getConstitutionSjr();
      if ((constitutionSjr != null) && (constitutionSjr.getSjrip() != null)) {
        return constitutionSjr.getSjri();
      }
    }
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getSalaireJournalierInitial();
    }
    return null;
  }
  
  public SalaireJournalierSpec getSalaireJournalierConserve()
  {
    if (OutilDemande.estUneDemandeFinDroitAsp(getDemande()))
    {
      ConstitutionSjc constitutionSjc = getConstitutionElementsReprise().getConstitutionSjc();
      if ((constitutionSjc != null) && (constitutionSjc.getSjci() != null)) {
        return constitutionSjc.getSjci();
      }
    }
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getSalaireJournalierConserve();
    }
    return null;
  }
  
  public Boolean estAvecPrecompteCRC()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().estAvecPrecompteCRC();
    }
    return null;
  }
  
  public BigDecimal getCoefficientSaisonnier()
  {
    BigDecimal coefficientSaisonnier = null;
    if (getConstitutionCoefficientSaisonnier() != null) {
      coefficientSaisonnier = getConstitutionCoefficientSaisonnier().getCoefficientSaisonnierRetenu();
    } else if (getAttributionPrecedente() != null) {
      coefficientSaisonnier = getAttributionPrecedente().getCoefficientSaisonnier();
    }
    return coefficientSaisonnier;
  }
  
  public int getNatureCoefficientSaisonnier()
  {
    int natureCoefficienSaisonnier = -1;
    if (getConstitutionCaractereSaisonnier() != null) {
      natureCoefficienSaisonnier = getConstitutionCaractereSaisonnier().getTypeCaractereSaisonnierRetenu();
    } else if (getAttributionPrecedente() != null) {
      natureCoefficienSaisonnier = getAttributionPrecedente().getNatureCoefficientSaisonnier();
    }
    return natureCoefficienSaisonnier;
  }
  
  public boolean a3ansActiviteEn5ans()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().a3ansActiviteEn5ans();
    }
    return false;
  }
  
  public BigDecimal getCoefficientTempsPartiel()
  {
    BigDecimal coefficientTempsPartiel = null;
    if (getConstitutionCoefficientTempsPartiel() != null) {
      coefficientTempsPartiel = getConstitutionCoefficientTempsPartiel().getCoefficientTempsPartielRetenu();
    } else if (getAttributionPrecedente() != null) {
      coefficientTempsPartiel = getAttributionPrecedente().getCoefficientTempsPartiel();
    }
    return coefficientTempsPartiel;
  }
  
  public boolean estSjrBaseSmic()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().estSjrBaseSmic();
    }
    return false;
  }
  
  public int getCategorieEmploiA2B()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getCategorieEmploiA2B();
    }
    return 0;
  }
  
  public ReglementApplicableSpec getReglementApplicableMontantRetenu()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getReglementApplicableMontantRetenu();
    }
    return null;
  }
  
  protected ConstitutionDateLimiteIndemnisation getConstitutionDateLimiteIndemnisationAttributionOrigine()
  {
    ConstitutionDateLimiteIndemnisation constitutionDateLimiteIndemnisation = null;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "AREENTRCSP"))
    {
      constitutionDateLimiteIndemnisation = getConstitutionDateLimiteIndemnisation();
    }
    else
    {
      Attribution attributionPrecedente = (Attribution)getAttributionPrecedente();
      if (attributionPrecedente != null) {
        constitutionDateLimiteIndemnisation = attributionPrecedente.getConstitutionDateLimiteIndemnisationAttributionOrigine();
      }
    }
    return constitutionDateLimiteIndemnisation;
  }
  
  public ResultatAvant determinationEtatACT()
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public Collection<SjrActiviteConservee> getCollectionSjrActiviteConservee()
  {
    return ((Decision)getOuvertureDroit()).getCollectionSjrActiviteConservee();
  }
  
  public Collection<SjrActiviteConservee> getCollectionSjrActiviteConserveePerdue()
  {
    return ((Decision)getOuvertureDroit()).getCollectionSjrActiviteConserveePerdue();
  }
  
  public List<TravailSpec> getListeActiviteConserveePerduesRevisees()
  {
    return ((Decision)getOuvertureDroit()).getListeActiviteConserveePerduesRevisees();
  }
  
  public Damj getDateDebutDelaiDecheance()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getDateDebutDelaiDecheance();
    }
    return null;
  }
}

/* Location:
 * Qualified Name:     Reprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */