package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ContributionParticuliereSpec;
import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.RevisionGen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConditionsAttributionSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;

public class Revision
  extends RevisionGen
  implements RevisionSpec
{
  private static final long serialVersionUID = 1686903921698230206L;
  private static final String DEBUG_ATTRIBUTION_PRECEDENTE_NON_TROUVEE = "Impossible de trouver l'attribution précédente.";
  
  public Revision(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Revision() {}
  
  public Revision(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public Revision(Damj dateEvenement, DossierExamen dossierExamen)
  {
    this(dateEvenement);
    copie(dossierExamen);
  }
  
  public ObjetMetierSpec copie()
  {
    Revision copie = new Revision();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copieSpec)
  {
    Revision copie = (Revision)copieSpec;
    if (getConditionsAttributionAdmission() == null) {
      setConditionsAttributionAdmission(new ConditionsAttributionAdmission());
    }
    getConditionsAttributionAdmission().copieElements(copie.getConditionsAttributionAdmission());
    if (getConstitutionElementsAdmission() == null) {
      setConstitutionElementsAdmission(new ConstitutionElementsAdmission());
    }
    getConstitutionElementsAdmission().copieElements(copie.getConstitutionElementsAdmission());
    if (getConditionsAttributionReprise() == null) {
      setConditionsAttributionReprise(new ConditionsAttributionReprise());
    }
    getConditionsAttributionReprise().copieElements(copie.getConditionsAttributionReprise());
    if (getConstitutionElementsReprise() == null) {
      setConstitutionElementsReprise(new ConstitutionElementsReprise());
    }
    getConstitutionElementsReprise().copieElements(copie.getConstitutionElementsReprise());
    if (getConditionsAttributionRevision() == null) {
      setConditionsAttributionRevision(new ConditionsAttributionRevision());
    }
    getConditionsAttributionRevision().copieElements(copie.getConditionsAttributionRevision());
    if (getConstitutionElementsRevision() == null) {
      setConstitutionElementsRevision(new ConstitutionElementsRevision());
    }
    getConstitutionElementsRevision().copieElements(copie.getConstitutionElementsRevision());
    
    copie.setContexteDdeExpresse(getContexteDdeExpresse());
    if (getContributionParticuliere() != null) {
      copie.setContributionParticuliere((ContributionParticuliere)getContributionParticuliere().copie());
    }
    copie.setDateEvenement(getDateEvenement());
    copie.setNatureDecision(getNatureDecision());
    copie.setAttributionPrecedente(getAttributionPrecedente());
  }
  
  public String getSituationParticuliere()
  {
    return "";
  }
  
  public boolean isInvestigationFraude()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().isInvestigationFraude();
    }
    return false;
  }
  
  public String getRsod()
  {
    String rsod = "0";
    if (getAttributionPrecedente() != null) {
      rsod = getAttributionPrecedente().getRsod();
    }
    return rsod;
  }
  
  public String getRsrp()
  {
    return "0";
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public JustificationAffiliationSpec getJustificationAffiliation()
  {
    return null;
  }
  
  public Quantite getMontantAttributionPrecedente()
    throws CoucheLogiqueException
  {
    Attribution attribution = recupererAttributionPrecedente();
    if (attribution != null)
    {
      MontantBaseSpec montantPrecedent = null;
      try
      {
        GammeAsuSpec gamme = (GammeAsuSpec)attribution.getGamme();
        DonneesEntreesRecuperationMontant donneesEntree = gamme.mapperDonneesEntreesRecuperationMontant(attribution);
        donneesEntree.setDateCalculMontant(getDateAttribution());
        montantPrecedent = DeterminationMontant.determinerMontant(donneesEntree);
      }
      catch (ApplicativeException ex)
      {
        throw new CoucheLogiqueException(ex.getCode());
      }
      if (montantPrecedent != null) {
        return montantPrecedent.getMontantPrecompteEffectif();
      }
    }
    return null;
  }
  
  public ReglementApplicableSpec getConstitutionReglementApplicable()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionReglementApplicable();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Impossible de trouver l'attribution précédente." });
    
    return null;
  }
  
  private Attribution recupererAttributionPrecedente()
  {
    if ((getAttributionPrecedente() instanceof Attribution)) {
      return (Attribution)getAttributionPrecedente();
    }
    return null;
  }
  
  public String getReferenceExterne()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getReferenceExterne();
    }
    if (Log.isTraceActive(Revision.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, Revision.class, "getReferenceExterne", " Impossible de trouver l'attribution précédente");
    }
    return null;
  }
  
  public FaitGenerateurSpec getConditionFaitGenerateur()
  {
    AttributionSpec attributionOrigine = getOuvertureDroit();
    if (!(attributionOrigine instanceof Attribution)) {
      return null;
    }
    return ((Attribution)attributionOrigine).getConditionFaitGenerateur();
  }
  
  public Quantite getDureeIndemnisationTheorique()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getDureeIndemnisationTheorique();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Impossible de trouver l'attribution précédente." });
    
    return null;
  }
  
  public CompetenceSpec getCompetence()
  {
    CompetenceSpec competenceRetour = null;
    if (estCompetencePersistee())
    {
      competenceRetour = super.getCompetence();
    }
    else
    {
      Attribution attributionPrecedente = recupererAttributionPrecedente();
      if ((attributionPrecedente != null) && (!attributionPrecedente.getDemande().estEnReExamen()) && (!attributionPrecedente.getDemande().estDemandeLiquidee()))
      {
        CompetenceSpec competence = (CompetenceSpec)attributionPrecedente.getCompetence().copie();
        setCompetence(competence);
        return competence;
      }
      setAttributionPrecedente(null);
      CompetenceSpec competenceAdministrativeParDefaut = new Competence();
      competenceAdministrativeParDefaut.setCompetenceFinanciere(1);
      competenceAdministrativeParDefaut.setCompetenceAdministrative(1);
      setCompetence(competenceAdministrativeParDefaut);
      return competenceAdministrativeParDefaut;
    }
    return competenceRetour;
  }
  
  public ConstitutionDurees getConstitutionDurees()
  {
    return getConstitutionElementsRevision().getConstitutionDurees();
  }
  
  public ConstitutionQuantiteAffiliation getConstitutionQuantiteAffiliation()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionQuantiteAffiliation();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Impossible de trouver l'attribution précédente." });
    
    return null;
  }
  
  public ConstitutionCaractereSaisonnier getConstitutionCaractereSaisonnier()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionCaractereSaisonnier();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Impossible de trouver l'attribution précédente." });
    
    return null;
  }
  
  public ConstitutionCoefficientSaisonnier getConstitutionCoefficientSaisonnier()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionCoefficientSaisonnier();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Impossible de trouver l'attribution précédente." });
    
    return null;
  }
  
  public ConstitutionSjr getConstitutionSjr()
  {
    return getConstitutionElementsRevision().getConstitutionSjr();
  }
  
  public ConstitutionDelais getConstitutionDelais()
  {
    return getConstitutionElementsRevision().getConstitutionDelais();
  }
  
  public ConstitutionSjc getConstitutionSjc()
  {
    return getConstitutionElementsRevision().getConstitutionSjc();
  }
  
  public ConstitutionDateAttribution getConstitutionDateAttribution()
  {
    return getConstitutionElementsRevision().getConstitutionDateAttribution();
  }
  
  public ConstitutionMontantsBruts getConstitutionMontantsBruts()
  {
    return getConstitutionElementsRevision().getConstitutionMontantsBruts();
  }
  
  public ConstitutionPointDepartIndemnisation getConstitutionPointDepartIndemnisation()
  {
    return getConstitutionElementsRevision().getConstitutionPointDepartIndemnisation();
  }
  
  public ConstitutionCoefficientTempsPartiel getConstitutionCoefficientTempsPartiel()
  {
    return getConstitutionElementsRevision().getConstitutionCoefficientTempsPartiel();
  }
  
  public ConstitutionProduitResultant getConstitutionProduitResultant()
  {
    return null;
  }
  
  public ConstitutionElementsSpec getConstitutionElementsActifs()
  {
    return getConstitutionElementsRevision();
  }
  
  public ConditionsAttributionSpec getConditionsAttributionActives()
  {
    return getConditionsAttributionRevision();
  }
  
  public ConditionMontantRevise getConditionMontantRevise()
  {
    return getConditionsAttributionRevision().getConditionMontantRevise();
  }
  
  public Sjc getSJC()
  {
    Sjc sjcTemporaire = null;
    if ((getConstitutionSjc() != null) && (getConstitutionSjc().getSjcip() != null)) {
      sjcTemporaire = getConstitutionSjc().getSjci();
    } else {
      sjcTemporaire = new Sjc(BigDecimal.ZERO, getConstitutionSjr().getSjrip().getDateEffet(), getConstitutionSjr().getSjrip().getContexteParticulierSjr());
    }
    return sjcTemporaire;
  }
  
  public Collection getListeCarences()
  {
    return getConstitutionDelais().getListCarences();
  }
  
  public AttributionSpec getAttributionMaitre()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionMaitre();
    }
    return null;
  }
  
  public AttributionAssuranceSpec getAttributionOrigine()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionOrigine();
    }
    return null;
  }
  
  public Damj getDateFaitGenerateurDroit()
  {
    return getAttributionPrecedente().getDateFaitGenerateurDroit();
  }
  
  public Damj getDateLimiteIndemnisation()
  {
    Attribution attributionOrigine = (Attribution)getOuvertureDroit();
    if (attributionOrigine != null) {
      return attributionOrigine.getDateLimiteIndemnisation();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Impossible de trouver l'attribution précédente." });
    
    return null;
  }
  
  public ConditionActiviteConservee getConditionActiviteConservee()
  {
    return ((DossierExamen)getOuvertureDroit()).getConditionsAttributionAdmission().getConditionActiviteConservee();
  }
  
  public MaintienEuropeen getMaintienEuropeen()
  {
    if ((maintienEuropeen == null) && (recupererAttributionPrecedente() != null)) {
      if (recupererAttributionPrecedente().getMaintienEuropeen() == null) {
        maintienEuropeen = MaintienEuropeen.getInstanceMaintienEuropeen(this);
      } else {
        maintienEuropeen = recupererAttributionPrecedente().getMaintienEuropeen();
      }
    }
    return maintienEuropeen;
  }
  
  public boolean estRejetDV()
  {
    return false;
  }
  
  protected void verifierCoherenceReferenceExterne() {}
  
  public boolean estMaintenue()
  {
    if (getOuvertureDroit().getNatureDecision() == 38) {
      return ((fr.unedic.cali.asu.dom.OdAssuranceSpec)getOuvertureDroit()).estMaintenue();
    }
    return super.estMaintenue();
  }
  
  public Collection getListePlafonnementAffiliation()
  {
    return new ArrayList();
  }
  
  public int getTypeMontantRetenu()
  {
    return getAttributionPrecedente().getTypeMontantRetenu();
  }
  
  public int getTypeCapitalRetenu()
  {
    throw new UnsupportedOperationException("HG_PR_L_METHODE_NON_IMPLEMENTEE_ATTRIBUTION");
  }
  
  public fr.unedic.cali.dom.OdAssuranceSpec getOuvertureDroit()
  {
    fr.unedic.cali.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroit();
    }
    return ouvertureDeDroit;
  }
  
  public fr.unedic.cali.asu.dom.OdAssuranceSpec getOuvertureDroitCapitalRetenu()
  {
    fr.unedic.cali.asu.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroitCapitalRetenu();
    }
    return ouvertureDeDroit;
  }
  
  public ConditionCSRAccordCP getConditionCSRAccordCP()
  {
    return ((Attribution)getAttributionPrecedente()).getConditionCSRAccordCP();
  }
  
  public Collection getListePensionInvalidite()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getListePensionInvalidite();
    }
    return null;
  }
  
  public ReglementApplicableSpec getReglementApplicableMontantRetenu()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getReglementApplicableMontantRetenu();
    }
    return null;
  }
  
  public ResultatAvant determinationEtatACT()
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public int getType()
  {
    return 1;
  }
  
  public boolean porteUnRejetDv()
  {
    return false;
  }
  
  public boolean estExecutable()
  {
    boolean resultat = false;
    if (super.estExecutable())
    {
      ObjetChronoPeriodePriseEnCharge periodePEC = OutillagePeriodes.recupererPeriodePECContenant(getDemandeur(), getDateAttribution());
      if ((periodePEC != null) && ((periodePEC.getTypePec() == null) || (periodePEC.getSousType() == null) || (nestPasDeTypeAdrOuArce(periodePEC)))) {
        resultat = true;
      }
    }
    return resultat;
  }
  
  private boolean nestPasDeTypeAdrOuArce(ObjetChronoPeriodePriseEnCharge periodePEC)
  {
    return (!periodePEC.estDeTypeAdr()) && (!periodePEC.estDeTypeArce());
  }
  
  protected ConstitutionDateLimiteIndemnisation getConstitutionDateLimiteIndemnisationAttributionOrigine()
  {
    ConstitutionDateLimiteIndemnisation cepaDateLimite = null;
    Attribution attributionPrecedente = (Attribution)getAttributionPrecedente();
    if (attributionPrecedente != null) {
      cepaDateLimite = attributionPrecedente.getConstitutionDateLimiteIndemnisationAttributionOrigine();
    }
    return cepaDateLimite;
  }
}

/* Location:
 * Qualified Name:     Revision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */