package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P02;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class OutilRecuperationMontantSP
  implements OutilFonctionnel
{
  public static OutilRecuperationMontantSP getInstance()
  {
    return new OutilRecuperationMontantSP();
  }
  
  public MontantBaseSpec recupererMontantSP(Demande demande)
    throws CoucheLogiqueException
  {
    DonneesEntreesRecuperationMontant donneesEntrees = new DonneesEntreesRecuperationMontant();
    IndividuSpec individu = demande.getDemandeur();
    DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)demande.getDossierExamen();
    ProduitSpec produitCourant = ((AttributionAssuranceSpec)dossierExamen).getProduit();
    
    alimenterDonneesCalculMontant(demande, dossierExamen, produitCourant, donneesEntrees);
    
    Competences competence = new Competences();
    competence.setCompetenceAdministrative(2);
    competence.setCompetenceFinanciere(2);
    donneesEntrees.setCompetences(competence);
    
    Damj dateAttrib = dossierExamen.getDateAttribution();
    donneesEntrees.setDateCalculMontant(dateAttrib);
    
    donneesEntrees.setIndividu(individu);
    try
    {
      return ((ProduitAsuSpec)produitCourant).recupererMontant(donneesEntrees);
    }
    catch (ApplicativeException e)
    {
      throw new CoucheLogiqueException(e.getCode(), e);
    }
  }
  
  private ProduitAsuSpec recupererProduitPrecedent(Demande demande)
    throws CoucheLogiqueException
  {
    ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
    conteneur.setDateFinContrat(demande.getDonneesTemporaires().getDateFgDroitAnterieurSp());
    conteneur.setDateRecherche(demande.getDonneesTemporaires().getDateFgDroitAnterieurSp());
    conteneur.setBesoinCritereQualif(false);
    conteneur.setDemande(demande);
    DecorReglementaire decorReglementaireDateExamen = ConstitutionDecorReglementaire.recupererDecor(conteneur);
    
    ProduitAsuSpec produitPrecedent = null;
    if ((decorReglementaireDateExamen == null) && (demande.getDonneesTemporaires().getDateFgDroitAnterieurSp().estAvant(ProduitAsuCge01P02.getInstance().getPeriodeValidite().getDebut()))) {
      produitPrecedent = ProduitAsuCge01P02.getInstance();
    } else {
      produitPrecedent = (ProduitAsuSpec)decorReglementaireDateExamen.determinerProduitEffectifDeLaLigne(LigneAsuCge01.getInstance());
    }
    return produitPrecedent;
  }
  
  private void alimenterDonneesCalculMontant(Demande demande, DossierExamenAssuranceSpec dossierExamen, ProduitSpec produitCourant, DonneesEntreesRecuperationMontant donneesEntrees)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produitPrecedent = recupererProduitPrecedent(demande);
    
    Boolean estProduitGerantPensionInvalidite = Boolean.valueOf(((ProduitAsuSpec)produitCourant).estProduitGerantPensionInvalidite(demande));
    
    ContexteDemande contexte = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demande, new String[] { "AREMAYOTTE" });
    
    String contexteDemande = null;
    if (contexte != null) {
      contexteDemande = contexte.getTypeContexteDemande();
    }
    donneesEntrees.getDonneesCalculMontant().setSalaireJournalier(new Sjr(demande.getDonneesTemporaires().getSjrSP().getValeur(), demande.getDonneesTemporaires().getTermePrcSp(), contexteDemande));
    
    donneesEntrees.getDonneesCalculMontant().setCoefficientSaisonnier(demande.getDonneesTemporaires().getCoefficientSaisonnierSp());
    donneesEntrees.getDonneesCalculMontant().setCoefficientTempsPartiel(demande.getDonneesTemporaires().getCoefficientTempsPartielSp());
    donneesEntrees.getDonneesCalculMontant().setConditionCaractereSaisonnierParRythme(false);
    donneesEntrees.getDonneesCalculMontant().setTypeCaractereSaisonnierRetenu(-1);
    if (dossierExamen.getReglementApplicable() != null) {
      donneesEntrees.getDonneesCalculMontant().setReglementMontantRetenu(dossierExamen.getReglementApplicable().getReglement());
    }
    donneesEntrees.getDonneesCalculMontant().setEstProduitGerantPensionInvalidite(estProduitGerantPensionInvalidite);
    donneesEntrees.getDonneesCalculMontant().setListePensionInvalidite(((AttributionAssuranceSpec)dossierExamen).getListePensionInvalidite());
    if (demande.getDonneesTemporaires().isEstPCRCForceDroitPrecedent()) {
      donneesEntrees.getDonneesCalculMontant().setAvecPrecompteCRC(Boolean.TRUE);
    }
    FormuleMontantSpec formule = produitPrecedent.getFormuleMontant("1");
    donneesEntrees.getDonneesCalculMontant().setFormuleMontant(formule);
    donneesEntrees.getDonneesCalculMontant().setProduit(produitPrecedent);
    donneesEntrees.getDonneesCalculMontant().setContexteFormation(false);
  }
}

/* Location:
 * Qualified Name:     OutilRecuperationMontantSP
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */