package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels;

import fr.pe.cali.liquidation.outilsfonctionnels.dom.ResultatImputationSuiteArce;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDeterminationObjectifReprise;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.ElementConditionValiditeReliquat;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;

public class RechercheConditionValiditeReliquat
  implements OutilFonctionnel
{
  public static RechercheConditionValiditeReliquat getInstance()
  {
    return new RechercheConditionValiditeReliquat();
  }
  
  public ElementConditionValiditeReliquat rechercherConditionValiditeReliquat(ResultatExecutionCalculSpec resultatCalcul, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    return traitementCondition(resultatCalcul, demande, null);
  }
  
  protected ElementConditionValiditeReliquat traitementCondition(ResultatExecutionCalculSpec resultatCalcul, DemandeSpec demande, ResultatImputationSuiteArce resultatImputationArce)
    throws CoucheLogiqueException
  {
    ElementConditionValiditeReliquat elementConditionValiditeReliquat = new ElementConditionValiditeReliquat();
    elementConditionValiditeReliquat.setEtat(0);
    copierResultatDansCap(elementConditionValiditeReliquat, resultatCalcul, demande);
    switch (resultatCalcul.getEtatAttribution())
    {
    case 4: 
      elementConditionValiditeReliquat.setCodeMotifEchec(272);
      elementConditionValiditeReliquat.setEtat(1);
      break;
    case 1: 
      elementConditionValiditeReliquat.setCodeMotifEchec(273);
      elementConditionValiditeReliquat.setEtat(1);
      break;
    case 2: 
      elementConditionValiditeReliquat.setCodeMotifEchec(271);
      elementConditionValiditeReliquat.setEtat(1);
      break;
    case 3: 
    default: 
      traiterReliquatPresent(demande, elementConditionValiditeReliquat, resultatCalcul, resultatImputationArce);
    }
    return elementConditionValiditeReliquat;
  }
  
  protected void traiterReliquatPresent(DemandeSpec demande, ElementConditionValiditeReliquat elementConditionValiditeReliquat, ResultatExecutionCalculSpec resultatCalcul, ResultatImputationSuiteArce resultatImputationArce)
    throws CoucheLogiqueException
  {
    Damj dateEpuisement = traiterEpuisementReliquat(demande, elementConditionValiditeReliquat, resultatCalcul, resultatImputationArce);
    if (dateEpuisement == null) {
      traiterExtinctionReliquat(demande, elementConditionValiditeReliquat);
    }
  }
  
  protected void copierResultatDansCap(ElementConditionValiditeReliquat elementConditionValiditeReliquat, ResultatExecutionCalculSpec resultatCalcul, DemandeSpec demande)
  {
    elementConditionValiditeReliquat.setMotifNonValidite(resultatCalcul.getEtatAttribution());
    elementConditionValiditeReliquat.setCauseExtinction(resultatCalcul.getEtatAttribution());
    elementConditionValiditeReliquat.setDateDecheance(resultatCalcul.getDateEtatAttribution());
  }
  
  protected Damj traiterExtinctionReliquat(DemandeSpec demande, ElementConditionValiditeReliquat elementConditionValiditeReliquat)
    throws CoucheLogiqueException
  {
    Damj dateExtinction = OutilDeterminationObjectifReprise.getInstance().determineDateExtinctionReliquatSurObjectifReprise(demande);
    if (dateExtinction != null)
    {
      elementConditionValiditeReliquat.setCodeMotifEchec(273);
      elementConditionValiditeReliquat.setEtat(1);
      elementConditionValiditeReliquat.setDateDecheance(dateExtinction);
      elementConditionValiditeReliquat.setMotifNonValidite(1);
      elementConditionValiditeReliquat.setCauseExtinction(1);
    }
    return dateExtinction;
  }
  
  protected Damj traiterEpuisementReliquat(DemandeSpec demande, ElementConditionValiditeReliquat elementConditionValiditeReliquat, ResultatExecutionCalculSpec resultatCalcul, ResultatImputationSuiteArce resultatImputationArce)
    throws CoucheLogiqueException
  {
    return null;
  }
}

/* Location:
 * Qualified Name:     RechercheConditionValiditeReliquat
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */