package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.ElementBaseActiviteReduite;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.Revision;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.produits.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;

public class RecuperationElementActiviteReduite
  implements OutilFonctionnel
{
  private static final int CODE_SERVICE_LECTURE_DECISION = 3;
  
  public static ElementBaseActiviteReduite recupererElementBaseActiviteReduite(AttributionSpec p_attribution)
  {
    Attribution attribution = (Attribution)p_attribution;
    ElementBaseActiviteReduite ebar = new ElementBaseActiviteReduite();
    
    ebar.setSjc(getSjci(attribution));
    
    ebar.setTermePrcActiviteConservee(getTermePrcActiviteConservee(attribution));
    
    ebar.setListeSjrActiviteConservee(getListeSjrActiviteConservee(attribution));
    
    ebar.setApprenti(isApprenti(attribution));
    if (attribution.getDemandeur().getDonneesChargementGaec().getAgregatGaec().getCodeService() != 3) {
      ebar.setIdentifiantBne(getIdentifiantBne(attribution));
    }
    ebar.setNomReglementApplicable(getNomReglementApplicable(attribution));
    
    ebar.setListePeriodesRepriseActiviteMemeEmployeur(getListePeriodesRepriseActiviteMemeEmployeur(attribution));
    
    return ebar;
  }
  
  private static Sjc getSjci(Attribution p_attribution)
  {
    Sjc sjcTemporaire = null;
    if ((p_attribution.getConstitutionSjc() != null) && (p_attribution.getConstitutionSjc().getSjcip() != null)) {
      sjcTemporaire = p_attribution.getConstitutionSjc().getSjci();
    } else {
      sjcTemporaire = new Sjc(new BigDecimal("0"), p_attribution.getConstitutionSjr().getSjrip().getDateEffet(), p_attribution.getConstitutionSjr().getSjrip().getContexteParticulierSjr());
    }
    return sjcTemporaire;
  }
  
  private static Collection getListeSjrActiviteConservee(Attribution p_attribution)
  {
    Collection<SjrActiviteConservee> listeSjrActiviteConservees = null;
    if ((p_attribution.getConstitutionSjc() != null) && (p_attribution.getConstitutionSjc().getSjcip() != null)) {
      listeSjrActiviteConservees = p_attribution.getConstitutionSjc().getSjcip().getCollectionSjrActiviteConservee();
    } else if (p_attribution.getConditionActiviteConservee() != null) {
      listeSjrActiviteConservees = p_attribution.getConditionActiviteConservee().getCollectionSjrActiviteConservee();
    }
    return listeSjrActiviteConservees;
  }
  
  private static Damj getTermePrcActiviteConservee(Attribution p_attribution)
  {
    Damj termePrcSjc = null;
    if ((p_attribution.getConstitutionSjc() != null) && (p_attribution.getConstitutionSjc().getSjcip() != null)) {
      termePrcSjc = p_attribution.getConstitutionSjc().getSjcip().getDateEffet();
    }
    return termePrcSjc;
  }
  
  public static boolean isApprenti(Attribution p_attribution)
  {
    Attribution attribution = null;
    if (estUneRevision(p_attribution)) {
      attribution = (Attribution)p_attribution.getAttributionPrecedente();
    } else {
      attribution = p_attribution;
    }
    if ((attribution.getConstitutionSjr().getSjrip() != null) && (attribution.getConstitutionSjr().getSjrip().getPrc() != null)) {
      return attribution.getConstitutionSjr().getSjrip().getPrc().isTopContratsDeTypeParticulier();
    }
    return false;
  }
  
  private static boolean estUneRevision(Attribution p_attribution)
  {
    return p_attribution instanceof Revision;
  }
  
  private static String getIdentifiantBne(Attribution p_attribution)
  {
    if ((p_attribution.getConditionFaitGenerateur() != null) && (p_attribution.getConditionFaitGenerateur().getPeriodeFaitGenerateur() != null)) {
      return p_attribution.getConditionFaitGenerateur().getPeriodeFaitGenerateur().getEntreprise().getIdentifiantBNE();
    }
    return null;
  }
  
  private static String getNomReglementApplicable(Attribution p_attribution)
  {
    return p_attribution.getNomReglementApplicable();
  }
  
  private static Collection getListePeriodesRepriseActiviteMemeEmployeur(Attribution p_attribution)
  {
    Demande demande = null;
    if (estUneRevision(p_attribution))
    {
      AttributionAssuranceSpec attributionOrigine = (AttributionAssuranceSpec)p_attribution.getOuvertureDroit();
      if (attributionOrigine != null) {
        demande = (Demande)attributionOrigine.getDemande();
      }
    }
    else
    {
      AttributionSpec attributionMaitre = p_attribution.getOuvertureDroitCapitalRetenu();
      if (attributionMaitre != null) {
        demande = (Demande)p_attribution.getDemande();
      }
    }
    if ((demande != null) && (demande.getDonneesTemporaires() != null)) {
      return demande.getDonneesTemporaires().getListePeriodesRepriseActiviteMemeEmployeur();
    }
    return null;
  }
}

/* Location:
 * Qualified Name:     RecuperationElementActiviteReduite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */