package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.Competence;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCaractereSaisonnier;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientSaisonnier;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientTempsPartiel;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.ProduitAsuExp03P01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSecurisationProfessionnelleSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.ApplicativeRuntimeException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

public final class RecuperationElementIndemnisation
  implements OutilFonctionnel
{
  public static final int CINQUANTE = 50;
  
  public static ElementBaseIndemnisation recupererElementBaseIndemnisation(AttributionSpec attribution)
  {
    ElementBaseIndemnisation ebi = new ElementBaseIndemnisation();
    alimenterEBIavecAttribution(attribution, ebi);
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), 9)) {
      alimenterSousEbiPourAspDcSurAre(attribution, ebi);
    }
    return ebi;
  }
  
  public static void alimenterSousEbiPourAspDcSurAre(AttributionSpec attribution, ElementBaseIndemnisation ebi)
  {
    ElementBaseIndemnisation sousEbiAspSousJacent = new ElementBaseIndemnisation();
    alimenterEBIavecAttributionEntreeAspSousJacent(attribution, sousEbiAspSousJacent);
    
    Collection<ElementBaseIndemnisation> listeSousEbiAdmissions = new ArrayList();
    alimenterListeEBIAvecODouNovationOuRevision(attribution, listeSousEbiAdmissions);
    
    Collection<ElementBaseIndemnisation> listeSousEbi = new ArrayList();
    listeSousEbi.add(sousEbiAspSousJacent);
    listeSousEbi.addAll(listeSousEbiAdmissions);
    ebi.setListeSousEBI(listeSousEbi);
  }
  
  public static ElementBaseIndemnisation recupererElementBaseIndemnisation(DonneesTemporaires donneesForcees)
  {
    return recupererElementBaseIndemnisation(donneesForcees, null);
  }
  
  private static void alimenterListeEBIAvecODouNovationOuRevision(AttributionSpec attribution, Collection<ElementBaseIndemnisation> listeSousEbi)
  {
    Attribution attributionCourante = (Attribution)attribution;
    
    Collection<DemandeAssuranceSpec> admissionsDurantDispositifCsp = OutilAsp.getInstance().recupererAdmissionsDurantDispositifCSP(attributionCourante);
    if (!admissionsDurantDispositifCsp.isEmpty())
    {
      Iterator<DemandeAssuranceSpec> iterDemande = admissionsDurantDispositifCsp.iterator();
      while (iterDemande.hasNext())
      {
        DemandeAssuranceSpec demande = (DemandeAssuranceSpec)iterDemande.next();
        ElementBaseIndemnisation ebi = new ElementBaseIndemnisation();
        alimenterEBIavecAttribution(demande.getAttribution(), ebi);
        
        ebi.setProduitMontantRetenu(demande.getAttribution().getProduitMontantRetenu());
        
        Competences competenceAttribution = creerConteneurCompetence(demande.getAttribution());
        ebi.setCompetence(competenceAttribution);
        
        ebi.setAvecPrecompteCRC(demande.getAttribution().estAvecPrecompteCRC());
        listeSousEbi.add(ebi);
      }
    }
  }
  
  public static void alimenterEBIavecAttributionEntreeAspSousJacent(AttributionSpec attribution, ElementBaseIndemnisation ebi)
  {
    AttributionSpec attributionEntreeCsp = OutilAsp.getInstance().recupererAttributionEntreeCsp(attribution);
    if (attributionEntreeCsp != null)
    {
      Demande demandeEntreeCsp = (Demande)attributionEntreeCsp.getDemande();
      if (demandeEntreeCsp.getDonneesDemandeAssociee().getDemandeAssociee() != null)
      {
        Attribution attributionSousJacenteEntreeCsp = (Attribution)demandeEntreeCsp.getDonneesDemandeAssociee().getDemandeAssociee().getAttribution();
        
        alimenterEBIavecAttribution(attributionSousJacenteEntreeCsp, ebi);
        
        ebi.setProduitMontantRetenu((ProduitAsuSpec)attributionEntreeCsp.getProduitExecution());
        Competences competenceAttribution = creerConteneurCompetence(attributionSousJacenteEntreeCsp);
        ebi.setCompetence(competenceAttribution);
        
        ebi.setAvecPrecompteCRC(attributionSousJacenteEntreeCsp.estAvecPrecompteCRC());
        alimenterContextePap(attribution.getDemande(), ebi);
      }
    }
  }
  
  private static void alimenterEBIavecAttribution(AttributionSpec pAttribution, ElementBaseIndemnisation ebi)
  {
    Attribution attribution = (Attribution)pAttribution;
    
    ebi.setSjr(getSjri(attribution));
    
    ebi.setCoefficientSaisonnier(getCoefficientSaisonnier(attribution));
    
    Quantite dureePostPrime = attribution.getDureePostPrime();
    if ((dureePostPrime != null) && (dureePostPrime.getValeurEntiere() == 0)) {
      ebi.setEstDureePostPrimeEpuisee(true);
    }
    alimenterCaractereSaisonnier(attribution, ebi);
    
    ebi.setCoefficientTempsPartiel(getCoefficientTempsPartiel(attribution));
    
    ebi.setIsSjrBaseSurPourcentageSMIC(attribution.isTopContratsRemuneresBaseSmic());
    if (attribution.getConstitutionSjr() != null) {
      ebi.setCodeEmploiA2B(attribution.getConstitutionSjr().getCodeEmploiA2b());
    }
    ebi.setReglementApplicableMontantRetenu(attribution.getReglementApplicable());
    
    alimenterMontantPreavis(attribution, ebi);
    
    ebi.setListePensionInvalidite(attribution.getListePensionInvalidite());
    
    Boolean estProduitGerantPensionInvalidite = Boolean.valueOf(((ProduitAsuSpec)attribution.getProduit()).estProduitGerantPensionInvalidite(attribution.getDemande()));
    
    ebi.setEstProduitGerantPensionInvalidite(estProduitGerantPensionInvalidite);
    
    alimenterDemandeAssociee(attribution, ebi);
    if ((((DossierExamen)attribution.getDossierAffecte().getDossierExamen()).getCompetence().getCompetenceAdministrative() == 2) && (((Competence)((DossierExamen)pAttribution.getDossierAffecte().getDossierExamen()).getCompetence()).isEstPCRCForce())) {
      ebi.setAvecPrecompteCRC(Boolean.TRUE);
    }
    alimenterProduitAreActif(attribution, ebi);
    
    alimenterContextePap(attribution.getDemande(), ebi);
    
    alimenterTopExpatrie(attribution, ebi);
  }
  
  protected static void alimenterTopExpatrie(Attribution attribution, ElementBaseIndemnisation ebi)
  {
    boolean estDecorApresConvention17 = false;
    if (((attribution.getDossierAffecte() instanceof DossierAffectation)) && (((DossierAffectation)attribution.getDossierAffecte()).getDecorReglementaire() != null))
    {
      DecorReglementaire decor = ((DossierAffectation)attribution.getDossierAffecte()).getDecorReglementaire();
      Damj debutDecor = decor.getPeriodeValidite().getDebut();
      try
      {
        Damj dateDebutDecor17 = GestionnaireDateApplication.getInstance().recupererDateApplication("Date de debut du décor réglementaire 2017");
        if (debutDecor.estApresOuCoincideAvec(dateDebutDecor17)) {
          estDecorApresConvention17 = true;
        }
      }
      catch (CoucheLogiqueException e)
      {
        throw new ApplicativeRuntimeException(e.getCode(), e);
      }
    }
    boolean estProduitExpatrie = ProduitAsuExp03P01.getInstance().getNomUnique().equals(attribution.getProduit().getNom());
    
    ebi.setExpatrieApresConvention17((estDecorApresConvention17) && (estProduitExpatrie));
  }
  
  private static void alimenterMontantPreavis(Attribution attribution, ElementBaseIndemnisation ebi)
  {
    if (attribution.getConstitutionMontantsBruts() != null)
    {
      Quantite montantJournalierPreavis = attribution.getConstitutionMontantsBruts().getMontantJournalierPreavis();
      if (montantJournalierPreavis != null) {
        ebi.setMontantPreavis(attribution.getConstitutionMontantsBruts().getMontantJournalierPreavis().getValeur());
      }
    }
  }
  
  private static void alimenterProduitAreActif(Attribution attribution, ElementBaseIndemnisation ebi)
  {
    if (((attribution.getDemande() != null) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), "ARECOURCSP"))) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), "AREENTRCSP"))) {
      ebi.setProduitAreActif(attribution.getProduit());
    } else if ((attribution.getProduit() instanceof ProduitSecurisationProfessionnelleSpec)) {
      ebi.setProduitAreActif(((ProduitSecurisationProfessionnelleSpec)attribution.getProduit()).recupererProduitAreActif(attribution));
    }
  }
  
  private static void alimenterDemandeAssociee(Attribution attribution, ElementBaseIndemnisation ebi)
  {
    Demande demande = (Demande)attribution.getDemande();
    if (demandeNecessiteAlimentationEbiAssocie(demande))
    {
      Demande demandeAssociee = demande.getDonneesDemandeAssociee().getDemandeAssociee();
      
      demandeAssociee.desactiverTrancheExecutable();
      ebi.setElementBaseIndemnisationDroitAssocie(demandeAssociee.getAttribution().getElementBaseIndemnisation());
      ebi.getElementBaseIndemnisationDroitAssocie().setProduitAreActif(demandeAssociee.getAttribution().getProduitExecution());
      demandeAssociee.reactiverTrancheExecutable();
    }
  }
  
  private static boolean demandeNecessiteAlimentationEbiAssocie(Demande demande)
  {
    return (demande.getDonneesDemandeAssociee() != null) && (demande.getDonneesDemandeAssociee().getDemandeAssociee() != null) && (demande.getDonneesDemandeAssociee().getDemandeAssociee().getAttribution() != null) && (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 9));
  }
  
  private static void alimenterCaractereSaisonnier(Attribution attribution, ElementBaseIndemnisation ebi)
  {
    if (attribution.getConstitutionCaractereSaisonnier() != null)
    {
      DureeCalendaire ageALAttribution = new DureeCalendaire(50);
      if (((Demande)attribution.getDemande()).getDonneesTemporaires().isCaractereSaisonnierForce())
      {
        if (((Demande)attribution.getDemande()).getDonneesTemporaires().getTypeCaractereSaisonnierForce() == 1) {
          if (ageALAttribution.compareTo(attribution.getDemandeur().getAgeALaDate(attribution.getDemande().getDateDeclenchementExamen())) > 0) {
            ebi.setIsConditionCaractereSaisonnierParRythme(true);
          } else {
            ebi.setIsConditionCaractereSaisonnierParRythme(attribution.getConstitutionCaractereSaisonnier().isActivite3Sur5());
          }
        }
      }
      else {
        ebi.setIsConditionCaractereSaisonnierParRythme(attribution.getConstitutionCaractereSaisonnier().isActivite3Sur5());
      }
      ebi.setTypeCaractereSaisonnierRetenu(attribution.getConstitutionCaractereSaisonnier().getTypeCaractereSaisonnierRetenu());
    }
    else
    {
      ebi.setIsConditionCaractereSaisonnierParRythme(false);
      ebi.setTypeCaractereSaisonnierRetenu(-1);
    }
  }
  
  public static ElementBaseIndemnisation recupererElementBaseIndemnisation(DonneesTemporaires donneesForcees, AttributionSpec attribution)
  {
    ElementBaseIndemnisation ebi = new ElementBaseIndemnisation();
    
    ebi.setSjr(new Sjr(donneesForcees.getSjrSP().getValeur(), donneesForcees.getTermePrcSp(), null));
    
    ebi.setCoefficientSaisonnier(donneesForcees.getCoefficientSaisonnierSp());
    
    ebi.setIsConditionCaractereSaisonnierParRythme(false);
    ebi.setTypeCaractereSaisonnierRetenu(donneesForcees.getTypeCaractereSaisonnierForce());
    
    ebi.setCoefficientTempsPartiel(donneesForcees.getCoefficientTempsPartielSp());
    
    ebi.setIsSjrBaseSurPourcentageSMIC(false);
    
    ebi.setReglementApplicableMontantRetenu(null);
    if (attribution != null)
    {
      Attribution attributionAssurance = (Attribution)attribution;
      ebi.setReglementApplicableMontantRetenu(attributionAssurance.getReglementApplicable());
      
      String contexteDemande = OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attributionAssurance.getDemande(), "AREMAYOTTE") ? "AREMAYOTTE" : null;
      
      ebi.getSjr().setContexteParticulier(contexteDemande);
    }
    return ebi;
  }
  
  private static Sjr getSjri(Attribution attribution)
  {
    Sjr sjrTemporaire = null;
    if (attribution.getConstitutionSjr() != null) {
      sjrTemporaire = attribution.getConstitutionSjr().getSjri();
    }
    return sjrTemporaire;
  }
  
  private static BigDecimal getCoefficientTempsPartiel(Attribution attribution)
  {
    BigDecimal valeurCoefficientTempsPartiel = null;
    if (attribution.getConstitutionCoefficientTempsPartiel() != null) {
      valeurCoefficientTempsPartiel = attribution.getConstitutionCoefficientTempsPartiel().getCoefficientTempsPartielRetenu();
    }
    if (valeurCoefficientTempsPartiel == null) {
      valeurCoefficientTempsPartiel = BigDecimal.ONE;
    }
    return valeurCoefficientTempsPartiel;
  }
  
  private static BigDecimal getCoefficientSaisonnier(Attribution attribution)
  {
    BigDecimal valeurCoefficientSaisonnier = null;
    if (attribution.getConstitutionCoefficientSaisonnier() != null) {
      valeurCoefficientSaisonnier = attribution.getConstitutionCoefficientSaisonnier().getCoefficientSaisonnierRetenu();
    }
    if (valeurCoefficientSaisonnier == null) {
      valeurCoefficientSaisonnier = BigDecimal.ONE;
    }
    return valeurCoefficientSaisonnier;
  }
  
  private static Competences creerConteneurCompetence(AttributionAssuranceSpec attribution)
  {
    Competences conteneurCompetences = new Competences();
    conteneurCompetences.setCompetenceAdministrative(attribution.getCompetenceAdministrative());
    conteneurCompetences.setCompetenceFinanciere(attribution.getCompetenceFinanciere());
    conteneurCompetences.setConventionGestion(attribution.getConventionGestion());
    if ((attribution.getCompetence() instanceof Competence)) {
      conteneurCompetences.setEstPCRCForce(((Competence)attribution.getCompetence()).isEstPCRCForce());
    }
    return conteneurCompetences;
  }
  
  protected static void alimenterContextePap(DemandeSpec demande, ElementBaseIndemnisation ebi)
  {
    ebi.setContextePAPPresent(demande.estEnContexteDemande(10));
    ebi.setContextePapParlementaire(demande.estEnContexteDemande("PAPPARLEM"));
  }
}

/* Location:
 * Qualified Name:     RecuperationElementIndemnisation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */