package fr.unedic.cali.asu.spe02.antecedent;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Antecedent;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionAge;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDateAttribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsAdmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionNbHeuresTravaillees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.ParametresAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ParametresCalculAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationMontantsBruts;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationSalaireReference;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.Retraite;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P03;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.Unite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public abstract class GrapheAntecedent
  extends fr.unedic.cali.asu.antecedent.GrapheAntecedent
{
  public void alimenterGrapheDecisionAntecedent(Contexte contexte)
    throws CoucheLogiqueException
  {
    alimenterValidationProduit(DomLiquidationAssurance.getDemande(contexte));
    
    super.alimenterGrapheDecisionAntecedent(contexte);
  }
  
  protected void alimenterValidationProduit(Demande demande)
  {
    DossierAffecte dossierAffecte = (DossierAffecte)demande.getDossierAffectation();
    fr.unedic.cali.asu.dom.ValidationProduit validationProduitGamme = dossierAffecte.getValidationProduit();
    SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
    
    fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit validationProduitSpectacle = new fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit();
    
    validationProduitGamme.copieElements(validationProduitSpectacle);
    dossierAffecte.setValidationProduit(validationProduitSpectacle);
    
    validationProduitSpectacle.setHeuresRequises(new Quantite(determinerAffiliationRequise(demande), Unite.getParCode("3")));
    if ((saisieAntecedent.getContexteDemande().intValue() != 4) && (saisieAntecedent.getCodeProduit().intValue() != 4))
    {
      ParametresCalculAffiliation parametres = new ParametresCalculAffiliation();
      
      int rangAllongement = 0;
      if (saisieAntecedent.getRangAllongementPraSpectacle() != null) {
        rangAllongement = saisieAntecedent.getRangAllongementPraSpectacle().intValue();
      }
      parametres.setRangEtude(rangAllongement);
      parametres.setReglementEtudie(Reglement.getInstance(saisieAntecedent.getNomReglementApplicable(), ProduitAsuSpe02P03.getInstance()));
      
      ParametresAffiliation parametresAffiliation = new ParametresAffiliation();
      DureeCalendaire dureePra = parametresAffiliation.determinerDureePeriodeReference(parametres);
      
      Periode pra = new Periode();
      pra.setFin(saisieAntecedent.getPeriodeFGD().getDateFin());
      pra.setDebut(pra.getFin().deplacerVersArriere(dureePra).lendemain());
      validationProduitSpectacle.setPeriodePra(pra);
    }
  }
  
  protected BigDecimal determinerAffiliationRequise(Demande demande)
  {
    SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
    DossierAffecte dossierAffecte = (DossierAffecte)demande.getDossierAffectation();
    
    int rangAllongement = 0;
    if (saisieAntecedent.getRangAllongementPraSpectacle() != null) {
      rangAllongement = saisieAntecedent.getRangAllongementPraSpectacle().intValue();
    }
    String identifiantFaitGenerateur = saisieAntecedent.getIdentifiantFaitGenerateur();
    ActiviteSalarie periodeFaitGenerateur = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(identifiantFaitGenerateur);
    
    ParametresCalculAffiliation parametres = new ParametresCalculAffiliation();
    parametres.setRangEtude(rangAllongement);
    parametres.setReglementEtudie(dossierAffecte.getReglementPeriodeValidationProduit());
    parametres.setFaitGenerateurDroit(periodeFaitGenerateur);
    
    ParametresAffiliation outilParametresAffiliation = new ParametresAffiliation();
    return outilParametresAffiliation.determinerQuantiteAffiliationRequise(parametres);
  }
  
  protected void initialiserDossierExamen(Demande demande)
    throws CoucheLogiqueException
  {
    demande.getDossierAffectation().setDossierExamen(new Antecedent());
  }
  
  protected void alimenterConditionsAdmission(Demande demande)
    throws CoucheLogiqueException
  {
    SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    alimenterConditionFaitGenerateur(dossierExamen, saisieAntecedent);
    
    alimenterConditionAge(dossierExamen);
  }
  
  protected void alimenterConditionFaitGenerateur(DossierExamen dossierExamen, SaisieAntecedent saisieAntecedent)
  {
    IndividuSpec demandeur = dossierExamen.getDemande().getDemandeur();
    ConditionFaitGenerateur conditionFaitGenerateur = dossierExamen.getConditionAttributionAdmission().createConditionFaitGenerateur();
    
    String identifiantFaitGenerateur = saisieAntecedent.getIdentifiantFaitGenerateur();
    ActiviteSalarie periodeFaitGenerateur = (ActiviteSalarie)demandeur.rechercherPeriodePasseProfessionnel(identifiantFaitGenerateur);
    
    conditionFaitGenerateur.setPeriodeFaitGenerateur(periodeFaitGenerateur);
    conditionFaitGenerateur.setAgeIndividuDateFG(demandeur.getAgeALaDate(periodeFaitGenerateur.getDateFin()));
    conditionFaitGenerateur.setEtatSatisfait(true);
  }
  
  protected void alimenterConditionsAdmissionSupplementaire(Demande demande)
    throws CoucheLogiqueException
  {}
  
  protected void alimenterConditionAge(DossierExamen dossierExamen)
    throws CoucheLogiqueException
  {
    IndividuSpec demandeur = dossierExamen.getDemande().getDemandeur();
    ConditionAge conditionAge = dossierExamen.getConditionAttributionAdmission().createConditionAge();
    
    Damj dateEffetTheoriquePensionRetraite = OutilRetraite.getInstance().determinerRetraite(demandeur).getDate();
    conditionAge.setDatePensionRetraite(dateEffetTheoriquePensionRetraite);
  }
  
  protected void alimenterConstituantsAdmission(Demande demande)
    throws CoucheLogiqueException
  {
    SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    alimenterConstitutionDateAttribution(dossierExamen, saisieAntecedent);
    if (saisieAntecedent.getContexteDemande().intValue() != 4)
    {
      alimenterConstitutionReglementApplicable(dossierExamen, saisieAntecedent);
      
      alimenterConstitutionNHT(dossierExamen, saisieAntecedent);
      
      alimenterConstitutionSjm(dossierExamen, saisieAntecedent);
      
      alimenterDateLimiteIndemnisation(dossierExamen, saisieAntecedent);
      
      alimenterConstitutionDurees(dossierExamen, saisieAntecedent);
      
      alimenterConstitutionDelais(dossierExamen, saisieAntecedent);
      
      alimenterConstitutionMontantBrut(dossierExamen, saisieAntecedent);
    }
    alimenterConstitutionPointDeDepart(dossierExamen, saisieAntecedent);
  }
  
  protected void alimenterConstitutionDateAttribution(DossierExamen dossierExamen, SaisieAntecedent saisieAntecedent)
  {
    ConstitutionDateAttribution constitutionDateAttribution = dossierExamen.getConstitutionElementsActifs().createConstitutionDateAttribution();
    
    Damj dateAttribution = saisieAntecedent.getDateAttribution();
    
    constitutionDateAttribution.setDateAttribution(dateAttribution);
  }
  
  protected void alimenterConstitutionReglementApplicable(DossierExamen dossierExamen, SaisieAntecedent saisieAntecedent)
  {
    ReglementApplicableSpec constitutionReglementApplicable = dossierExamen.getConstitutionElementsActifs().createConstitutionReglementApplicable();
    
    Reglement reglement = ((DossierAffecte)dossierExamen.getDossierAffecte()).getReglementPeriodeValidationProduit();
    
    constitutionReglementApplicable.setReglement(reglement);
  }
  
  protected void alimenterConstitutionNHT(DossierExamen dossierExamen, SaisieAntecedent saisieAntecedent)
  {
    ConstitutionNbHeuresTravaillees constitutionNHT = dossierExamen.getConstitutionElementsAdmission().createConstitutionNbHeuresTravaillees();
    
    BigDecimal nbHeureTravailEtendu = saisieAntecedent.getNbHeuresTravailEtendu();
    BigDecimal nbHeureTravailPlafonne = saisieAntecedent.getNbHeuresTravailPlafonne();
    
    constitutionNHT.setNombreHeuresTravailleesEtendu(nbHeureTravailEtendu);
    constitutionNHT.setNombreHeuresTravailleesPlafonne(nbHeureTravailPlafonne);
    constitutionNHT.setNombreHeuresTravailleesMajorees(nbHeureTravailPlafonne);
  }
  
  protected void alimenterConstitutionSjm(DossierExamen dossierExamen, SaisieAntecedent saisieAntecedent)
  {
    IndividuSpec demandeur = dossierExamen.getDemande().getDemandeur();
    
    alimenterConstitutionSr(saisieAntecedent, demandeur, dossierExamen);
    
    determinerSalaireJournalierMoyen((Demande)dossierExamen.getDemande());
  }
  
  protected void alimenterConstitutionSr(SaisieAntecedent saisieAntecedent, IndividuSpec demandeur, DossierExamen dossierExamen)
  {
    Quantite salaireReferenceInitialPlafonne = saisieAntecedent.getSalaireReferenceInitialPlafonne();
    int nombreJourEmploiPRA = 0;
    if (saisieAntecedent.getNbJourContratSurPra() != null) {
      nombreJourEmploiPRA = saisieAntecedent.getNbJourContratSurPra().intValue();
    }
    String identifiantFCTRetenue = saisieAntecedent.getIdentifiantFCTRetenue();
    ActiviteSalarie periodeFCTRetenue = (ActiviteSalarie)demandeur.rechercherPeriodePasseProfessionnel(identifiantFCTRetenue);
    
    BigDecimal plafondSR = DeterminationSalaireReference.determinerPlafondSrr(nombreJourEmploiPRA, dossierExamen.getDateAttribution());
    
    ConstitutionSalaireReference salaireReference = dossierExamen.getConstitutionElementsActifs().createConstitutionSalaireReference();
    
    BigDecimal srip = new BigDecimal("0");
    if (salaireReferenceInitialPlafonne != null) {
      srip = salaireReferenceInitialPlafonne.getValeur();
    }
    salaireReference.setSalaireReferenceInitialPlafonne(new QuantiteEuro(srip));
    salaireReference.setNombreJoursEmploiDansPRC(nombreJourEmploiPRA);
    salaireReference.setPrc(new Periode(periodeFCTRetenue.getDateFin(), periodeFCTRetenue.getDateFin()));
    salaireReference.setMontantPlafond(new QuantiteEuro(plafondSR));
    
    QuantiteEuro srrp = DeterminationSalaireReference.determinerSrrp(salaireReference, dossierExamen.getDateAttribution());
    salaireReference.setSalaireReferenceRevalorisePlafonne(srrp);
    
    salaireReference.setSalaireReferenceInitial(null);
  }
  
  protected abstract void determinerSalaireJournalierMoyen(Demande paramDemande);
  
  protected abstract void alimenterDateLimiteIndemnisation(DossierExamen paramDossierExamen, SaisieAntecedent paramSaisieAntecedent)
    throws CoucheLogiqueException;
  
  protected abstract void alimenterConstitutionDurees(DossierExamen paramDossierExamen, SaisieAntecedent paramSaisieAntecedent)
    throws CoucheLogiqueException;
  
  protected void alimenterConstitutionMontantBrut(DossierExamen dossierExamen, SaisieAntecedent saisieAntecedent)
    throws CoucheLogiqueException
  {
    DeterminationMontantsBruts.getInstance().determinerMontantsBruts((Demande)dossierExamen.getDemande());
  }
  
  protected abstract void alimenterConstitutionDelais(DossierExamen paramDossierExamen, SaisieAntecedent paramSaisieAntecedent);
  
  protected void alimenterConstitutionPointDeDepart(DossierExamen dossierExamen, SaisieAntecedent saisieAntecedent)
  {
    ConstitutionPointDepartIndemnisation constitutionPointDepartIndemnisation = dossierExamen.getConstitutionElementsActifs().createConstitutionPointDepartIndemnisation();
    
    Damj pji = saisieAntecedent.getPremierJourIndemnisable();
    
    constitutionPointDepartIndemnisation.setPointDepartIndemnisation(pji);
  }
}

/* Location:
 * Qualified Name:     GrapheAntecedent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */