package fr.unedic.cali.asu.spe02.p03.antecedent;

import fr.unedic.cali.asu.antecedent.GestionAntecedentCalculAsu;
import fr.unedic.cali.asu.antecedent.GestionAntecedentCalculAsuSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.spe02.p03.calcul.dom.CalendrierExecutionCalcul;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Antecedent;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvant;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.EtatAuDernierJourAvant;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.MontantBaseAbstrait;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class GestionAntecedentCalcul
  extends GestionAntecedentCalculAsu
{
  public static GestionAntecedentCalculAsuSpec getInstance()
  {
    return new GestionAntecedentCalcul();
  }
  
  public void alimenterGrapheCalcul(AttributionSpec p_attribution)
  {
    AttributionAssuranceSpec antecedent = (AttributionAssuranceSpec)p_attribution;
    SaisieAntecedent saisieAntecedent = ((Antecedent)antecedent).getSaisieAntecedent();
    
    alimenterCalendrierExecutionCalculAvant(antecedent, saisieAntecedent);
    
    alimenterCalendrierExecutionCalculPendant(antecedent, saisieAntecedent);
  }
  
  protected void alimenterCalendrierExecutionCalculAvant(AttributionAssuranceSpec p_antecedent, SaisieAntecedent p_saisieAntecedent)
  {
    CalendrierExecutionAvant calendrierAvant = new CalendrierExecutionAvant();
    calendrierAvant.setPremierJourAvant(p_saisieAntecedent.getDateDernierJourCalcule());
    calendrierAvant.setDernierJourAvant(p_saisieAntecedent.getDateDernierJourCalcule());
    EtatAuDernierJourAvant etatAuDernierJourAvant = new EtatAuDernierJourAvant();
    calendrierAvant.setEtatAuDernierJourAvant(etatAuDernierJourAvant);
    
    p_antecedent.setCalendrierExecutionAvant(calendrierAvant);
    
    alimenterEtatAuDernierJourAvant(calendrierAvant, p_saisieAntecedent);
  }
  
  protected void alimenterEtatAuDernierJourAvant(CalendrierExecutionAvant p_calendrierAvant, SaisieAntecedent p_saisieAntecedent)
  {
    EtatAuDernierJourAvant etatAuDernierJourAvant = p_calendrierAvant.getEtatAuDernierJourAvant();
    int etat = 0;
    if ((p_saisieAntecedent.getDateFinPMC() != null) && (p_saisieAntecedent.getDateFinPMC().estApres(p_saisieAntecedent.getDateDernierJourCalcule())))
    {
      int reliquatPMC = p_saisieAntecedent.getDateFinPMC().joursEntre(p_saisieAntecedent.getDateDernierJourCalcule());
      etatAuDernierJourAvant.setReliquatPMC(Integer.valueOf(reliquatPMC));
      etatAuDernierJourAvant.setPeriodeApplicationPMC(p_calendrierAvant.getPeriode());
      etatAuDernierJourAvant.setDureeInitialePMC(etatAuDernierJourAvant.getReliquatPMC());
      etat = 1;
    }
    if ((p_saisieAntecedent.getReliquatJourDiffereStandard() != null) && (p_saisieAntecedent.getReliquatJourDiffereStandard().intValue() > 0)) {
      etat = miseAJourInformationICCP(etatAuDernierJourAvant, p_saisieAntecedent, p_calendrierAvant, etat);
    }
    if ((p_saisieAntecedent.getReliquatJoursISLR() != null) && (p_saisieAntecedent.getReliquatJoursISLR().intValue() > 0))
    {
      etatAuDernierJourAvant.setReliquatISLR(p_saisieAntecedent.getReliquatJoursISLR());
      etatAuDernierJourAvant.setDureeInitialeISLR(p_saisieAntecedent.getReliquatJoursISLR());
      etatAuDernierJourAvant.setPeriodeApplicationISLR(p_calendrierAvant.getPeriode());
      etat = 1;
    }
    if ((p_saisieAntecedent.getReliquatJoursDelaiAttente() != null) && (p_saisieAntecedent.getReliquatJoursDelaiAttente().intValue() > 0))
    {
      etatAuDernierJourAvant.setReliquatDelaiAttente(p_saisieAntecedent.getReliquatJoursDelaiAttente());
      etatAuDernierJourAvant.setDureeInitialeDelaiAttente(p_saisieAntecedent.getReliquatJoursDelaiAttente());
      etatAuDernierJourAvant.setPeriodeApplicationDelaiAttente(p_calendrierAvant.getPeriode());
      etat = 1;
    }
    if (((p_saisieAntecedent.getReliquatJoursDelaiAttente() == null) || (p_saisieAntecedent.getReliquatJoursDelaiAttente().compareTo(Integer.valueOf(7)) < 0)) && (p_saisieAntecedent.isDelaiAttente()))
    {
      etatAuDernierJourAvant.setDelaiAttenteEntame(true);
    }
    else
    {
      etatAuDernierJourAvant.setPeriodeApplicationDelaiAttente(null);
      etatAuDernierJourAvant.setDelaiAttenteEntame(false);
    }
    etatAuDernierJourAvant.setEtat(etat);
  }
  
  protected int miseAJourInformationICCP(EtatAuDernierJourAvant etatAuDernierJourAvant, SaisieAntecedent saisieAntecedent, CalendrierExecutionAvant calendrierAvant, int etat)
  {
    etatAuDernierJourAvant.setReliquatICCP(saisieAntecedent.getReliquatJourDiffereStandard());
    etatAuDernierJourAvant.setDureeInitialeICCP(saisieAntecedent.getReliquatJourDiffereStandard());
    etatAuDernierJourAvant.setPeriodeApplicationICCP(calendrierAvant.getPeriode());
    return 1;
  }
  
  protected MontantBaseAbstrait determinerMontant(AttributionAssuranceSpec p_antecedent, SaisieAntecedent p_saisieAntecedent)
  {
    if (p_saisieAntecedent.getContexteDemande().intValue() == 4) {
      return null;
    }
    return super.determinerMontant(p_antecedent, p_saisieAntecedent);
  }
  
  protected CalendrierExecutionCalculPeriodique instancierCalendrierExecutionCalcul()
  {
    return new CalendrierExecutionCalcul();
  }
  
  protected fr.unedic.cali.calcul.dom.UniteTraitement instancierUniteTraitement(Unite p_uniteParDefautQuantites, Periode p_periode)
  {
    return new fr.unedic.cali.asu.spe02.p03.calcul.dom.UniteTraitement(p_uniteParDefautQuantites, p_periode);
  }
}

/* Location:
 * Qualified Name:     GestionAntecedentCalcul
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */