package fr.unedic.cali.asu.spe02.p03.avant.outilsfonctionnels;

import fr.unedic.cali.calcul.dom.ArretProduitAvecRaison;
import fr.unedic.cali.calcul.dom.ConsommationPeriodes;
import fr.unedic.cali.calcul.dom.DureeConsommableAvant;
import fr.unedic.cali.calcul.dom.EvenementLendemainFinQuantiteDroit;
import fr.unedic.cali.calcul.dom.UniteTraitementAvant;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyseSpec;
import fr.unedic.cali.dom.ImputationSpec;
import fr.unedic.cali.dom.QuantiteDroitSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public final class TraitementDureeConsommableAvant
{
  public static Quantite simulerImputationEtImputerLaQuantite(Quantite quantiteAImputer, DureeConsommableAvant dureeConcommableAvant, UniteTraitementAvant utAvant, Damj dateDebutConsommation)
    throws CoucheLogiqueException
  {
    QuantiteDroitSpec quantiteDroitAImputer = null;
    Quantite quantiteAImputerTmp = null;
    Quantite quantiteRestantAImputer = null;
    
    quantiteRestantAImputer = quantiteAImputer;
    
    quantiteAImputerTmp = quantiteAImputer;
    quantiteDroitAImputer = determinerQuantiteDroitAImputer(dureeConcommableAvant, quantiteAImputer);
    if (quantiteDroitAImputer != null) {
      quantiteAImputerTmp = quantiteDroitAImputer.getQuantiteCourante();
    }
    dureeConcommableAvant.imputer(quantiteAImputerTmp);
    if (dureeConcommableAvant.getQuantiteCourante().getValeur().compareTo(BigDecimal.ZERO) == 0)
    {
      dureeConcommableAvant.epuiser();
      
      DureeCalendaire d = new DureeCalendaire(0, 0, quantiteAImputerTmp.getValeurEntiere());
      Damj dateFinQuantiteDroit = dateDebutConsommation.deplacerVersAvant(d).veille();
      Periode p = utAvant.getConsommationPeriodes().getPeriodesParTypologie(dureeConcommableAvant.getTypeDureeConsommable());
      if (p != null) {
        p.setFin(dateFinQuantiteDroit);
      }
    }
    quantiteRestantAImputer = quantiteRestantAImputer.soustraire(quantiteAImputerTmp);
    
    return quantiteRestantAImputer;
  }
  
  public static void simulerImputationEtImputerLaQuantiteEtTerminerProduit(Quantite quantiteAImputer, PeriodeAnalyseSpec pa, DureeConsommableAvant dureeConcommableAvant, UniteTraitementAvant utAvant, Damj dateDebutConsommation, ArretProduitAvecRaison arretProduitAvecRaison)
    throws CoucheLogiqueException
  {
    QuantiteDroitSpec quantiteDroitAImputer = null;
    Quantite quantiteAImputerTmp = null;
    Quantite quantiteRestantAImputer = null;
    boolean finDeProduit = false;
    boolean finDeQuantiteDroitDansPeriodeAnalyse = false;
    Damj dateDebutQuantiteDroit = null;
    Damj dateFinQuantiteDroit = null;
    
    quantiteRestantAImputer = quantiteAImputer;
    
    dateDebutQuantiteDroit = dateDebutConsommation;
    
    finDeQuantiteDroitDansPeriodeAnalyse = detecterFinQuantiteDansPeriodeAnalyse(dureeConcommableAvant, quantiteRestantAImputer);
    while ((quantiteRestantAImputer.getValeur().compareTo(BigDecimal.ZERO) > 0) && (!finDeProduit))
    {
      quantiteDroitAImputer = determinerQuantiteDroitAImputer(dureeConcommableAvant, quantiteRestantAImputer);
      
      quantiteAImputerTmp = quantiteRestantAImputer;
      if (quantiteDroitAImputer != null) {
        quantiteAImputerTmp = quantiteDroitAImputer.getQuantiteCourante();
      }
      if (finDeQuantiteDroitDansPeriodeAnalyse)
      {
        if (dateFinQuantiteDroit != null)
        {
          dateDebutQuantiteDroit = dateFinQuantiteDroit.lendemain();
          dateFinQuantiteDroit = pa.getDateFin();
        }
        if (quantiteDroitAImputer != null)
        {
          DureeCalendaire d = new DureeCalendaire(0, 0, quantiteDroitAImputer.getQuantiteCourante().getValeurEntiere());
          dateFinQuantiteDroit = dateDebutQuantiteDroit.deplacerVersAvant(d).veille();
          
          pa.addEvenement(new fr.unedic.cali.asu.calcul.dom.EvenementFinQuantiteDroit(dateFinQuantiteDroit, quantiteDroitAImputer));
        }
      }
      finDeProduit = imputerLaQuantite(dureeConcommableAvant, quantiteAImputerTmp, dateFinQuantiteDroit, arretProduitAvecRaison);
      
      quantiteRestantAImputer = quantiteRestantAImputer.soustraire(quantiteAImputerTmp);
      if (finDeProduit)
      {
        pa.setProduitATerminerApresUT(true);
        
        DureeCalendaire d = new DureeCalendaire(0, 0, quantiteAImputerTmp.getValeurEntiere());
        dateFinQuantiteDroit = dateDebutConsommation.deplacerVersAvant(d).veille();
        Periode p = utAvant.getConsommationPeriodes().getPeriodesParTypologie(dureeConcommableAvant.getTypeDureeConsommable());
        if (p != null) {
          p.setFin(dateFinQuantiteDroit);
        }
      }
      if (finDeProduit) {
        pa.setQuantiteNonIndemnisee(pa.getQuantiteNonIndemnisee().ajouter(quantiteRestantAImputer));
      }
    }
  }
  
  private static boolean detecterFinQuantiteDansPeriodeAnalyse(DureeConsommableAvant quantiteActive, Quantite quantiteAImputer)
  {
    ImputationSpec quantiteImputee = null;
    boolean finDeQuantiteDroitDansPeriodeAnalyse = false;
    
    quantiteImputee = quantiteActive.simulerImputer(quantiteAImputer);
    if ((quantiteImputee.estImpute()) && (quantiteImputee.getResteAImputer().getValeur().compareTo(BigDecimal.ZERO) <= 0)) {
      finDeQuantiteDroitDansPeriodeAnalyse = true;
    }
    return finDeQuantiteDroitDansPeriodeAnalyse;
  }
  
  private static QuantiteDroitSpec determinerQuantiteDroitAImputer(DureeConsommableAvant dureeIndemnisation, Quantite quantiteAImputer)
  {
    ImputationSpec imputationImputee = null;
    QuantiteDroitSpec quantiteDroitAImputer = null;
    
    imputationImputee = dureeIndemnisation.simulerImputer(quantiteAImputer);
    if ((imputationImputee.estImpute()) && (imputationImputee.getResteAImputer().getValeur().compareTo(BigDecimal.ZERO) <= 0)) {
      quantiteDroitAImputer = imputationImputee.getQuantiteDroit();
    }
    return quantiteDroitAImputer;
  }
  
  private static boolean imputerLaQuantite(DureeConsommableAvant dureeIndemnisationActive, Quantite quantiteAImputer, Damj dateFinQuantiteDroit, ArretProduitAvecRaison arretProduitAvecRaison)
    throws CoucheLogiqueException
  {
    boolean finDeProduit = false;
    
    dureeIndemnisationActive.imputer(quantiteAImputer);
    if (dureeIndemnisationActive.getQuantiteCourante().getValeur().compareTo(BigDecimal.ZERO) == 0)
    {
      dureeIndemnisationActive.epuiser();
      finDeProduit = true;
      
      fr.unedic.cali.calcul.dom.EvenementFinQuantiteDroit evtFinQuantiteDroit = new fr.unedic.cali.asu.calcul.dom.EvenementFinQuantiteDroit(dateFinQuantiteDroit, dureeIndemnisationActive);
      evtFinQuantiteDroit.setEstCauseFinProduit(finDeProduit);
      
      EvenementLendemainFinQuantiteDroit evtLendemainFinQuantiteDroit = new EvenementLendemainFinQuantiteDroit(dateFinQuantiteDroit.lendemain(), dureeIndemnisationActive);
      
      evtLendemainFinQuantiteDroit.setEstCauseFinProduit(finDeProduit);
      
      arretProduitAvecRaison.ajouteLendemainFinQuantiteDroitArretCalcul(evtLendemainFinQuantiteDroit);
    }
    return finDeProduit;
  }
}

/* Location:
 * Qualified Name:     TraitementDureeConsommableAvant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */