package fr.unedic.cali.asu.spe02.p03.avant.outilsfonctionnels;

import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeSuspensionIndemnisation;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.UniteTraitementAvant;
import fr.unedic.cali.calcul.dom.periode.DsmMaladie;
import fr.unedic.cali.calcul.dom.periode.PeriodeAbsenceAuPointage;
import fr.unedic.cali.calcul.dom.periode.PeriodeEvenementPersonnel;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyse;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyseSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltreDebutDansBornes;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.util.ListIterator;

public final class TraitementPeriodesAvant
{
  public static ChronologiePeriodes traitementPeriodesSegmentantes(Periode periode, UniteTraitementAvant utAvant, ChronologiePeriodes periodesSegmentantes)
    throws CoucheLogiqueException
  {
    PeriodeAnalyseSpec periodeAnalysePrecedente = null;
    PeriodeAnalyseSpec periodeAnalyseNouvelle = null;
    ObjetChronoPeriode periodeSegmentante = null;
    ChronologiePeriodes chronoPeriodesAnalyse = new ChronologiePeriodes();
    ListIterator<?> iterateur = null;
    ChronologiePeriodes chronoPeriodesSegmentantesSurUt = null;
    
    periodeAnalysePrecedente = new PeriodeAnalyse(utAvant.getUniteParDefautQuantites(), new Periode(periode.getDebut(), periode.getFin()));
    
    chronoPeriodesAnalyse.ajouter(periodeAnalysePrecedente);
    
    chronoPeriodesSegmentantesSurUt = (ChronologiePeriodes)periodesSegmentantes.copier(new FiltreDebutDansBornes(periode));
    
    iterateur = chronoPeriodesSegmentantesSurUt.iterer();
    while (iterateur.hasNext())
    {
      periodeSegmentante = (ObjetChronoPeriode)iterateur.next();
      if (!periodeSegmentante.getDateDebut().coincideAvec(periodeAnalysePrecedente.getDateDebut()))
      {
        if (periodeSegmentante.getDateDebut().estApres(periodeAnalysePrecedente.getDateFin())) {
          throw new CoucheLogiqueException("HG_PR_CALI_L_ERREUR_TRAITEMENT_PERIODE_SEGMENTANTE", "Erreur de date de début lors du traitement des périodes segmentantes dans le Calcul.", null);
        }
        periodeAnalysePrecedente.setDateFin(periodeSegmentante.getDateDebut().veille());
        
        periodeAnalyseNouvelle = new PeriodeAnalyse(utAvant.getUniteParDefautQuantites(), new Periode(periodeSegmentante.getDateDebut(), periode.getFin()));
        
        chronoPeriodesAnalyse.ajouter(periodeAnalyseNouvelle);
        
        periodeAnalysePrecedente = periodeAnalyseNouvelle;
      }
    }
    return chronoPeriodesAnalyse;
  }
  
  public static boolean traitementPeriodesSuspensives(PeriodeAnalyseSpec pa, QualificationPeriodes qualificationPeriodes)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronologiePeriodesSuspensivesSurPeriode = new ChronologiePeriodes();
    chronologiePeriodesSuspensivesSurPeriode.ajouter((ChronologiePeriodes)qualificationPeriodes.getPeriodesSuspensives().copier(new FiltreChevauchePeriode(pa.getPeriode())));
    if (!chronologiePeriodesSuspensivesSurPeriode.estVide()) {
      return true;
    }
    return false;
  }
  
  public static boolean traitementPeriodesSuspensivesPourDebutConsommationDelaiAttente(PeriodeAnalyseSpec pa, QualificationPeriodes qualificationPeriodes, Damj dateDebutConsommationDelaiAttente)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesSuspensivesSurPa = (ChronologiePeriodes)qualificationPeriodes.getPeriodesSuspensives().copier(new FiltreChevauchePeriode(pa.getPeriode()));
    
    periodesSuspensivesSurPa.ajouter((ChronologiePeriodes)qualificationPeriodes.getPeriodesInterruptives().copier(new FiltreChevauchePeriode(pa.getPeriode())));
    
    ChronologiePeriodes chronologiePeriodesSuspensivesSurPeriode = new ChronologiePeriodes();
    
    periodesSuspensivesSurPa.iterer();
    while (periodesSuspensivesSurPa.encoreSuivant())
    {
      Temporel periode = periodesSuspensivesSurPa.elementSuivant();
      if (periode.getDateDebut().estAvantOuCoincideAvec(dateDebutConsommationDelaiAttente)) {
        if ((periode instanceof DsmMaladie)) {
          chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
        } else if ((periode instanceof PeriodeEvenementPersonnel)) {
          chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
        } else if ((periode instanceof PeriodeAbsenceAuPointage)) {
          chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
        }
      }
      if ((periode instanceof ObjetChronoPeriodeSuspensionIndemnisation)) {
        chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
      }
    }
    if (!chronologiePeriodesSuspensivesSurPeriode.estVide()) {
      return true;
    }
    return false;
  }
}

/* Location:
 * Qualified Name:     TraitementPeriodesAvant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */