package fr.unedic.cali.asu.spe02.p03.calcul.dom;

import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.SalaireReference;
import fr.unedic.cali.asu.dom.Sjm;
import fr.unedic.cali.asu.spe02.p03.calcul.outilsfonctionnels.CotisationRetraiteComplementaire;
import fr.unedic.cali.asu.spe02.p03.calcul.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.UniteMonaitaire;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class FormuleMontantRegimeGeneral
  implements FormuleMontantSpec
{
  private static final BigDecimal SRF = new BigDecimal("12000");
  private static final BigDecimal NHF = new BigDecimal("600");
  private static final BigDecimal CA2_A8_A10 = new BigDecimal("0.05");
  private static final BigDecimal CB1_A8_A10 = new BigDecimal("0.30");
  private static final BigDecimal CB2_A8_A10 = new BigDecimal("0.10");
  private static final BigDecimal CA1_A8 = new BigDecimal("0.50");
  private static final BigDecimal CA1_A10 = new BigDecimal("0.40");
  private static final BigDecimal CC1_A8 = new BigDecimal("0.40");
  private static final BigDecimal CC1_A10 = new BigDecimal("0.70");
  protected static final BigDecimal ZERO = new BigDecimal("0");
  
  public static String getCode()
  {
    return "1";
  }
  
  public MontantBaseSpec calculer(ConstituantsIndemnisation p_constituantsIndemnisation, Damj p_dateCalcul)
    throws CoucheLogiqueException
  {
    Montant montant = new Montant();
    Quantite montantBrut = null;
    BigDecimal montantBase = null;
    BigDecimal montantMaxi = null;
    BigDecimal montantMini = null;
    BigDecimal montantTmp = null;
    BigDecimal montantRes = null;
    BigDecimal montantAVDeduit = null;
    BigDecimal montantA = null;
    BigDecimal montantB = null;
    BigDecimal montantC = null;
    
    ElementBaseIndemnisation coefficient = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
    fr.unedic.cali.asu.spe02.p03.parametres.EvenementParametre parametres = fr.unedic.cali.asu.spe02.p03.parametres.ParametresIndemnisation.getParametresIndemnisation().getElementActif(p_dateCalcul);
    
    SalaireReference srrp = RevalorisationSalaire.determinerSrrp(coefficient.getSalaireReference(), coefficient.getNbJoursEmploiSurPrc(), p_dateCalcul);
    
    Sjm sjmrp = RevalorisationSalaire.determinerSjmrp(srrp, coefficient.getCoefficientHoraireJour(), coefficient.getNombreHeuresTravailleesPlafonnees(), p_dateCalcul);
    
    Reglement reglement = coefficient.getReglementApplicable();
    if (reglement.getLibelleCourt().equalsIgnoreCase("A8"))
    {
      montant.setCoefA1(CA1_A8);
      montant.setCoefC(CC1_A8);
    }
    else
    {
      montant.setCoefA1(CA1_A10);
      montant.setCoefC(CC1_A10);
    }
    montant.setCoefA2(CA2_A8_A10);
    montant.setCoefB1(CB1_A8_A10);
    montant.setCoefB2(CB2_A8_A10);
    
    montant.setSrf(SRF);
    montant.setNhf(NHF);
    
    montantA = calculerMontantBrutPartieA(p_constituantsIndemnisation, p_dateCalcul);
    montantB = calculerMontantBrutPartieB(p_constituantsIndemnisation, p_dateCalcul);
    montantC = calculerMontantBrutPartieC(p_constituantsIndemnisation, p_dateCalcul);
    
    montantAVDeduit = coefficient.getTauxAvantageVieillesse().multiply(coefficient.getCoefficientAvantageVieillesse().multiply(sjmrp.getSalaire()));
    
    montantBase = montantA.add(montantB.add(montantC));
    
    montantMaxi = parametres.getAllocationMaximale();
    
    montantBase = montantBase.min(montantMaxi);
    
    montantMini = parametres.getAllocationMinimale();
    
    montantTmp = montantBase.subtract(montantAVDeduit);
    montantTmp = montantTmp.max(montantMini);
    
    montantRes = montantTmp.min(montantBase);
    if (montantRes.equals(montantMaxi)) {
      montant.setJustificationCalculMontant("03");
    } else if (montantRes.equals(montantMini)) {
      montant.setJustificationCalculMontant("02");
    } else {
      montant.setMontantJournalierAvantageVieillesseDeduit(new QuantiteEuro(Mathematiques.arrondiASup(montantAVDeduit, 2)));
    }
    montant.setMontantBrutSansPensionInvaliditeADeduire(new Quantite(Mathematiques.arrondiASup(montantRes, 2), UniteMonaitaire.get("Euros")));
    
    montant.setMontantBrutSansAvantageVieillesseDeduit(new Quantite(Mathematiques.arrondiASup(montantBase, 2), UniteMonaitaire.get("Euros")));
    
    montantRes = montantRes.subtract(coefficient.getMontantPensionInvaliditeADeduire());
    
    montantRes = montantRes.max(ZERO);
    
    montantRes = Mathematiques.arrondiASup(montantRes, 2);
    
    montantBrut = new Quantite(montantRes, UniteMonaitaire.get("Euros"));
    
    montant.setPensionInvaliditeADeduirePriseEnCompte(new Quantite(coefficient.getMontantPensionInvaliditeADeduire(), UniteMonaitaire.get("Euros")));
    
    montant.setMontantJournalierAvantageVieillesse(new QuantiteEuro(coefficient.getMontantAvantageVieillesse()));
    montant.setPlafond(new Quantite(Mathematiques.arrondiASup(montantMaxi, 2), UniteMonaitaire.get("Euros")));
    montant.setMini(new Quantite(Mathematiques.arrondiASup(montantMini, 2), UniteMonaitaire.get("Euros")));
    montant.setBase(new Quantite(Mathematiques.arrondiASup(montantBase, 2), UniteMonaitaire.get("Euros")));
    montant.setMontantBrut(montantBrut);
    montant.setPartieA(new Quantite(Mathematiques.arrondiASup(montantA, 2), UniteMonaitaire.get("Euros")));
    montant.setPartieB(new Quantite(Mathematiques.arrondiASup(montantB, 2), UniteMonaitaire.get("Euros")));
    montant.setPartieC(new Quantite(Mathematiques.arrondiASup(montantC, 2), UniteMonaitaire.get("Euros")));
    
    boolean estAvecCRC = coefficient.getAvecPrecompteCRC() != null ? coefficient.getAvecPrecompteCRC().booleanValue() : true;
    
    montant.setAvecPrecompteCRC(estAvecCRC);
    if (estAvecCRC)
    {
      montant.setCrc(CotisationRetraiteComplementaire.getCotisationEffective(montant, sjmrp.getSalaire(), montantRes, montantMini, parametres.getCotisationRetraiteComplementaire()));
    }
    else
    {
      montant.setCrc(new Quantite(0, UniteMonaitaire.get("Euros")));
      
      montant.setSjrNonReduit(sjmrp.getSalaire());
    }
    if ((coefficient.getCoefficientSanctionReduction() != null) && (!coefficient.getCoefficientSanctionReduction().equals(new BigDecimal("1.00"))))
    {
      BigDecimal mtApresPart = montantRes.subtract(montant.getCrc().getValeur());
      mtApresPart = mtApresPart.multiply(coefficient.getCoefficientSanctionReduction());
      mtApresPart = mtApresPart.add(montant.getCrc().getValeur());
      mtApresPart = Mathematiques.arrondiASup(mtApresPart, 2);
      montant.setMontantBrut(new Quantite(mtApresPart, UniteMonaitaire.EUROS));
    }
    return montant;
  }
  
  public BigDecimal calculerMontantBrutPartieA(ConstituantsIndemnisation p_constituantsIndemnisation, Damj p_date)
  {
    BigDecimal montantA = null;
    BigDecimal montantMini = null;
    BigDecimal montantTmp = null;
    BigDecimal montantPA = null;
    BigDecimal montantPB = null;
    BigDecimal smicHoraire = null;
    
    fr.unedic.cali.asu.spe02.p03.parametres.EvenementParametre evenementParametre = null;
    fr.unedic.cali.asu.parametres.EvenementParametre evenementParametreASU = null;
    
    ElementBaseIndemnisation elementBaseIndem = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
    
    evenementParametre = fr.unedic.cali.asu.spe02.p03.parametres.ParametresIndemnisation.getParametresIndemnisation().getElementActif(p_date);
    montantMini = evenementParametre.getAllocationMinimale();
    
    evenementParametreASU = fr.unedic.cali.asu.parametres.ParametresIndemnisation.getParametresIndemnisation().getElementActif(elementBaseIndem.getDateFinPRC());
    smicHoraire = evenementParametreASU.getSmicHoraire();
    
    Reglement reglement = elementBaseIndem.getReglementApplicable();
    SalaireReference srrp = RevalorisationSalaire.determinerSrrp(elementBaseIndem.getSalaireReference(), elementBaseIndem.getNbJoursEmploiSurPrc(), p_date);
    
    montantTmp = srrp.getSalaire().subtract(SRF);
    if (reglement.getLibelleCourt().equalsIgnoreCase("A8")) {
      montantPA = CA1_A8.multiply(SRF.min(srrp.getSalaire()));
    } else {
      montantPA = CA1_A10.multiply(SRF.min(srrp.getSalaire()));
    }
    montantPB = CA2_A8_A10.multiply(montantTmp.max(ZERO));
    
    montantA = montantMini.multiply(montantPA.add(montantPB));
    
    montantA = montantA.divide(elementBaseIndem.getAffiliationRequisePourPRA().getValeur().multiply(smicHoraire), 4);
    
    montantA = Mathematiques.arrondiASup(montantA, 2);
    
    return montantA;
  }
  
  public BigDecimal calculerMontantBrutPartieB(ConstituantsIndemnisation p_constituantsIndemnisation, Damj p_date)
  {
    BigDecimal montantB = null;
    BigDecimal montantMini = null;
    BigDecimal montantTmp = null;
    BigDecimal montantPA = null;
    BigDecimal montantPB = null;
    
    fr.unedic.cali.asu.spe02.p03.parametres.EvenementParametre evenementParametre = null;
    evenementParametre = fr.unedic.cali.asu.spe02.p03.parametres.ParametresIndemnisation.getParametresIndemnisation().getElementActif(p_date);
    
    ElementBaseIndemnisation elementBaseIndem = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
    
    montantMini = evenementParametre.getAllocationMinimale();
    
    montantTmp = NHF.min(elementBaseIndem.getNombreHeureTravaillesEtendu());
    montantPA = CB1_A8_A10.multiply(montantTmp);
    
    montantTmp = elementBaseIndem.getNombreHeureTravaillesEtendu().subtract(NHF);
    montantPB = CB2_A8_A10.multiply(montantTmp.max(ZERO));
    
    montantB = montantMini.multiply(montantPA.add(montantPB));
    
    montantB = montantB.divide(elementBaseIndem.getAffiliationRequisePourPRA().getValeur(), 4);
    montantB = Mathematiques.arrondiASup(montantB, 2);
    
    return montantB;
  }
  
  public BigDecimal calculerMontantBrutPartieC(ConstituantsIndemnisation p_constituantsIndemnisation, Damj p_date)
  {
    BigDecimal montantC = null;
    BigDecimal montantMini = null;
    
    fr.unedic.cali.asu.spe02.p03.parametres.EvenementParametre evenementParametre = null;
    evenementParametre = fr.unedic.cali.asu.spe02.p03.parametres.ParametresIndemnisation.getParametresIndemnisation().getElementActif(p_date);
    
    ElementBaseIndemnisation elementBaseIndem = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
    
    montantMini = evenementParametre.getAllocationMinimale();
    
    Reglement reglement = elementBaseIndem.getReglementApplicable();
    if (reglement.getLibelleCourt().equalsIgnoreCase("A8")) {
      montantC = montantMini.multiply(CC1_A8);
    } else {
      montantC = montantMini.multiply(CC1_A10);
    }
    montantC = Mathematiques.arrondiASup(montantC, 2);
    
    return montantC;
  }
  
  public void setFormuleMontantDroitAssocie(FormuleMontantSpec p_formuleMontantDroitAssocie) {}
  
  public void setFormuleMontantApplicable(int p_formuleMontantApplicable) {}
}

/* Location:
 * Qualified Name:     FormuleMontantRegimeGeneral
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */