package fr.unedic.cali.asu.spe02.p03.liquidation.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.gen.OdGen;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationMontantTotalSalaires;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationSituationParticuliere;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.outilsfonctionnels.AppelAvant;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;

public class Od
  extends OdGen
  implements fr.unedic.cali.asu.dom.OdAssuranceSpec
{
  private static final long serialVersionUID = -1949754731050471502L;
  
  public Od(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Od() {}
  
  public Od(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public ObjetMetierSpec copie()
  {
    Od copie = new Od();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec pCopie)
  {
    Od copie = (Od)pCopie;
    super.copieElements(copie);
  }
  
  public void marquerGraphePersistant()
  {
    super.marquerGraphePersistant();
  }
  
  public String getRsod()
  {
    return getReferenceExterne();
  }
  
  public String getRsrp()
  {
    return "0";
  }
  
  public String getSituationParticuliere()
  {
    String situationParticuliere = super.getSituationParticuliere();
    if (situationParticuliere == null) {
      situationParticuliere = DeterminationSituationParticuliere.getSituationParticuliere();
    }
    return situationParticuliere;
  }
  
  public JustificationAffiliationSpec getJustificationAffiliation()
  {
    return ((ValidationProduit)((DossierAffecte)getDossierAffecte()).getValidationProduit()).getJustificationAffiliation();
  }
  
  public AttributionSpec getAttributionMaitre()
  {
    return this;
  }
  
  public AttributionAssuranceSpec getAttributionOrigine()
  {
    return this;
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public boolean isTopContratsRemuneresBaseSmic()
  {
    return false;
  }
  
  public Damj getDateFaitGenerateurDroit()
  {
    return getConditionFaitGenerateur().getDateFaitGenerateur();
  }
  
  public fr.unedic.cali.dom.OdAssuranceSpec getOuvertureDroit()
  {
    return this;
  }
  
  public fr.unedic.cali.asu.dom.OdAssuranceSpec getOuvertureDroitCapitalRetenu()
  {
    return this;
  }
  
  public ResultatAvant determinationEtatACT()
    throws CoucheLogiqueException
  {
    ResultatAvant resultatAvant = null;
    
    Collection<CarencePrefixeAFixer> carences = getListeCarences();
    
    BigDecimal remuneration = getRemuneration(getDemandeAssurance(), getConstitutionDelaisReport().getJustificationDiffere());
    Quantite quantiteDiffere2014 = getDiffereStandard(getDemande(), remuneration);
    boolean possedeUneCarenceStandard = false;
    
    CarencePrefixeAFixer cpaf = null;
    for (CarencePrefixeAFixer carence : carences)
    {
      if ((carence instanceof CarenceIslr))
      {
        cpaf = new CarenceIslr();
        cpaf = (CarenceIslr)carence.copie();
      }
      if ((carence instanceof PreavisMesureConservatoireIndemnisable))
      {
        cpaf = new PreavisMesureConservatoireIndemnisable();
        cpaf = (PreavisMesureConservatoireIndemnisable)carence.copie();
      }
      if ((carence instanceof PreavisMesureConservatoireNonIndemnisable))
      {
        cpaf = new PreavisMesureConservatoireNonIndemnisable();
        cpaf = (PreavisMesureConservatoireNonIndemnisable)carence.copie();
      }
      if ((carence instanceof CarenceStandard))
      {
        cpaf = new CarenceStandard();
        cpaf = (CarenceStandard)carence.copie();
      }
      if ((carence instanceof Differe))
      {
        cpaf = new Differe();
        cpaf = (Differe)carence.copie();
        cpaf.setReliquat(carence.getReliquat());
        cpaf.setOrigineReliquat(carence.getOrigineReliquat());
      }
      if ("4".equals(cpaf.getTypeCarence()))
      {
        cpaf.setQuantiteInitiale(quantiteDiffere2014);
        possedeUneCarenceStandard = true;
      }
      ajouterCarenceForce(cpaf);
    }
    if ((!possedeUneCarenceStandard) && (quantiteDiffere2014 != null) && (quantiteDiffere2014.getValeurEntiere() != 0))
    {
      cpaf = new CarenceStandard();
      cpaf.setQuantiteInitiale(quantiteDiffere2014);
      cpaf.setDateFinPeriodeOrigine(getDateAttribution());
      ajouterCarenceForce(cpaf);
    }
    try
    {
      resultatAvant = AppelAvant.executerCalculDeterminationEtatAvantSansDate(this);
    }
    catch (ApplicativeException ex)
    {
      throw new CoucheLogiqueException(ex.getCode());
    }
    viderCarencesForcees();
    
    setDateFinAct(resultatAvant.getPji());
    setDateFinAvant(resultatAvant.getDernierJourAvant().lendemain());
    for (Object ca : resultatAvant.getListeCarencesEffectives()) {
      if (((CarencePrefixeAFixer)ca).getReliquat().getValeur().signum() == 1) {
        ajouterCarenceReliquat((CarencePrefixeAFixer)ca);
      }
    }
    return resultatAvant;
  }
  
  private BigDecimal getRemuneration(DemandeAssuranceSpec demande, JustificationDiffere justificationDiffere)
  {
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    Periode periodeRechercheCalcul = dossierExamen.getConstitutionSalaireReference().getPrc();
    return calculMontantTotalSalaires(justificationDiffere, demande, periodeRechercheCalcul);
  }
  
  private BigDecimal calculMontantTotalSalaires(JustificationDiffere justification, DemandeAssuranceSpec demande, Periode periodeRecherche)
  {
    DeterminationMontantTotalSalaires outilDeterminationMontantTotalSalaires = new DeterminationMontantTotalSalaires();
    return DeterminationMontantTotalSalaires.determinerMontantTotalSalaires(justification, demande, periodeRecherche);
  }
}

/* Location:
 * Qualified Name:     Od
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */