package fr.unedic.cali.asu.spe02.p03.liquidation.dom.gen;

import fr.unedic.archi.commun.exception.TechniqueException;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDateAttribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsAbstrait;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionReglementApplicable;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.pc.ConstitutionElementsReprisePC;
import fr.unedic.transverse.dom.ContexteSuppressionEnProfondeur;
import fr.unedic.transverse.dom.spec.DomGenSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.ApplicativeRuntimeException;

public abstract class ConstitutionElementsRepriseGen
  extends ConstitutionElementsAbstrait
  implements DomGenSpec
{
  protected transient DomPCSpec m_constitutionElementsReprisePC;
  private transient ConstitutionDurees m_constitutionDurees = null;
  private transient ConstitutionMontantsBruts m_constitutionMontantsBruts = null;
  private transient ConstitutionSalaireJournalierMoyen m_constitutionSalaireJournalierMoyen = null;
  private transient ConstitutionDelaisReport m_constitutionDelaisReport = null;
  private transient ConstitutionReglementApplicable m_constitutionReglementApplicable = null;
  private transient ConstitutionDateAttribution m_constitutionDateAttribution = null;
  private transient ConstitutionPointDepartIndemnisation m_constitutionPointDepartIndemnisation = null;
  private ConstitutionDateLimiteIndemnisation m_constitutionDateLimiteIndemnisation = null;
  
  public ConstitutionElementsRepriseGen(DomPCSpec p_pc)
  {
    setPC(p_pc);
  }
  
  public ConstitutionElementsRepriseGen()
  {
    setPC(createPC());
  }
  
  protected DomPCSpec createPC()
  {
    return new ConstitutionElementsReprisePC();
  }
  
  public DomPCSpec getPC()
  {
    return m_constitutionElementsReprisePC;
  }
  
  public Object getGenericPC()
  {
    return getPC();
  }
  
  public void setPC(DomPCSpec p_constitutionElementsReprisePC)
  {
    m_constitutionElementsReprisePC = p_constitutionElementsReprisePC;
  }
  
  public void supprimerEnProfondeur(ContexteSuppressionEnProfondeur p_contexteSuppression)
    throws TechniqueException
  {
    p_contexteSuppression.addElementEnCoursDeSuppression(this);
    if (getConstitutionDurees() != null)
    {
      getConstitutionDurees().supprimerEnProfondeur(p_contexteSuppression);
      m_constitutionDurees = null;
    }
    if (getConstitutionMontantsBruts() != null)
    {
      getConstitutionMontantsBruts().supprimerEnProfondeur(p_contexteSuppression);
      m_constitutionMontantsBruts = null;
    }
    if (getConstitutionSalaireJournalierMoyen() != null)
    {
      getConstitutionSalaireJournalierMoyen().supprimerEnProfondeur(p_contexteSuppression);
      m_constitutionSalaireJournalierMoyen = null;
    }
    if (getConstitutionDelaisReport() != null)
    {
      getConstitutionDelaisReport().supprimerEnProfondeur(p_contexteSuppression);
      m_constitutionDelaisReport = null;
    }
    if (getConstitutionReglementApplicable() != null)
    {
      getConstitutionReglementApplicable().supprimerEnProfondeur(p_contexteSuppression);
      m_constitutionReglementApplicable = null;
    }
    if (getConstitutionDateAttribution() != null)
    {
      getConstitutionDateAttribution().supprimerEnProfondeur(p_contexteSuppression);
      m_constitutionDateAttribution = null;
    }
    if (getConstitutionPointDepartIndemnisation() != null)
    {
      getConstitutionPointDepartIndemnisation().supprimerEnProfondeur(p_contexteSuppression);
      m_constitutionPointDepartIndemnisation = null;
    }
    if (getConstitutionDateLimiteIndemnisation() != null)
    {
      getConstitutionDateLimiteIndemnisation().supprimerEnProfondeur(p_contexteSuppression);
      m_constitutionDateLimiteIndemnisation = null;
    }
  }
  
  public ConstitutionDurees getConstitutionDurees()
  {
    if ((((ConstitutionElementsReprisePC)getPC()).isPresenceDonneesConstitutionDurees()) && (m_constitutionDurees == null)) {
      m_constitutionDurees = new ConstitutionDurees(getPC());
    }
    return m_constitutionDurees;
  }
  
  public ConstitutionDurees createConstitutionDurees()
  {
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionDurees(true);
    if (m_constitutionDurees == null) {
      m_constitutionDurees = new ConstitutionDurees(getPC());
    }
    try
    {
      m_constitutionDurees.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_constitutionDurees;
  }
  
  public void removeConstitutionDurees()
  {
    try
    {
      m_constitutionDurees.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionDurees(false);
  }
  
  public ConstitutionMontantsBruts getConstitutionMontantsBruts()
  {
    if ((((ConstitutionElementsReprisePC)getPC()).isPresenceDonneesConstitutionMontantsBruts()) && (m_constitutionMontantsBruts == null)) {
      m_constitutionMontantsBruts = new ConstitutionMontantsBruts(getPC());
    }
    return m_constitutionMontantsBruts;
  }
  
  public ConstitutionMontantsBruts createConstitutionMontantsBruts()
  {
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionMontantsBruts(true);
    if (m_constitutionMontantsBruts == null) {
      m_constitutionMontantsBruts = new ConstitutionMontantsBruts(getPC());
    }
    try
    {
      m_constitutionMontantsBruts.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_constitutionMontantsBruts;
  }
  
  public void removeConstitutionMontantsBruts()
  {
    try
    {
      m_constitutionMontantsBruts.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionMontantsBruts(false);
  }
  
  public ConstitutionSalaireJournalierMoyen getConstitutionSalaireJournalierMoyen()
  {
    if ((((ConstitutionElementsReprisePC)getPC()).isPresenceDonneesConstitutionSalaireJournalierMoyen()) && (m_constitutionSalaireJournalierMoyen == null)) {
      m_constitutionSalaireJournalierMoyen = new ConstitutionSalaireJournalierMoyen(getPC());
    }
    return m_constitutionSalaireJournalierMoyen;
  }
  
  public ConstitutionSalaireJournalierMoyen createConstitutionSalaireJournalierMoyen()
  {
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionSalaireJournalierMoyen(true);
    if (m_constitutionSalaireJournalierMoyen == null) {
      m_constitutionSalaireJournalierMoyen = new ConstitutionSalaireJournalierMoyen(getPC());
    }
    try
    {
      m_constitutionSalaireJournalierMoyen.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_constitutionSalaireJournalierMoyen;
  }
  
  public void removeConstitutionSalaireJournalierMoyen()
  {
    try
    {
      m_constitutionSalaireJournalierMoyen.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionSalaireJournalierMoyen(false);
  }
  
  public ConstitutionDelaisReport getConstitutionDelaisReport()
  {
    if ((((ConstitutionElementsReprisePC)getPC()).isPresenceDonneesConstitutionDelaisReport()) && (m_constitutionDelaisReport == null)) {
      m_constitutionDelaisReport = new ConstitutionDelaisReport(getPC());
    }
    return m_constitutionDelaisReport;
  }
  
  public ConstitutionDelaisReport createConstitutionDelaisReport()
  {
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionDelaisReport(true);
    if (m_constitutionDelaisReport == null) {
      m_constitutionDelaisReport = new ConstitutionDelaisReport(getPC());
    }
    try
    {
      m_constitutionDelaisReport.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_constitutionDelaisReport;
  }
  
  public void removeConstitutionDelaisReport()
  {
    try
    {
      m_constitutionDelaisReport.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionDelaisReport(false);
  }
  
  public ConstitutionReglementApplicable getConstitutionReglementApplicable()
  {
    if ((((ConstitutionElementsReprisePC)getPC()).isPresenceDonneesConstitutionReglementApplicable()) && (m_constitutionReglementApplicable == null)) {
      m_constitutionReglementApplicable = new ConstitutionReglementApplicable(getPC());
    }
    return m_constitutionReglementApplicable;
  }
  
  public ConstitutionReglementApplicable createConstitutionReglementApplicable()
  {
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionReglementApplicable(true);
    if (m_constitutionReglementApplicable == null) {
      m_constitutionReglementApplicable = new ConstitutionReglementApplicable(getPC());
    }
    try
    {
      m_constitutionReglementApplicable.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_constitutionReglementApplicable;
  }
  
  public void removeConstitutionReglementApplicable()
  {
    try
    {
      m_constitutionReglementApplicable.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionReglementApplicable(false);
  }
  
  public ConstitutionDateAttribution getConstitutionDateAttribution()
  {
    if ((((ConstitutionElementsReprisePC)getPC()).isPresenceDonneesConstitutionDateAttribution()) && (m_constitutionDateAttribution == null)) {
      m_constitutionDateAttribution = new ConstitutionDateAttribution(getPC());
    }
    return m_constitutionDateAttribution;
  }
  
  public ConstitutionDateAttribution createConstitutionDateAttribution()
  {
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionDateAttribution(true);
    if (m_constitutionDateAttribution == null) {
      m_constitutionDateAttribution = new ConstitutionDateAttribution(getPC());
    }
    try
    {
      m_constitutionDateAttribution.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_constitutionDateAttribution;
  }
  
  public void removeConstitutionDateAttribution()
  {
    try
    {
      m_constitutionDateAttribution.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionDateAttribution(false);
  }
  
  public ConstitutionPointDepartIndemnisation getConstitutionPointDepartIndemnisation()
  {
    if ((((ConstitutionElementsReprisePC)getPC()).isPresenceDonneesConstitutionPointDepartIndemnisation()) && (m_constitutionPointDepartIndemnisation == null)) {
      m_constitutionPointDepartIndemnisation = new ConstitutionPointDepartIndemnisation(getPC());
    }
    return m_constitutionPointDepartIndemnisation;
  }
  
  public ConstitutionPointDepartIndemnisation createConstitutionPointDepartIndemnisation()
  {
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionPointDepartIndemnisation(true);
    if (m_constitutionPointDepartIndemnisation == null) {
      m_constitutionPointDepartIndemnisation = new ConstitutionPointDepartIndemnisation(getPC());
    }
    try
    {
      m_constitutionPointDepartIndemnisation.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_constitutionPointDepartIndemnisation;
  }
  
  public void removeConstitutionPointDepartIndemnisation()
  {
    try
    {
      m_constitutionPointDepartIndemnisation.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    ((ConstitutionElementsReprisePC)getPC()).setPresenceDonneesConstitutionPointDepartIndemnisation(false);
  }
  
  public ConstitutionDateLimiteIndemnisation getConstitutionDateLimiteIndemnisation()
  {
    if (m_constitutionDateLimiteIndemnisation == null) {
      m_constitutionDateLimiteIndemnisation = new ConstitutionDateLimiteIndemnisation(getPC());
    }
    return m_constitutionDateLimiteIndemnisation;
  }
  
  public ConstitutionDateLimiteIndemnisation createConstitutionDateLimiteIndemnisation()
  {
    if (m_constitutionDateLimiteIndemnisation == null) {
      m_constitutionDateLimiteIndemnisation = new ConstitutionDateLimiteIndemnisation(getPC());
    }
    try
    {
      m_constitutionDateLimiteIndemnisation.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_constitutionDateLimiteIndemnisation;
  }
  
  public void removeConstitutionDateLimiteIndemnisation()
  {
    try
    {
      m_constitutionDateLimiteIndemnisation.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
  }
  
  public void copieElements(ObjetMetierSpec p_copie) {}
}

/* Location:
 * Qualified Name:     ConstitutionElementsRepriseGen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */