package fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.CalculAffiliationBaseSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.JustifierAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ParametresAffiliationSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class CalculAffiliationBase
  implements CalculAffiliationBaseSpec
{
  private static final Quantite ZERO = CalculAppartenance.ZERO;
  
  public Quantite determinerAffiliationDeBase(IndividuSpec individu, Map chronologies, ComportementAffiliationSpec comportementCalcul, JustificationAffiliation justification, Collection collectionAlertesNonBloquantes)
    throws CoucheLogiqueException
  {
    verifierComportement(comportementCalcul);
    
    ParametresAffiliationSpec parametresAffiliation = comportementCalcul.getOutilParametreAffiliation();
    JustifierAffiliationSpec justifierAffiliation = comportementCalcul.getOutilJustifierAffiliation();
    
    Chronologie chronoPourAffiliationBase = (Chronologie)chronologies.get("chronoAffiBase");
    
    Quantite affiliationDeBase = ZERO;
    if ((chronoPourAffiliationBase != null) && (!chronoPourAffiliationBase.estVide()))
    {
      List<?> listePeriodeElementaire = OutilPeriodeAffiliation.decouperEnPeriodesElementaires(comportementCalcul.getPeriodeRecherche());
      
      Iterator<?> itPeriodeElementaire = listePeriodeElementaire.iterator();
      while (itPeriodeElementaire.hasNext())
      {
        boolean justifierPeriode = true;
        PeriodeElementaireAffiliation periodeElementaire = (PeriodeElementaireAffiliation)itPeriodeElementaire.next();
        
        boolean presenceActiviteSurPeriode = calculerQuantiteTravailPourPeriodeElementaire(individu, chronoPourAffiliationBase, periodeElementaire, comportementCalcul.getFaitGenerateur().getDateFin(), collectionAlertesNonBloquantes, comportementCalcul.getDateExamen(), comportementCalcul.getConvertisseurUniteAffiliation());
        
        applicationPlafondSpecifique(parametresAffiliation, periodeElementaire);
        
        BigDecimal plafondHeure = parametresAffiliation.determinerPlafondHeureApplicable(periodeElementaire, chronoPourAffiliationBase);
        periodeElementaire.setMontantPlafondHeures(plafondHeure);
        
        BigDecimal plafondCachet = parametresAffiliation.determinerPlafondCachetSurPeriodeElementaire(periodeElementaire);
        periodeElementaire.setMontantPlafondCachets(plafondCachet);
        if (presenceActiviteSurPeriode)
        {
          OutilPeriodeElementaire outilPeriodeElementaire = recupereOutilPeriodeElementaire();
          Quantite quantiteAffiliationSurPeriode = outilPeriodeElementaire.calculerQuantiteAppartenanceARetenir(periodeElementaire, comportementCalcul.getConvertisseurUniteAffiliation());
          if (quantiteAffiliationSurPeriode.equals(ZERO)) {
            justifierPeriode = false;
          } else {
            affiliationDeBase = affiliationDeBase.ajouter(quantiteAffiliationSurPeriode);
          }
        }
        else
        {
          periodeElementaire.setAffiliationRetenue(ZERO);
          justifierPeriode = false;
        }
        if ((comportementCalcul.isJustifierPeriodesSansAffiliation()) || (justifierPeriode)) {
          justifierAffiliation.ajouterPeriodeElementaire(justification, periodeElementaire);
        }
      }
    }
    return affiliationDeBase;
  }
  
  protected OutilPeriodeElementaire recupereOutilPeriodeElementaire()
  {
    return OutilPeriodeElementaire.getInstance();
  }
  
  protected boolean calculerQuantiteTravailPourPeriodeElementaire(IndividuSpec individu, Chronologie chronoPourAffiliationBase, PeriodeElementaireAffiliation periodeElementaire, Damj dateCalcul, Collection<?> collectionAlertesNonBloquantes, Damj dateExamen, Convertisseur convertisseurUniteAffiliation)
    throws CoucheLogiqueException
  {
    boolean presenceActiviteSurPeriode = false;
    
    Iterator<?> itAffiliationBase = chronoPourAffiliationBase.iterer();
    while (itAffiliationBase.hasNext())
    {
      ActiviteSalarie activite = (ActiviteSalarie)itAffiliationBase.next();
      if (activite.chevauche(periodeElementaire.getMois()))
      {
        periodeElementaireCalculQuantiteTravail(individu, periodeElementaire, activite, dateCalcul, collectionAlertesNonBloquantes, dateExamen, convertisseurUniteAffiliation);
        presenceActiviteSurPeriode = true;
      }
    }
    return presenceActiviteSurPeriode;
  }
  
  protected void applicationPlafondSpecifique(ParametresAffiliationSpec parametresAffiliation, PeriodeElementaireAffiliation periodeElementaire) {}
  
  protected void periodeElementaireCalculQuantiteTravail(IndividuSpec individu, PeriodeElementaireAffiliation periodeElementaire, ActiviteSalarie activite, Damj dateCalcul, Collection<?> collectionAlertesNonBloquantes, Damj dateExamen, Convertisseur convertisseurUniteAffiliation)
    throws CoucheLogiqueException
  {
    recupereOutilPeriodeElementaire().calculerQuantiteTravail(individu, periodeElementaire, activite, dateCalcul, collectionAlertesNonBloquantes, dateExamen);
  }
  
  private void verifierComportement(ComportementAffiliationSpec comportement)
    throws CoucheLogiqueException
  {
    if (comportement == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_AFFILIATION_ABSENT");
    }
    if (comportement.getPeriodeRecherche() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_PERIODE_ABSENTE");
    }
  }
}

/* Location:
 * Qualified Name:     CalculAffiliationBase
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */