package fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.CalculAffiliationBaseSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.CalculAffiliationSupplementaireSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.CalculAssimilationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ConstructionChronologieSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.JustifierAffiliationSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;
import java.util.Map;

public class CalculAppartenance
  implements OutilFonctionnel
{
  public static final Unite UNITE_HEURE = Unite.getParCode("18");
  public static final Quantite ZERO = new Quantite(new BigDecimal(0), UNITE_HEURE);
  private static final int ARRONDI = 0;
  
  public static Quantite calculerQuantiteAffiliation(IndividuSpec p_individu, ComportementAffiliationSpec p_comportementCalcul, JustificationAffiliation p_justification, Collection p_collectionAlertesNonBloquantes)
    throws CoucheLogiqueException
  {
    verifierComportement(p_comportementCalcul);
    
    Quantite quantiteAffiBase = null;
    Quantite quantiteAffiSuppl = null;
    Quantite quantiteAssim = null;
    Quantite total = ZERO;
    
    Map chronologies = p_comportementCalcul.getOutilConstructionChronologie().determinerChronologies(p_individu, p_comportementCalcul);
    
    determinerPeriodesAffiliationPourAlimentationBasePivot(p_comportementCalcul.getDemande(), chronologies);
    if (p_comportementCalcul.isCalculAffiliationDeBase())
    {
      quantiteAffiBase = p_comportementCalcul.getOutilCalculAffiliationBase().determinerAffiliationDeBase(p_individu, chronologies, p_comportementCalcul, p_justification, p_collectionAlertesNonBloquantes);
      
      total = total.ajouter(quantiteAffiBase);
    }
    quantiteAffiSuppl = p_comportementCalcul.getOutilCalculAffiliationSupplementaire().determinerAffiliationSupplementaire(p_individu, p_comportementCalcul, p_justification, chronologies);
    
    total = total.ajouter(quantiteAffiSuppl);
    
    quantiteAssim = p_comportementCalcul.getOutilCalculAssimilation().determinerAssimilation(p_individu, p_comportementCalcul, p_justification, chronologies, p_collectionAlertesNonBloquantes);
    
    total = total.ajouter(quantiteAssim);
    
    p_comportementCalcul.getOutilJustifierAffiliation().justifierAffiliations(p_comportementCalcul, p_justification, chronologies);
    
    total = new Quantite(Mathematiques.arrondiASup(total.getValeur(), 0), UNITE_HEURE);
    return total;
  }
  
  private static void verifierComportement(ComportementAffiliationSpec p_comportement)
    throws CoucheLogiqueException
  {
    if (p_comportement == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_AFFILIATION_ABSENT");
    }
    if (p_comportement.getChronologieActivitesParticipantes() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_PERIODE_ABSENTE");
    }
  }
  
  public static void determinerPeriodesAffiliationPourAlimentationBasePivot(DemandeSpec p_demande, Map p_chronologies)
  {
    if (p_demande != null)
    {
      Chronologie listePeriodesAffiliation = new ChronologiePeriodes();
      Iterator iter;
      if (p_chronologies != null) {
        for (iter = p_chronologies.values().iterator(); iter.hasNext();)
        {
          Chronologie chronologie = (Chronologie)iter.next();
          listePeriodesAffiliation.ajouter(chronologie);
        }
      }
      ((Demande)p_demande).setPeriodesAffiliation(listePeriodesAffiliation);
    }
  }
}

/* Location:
 * Qualified Name:     CalculAppartenance
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */