package fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.liquidation.pnds.OutilDeterminationPNDS;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.CalculAssimilationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.JustifierAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ParametresAffiliationSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeEvenementPersonnel;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeEvenementPersonnelIndemnisable;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeFormationAssimilable;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.pnds.PeriodeNonDeclareeSanction;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class CalculAssimilation
  implements CalculAssimilationSpec
{
  protected static final Unite UNITE_HEURE = CalculAppartenance.UNITE_HEURE;
  protected static final Quantite ZERO = CalculAppartenance.ZERO;
  
  public Quantite determinerAssimilation(IndividuSpec individu, ComportementAffiliationSpec comportementCalcul, JustificationAffiliation justification, Map chronologies, Collection collectionAlertesNonBloquantes)
    throws CoucheLogiqueException
  {
    Quantite quantiteTotalAssimilation = ZERO;
    Quantite quantiteAssimilationEnseignement = ZERO;
    Quantite quantiteAssimilationFormation = ZERO;
    Quantite quantiteAssimilationMaterniteAdoptionAccidentTravail = ZERO;
    Quantite quantiteAssimilationMaladie = ZERO;
    if (comportementCalcul.isCalculAffiliationAssimilableEnseignement())
    {
      verifierComportementEnseignement(comportementCalcul);
      if (comportementCalcul.estEnseignementApplicablePourReglement(comportementCalcul.getReglementCandidat())) {
        quantiteAssimilationEnseignement = calculerAssimilationEnseignement(individu, comportementCalcul, justification, chronologies, collectionAlertesNonBloquantes);
      }
    }
    if (comportementCalcul.isCalculAffiliationAssimilableFormation())
    {
      verifierComportementFormation(comportementCalcul);
      
      quantiteAssimilationFormation = calculerAssimilationFormation(comportementCalcul, justification, chronologies, quantiteAssimilationEnseignement);
    }
    if (comportementCalcul.isCalculAffiliationAssimilableMaterniteAdoptionAccidentTravail())
    {
      verifierComportementMaterniteAdoptionAccidentTravail(comportementCalcul);
      
      quantiteAssimilationMaterniteAdoptionAccidentTravail = calculerAssimilationMaterniteAdoptionAccidentTravail(comportementCalcul, justification, chronologies);
    }
    if (comportementCalcul.isCalculAffiliationAssimilableMaladie()) {
      quantiteAssimilationMaladie = calculerMaladieSurChevauchementAffiliationA(comportementCalcul, justification, chronologies);
    }
    if (quantiteAssimilationEnseignement != null) {
      quantiteTotalAssimilation = quantiteTotalAssimilation.ajouter(quantiteAssimilationEnseignement);
    }
    if (quantiteAssimilationFormation != null) {
      quantiteTotalAssimilation = quantiteTotalAssimilation.ajouter(quantiteAssimilationFormation);
    }
    if (quantiteAssimilationMaterniteAdoptionAccidentTravail != null) {
      quantiteTotalAssimilation = quantiteTotalAssimilation.ajouter(quantiteAssimilationMaterniteAdoptionAccidentTravail);
    }
    if (quantiteAssimilationMaladie != null) {
      quantiteTotalAssimilation = quantiteTotalAssimilation.ajouter(quantiteAssimilationMaladie);
    }
    return quantiteTotalAssimilation;
  }
  
  private Quantite calculerAssimilationEnseignement(IndividuSpec individu, ComportementAffiliationSpec comportementCalcul, JustificationAffiliation justification, Map chronologies, Collection collectionAlertesNonBloquantes)
    throws CoucheLogiqueException
  {
    ParametresAffiliationSpec parametresAffiliation = comportementCalcul.getOutilParametreAffiliation();
    JustifierAffiliationSpec justifierAffiliation = comportementCalcul.getOutilJustifierAffiliation();
    
    Chronologie chronoPourAssimilationEnseignant = (Chronologie)chronologies.get("chronoAffiEnseignement");
    
    Quantite quantiteTotalHeureEnseignement = ZERO;
    
    Iterator<?> itAssimilationEnseignant = chronoPourAssimilationEnseignant.iterer();
    while (itAssimilationEnseignant.hasNext())
    {
      ActiviteSalarie enseignement = (ActiviteSalarie)itAssimilationEnseignant.next();
      if (comportementCalcul.estActiviteAPrendreEnComptePourEnseignement(enseignement))
      {
        PeriodeNonDeclareeSanction pnds = determinerPNDS(individu, enseignement, comportementCalcul.getFaitGenerateur().getDateFin(), comportementCalcul.getDateExamen());
        if ((pnds != null) && (pnds.getChronoPeriodePNDS() != null) && (!pnds.getChronoPeriodePNDS().estVide()))
        {
          OutilPeriodeAffiliation.alimenterCollectionAlertesPNDS(pnds.getChronoPeriodePNDS(), collectionAlertesNonBloquantes);
          enseignement.setPresencePNDSDetectee(true);
        }
        Chronologie chronoMesureActivites = trouverListePeriodeMesureActivite(enseignement);
        Iterator<?> itChronoMesureActivite = chronoMesureActivites.iterer();
        while (itChronoMesureActivite.hasNext())
        {
          PeriodeMesureActivite pma = (PeriodeMesureActivite)itChronoMesureActivite.next();
          Quantite quantiteHeureSurPeriode = determinerQuantiteTravailDansPeriode(pma, comportementCalcul.getPeriodeRecherche(), pnds, comportementCalcul.getConvertisseurUniteAffiliation());
          
          quantiteTotalHeureEnseignement = quantiteTotalHeureEnseignement.ajouter(quantiteHeureSurPeriode);
        }
      }
    }
    Quantite plafondHeuresEnseignement = parametresAffiliation.determinerPlafondHeureEnseignement(individu, comportementCalcul);
    
    Quantite quantiteEnseignementARetenir = plafondHeuresEnseignement.min(quantiteTotalHeureEnseignement);
    
    justifierAffiliation.ajouterAssimilation(justification, 7, quantiteEnseignementARetenir);
    
    return quantiteEnseignementARetenir;
  }
  
  private static PeriodeNonDeclareeSanction determinerPNDS(IndividuSpec individu, ActiviteSalarie activite, Damj dateCalcul, Damj dateEtudeMax)
    throws CoucheLogiqueException
  {
    try
    {
      PeriodeNonDeclareeSanction periodesNonDeclareeSanction = null;
      if ((dateEtudeMax.estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("Activation des nouvelles sanctions pour les PND Spectacle en 17SI2"))) || (dateEtudeMax.estAvant(GestionnaireDateApplication.getInstance().recupererDateApplication("Réactivation de la détermination des PNDS")))) {
        if (activite.estPndsSpectacleCharge())
        {
          periodesNonDeclareeSanction = activite.getPndsSpectacle();
        }
        else
        {
          periodesNonDeclareeSanction = OutilDeterminationPNDS.determinerPNDS(individu, activite, activite.getDateDebut(), activite.getDateFin(), dateCalcul, dateEtudeMax);
          
          activite.setPndsSpectacleCharge(true);
          activite.setPndsSpectacle(periodesNonDeclareeSanction);
        }
      }
      return periodesNonDeclareeSanction;
    }
    catch (ApplicativeException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle(), ex);
    }
  }
  
  private Quantite calculerAssimilationFormation(ComportementAffiliationSpec comportementCalcul, JustificationAffiliation justification, Map chronologies, Quantite quantiteARetenirEnseignement)
  {
    ParametresAffiliationSpec parametresAffiliation = comportementCalcul.getOutilParametreAffiliation();
    JustifierAffiliationSpec justifierAffiliation = comportementCalcul.getOutilJustifierAffiliation();
    
    Chronologie chronoPourAssimilationFormation = (Chronologie)chronologies.get("chronoAffiFormation");
    
    Quantite quantiteTotalHeureFormation = ZERO;
    
    Iterator<?> itChronoFormation = chronoPourAssimilationFormation.iterer();
    while (itChronoFormation.hasNext())
    {
      PeriodeFormationAssimilable formation = (PeriodeFormationAssimilable)itChronoFormation.next();
      Enumeration<?> enumQuantiteAppartenance = formation.getListeQuantitesAppartenance().elements();
      while (enumQuantiteAppartenance.hasMoreElements())
      {
        Quantite quantite = (Quantite)enumQuantiteAppartenance.nextElement();
        Quantite quantiteHeureARetenir = determinerQuantiteHeureSurPeriode(formation.getPeriode(), quantite, comportementCalcul.getPeriodeRecherche(), null, comportementCalcul.getConvertisseurUniteAffiliation());
        
        quantiteTotalHeureFormation = quantiteTotalHeureFormation.ajouter(quantiteHeureARetenir);
      }
    }
    Quantite plafondFormation = parametresAffiliation.determinerPlafondHeureFormation(comportementCalcul, quantiteARetenirEnseignement);
    
    Quantite quantiteFormationARetenir = plafondFormation.min(quantiteTotalHeureFormation);
    
    justifierAffiliation.ajouterAssimilation(justification, 6, quantiteFormationARetenir);
    
    return quantiteFormationARetenir;
  }
  
  protected Quantite calculerAssimilationMaterniteAdoptionAccidentTravail(ComportementAffiliationSpec comportementCalcul, JustificationAffiliation justification, Map chronologies)
  {
    Chronologie chronoPourAssimilationMaterniteAdoptionAccidentTravail = (Chronologie)chronologies.get("chronoAffiMaterAdoptionAccTravail");
    
    Quantite quantiteTotalHeure = ZERO;
    if ((chronoPourAssimilationMaterniteAdoptionAccidentTravail != null) && (!chronoPourAssimilationMaterniteAdoptionAccidentTravail.estVide()))
    {
      ParametresAffiliationSpec parametresAffiliation = comportementCalcul.getOutilParametreAffiliation();
      JustifierAffiliationSpec justifierAffiliation = comportementCalcul.getOutilJustifierAffiliation();
      
      Chronologie chronoActivitesAffiliationBase = (Chronologie)chronologies.get("chronoAffiBase");
      ChronologiePeriodes chronoActiviteBaseSansChevauchement;
      if (!chronoActivitesAffiliationBase.estVide())
      {
        ChronologiePeriodes chronoActiviteBaseSansChevauchement = OutilPeriodeAffiliation.construireChronologiePeriode(chronoActivitesAffiliationBase);
        
        chronoActiviteBaseSansChevauchement.fusionnerChevauchementPeriodes();
      }
      else
      {
        chronoActiviteBaseSansChevauchement = new ChronologiePeriodes();
      }
      Iterator<?> itChronoAssimilation = chronoPourAssimilationMaterniteAdoptionAccidentTravail.iterer();
      while (itChronoAssimilation.hasNext())
      {
        PeriodeEvenementPersonnel pep = (PeriodeEvenementPersonnel)itChronoAssimilation.next();
        
        List<Periode> listePeriodesSansChevauchement = determinerListePeriodesSansChevauchement(chronoActiviteBaseSansChevauchement, pep);
        
        int nombreTotalJoursSansChevauchement = OutilPeriodeAffiliation.determinerNombreJoursChronoApresFusionPeriode(listePeriodesSansChevauchement, comportementCalcul.getPeriodeRecherche());
        
        ajouterJourInactivite(justification, pep, nombreTotalJoursSansChevauchement);
        
        Quantite quantiteAssimiationPourPep = parametresAffiliation.calculerQuantiteHeureMaterniteAdoptionAccidentTravail(nombreTotalJoursSansChevauchement);
        
        int nature = NatureAffiliation.determinerNatureActivite(pep);
        justifierAffiliation.ajouterAssimilation(justification, nature, quantiteAssimiationPourPep);
        
        quantiteTotalHeure = quantiteTotalHeure.ajouter(quantiteAssimiationPourPep);
      }
    }
    return quantiteTotalHeure;
  }
  
  protected void ajouterJourInactivite(JustificationAffiliation justification, PeriodeEvenementPersonnel pep, int nombreTotalJoursSansChevauchement)
  {
    if (justification != null)
    {
      List<Integer> listeNatureAdoptionMaternite = new ArrayList();
      listeNatureAdoptionMaternite.add(Integer.valueOf(25));
      listeNatureAdoptionMaternite.add(Integer.valueOf(26));
      List<Integer> listeNatureMaladies = new ArrayList();
      listeNatureMaladies.add(Integer.valueOf(21));
      listeNatureMaladies.add(Integer.valueOf(22));
      if ((listeNatureAdoptionMaternite.contains(Integer.valueOf(pep.getNature()))) || ((listeNatureMaladies.contains(Integer.valueOf(pep.getNature()))) && (((PeriodeEvenementPersonnelIndemnisable)pep).isMaladieGrave()))) {
        justification.setNombreJourAssimilationSalaire(justification.getNombreJourAssimilationSalaire() + nombreTotalJoursSansChevauchement);
      }
    }
  }
  
  protected List<Periode> determinerListePeriodesSansChevauchement(ChronologiePeriodes chronoActiviteBaseSansChevauchement, PeriodeEvenementPersonnel pep)
  {
    return OutilPeriodeAffiliation.determinerListePeriodesSansChevauchementPourChronoSansChevauchement(chronoActiviteBaseSansChevauchement, pep.getPeriode());
  }
  
  private Quantite calculerMaladieSurChevauchementAffiliationA(ComportementAffiliationSpec comportementCalcul, JustificationAffiliation justification, Map chronologies)
  {
    Chronologie chronoMaladieDansPRA = (Chronologie)chronologies.get("chronoMaladieDansPRA");
    
    Chronologie chronoActivitesAffiliationBase = (Chronologie)chronologies.get("chronoAffiBase");
    
    Quantite quantiteTotalHeure = ZERO;
    if ((chronoMaladieDansPRA != null) && (!chronoMaladieDansPRA.estVide()) && (chronoActivitesAffiliationBase != null) && (!chronoActivitesAffiliationBase.estVide()))
    {
      ParametresAffiliationSpec parametresAffiliation = comportementCalcul.getOutilParametreAffiliation();
      JustifierAffiliationSpec justifierAffiliation = comportementCalcul.getOutilJustifierAffiliation();
      
      Chronologie chronoActiviteBaseSansChevauchement = OutilPeriodeAffiliation.construireChronologiePeriode(chronoActivitesAffiliationBase).fusionnerChevauchementPeriodes();
      
      Chronologie chronoMaladieDansPRASansChevauchement = OutilPeriodeAffiliation.construireChronologiePeriode(chronoMaladieDansPRA).fusionnerChevauchementPeriodes();
      
      List<Periode> listePeriodesAvecChevauchement = OutilPeriodeAffiliation.determinerPeriodesAvecChevauchement(chronoMaladieDansPRASansChevauchement, chronoActiviteBaseSansChevauchement);
      for (int i = 0; i < listePeriodesAvecChevauchement.size(); i++)
      {
        Periode periodeCourante = (Periode)listePeriodesAvecChevauchement.get(i);
        
        Periode periodeAffiliationSupplementaireDansPRA = periodeCourante.periodeIntersection(comportementCalcul.getPeriodeRecherche());
        if (periodeAffiliationSupplementaireDansPRA != null)
        {
          int nombreJoursARetenir = periodeAffiliationSupplementaireDansPRA.getDuree();
          
          Quantite quantiteAssimilation = parametresAffiliation.calculerQuantiteHeureSuspension(nombreJoursARetenir);
          
          quantiteTotalHeure = quantiteTotalHeure.ajouter(quantiteAssimilation);
          
          justifierAffiliation.ajouterAssimilation(justification, 10, quantiteAssimilation);
        }
      }
    }
    return quantiteTotalHeure;
  }
  
  private Quantite determinerQuantiteTravailDansPeriode(PeriodeMesureActivite pma, Periode periodeRecherche, PeriodeNonDeclareeSanction pnds, Convertisseur convertisseurUniteAffiliation)
  {
    Enumeration<?> enumQuantitePma = pma.getListeQuantitesAffiliation().elements();
    Quantite totalHeure = ZERO;
    if (pma.getPeriode().chevauche(periodeRecherche)) {
      while (enumQuantitePma.hasMoreElements())
      {
        Quantite quantite = (Quantite)enumQuantitePma.nextElement();
        if (quantite.getUnite().equals(UNITE_HEURE))
        {
          Quantite quantiteHeureARetenir = determinerQuantiteHeureSurPeriode(pma.getPeriode(), quantite, periodeRecherche, pnds, convertisseurUniteAffiliation);
          
          totalHeure = totalHeure.ajouter(quantiteHeureARetenir);
        }
      }
    }
    return totalHeure;
  }
  
  private Quantite determinerQuantiteHeureSurPeriode(Periode periodeTravail, Quantite quantite, Periode periodeReference, PeriodeNonDeclareeSanction pnds, Convertisseur convertisseurUniteAffiliation)
  {
    Quantite quantiteEnHeure;
    Quantite quantiteEnHeure;
    if (!quantite.getUnite().equals(UNITE_HEURE)) {
      quantiteEnHeure = convertir(convertisseurUniteAffiliation, quantite, UNITE_HEURE);
    } else {
      quantiteEnHeure = quantite;
    }
    Periode intersectionPMAAvecPeriodeElementaire = periodeTravail.periodeIntersection(periodeReference);
    
    int nombreJoursTravailTotalDansMois = intersectionPMAAvecPeriodeElementaire.getDuree();
    
    int nombreJoursHorsPNDS = nombreJoursTravailTotalDansMois;
    if (pnds != null) {
      nombreJoursHorsPNDS -= intersectionPMAAvecPeriodeElementaire.inter(pnds.getChronoPeriodePNDS());
    }
    BigDecimal quantiteProratisee = ParametresAffiliation.proratiser(periodeTravail.getDuree(), nombreJoursHorsPNDS, quantiteEnHeure.getValeur());
    
    BigDecimal quantiteProratiseeArrondi = Mathematiques.arrondiASup(quantiteProratisee, 0);
    return new Quantite(quantiteProratiseeArrondi, UNITE_HEURE);
  }
  
  private Quantite convertir(Convertisseur convertisseurUniteAffiliation, Quantite quantiteOrigine, Unite unite)
  {
    return convertisseurUniteAffiliation.convertir(quantiteOrigine, unite);
  }
  
  private Chronologie trouverListePeriodeMesureActivite(Temporel temporel)
  {
    if (temporel.estType(ActiviteSalarie.class)) {
      return ((ActiviteSalarie)temporel).getListePeriodesMesureActivite();
    }
    if (temporel.estType(PeriodeActiviteSalarie.class)) {
      return ((PeriodeActiviteSalarie)temporel).getListePeriodesMesureActivite();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\t******** L'activité salariée passée en paramètre n'est pas génée pour le calcul de l'assimilation ********\n" });
    
    return null;
  }
  
  private void verifierComportementEnseignement(ComportementAffiliationSpec comportement)
    throws CoucheLogiqueException
  {
    verifierComportementBase(comportement);
    if (comportement.getReglementCandidat() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_REGLEMENT_CANDIDAT");
    }
    if (comportement.getFaitGenerateur() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_FGD_ABSENT");
    }
  }
  
  private void verifierComportementFormation(ComportementAffiliationSpec comportement)
    throws CoucheLogiqueException
  {
    verifierComportementBase(comportement);
    if (comportement.getQuantiteAffiliationRequise() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_QUANTITE_AFFILIATION");
    }
  }
  
  private void verifierComportementMaterniteAdoptionAccidentTravail(ComportementAffiliationSpec comportement)
    throws CoucheLogiqueException
  {
    verifierComportementBase(comportement);
  }
  
  protected void verifierComportementBase(ComportementAffiliationSpec comportement)
    throws CoucheLogiqueException
  {
    if (comportement == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_AFFILIATION_ABSENT");
    }
    if (comportement.getPeriodeRecherche() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_PERIODE_ABSENTE");
    }
  }
}

/* Location:
 * Qualified Name:     CalculAssimilation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */