package fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ParametresCalculAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ParametresAffiliationSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Iterator;

public class ParametresAffiliation
  implements ParametresAffiliationSpec
{
  protected static final Unite UNITE_HEURE = CalculAppartenance.UNITE_HEURE;
  protected static final Quantite ZERO = CalculAppartenance.ZERO;
  public static final int PREMIER_RANG_ETUDE = 0;
  private static final Damj DATE_PIVOT_QUANTITE_AFFILIATION = new Damj(2008, 4, 1);
  private static final int REGLEMENT_A8 = 8;
  private static final int REGLEMENT_A10 = 10;
  private static final BigDecimal VALEUR_REQUISE_INITIALE = new BigDecimal(507);
  private static final BigDecimal ALLONGEMENT_RANG_1_AVANT_DATE_PIVOT_A8 = new BigDecimal(48);
  private static final BigDecimal ALLONGEMENT_RANG_1_AVANT_DATE_PIVOT_A10 = new BigDecimal(22);
  private static final BigDecimal ALLONGEMENT_RANG_1_APRES_DATE_PIVOT_A8 = new BigDecimal(50);
  private static final BigDecimal ALLONGEMENT_RANG_1_APRES_DATE_PIVOT_A10 = new BigDecimal(24);
  private static final BigDecimal ALLONGEMENT_RANG_N_AVANT_DATE_PIVOT_A8 = new BigDecimal(48);
  private static final BigDecimal ALLONGEMENT_RANG_N_AVANT_DATE_PIVOT_A10 = new BigDecimal(45);
  private static final BigDecimal ALLONGEMENT_RANG_N_APRES_DATE_PIVOT_A8 = new BigDecimal(50);
  private static final BigDecimal ALLONGEMENT_RANG_N_APRES_DATE_PIVOT_A10 = new BigDecimal(48);
  private static final DureeCalendaire DUREE_PERIODE_INITIALE_A8 = new DureeCalendaire(0, 0, 304);
  private static final DureeCalendaire DUREE_PERIODE_INITIALE_A10 = new DureeCalendaire(0, 0, 319);
  private static final DureeCalendaire ALLONGEMENT_RANG_1_PERIODE_REFERENCE_A8 = new DureeCalendaire(0, 0, 31);
  private static final DureeCalendaire ALLONGEMENT_RANG_1_PERIODE_REFERENCE_A10 = new DureeCalendaire(0, 0, 16);
  private static final DureeCalendaire ALLONGEMENT_RANG_N_PERIODE_REFERENCE = new DureeCalendaire(0, 0, 30);
  private static final BigDecimal PLAFOND_HEURE_MENSUEL_SANS_DEROGATION = new BigDecimal(208);
  private static final BigDecimal PLAFOND_HEURE_MENSUEL_AVEC_DEROGATION = new BigDecimal(260);
  private static final BigDecimal PLAFOND_CACHET_MENSUEL = new BigDecimal(28);
  public static final BigDecimal NOMBRE_HEURE_PAR_JOUR_SUSPENSION = new BigDecimal(5);
  public static final BigDecimal NOMBRE_HEURE_PAR_JOUR_NON_EXECUTION = new BigDecimal(5);
  public static final BigDecimal NOMBRE_HEURE_PAR_JOUR_MATERNITE_ADOPTION_ACCIDENT_TRAVAIL = new BigDecimal(5);
  public static final DureeCalendaire AGE_PIVOT_PLAFOND_ENSEIGNEMENT = new DureeCalendaire(50);
  public static final Quantite PLAFOND_HEURE_ENSEIGNEMENT_AVANT_50_ANS = new Quantite(new BigDecimal(55), UNITE_HEURE);
  public static final Quantite PLAFOND_HEURE_ENSEIGNEMENT_APRES_50_ANS = new Quantite(new BigDecimal(90), UNITE_HEURE);
  private static final int DIVISEUR_PLAFOND_FORMATION = 3;
  private static final int DIVIDENDE_PLAFOND_FORMATION = 2;
  public static final BigDecimal FACTEUR_MULTIPLICATION_PLAFOND_FORMATION = new BigDecimal(0.6666666666666666D);
  
  public static BigDecimal proratiser(int nombreJoursTotal, int nombreJoursInclus, BigDecimal valeur)
  {
    return Mathematiques.proratiser(new BigDecimal(nombreJoursInclus), valeur, new BigDecimal(nombreJoursTotal));
  }
  
  public BigDecimal determinerQuantiteAffiliationRequise(ParametresCalculAffiliation parametres)
  {
    if (parametres.getRangEtude() == 0) {
      return determinerQuantiteRequiseInitialPourReglement(parametres);
    }
    ParametresCalculAffiliation parametreEtudeRangPrecedent = parametres.copie();
    parametreEtudeRangPrecedent.passerAuRangEtudePrecedent();
    
    BigDecimal valeurAuRangPrecedent = determinerQuantiteAffiliationRequise(parametreEtudeRangPrecedent);
    
    BigDecimal valeurAllongementAuRangCourant = determinerAllongementQuantiteRequisePourRangSelonReglement(parametres);
    
    return valeurAuRangPrecedent.add(valeurAllongementAuRangCourant);
  }
  
  public DureeCalendaire determinerDureePeriodeReference(ParametresCalculAffiliation parametres)
  {
    if (parametres.getRangEtude() == 0) {
      return determinerDureePeriodeReferenceInitialPourReglement(parametres);
    }
    ParametresCalculAffiliation parametreEtudeRangPrecedent = parametres.copie();
    parametreEtudeRangPrecedent.passerAuRangEtudePrecedent();
    
    DureeCalendaire valeurAuRangPrecedent = determinerDureePeriodeReference(parametreEtudeRangPrecedent);
    
    DureeCalendaire valeurAllongementAuRangCourant = determinerAllongementDureePeriodeReferencePourRangSelonReglement(parametres);
    
    return valeurAuRangPrecedent.ajouter(valeurAllongementAuRangCourant);
  }
  
  public BigDecimal determinerPlafondHeureApplicable(PeriodeElementaireAffiliation pPeriodeElementaire, Chronologie chronoActivitesParticipantes)
  {
    Iterator it = chronoActivitesParticipantes.iterer();
    BigDecimal baseCalculPlafond = PLAFOND_HEURE_MENSUEL_SANS_DEROGATION;
    boolean derogationTrouvee = false;
    while ((it.hasNext()) && (!derogationTrouvee))
    {
      ActiviteSalarie activite = (ActiviteSalarie)it.next();
      if ((activite.chevauche(pPeriodeElementaire.getMois())) && (activite.isDerogationPlafondMensuel()))
      {
        baseCalculPlafond = PLAFOND_HEURE_MENSUEL_AVEC_DEROGATION;
        derogationTrouvee = true;
      }
    }
    Periode periodeElementaire = pPeriodeElementaire.getMois();
    Periode moisCivil = determinerMoisCivilSelonPeriodeElementaire(pPeriodeElementaire);
    if (pPeriodeElementaire.getMois().equals(moisCivil)) {
      return baseCalculPlafond;
    }
    BigDecimal valeurProratiseeSansArrondi = proratiser(moisCivil.getDuree(), periodeElementaire.inter(moisCivil), baseCalculPlafond);
    return arrondirEntierSuperieur(valeurProratiseeSansArrondi);
  }
  
  public BigDecimal determinerPlafondCachetSurPeriodeElementaire(PeriodeElementaireAffiliation pPeriodeElementaire)
  {
    BigDecimal baseCalculPlafond = PLAFOND_CACHET_MENSUEL;
    
    Periode periodeElementaire = pPeriodeElementaire.getMois();
    Periode moisCivil = determinerMoisCivilSelonPeriodeElementaire(pPeriodeElementaire);
    if (pPeriodeElementaire.getMois().equals(moisCivil)) {
      return baseCalculPlafond;
    }
    BigDecimal valeurProratiseeSansArrondi = proratiser(moisCivil.getDuree(), periodeElementaire.inter(moisCivil), baseCalculPlafond);
    return arrondirEntierSuperieur(valeurProratiseeSansArrondi);
  }
  
  public Quantite determinerPlafondHeureEnseignement(IndividuSpec individu, ComportementAffiliationSpec comportementCalcul)
  {
    DureeCalendaire ageIndividuAuFGD = individu.getAgeALaDate(comportementCalcul.getFaitGenerateur().getDateFin());
    if (ageIndividuAuFGD.getAnnees() < AGE_PIVOT_PLAFOND_ENSEIGNEMENT.getAnnees()) {
      return PLAFOND_HEURE_ENSEIGNEMENT_AVANT_50_ANS;
    }
    return PLAFOND_HEURE_ENSEIGNEMENT_APRES_50_ANS;
  }
  
  public Quantite determinerPlafondHeureFormation(ComportementAffiliationSpec comportementCalcul, Quantite quantiteARetenirEnseignement)
  {
    BigDecimal quantiteAssimilationTheoriqueFormation = comportementCalcul.getQuantiteAffiliationRequise().getValeur().multiply(FACTEUR_MULTIPLICATION_PLAFOND_FORMATION);
    
    BigDecimal quantiteAssimilationTheoriqueFormationArrondi = arrondirEntierSuperieur(quantiteAssimilationTheoriqueFormation);
    
    BigDecimal plafond = quantiteAssimilationTheoriqueFormationArrondi.subtract(quantiteARetenirEnseignement.getValeur());
    
    plafond = plafond.max(ZERO.getValeur());
    return new Quantite(plafond, UNITE_HEURE);
  }
  
  public Quantite calculerQuantiteHeureMaterniteAdoptionAccidentTravail(int nombreJours)
  {
    return multiplierPourQuantiteHeure(NOMBRE_HEURE_PAR_JOUR_MATERNITE_ADOPTION_ACCIDENT_TRAVAIL, nombreJours);
  }
  
  public Quantite calculerQuantiteHeureSuspension(int nombreJours)
  {
    return multiplierPourQuantiteHeure(NOMBRE_HEURE_PAR_JOUR_SUSPENSION, nombreJours);
  }
  
  public Quantite calculerQuantiteHeureNonExecution(int nombreJours)
  {
    return multiplierPourQuantiteHeure(NOMBRE_HEURE_PAR_JOUR_NON_EXECUTION, nombreJours);
  }
  
  protected Quantite multiplierPourQuantiteHeure(BigDecimal valeur1, int valeur2)
  {
    BigDecimal quantite = valeur1.multiply(new BigDecimal(valeur2));
    return new Quantite(quantite, UNITE_HEURE);
  }
  
  protected BigDecimal arrondirEntierSuperieur(BigDecimal valeur)
  {
    BigDecimal valeurArrondi = Mathematiques.tronque(valeur, 0);
    if (valeurArrondi.doubleValue() == valeur.doubleValue()) {
      return valeurArrondi;
    }
    return valeurArrondi.add(BigDecimal.ONE);
  }
  
  protected BigDecimal determinerQuantiteRequiseInitialPourReglement(ParametresCalculAffiliation parametres)
  {
    if (parametres.getRangEtude() == 0) {
      return VALEUR_REQUISE_INITIALE;
    }
    return null;
  }
  
  protected DureeCalendaire determinerDureePeriodeReferenceInitialPourReglement(ParametresCalculAffiliation parametres)
  {
    int reglementEtudie = determinerReglement(parametres);
    switch (reglementEtudie)
    {
    case 8: 
      return DUREE_PERIODE_INITIALE_A8;
    case 10: 
      return DUREE_PERIODE_INITIALE_A10;
    }
    return null;
  }
  
  protected BigDecimal determinerAllongementQuantiteRequisePourRangSelonReglement(ParametresCalculAffiliation parametres)
  {
    Damj faitGenerateurDroit = determinerFaitGenerateurDroit(parametres);
    int reglementEtudie = determinerReglement(parametres);
    if (parametres.getRangEtude() == 1)
    {
      if (faitGenerateurDroit.estAvant(DATE_PIVOT_QUANTITE_AFFILIATION)) {
        switch (reglementEtudie)
        {
        case 8: 
          return ALLONGEMENT_RANG_1_AVANT_DATE_PIVOT_A8;
        case 10: 
          return ALLONGEMENT_RANG_1_AVANT_DATE_PIVOT_A10;
        }
      } else {
        switch (reglementEtudie)
        {
        case 8: 
          return ALLONGEMENT_RANG_1_APRES_DATE_PIVOT_A8;
        case 10: 
          return ALLONGEMENT_RANG_1_APRES_DATE_PIVOT_A10;
        }
      }
    }
    else if (faitGenerateurDroit.estAvant(DATE_PIVOT_QUANTITE_AFFILIATION)) {
      switch (reglementEtudie)
      {
      case 8: 
        return ALLONGEMENT_RANG_N_AVANT_DATE_PIVOT_A8;
      case 10: 
        return ALLONGEMENT_RANG_N_AVANT_DATE_PIVOT_A10;
      }
    } else {
      switch (reglementEtudie)
      {
      case 8: 
        return ALLONGEMENT_RANG_N_APRES_DATE_PIVOT_A8;
      case 10: 
        return ALLONGEMENT_RANG_N_APRES_DATE_PIVOT_A10;
      }
    }
    return null;
  }
  
  protected DureeCalendaire determinerAllongementDureePeriodeReferencePourRangSelonReglement(ParametresCalculAffiliation parametres)
  {
    int reglementEtudie = determinerReglement(parametres);
    if (parametres.getRangEtude() == 1) {
      switch (reglementEtudie)
      {
      case 8: 
        return ALLONGEMENT_RANG_1_PERIODE_REFERENCE_A8;
      case 10: 
        return ALLONGEMENT_RANG_1_PERIODE_REFERENCE_A10;
      }
    } else {
      return ALLONGEMENT_RANG_N_PERIODE_REFERENCE;
    }
    return null;
  }
  
  protected Damj determinerFaitGenerateurDroit(ParametresCalculAffiliation parametres)
  {
    return parametres.getFaitGenerateurDroit().getDateFin();
  }
  
  protected int determinerReglement(ParametresCalculAffiliation parametres)
  {
    if (parametres.getReglementEtudie().getLibelleCourt().equals("A8")) {
      return 8;
    }
    if (parametres.getReglementEtudie().getLibelleCourt().equals("A10")) {
      return 10;
    }
    return 0;
  }
  
  private Periode determinerMoisCivilSelonPeriodeElementaire(PeriodeElementaireAffiliation periodeElementaire)
  {
    return new Periode(periodeElementaire.getMois().getDebut().getDebutMois(), periodeElementaire.getMois().getFin().getFinMois());
  }
  
  public void determinerPlafondMonoEmployeur(PeriodeElementaireAffiliation periodeElementaire) {}
}

/* Location:
 * Qualified Name:     ParametresAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */