package fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.CalculAffiliationBase;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.CalculAffiliationSupplementaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.CalculAssimilation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.ConstructionChronologie;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.JustifierAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.ParametresAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.CalculAffiliationBaseSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.CalculAffiliationSupplementaireSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.CalculAssimilationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ConstructionChronologieSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.JustifierAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ParametresAffiliationSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.util.List;

public class ComportementCalculAffiliation
  implements ComportementAffiliationSpec
{
  private boolean calculAffiliationDeBase;
  private boolean calculAffiliationSupplementaireSuspension;
  private boolean calculAffiliationSupplementaireNonExecution;
  private boolean calculAffiliationAssimilableEnseignement;
  private boolean calculAffiliationAssimilableFormation;
  private boolean calculAffiliationAssimilableMaterniteAdoptionAccidentTravail;
  private boolean calculAffiliationAssimilableMaladie;
  private boolean calculAffiliationSupplementaireMaterniteAdoptionAccidentTravail;
  private boolean calculAffiliationSupplementaireMaladieGrave;
  private boolean calculAffiliationSupplementaireMaladieLongueDuree;
  private boolean justifierPeriodesSansAffiliation;
  private Quantite quantiteAffiliationRequise;
  private Periode periodeRecherche;
  private ObjetChronoPeriode faitGenerateur;
  private Reglement reglementCandidat;
  private List<Reglement> listeReglementPrisEnCompte;
  private Chronologie chronologieActivitesParticipantes;
  private Damj dateExamen;
  private Convertisseur convertisseurUniteAffiliation;
  private CalculAffiliationBaseSpec outilCalculAffiliationBase;
  private CalculAffiliationSupplementaireSpec outilCalculAffiliationSupplementaire;
  private CalculAssimilationSpec outilCalculAssimilation;
  private ConstructionChronologieSpec outilConstructionChronologie;
  private JustifierAffiliationSpec outilJustifierAffiliation;
  private ParametresAffiliationSpec outilParametreAffiliation;
  private Demande demande;
  private boolean primo;
  
  public static ComportementCalculAffiliation creerInstance()
  {
    return new ComportementCalculAffiliation();
  }
  
  public ComportementCalculAffiliation()
  {
    setOutilCalculAffiliationBase(new CalculAffiliationBase());
    setOutilCalculAffiliationSupplementaire(new CalculAffiliationSupplementaire());
    setOutilCalculAssimilation(new CalculAssimilation());
    setOutilConstructionChronologie(new ConstructionChronologie());
    setOutilJustifierAffiliation(new JustifierAffiliation());
    setOutilParametreAffiliation(new ParametresAffiliation());
  }
  
  public void setCalculTouteAffiliation(boolean calculTouteAffiliation)
  {
    setCalculAffiliationDeBase(calculTouteAffiliation);
    setCalculAffiliationAssimilable(calculTouteAffiliation);
    setCalculAffiliationSupplementaire(calculTouteAffiliation);
  }
  
  public void setCalculAffiliationAssimilable(boolean calculAffiliationAssimilable)
  {
    setCalculAffiliationAssimilableEnseignement(calculAffiliationAssimilable);
    setCalculAffiliationAssimilableFormation(calculAffiliationAssimilable);
    setCalculAffiliationAssimilableMaterniteAdoptionAccidentTravail(calculAffiliationAssimilable);
    setCalculAffiliationAssimilableMaladie(calculAffiliationAssimilable);
  }
  
  public void setCalculAffiliationSupplementaire(boolean calculAffiliationSupplementaire)
  {
    setCalculAffiliationSupplementaireNonExecution(calculAffiliationSupplementaire);
    setCalculAffiliationSupplementaireSuspension(calculAffiliationSupplementaire);
    setCalculAffiliationSupplementaireMaterniteAdoptionAccidentTravail(calculAffiliationSupplementaire);
    setCalculAffiliationSupplementaireMaladieLongueDuree(calculAffiliationSupplementaire);
    setCalculAffiliationSupplementaireMaladieGrave(calculAffiliationSupplementaire);
  }
  
  public Damj getDateExamen()
  {
    return dateExamen;
  }
  
  public void setDateExamen(Damj dateExamen)
  {
    this.dateExamen = dateExamen;
  }
  
  public boolean isCalculAffiliationDeBase()
  {
    return calculAffiliationDeBase;
  }
  
  public void setCalculAffiliationDeBase(boolean calculAffiliationDeBase)
  {
    this.calculAffiliationDeBase = calculAffiliationDeBase;
  }
  
  public List<Reglement> getListeReglementPrisEnCompte()
  {
    return listeReglementPrisEnCompte;
  }
  
  public void setListeReglementPrisEnCompte(List listeReglementPrisEnCompte)
  {
    this.listeReglementPrisEnCompte = listeReglementPrisEnCompte;
  }
  
  public Periode getPeriodeRecherche()
  {
    return periodeRecherche;
  }
  
  public void setPeriodeRecherche(Periode periodeRecherche)
  {
    this.periodeRecherche = periodeRecherche;
  }
  
  public void copie(ComportementCalculAffiliation copie)
  {
    copie.setCalculAffiliationAssimilableEnseignement(isCalculAffiliationAssimilableEnseignement());
    copie.setCalculAffiliationAssimilableFormation(isCalculAffiliationAssimilableFormation());
    copie.setCalculAffiliationAssimilableMaterniteAdoptionAccidentTravail(isCalculAffiliationAssimilableMaterniteAdoptionAccidentTravail());
    copie.setCalculAffiliationDeBase(isCalculAffiliationDeBase());
    copie.setCalculAffiliationSupplementaireNonExecution(isCalculAffiliationSupplementaireNonExecution());
    copie.setCalculAffiliationSupplementaireSuspension(isCalculAffiliationSupplementaireSuspension());
    copie.setChronologieActivitesParticipantes(getChronologieActivitesParticipantes());
    copie.setListeReglementPrisEnCompte(getListeReglementPrisEnCompte());
    copie.setPeriodeRecherche(getPeriodeRecherche());
    
    copie.setDateExamen(getDateExamen());
    
    copie.setConvertisseurUniteAffiliation(getConvertisseurUniteAffiliation());
  }
  
  public Chronologie getChronologieActivitesParticipantes()
  {
    return chronologieActivitesParticipantes;
  }
  
  public void setChronologieActivitesParticipantes(Chronologie chronologieActivitesParticipantes)
  {
    this.chronologieActivitesParticipantes = chronologieActivitesParticipantes;
  }
  
  public Reglement getReglementCandidat()
  {
    return reglementCandidat;
  }
  
  public void setReglementCandidat(Reglement reglementCandidat)
  {
    this.reglementCandidat = reglementCandidat;
  }
  
  public Quantite getQuantiteAffiliationRequise()
  {
    return quantiteAffiliationRequise;
  }
  
  public void setQuantiteAffiliationRequise(Quantite quantiteAffiliationRequise)
  {
    this.quantiteAffiliationRequise = quantiteAffiliationRequise;
  }
  
  public ObjetChronoPeriode getFaitGenerateur()
  {
    return faitGenerateur;
  }
  
  public void setFaitGenerateur(ObjetChronoPeriode faitGenerateur)
  {
    this.faitGenerateur = faitGenerateur;
  }
  
  public boolean isCalculAffiliationAssimilableEnseignement()
  {
    return calculAffiliationAssimilableEnseignement;
  }
  
  public void setCalculAffiliationAssimilableEnseignement(boolean calculAffiliationAssimilableEnseignement)
  {
    this.calculAffiliationAssimilableEnseignement = calculAffiliationAssimilableEnseignement;
  }
  
  public boolean isCalculAffiliationAssimilableFormation()
  {
    return calculAffiliationAssimilableFormation;
  }
  
  public void setCalculAffiliationAssimilableFormation(boolean calculAffiliationAssimilableFormation)
  {
    this.calculAffiliationAssimilableFormation = calculAffiliationAssimilableFormation;
  }
  
  public boolean isCalculAffiliationAssimilableMaterniteAdoptionAccidentTravail()
  {
    return calculAffiliationAssimilableMaterniteAdoptionAccidentTravail;
  }
  
  public void setCalculAffiliationAssimilableMaterniteAdoptionAccidentTravail(boolean calculAffiliationAssimilableMaterniteAdoptionAccidentTravail)
  {
    this.calculAffiliationAssimilableMaterniteAdoptionAccidentTravail = calculAffiliationAssimilableMaterniteAdoptionAccidentTravail;
  }
  
  public boolean isCalculAffiliationSupplementaireNonExecution()
  {
    return calculAffiliationSupplementaireNonExecution;
  }
  
  public void setCalculAffiliationSupplementaireNonExecution(boolean calculAffiliationSupplementaireNonExecution)
  {
    this.calculAffiliationSupplementaireNonExecution = calculAffiliationSupplementaireNonExecution;
  }
  
  public boolean isCalculAffiliationSupplementaireSuspension()
  {
    return calculAffiliationSupplementaireSuspension;
  }
  
  public void setCalculAffiliationSupplementaireSuspension(boolean calculAffiliationSupplementaireSuspension)
  {
    this.calculAffiliationSupplementaireSuspension = calculAffiliationSupplementaireSuspension;
  }
  
  public boolean isJustifierPeriodesSansAffiliation()
  {
    return justifierPeriodesSansAffiliation;
  }
  
  public void setJustifierPeriodesSansAffiliation(boolean justifierPeriodesSansAffiliation)
  {
    this.justifierPeriodesSansAffiliation = justifierPeriodesSansAffiliation;
  }
  
  public CalculAffiliationBaseSpec getOutilCalculAffiliationBase()
  {
    return outilCalculAffiliationBase;
  }
  
  public void setOutilCalculAffiliationBase(CalculAffiliationBaseSpec outilCalculAffiliationBase)
  {
    this.outilCalculAffiliationBase = outilCalculAffiliationBase;
  }
  
  public CalculAffiliationSupplementaireSpec getOutilCalculAffiliationSupplementaire()
  {
    return outilCalculAffiliationSupplementaire;
  }
  
  public void setOutilCalculAffiliationSupplementaire(CalculAffiliationSupplementaireSpec outilCalculAffiliationSupplementaire)
  {
    this.outilCalculAffiliationSupplementaire = outilCalculAffiliationSupplementaire;
  }
  
  public CalculAssimilationSpec getOutilCalculAssimilation()
  {
    return outilCalculAssimilation;
  }
  
  public void setOutilCalculAssimilation(CalculAssimilationSpec outilCalculAssimilation)
  {
    this.outilCalculAssimilation = outilCalculAssimilation;
  }
  
  public ConstructionChronologieSpec getOutilConstructionChronologie()
  {
    return outilConstructionChronologie;
  }
  
  public void setOutilConstructionChronologie(ConstructionChronologieSpec outilConstructionChronologie)
  {
    this.outilConstructionChronologie = outilConstructionChronologie;
  }
  
  public JustifierAffiliationSpec getOutilJustifierAffiliation()
  {
    return outilJustifierAffiliation;
  }
  
  public void setOutilJustifierAffiliation(JustifierAffiliationSpec outilJustifierAffiliation)
  {
    this.outilJustifierAffiliation = outilJustifierAffiliation;
  }
  
  public ParametresAffiliationSpec getOutilParametreAffiliation()
  {
    return outilParametreAffiliation;
  }
  
  public void setOutilParametreAffiliation(ParametresAffiliationSpec outilParametreAffiliation)
  {
    this.outilParametreAffiliation = outilParametreAffiliation;
  }
  
  public boolean isCalculAffiliationAssimilableMaladie()
  {
    return calculAffiliationAssimilableMaladie;
  }
  
  public void setCalculAffiliationAssimilableMaladie(boolean calculAffiliationAssimilableMaladie)
  {
    this.calculAffiliationAssimilableMaladie = calculAffiliationAssimilableMaladie;
  }
  
  public boolean isCalculAffiliationSupplementaireMaterniteAdoptionAccidentTravail()
  {
    return calculAffiliationSupplementaireMaterniteAdoptionAccidentTravail;
  }
  
  public void setCalculAffiliationSupplementaireMaterniteAdoptionAccidentTravail(boolean calculAffiliationSupplementaireMaterniteAdoptionAccidentTravail)
  {
    this.calculAffiliationSupplementaireMaterniteAdoptionAccidentTravail = calculAffiliationSupplementaireMaterniteAdoptionAccidentTravail;
  }
  
  public boolean isCalculAffiliationSupplementaireMaladieGrave()
  {
    return calculAffiliationSupplementaireMaladieGrave;
  }
  
  public void setCalculAffiliationSupplementaireMaladieGrave(boolean calculAffiliationSupplementaireMaladieGrave)
  {
    this.calculAffiliationSupplementaireMaladieGrave = calculAffiliationSupplementaireMaladieGrave;
  }
  
  public boolean isCalculAffiliationSupplementaireMaladieLongueDuree()
  {
    return calculAffiliationSupplementaireMaladieLongueDuree;
  }
  
  public boolean estEnseignementApplicablePourReglement(Reglement reglement)
  {
    return (reglement != null) && (reglement.getLibelleCourt().equals("A10"));
  }
  
  public void setCalculAffiliationSupplementaireMaladieLongueDuree(boolean calculAffiliationSupplementaireMaladieLongueDuree)
  {
    this.calculAffiliationSupplementaireMaladieLongueDuree = calculAffiliationSupplementaireMaladieLongueDuree;
  }
  
  public Convertisseur getConvertisseurUniteAffiliation()
  {
    return convertisseurUniteAffiliation;
  }
  
  public void setConvertisseurUniteAffiliation(Convertisseur convertisseurUniteAffiliation)
  {
    this.convertisseurUniteAffiliation = convertisseurUniteAffiliation;
  }
  
  public Demande getDemande()
  {
    return demande;
  }
  
  public void setDemande(Demande demande)
  {
    this.demande = demande;
  }
  
  public boolean estActiviteAPrendreEnComptePourEnseignement(ActiviteSalarie activite)
  {
    return true;
  }
  
  public void setEstPrimo(boolean isPrimo)
  {
    primo = isPrimo;
  }
  
  public boolean estUnPrimo()
  {
    return primo;
  }
}

/* Location:
 * Qualified Name:     ComportementCalculAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */