package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionNbHeuresTravaillees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class DeterminationSalaireJournalierMoyen
  implements OutilFonctionnel
{
  private static final BigDecimal NBRE_MOIS_ANNEE = new BigDecimal(12);
  private static final BigDecimal NBRE_JOURS_ANNEE = new BigDecimal(365);
  private static final int COEFFICIENT_HORAIRE_JOUR_A8 = 8;
  private static final int COEFFICIENT_HORAIRE_JOUR_A10 = 10;
  
  public static DeterminationSalaireJournalierMoyen getInstance()
  {
    return new DeterminationSalaireJournalierMoyen();
  }
  
  public ConstitutionSalaireJournalierMoyen determinerSalaireJournalierMoyen(Demande demande)
  {
    Damj dateAttribution = null;
    QuantiteEuro srrp = null;
    
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    ConstitutionSalaireJournalierMoyen constitutionSalaireJournalierMoyen = dossierExamen.getConstitutionElementsActifs().createConstitutionSalaireJournalierMoyen();
    
    srrp = dossierExamen.getConstitutionSalaireReference().getSalaireReferenceRevalorisePlafonne();
    
    dateAttribution = dossierExamen.getDateAttribution();
    determinerSalaireJournalierMoyenRevalorisePlafonne(dossierExamen, srrp, dateAttribution, constitutionSalaireJournalierMoyen);
    
    return constitutionSalaireJournalierMoyen;
  }
  
  public QuantiteEuro determinerSalaireJournalierMoyenRevalorise(QuantiteEuro srrp, int coefficientHoraireJour, BigDecimal nbreHeuresTravaillees)
  {
    QuantiteEuro sjmr = null;
    BigDecimal montantSalaireJournalierMoyenRevalorise = null;
    
    montantSalaireJournalierMoyenRevalorise = Mathematiques.proratiser(srrp.getValeurMontant(), new BigDecimal(coefficientHoraireJour), nbreHeuresTravaillees);
    
    montantSalaireJournalierMoyenRevalorise = Mathematiques.arrondiASup(montantSalaireJournalierMoyenRevalorise, 2);
    sjmr = new QuantiteEuro(montantSalaireJournalierMoyenRevalorise);
    
    return sjmr;
  }
  
  public int determinerCoefficientHoraireJour(Reglement reglementApplicable)
  {
    int coefficientHoraireJour = 0;
    if (reglementApplicable.estNomReglementIdentique("A8")) {
      coefficientHoraireJour = 8;
    } else if (reglementApplicable.estNomReglementIdentique("A10")) {
      coefficientHoraireJour = 10;
    }
    return coefficientHoraireJour;
  }
  
  public QuantiteEuro determinerPlafondSjmr(Damj dateRevalorisation)
  {
    BigDecimal plafondSjmr = null;
    ParametresIndemnisation parametresIndemnisation = null;
    BigDecimal plafondMensuelApplicable = null;
    
    parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    plafondMensuelApplicable = parametresIndemnisation.getElementActif(dateRevalorisation).getPlafond();
    plafondSjmr = Mathematiques.proratiser(NBRE_MOIS_ANNEE, plafondMensuelApplicable, NBRE_JOURS_ANNEE);
    
    plafondSjmr = Mathematiques.tronque(plafondSjmr, 2);
    return new QuantiteEuro(plafondSjmr);
  }
  
  public ConstitutionSalaireJournalierMoyen determinerSalaireJournalierMoyenPourReprise(Demande demande)
    throws CoucheLogiqueException
  {
    Damj dateAttribution = null;
    QuantiteEuro srrp = null;
    DossierExamen dossierExamenPrecedent = null;
    
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    ConstitutionSalaireJournalierMoyen constitutionSalaireJournalierMoyen = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionSalaireJournalierMoyen();
    
    dossierExamenPrecedent = (DossierExamen)dossierExamenCourant.getAttributionPrecedente();
    
    dateAttribution = dossierExamenCourant.getDateAttribution();
    srrp = DeterminationSalaireReference.determinerSrrp(dossierExamenPrecedent.getConstitutionSalaireReference(), dateAttribution);
    
    determinerSalaireJournalierMoyenRevalorisePlafonne(dossierExamenPrecedent, srrp, dateAttribution, constitutionSalaireJournalierMoyen);
    
    return constitutionSalaireJournalierMoyen;
  }
  
  private QuantiteEuro determinerSalaireJournalierMoyenRevalorisePlafonne(DossierExamen dossierExamen, QuantiteEuro srrp, Damj dateAttribution, ConstitutionSalaireJournalierMoyen cepaSjmAlimente)
  {
    Damj termePrc = null;
    BigDecimal nbreHeuresTravaillees = null;
    Reglement reglementApplicable = null;
    int coefficientHoraireJour = 0;
    
    QuantiteEuro sjmr = null;
    QuantiteEuro plafondSjmr = null;
    QuantiteEuro sjmrp = null;
    BigDecimal valeurSjmrp = null;
    
    nbreHeuresTravaillees = recupererNombreHeureDiviseur(dossierExamen);
    
    reglementApplicable = dossierExamen.getConstitutionReglementApplicable().getReglement();
    coefficientHoraireJour = determinerCoefficientHoraireJour(reglementApplicable);
    
    sjmr = determinerSalaireJournalierMoyenRevalorise(srrp, coefficientHoraireJour, nbreHeuresTravaillees);
    
    termePrc = dossierExamen.getConstitutionSalaireReference().getPrc().getFin();
    
    cepaSjmAlimente.setDateSalaireJournalierMoyenInitial(termePrc);
    cepaSjmAlimente.setMontantSalaireJournalierMoyenInitial(sjmr);
    
    plafondSjmr = determinerPlafondSjmr(dateAttribution);
    
    valeurSjmrp = sjmr.getValeurMontant().min(plafondSjmr.getValeurMontant());
    sjmrp = new QuantiteEuro(valeurSjmrp);
    
    cepaSjmAlimente.setMontantPlafond(plafondSjmr);
    cepaSjmAlimente.setDateSalaireJournalierMoyenRevalorisePlafonne(termePrc);
    cepaSjmAlimente.setMontantSalaireJournalierMoyenRevalorisePlafonne(sjmrp);
    
    return sjmrp;
  }
  
  protected BigDecimal recupererNombreHeureDiviseur(DossierExamen dossierExamen)
  {
    return dossierExamen.getConstitutionNbHeuresTravaillees().getNombreHeuresTravailleesPlafonne();
  }
}

/* Location:
 * Qualified Name:     DeterminationSalaireJournalierMoyen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */