package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.asu.spe02.p03.parametres.Parametres;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P03;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P04;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P05;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P06;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreAppartientReglements;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreDebutDansBornes;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.List;

public class OutilDeterminationConditionMaintien
{
  private static OutilDeterminationConditionMaintien instance;
  private static List<Reglement> listeReglementSpectacle = null;
  private static final int DUREE_3_ANS = 3;
  
  public static OutilDeterminationConditionMaintien getInstance()
  {
    if (instance == null) {
      instance = new OutilDeterminationConditionMaintien();
    }
    return instance;
  }
  
  static
  {
    listeReglementSpectacle = new ArrayList();
    listeReglementSpectacle.add(Reglement.getInstance("A10", ProduitAsuSpe02P04.getInstance()));
    listeReglementSpectacle.add(Reglement.getInstance("A8", ProduitAsuSpe02P04.getInstance()));
    listeReglementSpectacle.add(Reglement.getInstance("A10", ProduitAsuSpe02P05.getInstance()));
    listeReglementSpectacle.add(Reglement.getInstance("A8", ProduitAsuSpe02P05.getInstance()));
    listeReglementSpectacle.add(Reglement.getInstance("A10", ProduitAsuSpe02P06.getInstance()));
    listeReglementSpectacle.add(Reglement.getInstance("A8", ProduitAsuSpe02P06.getInstance()));
    listeReglementSpectacle.add(Reglement.getInstance("A10", ProduitAsuSpe02P03.getInstance()));
    listeReglementSpectacle.add(Reglement.getInstance("A8", ProduitAsuSpe02P03.getInstance()));
    listeReglementSpectacle.add(Reglement.getInstance("A10", ProduitAsuSpe02P01.getInstance()));
    listeReglementSpectacle.add(Reglement.getInstance("A8", ProduitAsuSpe02P01.getInstance()));
  }
  
  public Quantite quantiteActiviteAcquiseIntermittentDansLes3ans(DemandeMaintien demandeMaintien)
    throws CoucheLogiqueException
  {
    Damj dateFaitGenerateur = getDateFaitGenerateur(demandeMaintien);
    
    Damj dateBorneMin = dateFaitGenerateur.lendemain().deplacerVersArriere(new DureeCalendaire(3));
    
    Periode periodeDeCalcul = new Periode(dateBorneMin, dateFaitGenerateur);
    
    Quantite quantite = quantiteActiviteAcquiseIntermittentSurPeriode(demandeMaintien, periodeDeCalcul);
    
    return quantite;
  }
  
  public Damj getDateFaitGenerateur(DemandeMaintien demandeMaintien)
    throws CoucheLogiqueException
  {
    return demandeMaintien.getFGDDroitMaintenu().getDateFaitGenerateur();
  }
  
  public Damj getDate14ansIndividu(DemandeMaintien demandeMaintien)
  {
    IndividuSpec allocataire = demandeMaintien.getDemandeur();
    return allocataire.getDateNaissance().deplacerVersAvant(Parametres.AGE_DEBUT_PASSE_PROFESSIONNEL_MAINTIEN);
  }
  
  public Quantite quantiteActiviteAcquiseIntermittentSurPeriode(DemandeMaintien demandeMaintien, Periode periodeRecherche)
    throws CoucheLogiqueException
  {
    DossierAffectation dossierAffectation = (DossierAffectation)demandeMaintien.getDemandeMaintenue().getDossierAffectation();
    ConstitutionDecorReglementaire.recupererDecor(dossierAffectation);
    
    Convertisseur convertisseurUniteAffiliation = ((ProduitAsuSpec)dossierAffectation.getProduit()).determinerConvertisseurUniteAffiliation();
    
    IndividuSpec individu = demandeMaintien.getDemandeur();
    Chronologie passePro = individu.getChronoPeriodePasseProfessionnelLiquidation();
    
    FiltresTemporel filtresET = new FiltresTemporel();
    filtresET.ajouterFiltre(new FiltreActiviteSalarie());
    filtresET.ajouterFiltre(new FiltreAppartientReglements(listeReglementSpectacle));
    
    FiltrePeriodesSurFiltresExclusifs filtresOU = new FiltrePeriodesSurFiltresExclusifs();
    filtresOU.ajouterFiltre(new FiltreFinDansBornes(periodeRecherche));
    filtresOU.ajouterFiltre(new FiltreDebutDansBornes(periodeRecherche));
    
    filtresET.ajouterFiltre(filtresOU);
    Chronologie chronoPasseProFiltre = passePro.copier(filtresET);
    
    BigDecimal valeurQuantiteActivite = BigDecimal.ZERO;
    Quantite quantite;
    Quantite quantite;
    if (!chronoPasseProFiltre.estVide())
    {
      chronoPasseProFiltre.iterer();
      while (chronoPasseProFiltre.encoreSuivant())
      {
        ActiviteSalarie activitePro = (ActiviteSalarie)chronoPasseProFiltre.elementSuivant();
        
        BigDecimal nombreHeure = getNombreHeuresDegagees(activitePro, periodeRecherche, convertisseurUniteAffiliation);
        
        valeurQuantiteActivite = valeurQuantiteActivite.add(nombreHeure);
      }
      quantite = new Quantite(valeurQuantiteActivite, Unite.getParCode("3"));
    }
    else
    {
      quantite = new Quantite(0, Unite.getParCode("3"));
    }
    return quantite;
  }
  
  private BigDecimal getNombreHeuresDegagees(ActiviteSalarie activite, Periode periodeRecherche, Convertisseur convertisseurUniteAffiliation)
  {
    BigDecimal resultat = BigDecimal.ZERO;
    
    Chronologie listePMA = activite.getListePeriodesMesureActivite();
    
    listePMA.iterer();
    while (listePMA.encoreSuivant())
    {
      PeriodeMesureActivite pma = (PeriodeMesureActivite)listePMA.elementSuivant();
      
      Enumeration listeQuantiteAffiliation = pma.getListeQuantitesAffiliation().elements();
      BigDecimal valeurQuantiteAffiliationTotalPourLaPMA = BigDecimal.ZERO;
      while (listeQuantiteAffiliation.hasMoreElements())
      {
        Quantite quantiteAffiliation = (Quantite)listeQuantiteAffiliation.nextElement();
        if (quantiteAffiliation.getUnite().equals(Unite.getParCode("18")))
        {
          valeurQuantiteAffiliationTotalPourLaPMA = valeurQuantiteAffiliationTotalPourLaPMA.add(quantiteAffiliation.getValeur());
        }
        else
        {
          Quantite nouvelleQuantite = convertisseurUniteAffiliation.convertir(quantiteAffiliation, UniteAffiliation.HEURE_TRAVAIL);
          valeurQuantiteAffiliationTotalPourLaPMA = valeurQuantiteAffiliationTotalPourLaPMA.add(nouvelleQuantite.getValeur());
        }
      }
      if ((!pma.getPeriode().estContenueDans(periodeRecherche)) && (valeurQuantiteAffiliationTotalPourLaPMA.doubleValue() > 0.0D)) {
        if (periodeRecherche.periodeIntersection(pma.getPeriode()) != null) {
          valeurQuantiteAffiliationTotalPourLaPMA = Mathematiques.proratiser(valeurQuantiteAffiliationTotalPourLaPMA, new BigDecimal(periodeRecherche.periodeIntersection(pma.getPeriode()).getDuree()), new BigDecimal(pma.getPeriode().getDuree()));
        } else {
          valeurQuantiteAffiliationTotalPourLaPMA = BigDecimal.ZERO;
        }
      }
      resultat = resultat.add(valeurQuantiteAffiliationTotalPourLaPMA);
    }
    return resultat;
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationConditionMaintien
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */