package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.mnt.dom.ConditionActiviteMaintien;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.DonneesForcees;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.strategies.StrategieDeterminationConditionActiviteIntermittent3AnsApres;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.strategies.StrategieDeterminationConditionActiviteIntermittent3AnsAvant;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.strategies.StrategieDeterminationConditionActiviteIntermittent3AnsSpec;
import fr.unedic.cali.asu.spe02.p03.parametres.Parametres;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.fabriques.outilsfonctionnels.FabriqueStrategieGenerique;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreContratPaysValidesPourMaintien;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeFormationAssimilable;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeIndemnisationCaf;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class RechercheConditionActiviteMaintien
  implements OutilFonctionnel
{
  private static RechercheConditionActiviteMaintien instance;
  
  public static RechercheConditionActiviteMaintien getInstance()
  {
    if (instance == null) {
      instance = new RechercheConditionActiviteMaintien();
    }
    return instance;
  }
  
  public ConditionActiviteMaintien verifierActivite(DemandeMaintien demandeMaintien)
    throws CoucheLogiqueException
  {
    ConditionActiviteMaintien condition = new ConditionActiviteMaintien();
    condition.setEtatSatisfait(false);
    if (!verifierActiviteIntermittent(demandeMaintien, condition))
    {
      if (verifierActiviteEmploisSalaries(demandeMaintien, condition)) {
        condition.setEtatSatisfait(true);
      } else {
        condition.setCodeMotifEchec(984);
      }
    }
    else {
      condition.setEtatSatisfait(true);
    }
    return condition;
  }
  
  private boolean determinerResultatSousConditionActiviteIntermittent(DemandeMaintien demandeMaintien, ConditionActiviteMaintien conditionActiviteMaintien)
    throws CoucheLogiqueException
  {
    Quantite quantiteActiviteIntermittent = quantiteActiviteAcquiseIntermittent(demandeMaintien);
    Quantite quantiteActiviteIntermittentImposee = demandeMaintien.getDonneesForcees().getQuantiteAppartenance();
    Quantite quantiteActiviteIntermittentVerifiee;
    Quantite quantiteActiviteIntermittentVerifiee;
    if ((quantiteActiviteIntermittentImposee != null) && (quantiteActiviteIntermittentImposee.getValeur().compareTo(BigDecimal.ZERO) > 0)) {
      quantiteActiviteIntermittentVerifiee = quantiteActiviteIntermittentImposee;
    } else {
      quantiteActiviteIntermittentVerifiee = quantiteActiviteIntermittent;
    }
    boolean estConditionDureeActiviteIntermittentSatisfaite = quantiteActiviteIntermittentVerifiee.compareTo(Parametres.DUREE_ACTIVITE_INTERMITTENT) >= 0;
    
    conditionActiviteMaintien.setQuantiteActiviteIntermittentCalculee(quantiteActiviteIntermittent);
    conditionActiviteMaintien.setQuantiteActiviteIntermittentRequise(Parametres.DUREE_ACTIVITE_INTERMITTENT);
    conditionActiviteMaintien.setQuantiteActiviteIntermittentImposee(quantiteActiviteIntermittentImposee);
    
    return estConditionDureeActiviteIntermittentSatisfaite;
  }
  
  private boolean determinerResultatSousConditionActiviteIntermittent3Ans(DemandeMaintien demandeMaintien, ConditionActiviteMaintien conditionActiviteMaintien)
    throws CoucheLogiqueException
  {
    StrategieDeterminationConditionActiviteIntermittent3AnsSpec strategie = (StrategieDeterminationConditionActiviteIntermittent3AnsSpec)FabriqueStrategieGenerique.choisirStrategie(demandeMaintien.getDateExamen(), "Date d'application de la nouvelle convention Spectacle 2016", new StrategieDeterminationConditionActiviteIntermittent3AnsAvant(), new StrategieDeterminationConditionActiviteIntermittent3AnsApres());
    
    return strategie.determinerResultatSousConditionActiviteIntermittent3Ans(demandeMaintien, conditionActiviteMaintien);
  }
  
  private boolean verifierActiviteIntermittent(DemandeMaintien demandeMaintien, ConditionActiviteMaintien conditionActiviteMaintien)
    throws CoucheLogiqueException
  {
    boolean estConditionDureeActiviteIntermittentSatisfaite = determinerResultatSousConditionActiviteIntermittent(demandeMaintien, conditionActiviteMaintien);
    boolean estConditionDureeActiviteIntermittent3AnsSatisfaite = determinerResultatSousConditionActiviteIntermittent3Ans(demandeMaintien, conditionActiviteMaintien);
    
    return (estConditionDureeActiviteIntermittentSatisfaite) && (estConditionDureeActiviteIntermittent3AnsSatisfaite);
  }
  
  private Quantite quantiteActiviteAcquiseIntermittent(DemandeMaintien demandeMaintien)
    throws CoucheLogiqueException
  {
    Damj dateFaitGenerateur = OutilDeterminationConditionMaintien.getInstance().getDateFaitGenerateur(demandeMaintien);
    Damj dateAnniversaire14ans = OutilDeterminationConditionMaintien.getInstance().getDate14ansIndividu(demandeMaintien);
    
    Periode periodeDeCalcul = new Periode(dateAnniversaire14ans, dateFaitGenerateur);
    
    Quantite quantite = OutilDeterminationConditionMaintien.getInstance().quantiteActiviteAcquiseIntermittentSurPeriode(demandeMaintien, periodeDeCalcul);
    
    return quantite;
  }
  
  private boolean verifierActiviteEmploisSalaries(DemandeMaintien demandeMaintien, ConditionActiviteMaintien conditionActiviteMaintien)
    throws CoucheLogiqueException
  {
    boolean condition = false;
    
    Quantite quantiteActiviteAcquiseEnsembleCarriere = quantiteActiviteAcquiseEnsembleCarriere(demandeMaintien);
    if (quantiteActiviteAcquiseEnsembleCarriere.compareTo(Parametres.DUREE_ACTIVITE_EMPLOI_SALARIE) >= 0) {
      condition = true;
    }
    conditionActiviteMaintien.setQuantiteActiviteEmploiSalarieCalculee(quantiteActiviteAcquiseEnsembleCarriere);
    conditionActiviteMaintien.setQuantiteActiviteEmploiSalarieRequise(Parametres.DUREE_ACTIVITE_EMPLOI_SALARIE);
    
    return condition;
  }
  
  private Quantite quantiteActiviteAcquiseEnsembleCarriere(DemandeMaintien demandeMaintien)
    throws CoucheLogiqueException
  {
    Quantite resultat = new Quantite(0, Unite.getParCode("4"));
    
    Periode periodeReference = new Periode(OutilDeterminationConditionMaintien.getInstance().getDate14ansIndividu(demandeMaintien), OutilDeterminationConditionMaintien.getInstance().getDateFaitGenerateur(demandeMaintien));
    
    IndividuSpec individu = demandeMaintien.getDemandeur();
    ChronologiePeriodes chronoPassePro = individu.getChronoPeriodePasseProfessionnelLiquidation();
    
    Quantite quantiteActiviteSalarie = quantiteActiviteProfessionnellesSalariees(chronoPassePro, periodeReference);
    resultat = resultat.ajouter(quantiteActiviteSalarie);
    
    Quantite quantiteActiviteAvecLimite = quantiteActiviteAssimilablesAvecLimite(chronoPassePro, periodeReference);
    resultat = resultat.ajouter(quantiteActiviteAvecLimite);
    
    return resultat;
  }
  
  private Quantite quantiteActiviteProfessionnellesSalariees(ChronologiePeriodes chronoActRetenues, Periode periodeReference)
  {
    ChronologiePeriodes chronoActivitesRetenues = determinerChronoActivitesSalariees(chronoActRetenues, periodeReference);
    
    int nombreJoursActiviteDansPeriodeRef = periodeReference.inter(chronoActivitesRetenues);
    return new Quantite(nombreJoursActiviteDansPeriodeRef, Unite.getParCode("4"));
  }
  
  private ChronologiePeriodes determinerChronoActivitesSalariees(ChronologiePeriodes chronoPasseProfessionnel, Periode periodeReference)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarie());
    filtres.ajouterFiltre(new FiltreContratPaysValidesPourMaintien());
    filtres.ajouterFiltre(new FiltreChevauchePeriode(periodeReference));
    return (ChronologiePeriodes)chronoPasseProfessionnel.copier(filtres);
  }
  
  private Quantite quantiteActiviteAssimilablesAvecLimite(ChronologiePeriodes passeProfessionnel, Periode periodeReference)
  {
    ChronologiePeriodes chronoPeriodesAssimilablesAvecLimite = determinerChronoPeriodesAssimilablesAvecLimite(passeProfessionnel, periodeReference);
    
    int nombreJoursAssimilableAveclimiteDansPeriodeRef = periodeReference.inter(chronoPeriodesAssimilablesAvecLimite);
    Quantite quantiteAssimilableRetenue = new Quantite(nombreJoursAssimilableAveclimiteDansPeriodeRef, Unite.getParCode("4"));
    if (quantiteAssimilableRetenue.getValeurEntiere() > 0) {
      quantiteAssimilableRetenue = quantiteAssimilableRetenue.min(Parametres.PLAFOND_QUANTITE_ACTIVITES_ASSIMILABLES);
    }
    return quantiteAssimilableRetenue;
  }
  
  private ChronologiePeriodes determinerChronoPeriodesAssimilablesAvecLimite(ChronologiePeriodes chronoPasseProfessionnel, Periode periodeReference)
  {
    FiltresTemporel listeFiltres = new FiltresTemporel();
    
    listeFiltres.ajouterFiltre(new FiltreChevauchePeriode(periodeReference));
    
    FiltrePeriodesSurFiltresExclusifs filtreExclusif = new FiltrePeriodesSurFiltresExclusifs();
    
    filtreExclusif.ajouterFiltre(new FiltrePeriodeFormationAssimilable());
    
    filtreExclusif.ajouterFiltre(new FiltrePeriodeIndemnisationCaf());
    listeFiltres.ajouterFiltre(filtreExclusif);
    
    return (ChronologiePeriodes)chronoPasseProfessionnel.copier(listeFiltres);
  }
}

/* Location:
 * Qualified Name:     RechercheConditionActiviteMaintien
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */