package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeDeclare;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ProduitAsuSpectacleSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteContenuDansPra;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesDeclarees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesDsmSpectacle;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesHorsChampSpectacle;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesJustifiees;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.Map;

public final class RechercheConditionAffiliation
  implements OutilFonctionnel
{
  public static final String PARAM_DATE_FIN_DJN = "paramDateFinDNJ";
  
  public static ConditionQuantiteAffiliation rechercherConditionAffiliation(Demande demande, IndividuSpec individu)
    throws ApplicativeException
  {
    DossierAffectation dossierAffectation = (DossierAffectation)demande.getDossierAffectation();
    DossierExamen dossierExamen = (DossierExamen)dossierAffectation.getDossierExamen();
    fr.unedic.cali.asu.dom.ValidationProduit validationProduit = dossierAffectation.getValidationProduit();
    
    ConditionQuantiteAffiliation conditionQuantiteAffiliation = ((DossierExamen)demande.getDossierExamen()).getConditionAttributionAdmission().createConditionQuantiteAffiliation();
    
    conditionQuantiteAffiliation.setEtatSatisfait(false);
    if (dossierExamen.getConditionFaitGenerateur().estSatisfait())
    {
      if (validationProduit != null) {
        conditionQuantiteAffiliation.setValidationProduit(((DossierExamen)demande.getDossierExamen()).getValidationProduit());
      }
      if ((validationProduit != null) && (validationProduit.isEstProduitValide()))
      {
        conditionQuantiteAffiliation.setEtatSatisfait(true);
      }
      else
      {
        boolean estIprAvecValidationProduit = (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "EXAMENIPR")) && (validationProduit != null);
        if ((demande.getDonneesTemporaires().getPeriodeFctARetenir() == null) && (!estIprAvecValidationProduit))
        {
          Chronologie chronoPeriodesParticipantesRechercherDernierSinistre = fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre.determinerChronologieActivitesRechercheDernierSinistre(demande);
          if ((chronoPeriodesParticipantesRechercherDernierSinistre != null) && (!chronoPeriodesParticipantesRechercherDernierSinistre.estVide()))
          {
            ActiviteSalarie dernierSinistre = (ActiviteSalarie)fr.unedic.cali.asu.outilsfonctionnels.RechercherDernierSinistre.rechercherDernierSinistre(demande, chronoPeriodesParticipantesRechercherDernierSinistre);
            if ((dernierSinistre != null) && (validationProduit != null))
            {
              ProduitAsuSpectacleSpec produit = (ProduitAsuSpectacleSpec)demande.getDossierAffectation().getProduit();
              
              fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit validationProduitRejet = (fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit)produit.obtenirValidationProduit(dernierSinistre, individu, demande, false);
              
              fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit validationProduitSpe = (fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit)validationProduit;
              
              validationProduitRejet.copieElements(validationProduitSpe);
            }
          }
        }
        conditionQuantiteAffiliation.setEtatSatisfait(false);
        conditionQuantiteAffiliation.setCodeMotifEchec(71);
      }
    }
    else
    {
      conditionQuantiteAffiliation.setEtatSatisfait(true);
    }
    leverAlerteA11MB14SurPresenceDNJSDepuisDernierFGD(demande, individu);
    
    leverAlerteA11MNB1etA11MNB8(demande, individu);
    
    return conditionQuantiteAffiliation;
  }
  
  private static void leverAlerteA11MNB1etA11MNB8(DemandeSpec demande, IndividuSpec individu)
  {
    String codeAlerteNonBloquante1 = "A11MNB1";
    
    String codeAlerteNonBloquante8 = "A11MNB8";
    
    DossierAffectation dossierAffectation = (DossierAffectation)demande.getDossierAffectation();
    fr.unedic.cali.asu.dom.ValidationProduit validationProduit = dossierAffectation.getValidationProduit();
    if (validationProduit != null)
    {
      Periode pra = validationProduit.getPeriodePra();
      
      Chronologie chronoPAS = individu.getChronoPeriodePasseProfessionnelLiquidation();
      
      FiltreTemporel filtreContenuDansPra = new FiltreActiviteContenuDansPra(pra);
      
      FiltresTemporel filtrePna = new FiltresTemporel();
      filtrePna.ajouterFiltre(filtreContenuDansPra);
      filtrePna.ajouterFiltre(new FiltrePeriodesAttestees(false));
      Chronologie listePna = chronoPAS.copier(filtrePna);
      if (!listePna.estVide()) {
        demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante1, convertirChronoToCollectionObjetAlerteNB(listePna));
      }
      FiltresTemporel filtrePHSpe = new FiltresTemporel();
      filtrePHSpe.ajouterFiltre(filtreContenuDansPra);
      filtrePHSpe.ajouterFiltre(new FiltrePeriodesHorsChampSpectacle());
      Chronologie listePHSpe = chronoPAS.copier(filtrePHSpe);
      if (!listePHSpe.estVide()) {
        demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante8, convertirChronoToCollectionObjetAlerteNB(listePHSpe));
      }
    }
  }
  
  private static void leverAlerteA11MB14SurPresenceDNJSDepuisDernierFGD(DemandeSpec demande, IndividuSpec individu)
    throws CoucheLogiqueException
  {
    Damj dateFGD = ((Demande)demande).getDateFaitGenerateurOdPrecedente();
    if (dateFGD == null) {
      dateFGD = Damj.NUIT_DES_TEMPS;
    }
    Damj dateTraitement = demande.getDateExamen().veille();
    Periode periodeVerif = new Periode(dateFGD, dateTraitement);
    
    Collection<PeriodeDeclare> listeDnjs = new ArrayList();
    
    FiltresTemporel filtreDNJS = new FiltresTemporel();
    filtreDNJS.ajouterFiltre(new FiltrePeriodesDeclarees());
    filtreDNJS.ajouterFiltre(new FiltrePeriodesJustifiees(false));
    filtreDNJS.ajouterFiltre(new FiltrePeriodesDsmSpectacle());
    
    Chronologie chronoDNJS = individu.getChronoPeriodePasseProfessionnelLiquidation().copier(filtreDNJS);
    for (Iterator it = chronoDNJS.iterer(); it.hasNext();)
    {
      PeriodeDeclare pasTemp = (PeriodeDeclare)it.next();
      if (pasTemp.getPeriode().estContenueDans(periodeVerif)) {
        listeDnjs.add(pasTemp);
      }
    }
    if (!listeDnjs.isEmpty())
    {
      String[] params = new String[2];
      PeriodeDeclare pad = (PeriodeDeclare)listeDnjs.toArray()[0];
      params[0] = pad.getDateDebut().toString();
      params[1] = pad.getDateFin().toString();
      
      Map<String, Damj> parametres = new HashMap();
      parametres.put("paramDateFinDNJ", pad.getDateFin());
      
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB14", params, parametres);
    }
  }
  
  private static Collection<ObjetAlertesNonBloquantes> convertirChronoToCollectionObjetAlerteNB(Chronologie chrono)
  {
    Collection<ObjetAlertesNonBloquantes> retour = null;
    Iterator<ObjetAlertesNonBloquantes> it;
    if (chrono != null)
    {
      retour = new ArrayList();
      for (it = chrono.iterer(); it.hasNext();)
      {
        Temporel temp = (Temporel)it.next();
        retour.add(new ObjetAlertesNonBloquantes(temp.getDateDebut(), temp.getDateFin(), 2));
      }
    }
    return retour;
  }
}

/* Location:
 * Qualified Name:     RechercheConditionAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */