package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionChomageInvolontaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionsAttributionSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Pra;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.CalculAppartenance;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.parametres.Parametres;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.FacadeLiquidationProduitAsuSpectacleSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P03;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.ComparateurTemporelSurDateFinDecroissante;
import fr.unedic.cali.outilsfonctionnels.DetectionTypeChomage;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class RechercheConditionChomageInvolontaireDemandeClassique
  implements RechercheConditionChomageInvolontaireSpec
{
  private static final ProduitSpec PRODUIT = ;
  public static final Reglement REGLEMENT_A8 = PRODUIT.getReglement("A8");
  public static final Reglement REGLEMENT_A10 = PRODUIT.getReglement("A10");
  
  public ConditionChomageInvolontaire rechercherConditionChomageInvolontaire(Demande demande)
    throws CoucheLogiqueException
  {
    ConditionChomageInvolontaire conditionChomageInvolontaire = ((DossierExamen)demande.getDossierExamen()).getConditionsAttributionActives().createConditionChomageInvolontaire();
    
    conditionChomageInvolontaire.setEtatSatisfait(true);
    boolean estLeveeConditionChomageInvolontaire = demande.getDonneesTemporaires().isConditionChomageInvolontaireSatistaite();
    if (!estLeveeConditionChomageInvolontaire)
    {
      boolean echecCondition = verifierMotifFaitGenerateur(demande);
      if (echecCondition)
      {
        String identifiantActivitePortantDV = recupererIdentifiantActivitePortantDV(demande);
        conditionChomageInvolontaire.setIdentifiantActivitePortantDV(identifiantActivitePortantDV);
        
        conditionChomageInvolontaire.setEtatSatisfait(false);
        conditionChomageInvolontaire.setCodeMotifEchec(91);
      }
      else
      {
        Periode delaiRechercheFctDv = constituerDelaiRechercheFctDv(demande);
        if (delaiRechercheFctDv != null)
        {
          FaitGenerateurSpec faitGenerateurCourant = ((DossierExamen)demande.getDossierExamen()).getFaitGenerateur();
          Chronologie chronoPeriodesTravailDansDelaiRechercheFctDv = ConstructionChronologie.determinerChronoPeriodesTravailDelaiRechercheDv(delaiRechercheFctDv, faitGenerateurCourant.getPeriodeFaitGenerateur(), demande.getDemandeur().getChronoPeriodePasseProfessionnelPourLiquidationSansFiltrageDNJ());
          if (!chronoPeriodesTravailDansDelaiRechercheFctDv.estVide())
          {
            echecCondition = traiterDernierePeriodeTravail(demande, chronoPeriodesTravailDansDelaiRechercheFctDv);
            if (echecCondition)
            {
              conditionChomageInvolontaire.setIdentifiantActivitePortantDV(((TravailSpec)chronoPeriodesTravailDansDelaiRechercheFctDv.premierElement()).getIdentifiant());
              
              conditionChomageInvolontaire.setEtatSatisfait(false);
              conditionChomageInvolontaire.setCodeMotifEchec(92);
            }
          }
        }
      }
    }
    return conditionChomageInvolontaire;
  }
  
  private String recupererIdentifiantActivitePortantDV(Demande demande)
  {
    FaitGenerateurSpec faitGenerateurCourant = ((DossierExamen)demande.getDossierExamen()).getFaitGenerateur();
    ActiviteSalarie activiteSalarieFg = faitGenerateurCourant.getPeriodeFaitGenerateur();
    String identifiantActivitePortantDV = activiteSalarieFg.getIdentifiant();
    
    return identifiantActivitePortantDV;
  }
  
  private boolean verifierMotifFaitGenerateur(Demande demande)
  {
    boolean echecCondition = false;
    
    FaitGenerateurSpec faitGenerateurCourant = ((DossierExamen)demande.getDossierExamen()).getFaitGenerateur();
    if (faitGenerateurCourant != null)
    {
      ActiviteSalarie activiteSalarieFg = faitGenerateurCourant.getPeriodeFaitGenerateur();
      int codeMotifFin = activiteSalarieFg.getCodeMotifFin();
      int contexteDemisison = activiteSalarieFg.getContrat().getContexteDemission();
      if (!DetectionTypeChomage.estChomageLegitime(codeMotifFin, contexteDemisison)) {
        echecCondition = true;
      }
    }
    return echecCondition;
  }
  
  private Periode constituerDelaiRechercheFctDv(Demande demande)
  {
    Periode delaiRechercheFctDv = null;
    
    FaitGenerateurSpec faitGenerateurCourant = ((DossierExamen)demande.getDossierExamen()).getFaitGenerateur();
    if (faitGenerateurCourant != null)
    {
      Damj termePeriodeRechercheDV = faitGenerateurCourant.getDateFaitGenerateur();
      
      Damj debutPeriodeRechercheDV = Damj.NUIT_DES_TEMPS;
      if (demande.getDossierAffectationAdmission().getValidationProduit() != null) {
        debutPeriodeRechercheDV = demande.getDossierAffectationAdmission().getValidationProduit().getPeriodePra().getDebut();
      }
      delaiRechercheFctDv = new Periode(debutPeriodeRechercheDV, termePeriodeRechercheDV);
    }
    return delaiRechercheFctDv;
  }
  
  private boolean traiterDernierePeriodeTravail(Demande demande, Chronologie chronoPeriodesDansDelaiRechercheFctDv)
    throws CoucheLogiqueException
  {
    boolean echecCondition = false;
    
    chronoPeriodesDansDelaiRechercheFctDv.setComparateur(new ComparateurTemporelSurDateFinDecroissante());
    TravailSpec dernierePeriodeTravail = (TravailSpec)chronoPeriodesDansDelaiRechercheFctDv.premierElement();
    if (!verifierAffiliationMinimaleSurDernierDvNonLegitime(demande, dernierePeriodeTravail.getDateFin()))
    {
      echecCondition = true;
      
      RechercheConditionChomageInvolontaire.getInstance().verifierConditionChomageInvolontaireVerifiable(dernierePeriodeTravail);
    }
    return echecCondition;
  }
  
  private boolean verifierAffiliationMinimaleSurDernierDvNonLegitime(Demande pDemande, Damj dateDernierDv)
    throws CoucheLogiqueException
  {
    boolean conditionAffiliationMinimaleSatisfaite = false;
    
    Damj dateDebutPra = dateDernierDv.lendemain();
    Damj dateFinPra = pDemande.getDateFaitGenerateurOuDernierSinistre();
    Pra pra = new Pra(dateDebutPra, dateFinPra);
    
    Chronologie chronoActivitesSalarieesAppartenance = ConstructionChronologie.determinerChronoActivitesSalarieesFiniesDansDelai(pra, pDemande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    
    Chronologie chronoActivitesAssimilables = ConstructionChronologie.determinerChronoActivitesAssimilables(pra, pDemande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    
    Chronologie chronoActiviteParticipanteAffiliationMinimale = new ChronologiePeriodes();
    chronoActiviteParticipanteAffiliationMinimale.ajouter(chronoActivitesSalarieesAppartenance);
    chronoActiviteParticipanteAffiliationMinimale.ajouter(chronoActivitesAssimilables);
    
    Quantite quantiteAppartenanceRequiseHeures = Parametres.QUANTITE_APPARTENANCE_REQUISE_SUITE_DV;
    
    ProduitSpec produit = pDemande.getDossierAffectation().getProduit();
    ComportementAffiliationSpec comportementCalculAffiliation = creerComportementAffiliation(produit);
    comportementCalculAffiliation.setChronologieActivitesParticipantes(chronoActiviteParticipanteAffiliationMinimale);
    comportementCalculAffiliation.setPeriodeRecherche(pra);
    FaitGenerateurSpec faitGenerateurCourant = ((DossierExamen)pDemande.getDossierExamen()).getFaitGenerateur();
    comportementCalculAffiliation.setFaitGenerateur(faitGenerateurCourant.getPeriodeFaitGenerateur());
    
    comportementCalculAffiliation.setDateExamen(pDemande.getDateExamen());
    comportementCalculAffiliation.setQuantiteAffiliationRequise(quantiteAppartenanceRequiseHeures);
    comportementCalculAffiliation.setCalculAffiliationDeBase(true);
    comportementCalculAffiliation.setCalculAffiliationSupplementaire(true);
    comportementCalculAffiliation.setCalculAffiliationAssimilable(true);
    List<Reglement> listeReglementPrisEnCompte = new ArrayList();
    listeReglementPrisEnCompte.add(REGLEMENT_A8);
    listeReglementPrisEnCompte.add(REGLEMENT_A10);
    comportementCalculAffiliation.setListeReglementPrisEnCompte(listeReglementPrisEnCompte);
    Reglement reglementApplicable = ((DossierAffectation)pDemande.getDossierAffectation()).getReglementPeriodeValidationProduit();
    comportementCalculAffiliation.setReglementCandidat(reglementApplicable);
    
    ProduitAsuSpec produitAffecte = (ProduitAsuSpec)((DossierAffectation)pDemande.getDossierAffectation()).getProduit();
    Convertisseur convertisseurUniteAffiliation = produitAffecte.determinerConvertisseurUniteAffiliation();
    comportementCalculAffiliation.setConvertisseurUniteAffiliation(convertisseurUniteAffiliation);
    
    comportementCalculAffiliation.setDemande(pDemande);
    
    Quantite quantiteAffiliationAcquiseGlobale = CalculAppartenance.calculerQuantiteAffiliation(pDemande.getDemandeur(), comportementCalculAffiliation, null, null);
    
    Chronologie chronoActivitesSalarieesNonSpectacleAppartenance = ConstructionChronologie.determinerChronoActivitesSalarieesNonSpectacle(chronoActivitesSalarieesAppartenance);
    if ((chronoActivitesSalarieesNonSpectacleAppartenance != null) && (!chronoActivitesSalarieesNonSpectacleAppartenance.estVide()))
    {
      Quantite quantiteAppartenanceActivitesNonSpectacle = determinerQuantiteAppartenanceActivitesNonSpectacle(pra, chronoActivitesSalarieesNonSpectacleAppartenance, convertisseurUniteAffiliation);
      if (quantiteAppartenanceActivitesNonSpectacle != null) {
        quantiteAffiliationAcquiseGlobale = quantiteAffiliationAcquiseGlobale.ajouter(quantiteAppartenanceActivitesNonSpectacle);
      }
    }
    if ((quantiteAffiliationAcquiseGlobale != null) && (quantiteAffiliationAcquiseGlobale.compareTo(quantiteAppartenanceRequiseHeures) >= 0)) {
      conditionAffiliationMinimaleSatisfaite = true;
    }
    return conditionAffiliationMinimaleSatisfaite;
  }
  
  private Quantite determinerQuantiteAppartenanceActivitesNonSpectacle(Periode pra, Chronologie chronoActivitesSalarieesAppartenance, Convertisseur convertisseurUniteAffiliation)
  {
    Unite uniteHeure = Unite.get("heure de travail");
    Unite uniteJour = Unite.get("jour d'affiliation");
    
    Quantite quantiteAppartenanceCumulHeures = new Quantite(0, uniteHeure);
    ActiviteSalarie activiteSalarieCourante = null;
    Chronologie chronoPeriodeMesureActiviteCourante = null;
    PeriodeMesureActivite periodeMesureActiviteCourante = null;
    Quantite quantiteHeuresCourante = null;
    Quantite quantiteJoursCourante = null;
    BigDecimal nominateur = null;
    BigDecimal denominateur = null;
    BigDecimal nombreHeuresProratise = null;
    chronoActivitesSalarieesAppartenance.iterer();
    while (chronoActivitesSalarieesAppartenance.encoreSuivant())
    {
      activiteSalarieCourante = (ActiviteSalarie)chronoActivitesSalarieesAppartenance.elementSuivant();
      
      chronoPeriodeMesureActiviteCourante = activiteSalarieCourante.getListePeriodesMesureActivite();
      chronoPeriodeMesureActiviteCourante.iterer();
      while (chronoPeriodeMesureActiviteCourante.encoreSuivant())
      {
        periodeMesureActiviteCourante = (PeriodeMesureActivite)chronoPeriodeMesureActiviteCourante.elementSuivant();
        
        quantiteHeuresCourante = periodeMesureActiviteCourante.getQuantiteAffiliation(uniteHeure);
        if (quantiteHeuresCourante == null)
        {
          quantiteJoursCourante = periodeMesureActiviteCourante.getQuantiteAffiliation(uniteJour);
          if (quantiteJoursCourante != null) {
            quantiteHeuresCourante = convertisseurUniteAffiliation.convertir(quantiteJoursCourante, uniteHeure);
          }
        }
        if (quantiteHeuresCourante != null)
        {
          nominateur = new BigDecimal(String.valueOf(periodeMesureActiviteCourante.inter(pra)));
          denominateur = new BigDecimal(String.valueOf(periodeMesureActiviteCourante.getDuree()));
          nombreHeuresProratise = Mathematiques.proratiser(quantiteHeuresCourante.getValeur(), nominateur, denominateur);
          
          quantiteAppartenanceCumulHeures = quantiteAppartenanceCumulHeures.ajouter(new Quantite(nombreHeuresProratise, uniteHeure));
        }
      }
    }
    quantiteAppartenanceCumulHeures = new Quantite(Mathematiques.arrondiASup(quantiteAppartenanceCumulHeures.getValeur(), 2), uniteHeure);
    return quantiteAppartenanceCumulHeures;
  }
  
  public ConditionChomageInvolontaire rechercherConditionChomageInvolontairePourReprise(Demande demande)
    throws CoucheLogiqueException
  {
    ConditionChomageInvolontaire conditionChomageInvolontaire = ((DossierExamen)demande.getDossierExamen()).getConditionsAttributionActives().createConditionChomageInvolontaire();
    
    boolean estLeveeConditionChomageInvolontaire = demande.getDonneesTemporaires().isConditionChomageInvolontaireSatistaite();
    conditionChomageInvolontaire.setEtatSatisfait(true);
    if (!estLeveeConditionChomageInvolontaire)
    {
      boolean echecCondition = false;
      
      Damj dateDerniereRadiation = null;
      
      Chronologie chronoPeriodesPecIndemnisablesPrecedentes = OutillagePEC.getPeriodesPecFinAvantOuCoincideAvecDate(demande.getDemandeur(), demande.getDateExamen());
      if ((chronoPeriodesPecIndemnisablesPrecedentes != null) && (!chronoPeriodesPecIndemnisablesPrecedentes.estVide()))
      {
        ObjetChronoPeriodePriseEnCharge objetChronoPecPrecedente = (ObjetChronoPeriodePriseEnCharge)chronoPeriodesPecIndemnisablesPrecedentes.dernierElement();
        
        dateDerniereRadiation = objetChronoPecPrecedente.getDateFin();
      }
      Periode delaiRechercheFct = null;
      if ((dateDerniereRadiation != null) && (dateDerniereRadiation.estAvant(demande.getDateExamen()))) {
        delaiRechercheFct = new Periode(dateDerniereRadiation, demande.getDateExamen().veille());
      }
      Chronologie chronoPeriodesAttesteesDansDelai = ConstructionChronologie.determinerChronoActivitesSalarieesFiniesDansDelai(delaiRechercheFct, demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
      if ((chronoPeriodesAttesteesDansDelai != null) && (!chronoPeriodesAttesteesDansDelai.estVide()))
      {
        chronoPeriodesAttesteesDansDelai.setComparateur(new ComparateurTemporelsSurDateFin());
        ActiviteSalarie derniereFct = (ActiviteSalarie)chronoPeriodesAttesteesDansDelai.premierElement();
        
        echecCondition = !DetectionTypeChomage.estChomageLegitime(derniereFct.getCodeMotifFin(), derniereFct.getContrat().getContexteDemission());
        if (echecCondition)
        {
          conditionChomageInvolontaire.setIdentifiantActivitePortantDV(derniereFct.getIdentifiant());
          conditionChomageInvolontaire.setEtatSatisfait(false);
          conditionChomageInvolontaire.setCodeMotifEchec(91);
        }
      }
    }
    return conditionChomageInvolontaire;
  }
  
  protected ComportementAffiliationSpec creerComportementAffiliation(ProduitSpec produit)
  {
    return (ComportementAffiliationSpec)((FacadeLiquidationProduitAsuSpectacleSpec)produit).getComportementAffiliation();
  }
}

/* Location:
 * Qualified Name:     RechercheConditionChomageInvolontaireDemandeClassique
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */