package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.affectation.parametres.CriteresQualification;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SalaireReference;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionNbHeuresTravaillees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P05;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P06;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpectacleSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.ApplicativeRuntimeException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public final class RecuperationElementIndemnisation
  implements OutilFonctionnel
{
  private static RecuperationElementIndemnisation instance;
  public static final Damj DATE_PRISE_EN_COMPTE_CRC_APS = new Damj(2012, 1, 1);
  
  public static RecuperationElementIndemnisation getInstance()
  {
    if (instance == null) {
      instance = new RecuperationElementIndemnisation();
    }
    return instance;
  }
  
  public ElementBaseIndemnisation recupererElementBaseIndemnisation(AttributionSpec attribution)
  {
    ElementBaseIndemnisation ebi = new ElementBaseIndemnisation();
    Attribution attributionCourante = (Attribution)attribution;
    if (attributionCourante.getConstitutionReglementApplicable() != null)
    {
      Reglement reglementApplicable = attributionCourante.getConstitutionReglementApplicable().getReglement();
      ebi.setReglementApplicable(reglementApplicable);
      
      ebi.setCoefficientHoraireJour(DeterminationSalaireJournalierMoyen.getInstance().determinerCoefficientHoraireJour(reglementApplicable));
    }
    alimenterAffiliationRequise(ebi, attributionCourante);
    
    ConstitutionSalaireReference cepaSr = attributionCourante.getConstitutionSalaireReference();
    if (cepaSr != null)
    {
      ebi.setPrc(cepaSr.getPrc());
      if (cepaSr.getSalaireReferenceInitialPlafonne() != null)
      {
        SalaireReference srip = new SalaireReference(cepaSr.getSalaireReferenceInitialPlafonne().getValeur(), cepaSr.getPrc().getFin());
        ebi.setSalaireReference(srip);
      }
      if (cepaSr.getNombreJoursEmploiDansPRC() == 0)
      {
        ChronologiePeriodes chronoPeriodes = new ChronologiePeriodes();
        if ((cepaSr.getCollectionActiviteSalarieParticipantSr() != null) && (!cepaSr.getCollectionActiviteSalarieParticipantSr().isEmpty()))
        {
          chronoPeriodes.ajouter(cepaSr.getCollectionActiviteSalarieParticipantSr());
        }
        else
        {
          Collection<?> chronoPeriodesARetenir = cepaSr.getJustificationSalaireReference().getCollectionPeriodeActivite();
          chronoPeriodes.ajouter(chronoPeriodesARetenir);
        }
        ebi.setNbJoursEmploiSurPrc(DeterminationSalaireReference.determinerNbJoursEmploiDansPrc(((DemandeAssuranceSpec)attributionCourante.getDemande()).getDonneesTemporaires().getNbJourContratSurPraSpectacle(), cepaSr.getPrc(), chronoPeriodes));
      }
      else
      {
        ebi.setNbJoursEmploiSurPrc(cepaSr.getNombreJoursEmploiDansPRC());
      }
      if (cepaSr.getNombreJoursInactiviteDansPRC() != null) {
        ebi.setNombreJoursInactivite(cepaSr.getNombreJoursInactiviteDansPRC().intValue());
      } else {
        alimenterNbJoursInactiviteAvecRecalculAffiliation(attributionCourante, ebi);
      }
    }
    ConstitutionNbHeuresTravaillees cepaNbHeures = attributionCourante.getConstitutionNbHeuresTravaillees();
    if (cepaNbHeures != null)
    {
      ebi.setNombreHeureTravaillesEtendu(cepaNbHeures.getNombreHeuresTravailleesEtendu());
      
      ebi.setNombreHeuresTravailleesMajoree(cepaNbHeures.getNombreHeuresTravailleesMajorees());
      
      ebi.setNombreHeuresTravailleesPlafonnees(cepaNbHeures.getNombreHeuresTravailleesPlafonne());
    }
    ebi.setSjr(getSjr(attributionCourante));
    ebi.setReglementApplicableMontantRetenu(attributionCourante.getReglementApplicable());
    
    DemandeAssuranceSpec demande = (DemandeAssuranceSpec)attributionCourante.getDemande();
    if (demande.estUneDemandeAps()) {
      prendreEnCompteCRC(attributionCourante, ebi);
    }
    ebi.setListePensionInvalidite(attributionCourante.getListePensionInvalidite());
    
    Boolean estProduitGerantPensionInvalidite = Boolean.valueOf(((ProduitAsuSpec)attributionCourante.getProduit()).estProduitGerantPensionInvalidite(attributionCourante.getDemande()));
    
    ebi.setEstProduitGerantPensionInvalidite(estProduitGerantPensionInvalidite);
    
    alimenterDonneesSpectacle2016(attributionCourante, ebi);
    
    return ebi;
  }
  
  protected void alimenterNbJoursInactiviteAvecRecalculAffiliation(Attribution attributionCourante, ElementBaseIndemnisation ebi)
  {
    if (estBesoinRecalculAffiliation(attributionCourante))
    {
      DemandeSpec demande = attributionCourante.getDemande();
      try
      {
        if ((attributionCourante instanceof RepriseSpec))
        {
          ebi.setNombreJoursInactivite(attributionCourante.getAttributionPrecedente().getElementBaseIndemnisation().getNombreJoursInactivite());
        }
        else
        {
          DossierAffecte dossierAffecte = (DossierAffecte)demande.getDossierAffectation();
          CriteresQualification criteresQualification = new CriteresQualification(dossierAffecte.getDecorReglementaire(), dossierAffecte.getSinistre(), ((Demande)demande).getDonneesTemporaires().isEstCoordCee());
          
          AccesDecorReglementaire.getInstance().positionnerCriteresQualifSurPas(criteresQualification, (Individu)demande.getDemandeur());
          
          ValidationProduit validationProduit = attributionCourante.getValidationProduit();
          ValidationProduit validationCalculee = (ValidationProduit)((ProduitAsuSpec)attributionCourante.getProduit()).obtenirValidationProduit(validationProduit.getPeriodeValidationProduit(), demande.getDemandeur(), demande, false);
          ebi.setNombreJoursInactivite(validationCalculee.getJustificationAffiliation().getNombreJourAssimilationSalaire());
        }
      }
      catch (ApplicativeException e)
      {
        throw new ApplicativeRuntimeException(e.getCode(), e);
      }
    }
  }
  
  protected boolean estBesoinRecalculAffiliation(Attribution attributionCourante)
  {
    boolean retour = false;
    ValidationProduit validationProduit = attributionCourante.getValidationProduit();
    ProduitSpec produit = attributionCourante.getProduit();
    boolean produitSpectacle2016 = (ProduitAsuSpe02P05.getInstance().equals(produit)) || (ProduitAsuSpe02P06.getInstance().equals(produit));
    if ((validationProduit != null) && (validationProduit.getJustificationAffiliation() != null) && (produitSpectacle2016))
    {
      ConstitutionSalaireReference cepaSr = attributionCourante.getConstitutionSalaireReference();
      if ((cepaSr != null) && (cepaSr.getNombreJoursInactiviteDansPRC() == null) && (cepaSr.getSalaireReferenceInitialPlafonne() != null))
      {
        BigDecimal srrip = cepaSr.getSalaireReferenceInitialPlafonne().getValeur();
        
        BigDecimal plafond = DeterminationSalaireReference.determinerPlafondSrr(cepaSr.getNombreJoursEmploiDansPRC(), attributionCourante.getDateAttribution());
        if (srrip.compareTo(plafond) > 0) {
          retour = true;
        }
      }
    }
    return retour;
  }
  
  protected void alimenterAffiliationRequise(ElementBaseIndemnisation ebi, Attribution attributionCourante)
  {
    if (attributionCourante.getValidationProduit() != null)
    {
      ebi.setAffiliationRequisePourPRA(attributionCourante.getValidationProduit().getHeuresRequises());
      ebi.setRangAllongementPRA(attributionCourante.getValidationProduit().getRangAllongement());
    }
  }
  
  private static void alimenterDonneesSpectacle2016(Attribution attribution, ElementBaseIndemnisation ebi)
  {
    alimenterCepDelaisReportSpectacle2016(attribution, ebi);
    alimenterCepDateLimiteIndemnisationSpectacle2016(attribution, ebi);
    alimenterClauseDeRattrapage(attribution, ebi);
    alimenterDonneesMontantsPourFranchise(attribution, ebi);
  }
  
  private static void alimenterClauseDeRattrapage(Attribution attribution, ElementBaseIndemnisation ebi)
  {
    DemandeSpec demande = attribution.getDemande();
    List<String> liste = new ArrayList();
    liste.add("ENTREECRA");
    liste.add("ENCOURSCRA");
    
    boolean clauseRattrapage = OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent((Demande)demande, liste);
    ebi.setClauseRattrapage(clauseRattrapage);
    if (clauseRattrapage)
    {
      QuantiteEuro montant = attribution.getConstitutionElementsActifs().getConstitutionMontantsBruts().getMontantJournalierBrutNonPrecompte();
      ebi.setMontantCRA(montant.getValeur());
    }
  }
  
  private static void alimenterCepDateLimiteIndemnisationSpectacle2016(Attribution attribution, ElementBaseIndemnisation ebi)
  {
    ConstitutionDateLimiteIndemnisation constitution = attribution.getConstitutionElementsActifs().getConstitutionDateLimiteIndemnisation();
    if (constitution != null) {
      ebi.setDateLimiteIndemnisation(constitution.getDateLimiteIndemnisation());
    }
  }
  
  private static void alimenterCepDelaisReportSpectacle2016(Attribution attribution, ElementBaseIndemnisation ebi)
  {
    ConstitutionDelaisReport cepDelaisReports = attribution.getConstitutionDelaisReport();
    if (cepDelaisReports != null)
    {
      if (((ProduitAsuSpectacleSpec)attribution.getProduit()).estProduitGerantFranchiseCP())
      {
        if (cepDelaisReports.getQuantiteFranchiseCPMensuelle() != null) {
          ebi.setQuantiteMensConsomFranchiseCp(cepDelaisReports.getQuantiteFranchiseCPMensuelle().getValeurEntiere());
        }
        ebi.setDureeFranchiseCp(cepDelaisReports.getFranchiseCongesPayes());
      }
      if (((ProduitAsuSpectacleSpec)attribution.getProduit()).estProduitGerantFranchiseSalaire())
      {
        if (cepDelaisReports.getQuantiteFranchiseSalaireMensuelle() != null) {
          ebi.setQuantiteMensConsomFranchiseSalaire(cepDelaisReports.getQuantiteFranchiseSalaireMensuelle().getValeurEntiere());
        }
        ebi.setDureeFranchiseSalaire(cepDelaisReports.getNbJoursCarenceStandard());
      }
      List<CarencePrefixeAFixer> listeCarences = cepDelaisReports.getListCarence();
      for (CarencePrefixeAFixer courante : listeCarences) {
        if ("5".equals(courante.getTypeCarence())) {
          ebi.setNombreJoursDelaiAttente(courante.getQuantiteInitiale().getValeurEntiere());
        }
      }
    }
  }
  
  private static void alimenterDonneesMontantsPourFranchise(Attribution attribution, ElementBaseIndemnisation ebi)
  {
    ConstitutionMontantsBruts cep = attribution.getConstitutionMontantsBruts();
    if (cep != null)
    {
      if (cep.getMontantJournalierBrutNonPrecompte() != null) {
        ebi.setMontantBrut(cep.getMontantJournalierBrutNonPrecompte().getValeur());
      }
      if (cep.getMontantJournalierBrut() != null) {
        ebi.setMontantBrutPrecompte(cep.getMontantJournalierBrut().getValeur());
      }
    }
  }
  
  private static void prendreEnCompteCRC(Attribution attribution, ElementBaseIndemnisation ebi)
  {
    Attribution attributionOrigine = (Attribution)attribution.getOuvertureDroit();
    Damj dateAttribution = attributionOrigine.getDateAttribution();
    
    ebi.setAvecPrecompteCRC(Boolean.TRUE);
    if (dateAttribution.estApresOuCoincideAvec(DATE_PRISE_EN_COMPTE_CRC_APS)) {
      ebi.setAvecPrecompteCRC(Boolean.FALSE);
    }
  }
  
  private static Sjr getSjr(Attribution attribution)
  {
    Demande demande = (Demande)attribution.getDemande();
    
    String contexteDemande = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "AREMAYOTTE") ? "AREMAYOTTE" : null;
    
    ConstitutionSalaireJournalierMoyen cSjm = attribution.getConstitutionSalaireJournalierMoyen();
    Sjr sjr = null;
    if ((cSjm != null) && (cSjm.getMontantSalaireJournalierMoyenInitial() != null)) {
      sjr = new Sjr(cSjm.getMontantSalaireJournalierMoyenInitial().getValeurMontant(), cSjm.getDateSalaireJournalierMoyenInitial(), contexteDemande);
    }
    return sjr;
  }
}

/* Location:
 * Qualified Name:     RecuperationElementIndemnisation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */