package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationDiffere;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Reprise;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public final class VerificationDonneesForceesPostLiquidation
{
  private static void verifierSRIPInferieurTotalSalaire(DossierExamen dossierExamen)
    throws CoucheLogiqueException
  {
    ConstitutionSalaireReference constitutionSalaireReference = dossierExamen.getConstitutionElementsActifs().getConstitutionSalaireReference();
    if ((constitutionSalaireReference != null) && (constitutionSalaireReference.getSalaireReferenceInitialPlafonne() != null))
    {
      BigDecimal srip = constitutionSalaireReference.getSalaireReferenceInitialPlafonne().getValeur();
      
      ConstitutionDelaisReport constitutionDelaisReport = dossierExamen.getConstitutionElementsActifs().getConstitutionDelaisReport();
      if ((constitutionDelaisReport != null) && (constitutionDelaisReport.getJustificationDiffere() != null) && (constitutionDelaisReport.getJustificationDiffere().getTotalSalairesNonPlafonnes() != null))
      {
        BigDecimal totalSalaireNP = constitutionDelaisReport.getJustificationDiffere().getTotalSalairesNonPlafonnes().getValeur();
        if (srip.compareTo(totalSalaireNP) == 1) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_N_SRIP_INFERIEUR_TOTAL_SALAIRE", 1);
        }
      }
    }
  }
  
  private static void verifierDebutPRAApresFGDPrecedent(DossierExamen dossierExamen)
    throws CoucheLogiqueException
  {
    ValidationProduit validationProduit = dossierExamen.getValidationProduit();
    if ((validationProduit != null) && (validationProduit.getPeriodePra() != null))
    {
      Damj dateDebutPra = validationProduit.getPeriodePra().getDebut();
      AttributionAssuranceSpec attributionPrecedente = dossierExamen.getAttributionPrecedente();
      if ((attributionPrecedente != null) && (!(dossierExamen instanceof Reprise)))
      {
        Damj dateFaitGenerateurAttribPrecedente = attributionPrecedente.getDateFaitGenerateur();
        if ((dateFaitGenerateurAttribPrecedente != null) && (dateDebutPra.estAvant(dateFaitGenerateurAttribPrecedente))) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_N_SRIP_DEBUT_PRA_AVANT_FG_DROIT_PREC", 1);
        }
      }
    }
  }
  
  public static void verifierDonneesForceesPostLiquidationSpectacle(Demande demande)
    throws CoucheLogiqueException
  {
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    if ((demande.getDonneesTemporaires().getSripSpectacle() != null) || (demande.getDonneesTemporaires().getTotalRemunerationDansPRC() != null)) {
      verifierSRIPInferieurTotalSalaire(dossierExamen);
    }
    if (demande.getDonneesTemporaires().getRangAllongementPraSpectacle() != null) {
      verifierDebutPRAApresFGDPrecedent(dossierExamen);
    }
  }
  
  public static void verifierDonneesForceesPostLiquidationAreSpectacle(Demande demande)
    throws CoucheLogiqueException
  {
    verifierDonneesForceesPostLiquidationSpectacle(demande);
  }
}

/* Location:
 * Qualified Name:     VerificationDonneesForceesPostLiquidation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */