package fr.unedic.cali.asu.spe02.p05.liquidation.dom;

import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ObjectifExamenSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionDateAttribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionReglementApplicable;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionAge;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionChomageInvolontaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionCumulPrestationFamiliale;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionMontantProduitNonNul;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionRechercheEmploi;
import fr.unedic.cali.asu.spe02.p05.liquidation.dom.gen.ObjectifExamenAdmissionGen;
import fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels.faitgenerateur.DeterminationConditionFaitGenerateurConvention2016;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.ParcoursConditionAnciennete;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.ParcoursConstitutionCapitalAvecDureeEffective;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.ParcoursConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.ParcoursConstitutionDelaisReports;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.ParcoursObjectifAdmission;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.cep.montant.ParcoursConstitutionMontantBrut;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.cep.nht.ParcoursConstitutionNbHeuresTravaillees;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.cep.sjm.ConstitutionSalaireReferenceEtSjm;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.parcours.ParcoursTraitementSatisfait;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import java.util.List;

public class ObjectifExamenAdmission
  extends ObjectifExamenAdmissionGen
  implements ObjectifExamenSpec
{
  private static final long serialVersionUID = 1L;
  private List<ContexteDemandeSpec> contexteDemande;
  
  public ObjectifExamenAdmission(DomPCSpec pc)
  {
    super(pc);
  }
  
  public ObjectifExamenAdmission() {}
  
  public ObjectifExamenAdmission(List<ContexteDemandeSpec> contexteDemande)
  {
    this.contexteDemande = contexteDemande;
  }
  
  public Parcours creerParcoursObjectif()
  {
    return new ParcoursObjectifAdmission();
  }
  
  public ObjectifExamen getObjectifSauvegarde()
    throws CoucheLogiqueException
  {
    return (ObjectifExamen)copie();
  }
  
  public int getType()
  {
    return 1;
  }
  
  public void marquerGraphePersistant() {}
  
  public ObjetMetierSpec copie()
  {
    ObjectifExamenAdmission copie = new ObjectifExamenAdmission();
    copieElements(copie);
    return copie;
  }
  
  public Parcours creerParcoursConstitutionDureePostPrime()
  {
    return null;
  }
  
  public Parcours creerParcoursCapitalAvecDureeEffective()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contexteDemande, "ARESJREV")) {
      return new ParcoursConstitutionCapitalAvecDureeEffective();
    }
    return null;
  }
  
  public Parcours creerParcoursConditionAffiliation()
  {
    return new DeterminationConditionAffiliation();
  }
  
  public Parcours creerParcoursConditionAge()
  {
    return new DeterminationConditionAge();
  }
  
  public Parcours creerParcoursConditionBeneficeAutreProduit()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionChomageInvolontaire()
  {
    Parcours parcoursRetour;
    Parcours parcoursRetour;
    if (OutilGestionContexteDemande.estContextePresentDansRegroupement(contexteDemande, 8)) {
      parcoursRetour = new ParcoursTraitementSatisfait();
    } else {
      parcoursRetour = new DeterminationConditionChomageInvolontaire();
    }
    return parcoursRetour;
  }
  
  public Parcours creerParcoursConditionCumulPrestationFamiliale()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contexteDemande, "ARESJREV")) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionCumulPrestationFamiliale();
  }
  
  public Parcours creerParcoursConditionDureeNonNulle()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionFaitGenerateur()
  {
    return new DeterminationConditionFaitGenerateurConvention2016();
  }
  
  public Parcours creerParcoursConditionMontantProduitNonNul()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contexteDemande, "ARESJREV")) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionMontantProduitNonNul();
  }
  
  public Parcours creerParcoursConditionRechercheEmploi()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contexteDemande, "ARESJREV")) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionRechercheEmploi();
  }
  
  public Parcours creerParcoursConditionValiditeReliquat()
  {
    return null;
  }
  
  public Parcours creerParcoursDateAttribution()
  {
    return new ConstitutionDateAttribution();
  }
  
  public Parcours creerParcoursDelaisReports()
  {
    return new ParcoursConstitutionDelaisReports();
  }
  
  public Parcours creerParcoursDureeEffective()
  {
    return null;
  }
  
  public Parcours creerParcoursDurees()
  {
    return null;
  }
  
  public Parcours creerParcoursMontantsBruts()
  {
    return new ParcoursConstitutionMontantBrut();
  }
  
  public Parcours creerParcoursNbHeuresTravaillees()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contexteDemande, "ENTREECRA")) {
      return new ParcoursTraitementSatisfait();
    }
    return new ParcoursConstitutionNbHeuresTravaillees();
  }
  
  public Parcours creerParcoursPointDeDepart()
  {
    return new ConstitutionPointDepartIndemnisation();
  }
  
  public Parcours creerParcoursReglementApplicable()
  {
    return new ConstitutionReglementApplicable();
  }
  
  public Parcours creerParcoursSalaireJournalierMoyen()
  {
    return new ConstitutionSalaireReferenceEtSjm();
  }
  
  public Parcours creerParcoursDateLimiteIndemnisation()
  {
    return new ParcoursConstitutionDateLimiteIndemnisation();
  }
  
  public List<ContexteDemandeSpec> getContexteDemande()
  {
    return contexteDemande;
  }
  
  public void setContexteDemande(List<ContexteDemandeSpec> contexteDemande)
  {
    this.contexteDemande = contexteDemande;
  }
  
  public Parcours creerParcoursConditionAnciennete()
  {
    Parcours parcours;
    Parcours parcours;
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contexteDemande, "ENTREECRA")) {
      parcours = new ParcoursConditionAnciennete();
    } else {
      parcours = new ParcoursTraitementSatisfait();
    }
    return parcours;
  }
}

/* Location:
 * Qualified Name:     ObjectifExamenAdmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */