package fr.unedic.cali.asu.spe02.p05.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireEmployeur;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ParametresCalculAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.List;

public class ParametresAffiliation
  extends fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.ParametresAffiliation
{
  private static final int SCALE_ROUNDING = 2;
  private static final BigDecimal VALEUR_REQUISE_INITIALE = new BigDecimal(507);
  private static final BigDecimal VALEUR_REQUISE_INITIALE_CLAUSE_RATTRAPAGE = new BigDecimal(338);
  private static final BigDecimal ALLONGEMENT_RANG_N = new BigDecimal(42);
  protected static final DureeCalendaire DUREE_PERIODE = new DureeCalendaire(0, 0, 365);
  private static final DureeCalendaire ALLONGEMENT_RANG_N_PERIODE_REFERENCE = new DureeCalendaire(0, 0, 30);
  public static final DureeCalendaire AGE_PIVOT_PLAFOND_ENSEIGNEMENT = new DureeCalendaire(50);
  public static final Quantite PLAFOND_HEURE_ENSEIGNEMENT_AVANT_50_ANS = new Quantite(new BigDecimal(70), UNITE_HEURE);
  public static final Quantite PLAFOND_HEURE_ENSEIGNEMENT_APRES_50_ANS = new Quantite(new BigDecimal(120), UNITE_HEURE);
  private static final BigDecimal PLAFOND_HEURE_MENSUEL_MULTI_EMPLOYEUR_SANS_DEROGATION = BigDecimal.valueOf(250L);
  private static final BigDecimal PLAFOND_HEURE_MENSUEL_MULTI_EMPLOYEUR_AVEC_DEROGATION = BigDecimal.valueOf(260L);
  private static final BigDecimal PLAFOND_HEURE_MENSUEL_MONO_EMPLOYEUR_SANS_DEROGATION = BigDecimal.valueOf(208L);
  private static final BigDecimal PLAFOND_HEURE_MENSUEL_MONO_EMPLOYEUR_AVEC_DEROGATION = BigDecimal.valueOf(260L);
  private static final BigDecimal COEFFICIENT_REDUCTEUR = BigDecimal.valueOf(20.8D);
  private static final BigDecimal PLAFOND_CACHET_MENSUEL = BigDecimal.valueOf(28L);
  
  public BigDecimal determinerQuantiteAffiliationRequise(ParametresCalculAffiliation parametres)
  {
    BigDecimal dureeAffiInitial = determinerQuantiteRequiseInitialPourReglement(parametres);
    BigDecimal parametresAllongementAffi = determinerAllongementQuantiteRequisePourRangSelonReglement(parametres);
    BigDecimal rangEtudie = new BigDecimal(parametres.getRangEtude());
    return dureeAffiInitial.add(parametresAllongementAffi.multiply(rangEtudie));
  }
  
  public DureeCalendaire determinerDureePeriodeReference(ParametresCalculAffiliation parametres)
  {
    int dureePeriodeInitial = determinerDureePeriodeReferenceInitialPourReglement(parametres).getJours();
    int parametresAllongementDuree = determinerAllongementDureePeriodeReferencePourRangSelonReglement(parametres).getJours();
    int dureeAllonge = dureePeriodeInitial + parametresAllongementDuree * parametres.getRangEtude();
    return new DureeCalendaire(0, 0, dureeAllonge);
  }
  
  protected DureeCalendaire determinerDureePeriodeReferenceInitialPourReglement(ParametresCalculAffiliation parametres)
  {
    return DUREE_PERIODE;
  }
  
  public Quantite determinerPlafondHeureEnseignement(IndividuSpec individu, ComportementAffiliationSpec comportementCalcul)
  {
    DureeCalendaire ageIndividuAuFGD = individu.getAgeALaDate(comportementCalcul.getFaitGenerateur().getDateFin());
    if (ageIndividuAuFGD.getAnnees() < AGE_PIVOT_PLAFOND_ENSEIGNEMENT.getAnnees()) {
      return PLAFOND_HEURE_ENSEIGNEMENT_AVANT_50_ANS;
    }
    return PLAFOND_HEURE_ENSEIGNEMENT_APRES_50_ANS;
  }
  
  public BigDecimal determinerPlafondHeureApplicable(PeriodeElementaireAffiliation periodeElementaire, Chronologie chronoActivitesParticipantes)
  {
    BigDecimal baseCalculPlafond = PLAFOND_HEURE_MENSUEL_MULTI_EMPLOYEUR_SANS_DEROGATION;
    List<PeriodeElementaireEmployeur> listEmployeur = periodeElementaire.getListPeriodeElementaireEmployeur();
    for (PeriodeElementaireEmployeur employeur : listEmployeur) {
      if (employeur.isDerogation()) {
        baseCalculPlafond = PLAFOND_HEURE_MENSUEL_MULTI_EMPLOYEUR_AVEC_DEROGATION;
      }
    }
    baseCalculPlafond = determinerPlafondCoeficientReduit(periodeElementaire, baseCalculPlafond);
    
    return baseCalculPlafond;
  }
  
  public BigDecimal determinerPlafondCachetSurPeriodeElementaire(PeriodeElementaireAffiliation periodeElementaire)
  {
    BigDecimal baseCalculPlafond = PLAFOND_CACHET_MENSUEL;
    
    return determinerPlafondCoeficientReduit(periodeElementaire, baseCalculPlafond);
  }
  
  public void determinerPlafondMonoEmployeur(PeriodeElementaireAffiliation periodeElementaire)
  {
    List<PeriodeElementaireEmployeur> listEmployeur = periodeElementaire.getListPeriodeElementaireEmployeur();
    for (PeriodeElementaireEmployeur employeur : listEmployeur)
    {
      employeur.setPlafond(determinerPlafondCoeficientReduit(periodeElementaire, PLAFOND_HEURE_MENSUEL_MONO_EMPLOYEUR_SANS_DEROGATION));
      if (employeur.isDerogation()) {
        employeur.setPlafond(determinerPlafondCoeficientReduit(periodeElementaire, PLAFOND_HEURE_MENSUEL_MONO_EMPLOYEUR_AVEC_DEROGATION));
      }
      BigDecimal nombreHeure = BigDecimal.ZERO;
      BigDecimal heurePlafondMono = BigDecimal.ZERO;
      if (employeur.getHeuresA8Totales() != null) {
        nombreHeure = nombreHeure.add(employeur.getHeuresA8Totales());
      }
      if (employeur.getHeuresA10Totales() != null) {
        nombreHeure = nombreHeure.add(employeur.getHeuresA10Totales());
      }
      employeur.setEstPlafonneMonoEmployeur(false);
      if (employeur.getPlafond().compareTo(nombreHeure) < 0) {
        employeur.setEstPlafonneMonoEmployeur(true);
      }
      BigDecimal heuresPlafonnees = employeur.getPlafond().min(nombreHeure);
      
      employeur.setHeuresPlafonnees(heuresPlafonnees);
      if (periodeElementaire.getHeuresApresPlafonnementMonoEmployeur() != null) {
        heurePlafondMono = periodeElementaire.getHeuresApresPlafonnementMonoEmployeur();
      }
      periodeElementaire.setHeuresApresPlafonnementMonoEmployeur(heurePlafondMono.add(heuresPlafonnees));
    }
  }
  
  protected BigDecimal determinerAllongementQuantiteRequisePourRangSelonReglement(ParametresCalculAffiliation parametres)
  {
    return ALLONGEMENT_RANG_N;
  }
  
  protected DureeCalendaire determinerAllongementDureePeriodeReferencePourRangSelonReglement(ParametresCalculAffiliation parametres)
  {
    return ALLONGEMENT_RANG_N_PERIODE_REFERENCE;
  }
  
  private BigDecimal determinerPlafondCoeficientReduit(PeriodeElementaireAffiliation periodeElementaire, BigDecimal baseCalculPlafond)
  {
    BigDecimal nbJours = new BigDecimal(periodeElementaire.getMois().getDuree());
    BigDecimal coefficient = nbJours.divide(COEFFICIENT_REDUCTEUR, 2, RoundingMode.UP);
    coefficient = coefficient.min(BigDecimal.ONE);
    return arrondirEntierSuperieur(coefficient.multiply(baseCalculPlafond));
  }
  
  protected Periode determinerMoisCivilSelonPeriodeElementaire(PeriodeElementaireAffiliation periodeElementaire)
  {
    return new Periode(periodeElementaire.getMois().getDebut().getDebutMois(), periodeElementaire.getMois().getFin().getFinMois());
  }
  
  public BigDecimal determinerQuantiteRequiseInitialPourReglement(ParametresCalculAffiliation parametres)
  {
    BigDecimal resultat = VALEUR_REQUISE_INITIALE;
    if ((parametres.getDemande() != null) && (estContexteEntreeClauseRattrapage(parametres.getDemande()))) {
      resultat = VALEUR_REQUISE_INITIALE_CLAUSE_RATTRAPAGE;
    }
    return resultat;
  }
  
  protected boolean estContexteEntreeClauseRattrapage(DemandeAssuranceSpec demande)
  {
    return OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "ENTREECRA");
  }
}

/* Location:
 * Qualified Name:     ParametresAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */