package fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationReductionSalaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationReductionSalaireMoisCivil;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationReductionSalairePeriodeActiviteSurMois;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireEmployeur;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationSalaireReference;
import fr.unedic.cali.asu.spe02.p05.liquidation.outilsaffiliation.ConvertisseurUniteAffiliation;
import fr.unedic.cali.asu.spe02.p05.liquidation.outilsaffiliation.OutilPeriodeElementaire;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;

public class DeterminationSalaireReferenceSPE02P05
  extends DeterminationSalaireReference
{
  private static final String CONTEXTE_NON_PLAFONNE = "0";
  private static final String CONTEXTE_PLAFONNE_MONO = "1";
  private static final String CONTEXTE_PLAFONNE_MONO_ET_MULTI = "2";
  private static final String CONTEXTE_PLAFONNE_MULTI = "3";
  private Damj dateExamen;
  private Damj dateCalcul;
  private IndividuSpec individu;
  
  protected void alimenterJustificationReductionSalaire(ConstitutionSalaireReference constitutionSalaireReference, Demande demande, Chronologie chronoActivitesSalaries)
    throws CoucheLogiqueException
  {
    JustificationAffiliation justificationAffiliation = ((ValidationProduit)demande.getDossierAffectationAdmission().getValidationProduit()).getJustificationAffiliation();
    Iterator<PeriodeElementaireAffiliation> iterateurPeriodeElemAffi;
    if (justificationAffiliation != null)
    {
      setDateExamen(demande.getDateExamen());
      setDateCalcul(demande.getDateFaitGenerateurOuDernierSinistre());
      setIndividu(demande.getDemandeur());
      
      Collection<PeriodeElementaireAffiliation> collectionPeriodeElementaireAffiliation = justificationAffiliation.getCollectionPeriodeElementaireAffiliation();
      for (iterateurPeriodeElemAffi = collectionPeriodeElementaireAffiliation.iterator(); iterateurPeriodeElemAffi.hasNext();)
      {
        PeriodeElementaireAffiliation periodeElementaireAffiliationCourante = (PeriodeElementaireAffiliation)iterateurPeriodeElemAffi.next();
        
        JustificationReductionSalaireMoisCivil justif = justifierEcretement(periodeElementaireAffiliationCourante, chronoActivitesSalaries);
        if (justif != null) {
          constitutionSalaireReference.getJustificationReductionSalaire().ajouterMoisCivils(justif);
        }
      }
    }
  }
  
  protected JustificationReductionSalaireMoisCivil justifierEcretement(PeriodeElementaireAffiliation periode, Chronologie chronoActivitesSalaries)
    throws CoucheLogiqueException
  {
    boolean plafonneMulti = false;
    
    boolean ecretementHeure = false;
    
    JustificationReductionSalaireMoisCivil justif = initialiserJustifSRMoisCivil(periode);
    
    boolean ecretementCachet = ecreterCachets(periode, justif);
    
    BigDecimal heuresApresPlafMono = BigDecimal.ZERO;
    if (periode.getHeuresApresPlafonnementMonoEmployeur() != null) {
      heuresApresPlafMono = periode.getHeuresApresPlafonnementMonoEmployeur();
    }
    justif.setHeuresMulti(Mathematiques.arrondiASup(heuresApresPlafMono, 2));
    justif.setPlafondMulti(periode.getMontantPlafondHeures());
    if (periode.isEstPlafonneMultiEmployeur()) {
      plafonneMulti = true;
    }
    List<PeriodeElementaireEmployeur> listPeriodeEmployeur = periode.getListPeriodeElementaireEmployeur();
    for (PeriodeElementaireEmployeur sousPeriode : listPeriodeEmployeur)
    {
      boolean plafonneMono = false;
      
      BigDecimal nombreHeure = getNombreHeures(sousPeriode);
      if (sousPeriode.isEstPlafonneMonoEmployeur()) {
        plafonneMono = true;
      }
      BigDecimal coefFinal = calculerCoefficientEcretement(plafonneMono, plafonneMulti, nombreHeure, sousPeriode.getPlafond(), periode.getHeuresApresPlafonnementMonoEmployeur(), periode.getMontantPlafondHeures());
      
      Boolean ecretementHeureCourant = Boolean.valueOf(coefFinal.compareTo(BigDecimal.ONE) < 0);
      ecretementHeure = (ecretementHeure) || (ecretementHeureCourant.booleanValue());
      
      ListIterator<ActiviteSalarie> iteratorActivite = chronoActivitesSalaries.iterer();
      while (iteratorActivite.hasNext())
      {
        ActiviteSalarie activite = (ActiviteSalarie)iteratorActivite.next();
        if (estEmployeurCorrespondant(periode, sousPeriode, activite))
        {
          Periode periodeActiviteSurMois = activite.getPeriode().periodeIntersection(periode.getMois());
          
          JustificationReductionSalairePeriodeActiviteSurMois sousJustif = initialiserJustifRSPeriodeActivite(sousPeriode, periodeActiviteSurMois);
          sousJustif.setHeuresMono(Mathematiques.arrondiASup(nombreHeure, 2));
          sousJustif.setPlafondMono(sousPeriode.getPlafond());
          
          sousJustif.setCoefEcretementHeures(coefFinal);
          if ((ecretementHeureCourant.booleanValue()) || (ecretementCachet))
          {
            alimenterHeuresEtCachet(sousJustif, activite, periode.getMois());
            finaliserJustifRsActivite(plafonneMulti, plafonneMono, justif, sousJustif);
          }
        }
      }
    }
    justif = finaliserJustifRsMoisCivil(ecretementCachet, ecretementHeure, justif);
    
    return justif;
  }
  
  private BigDecimal calculerCoefficientEcretement(boolean plafonnementMono, boolean plafonnementMulti, BigDecimal heuresMono, BigDecimal plafondMono, BigDecimal heuresMulti, BigDecimal plafondMulti)
  {
    BigDecimal retour = BigDecimal.ONE;
    if ((plafonnementMono) && (plafonnementMulti))
    {
      BigDecimal plafond = plafondMono.multiply(plafondMulti);
      BigDecimal heures = heuresMono.multiply(heuresMulti);
      retour = plafond.divide(heures, 4, 0);
    }
    else if (plafonnementMono)
    {
      retour = plafondMono.divide(heuresMono, 4, 0);
    }
    else if (plafonnementMulti)
    {
      retour = plafondMulti.divide(heuresMulti, 4, 0);
    }
    return arrondirValeurPourPersistenceEtJustification(retour, 4);
  }
  
  protected void alimenterHeuresEtCachet(JustificationReductionSalairePeriodeActiviteSurMois sousJustif, ActiviteSalarie activite, Periode mois)
    throws CoucheLogiqueException
  {
    BigDecimal nombreHeuresActivite = BigDecimal.ZERO;
    BigDecimal nombreCachetsIsolesActivite = BigDecimal.ZERO;
    BigDecimal nombreCachetsGroupesActivite = BigDecimal.ZERO;
    
    PeriodeElementaireAffiliation nouvellePeriodeElementaireAffiliation = new PeriodeElementaireAffiliation();
    nouvellePeriodeElementaireAffiliation.setMois(mois);
    OutilPeriodeElementaire.getInstance().calculerQuantiteTravail(getIndividu(), nouvellePeriodeElementaireAffiliation, activite, getDateCalcul(), null, getDateExamen(), ConvertisseurUniteAffiliation.getInstance());
    if (nouvellePeriodeElementaireAffiliation.getHeuresA8() != null) {
      nombreHeuresActivite = nombreHeuresActivite.add(nouvellePeriodeElementaireAffiliation.getHeuresA8());
    }
    if (nouvellePeriodeElementaireAffiliation.getHeuresA10() != null) {
      nombreHeuresActivite = nombreHeuresActivite.add(nouvellePeriodeElementaireAffiliation.getHeuresA10());
    }
    if (nouvellePeriodeElementaireAffiliation.getCachetIsoleA8() != null) {
      nombreCachetsIsolesActivite = nombreCachetsIsolesActivite.add(nouvellePeriodeElementaireAffiliation.getCachetIsoleA8());
    }
    if (nouvellePeriodeElementaireAffiliation.getCachetIsoleA10() != null) {
      nombreCachetsIsolesActivite = nombreCachetsIsolesActivite.add(nouvellePeriodeElementaireAffiliation.getCachetIsoleA10());
    }
    if (nouvellePeriodeElementaireAffiliation.getCachetGroupeA8() != null) {
      nombreCachetsGroupesActivite = nombreCachetsGroupesActivite.add(nouvellePeriodeElementaireAffiliation.getCachetGroupeA8());
    }
    if (nouvellePeriodeElementaireAffiliation.getCachetGroupeA10() != null) {
      nombreCachetsGroupesActivite = nombreCachetsGroupesActivite.add(nouvellePeriodeElementaireAffiliation.getCachetGroupeA10());
    }
    sousJustif.setNombreHeures(arrondirValeurPourPersistenceEtJustification(nombreHeuresActivite, 2));
    
    sousJustif.setNombreCachetsIsoles(arrondirValeurPourPersistenceEtJustification(nombreCachetsIsolesActivite, 2));
    
    sousJustif.setNombreCachetsGroupes(arrondirValeurPourPersistenceEtJustification(nombreCachetsGroupesActivite, 2));
  }
  
  protected boolean estEmployeurCorrespondant(PeriodeElementaireAffiliation periode, PeriodeElementaireEmployeur sousPeriode, ActiviteSalarie activite)
  {
    return (activite.chevauche(periode.getMois())) && (OutilPeriodeElementaire.recupererIdentifiantEntreprise(activite.getEntreprise()).equals(sousPeriode.getNumeroSiret()));
  }
  
  protected BigDecimal getNombreHeures(PeriodeElementaireEmployeur sousPeriode)
  {
    BigDecimal nombreHeure = BigDecimal.ZERO;
    if (sousPeriode.getHeuresA8Totales() != null) {
      nombreHeure = sousPeriode.getHeuresA8Totales();
    }
    if (sousPeriode.getHeuresA10Totales() != null) {
      nombreHeure = nombreHeure.add(sousPeriode.getHeuresA10Totales());
    }
    return nombreHeure;
  }
  
  protected JustificationReductionSalaireMoisCivil finaliserJustifRsMoisCivil(boolean ecretementCachet, boolean ecretementHeure, JustificationReductionSalaireMoisCivil justif)
  {
    JustificationReductionSalaireMoisCivil retour = justif;
    if ((!ecretementHeure) && (!ecretementCachet)) {
      retour = null;
    }
    return retour;
  }
  
  protected void finaliserJustifRsActivite(boolean plafonneMulti, boolean plafonneMono, JustificationReductionSalaireMoisCivil justif, JustificationReductionSalairePeriodeActiviteSurMois sousJustif)
  {
    if ((plafonneMulti) && (!plafonneMono))
    {
      sousJustif.setContexteEcretement("3");
      justif.ajouterPeriodeActiviteSurMois(sousJustif);
    }
    else if ((plafonneMulti) && (plafonneMono))
    {
      sousJustif.setContexteEcretement("2");
      justif.ajouterPeriodeActiviteSurMois(sousJustif);
    }
    else if ((!plafonneMulti) && (plafonneMono))
    {
      sousJustif.setContexteEcretement("1");
      justif.ajouterPeriodeActiviteSurMois(sousJustif);
    }
    else
    {
      sousJustif.setContexteEcretement("0");
      justif.ajouterPeriodeActiviteSurMois(sousJustif);
    }
  }
  
  protected boolean ecreterCachets(PeriodeElementaireAffiliation periode, JustificationReductionSalaireMoisCivil justif)
  {
    boolean ecretementCachet = false;
    if (periode.isPlafondCachetsDepasse())
    {
      BigDecimal coefficientCachet = determinerCoefficientEcretementCachets(periode, justif);
      ecretementCachet = coefficientCachet.compareTo(BigDecimal.ONE) < 0;
    }
    return ecretementCachet;
  }
  
  private JustificationReductionSalairePeriodeActiviteSurMois initialiserJustifRSPeriodeActivite(PeriodeElementaireEmployeur employeur, Periode periode)
  {
    JustificationReductionSalairePeriodeActiviteSurMois justifReductionSalairePeriodeActiviteSurMoisCivilCourant = new JustificationReductionSalairePeriodeActiviteSurMois();
    
    justifReductionSalairePeriodeActiviteSurMoisCivilCourant.setPeriode(periode);
    justifReductionSalairePeriodeActiviteSurMoisCivilCourant.setRaisonSociale(employeur.getRaisonSociale());
    justifReductionSalairePeriodeActiviteSurMoisCivilCourant.setSiren(employeur.getNumeroSiret());
    
    return justifReductionSalairePeriodeActiviteSurMoisCivilCourant;
  }
  
  private JustificationReductionSalaireMoisCivil initialiserJustifSRMoisCivil(PeriodeElementaireAffiliation periode)
  {
    JustificationReductionSalaireMoisCivil justifReductionSalaireMoisCivilCourant = new JustificationReductionSalaireMoisCivil();
    justifReductionSalaireMoisCivilCourant.setPeriode(periode.getMois());
    return justifReductionSalaireMoisCivilCourant;
  }
  
  protected BigDecimal getCoefficientEcretementHeures(JustificationReductionSalaireMoisCivil justifReductionSalaireMoisCivilCourant, ActiviteSalarie activite)
  {
    String siren = activite.getEntreprise().getSiren();
    BigDecimal coefficient = BigDecimal.ONE;
    
    List<JustificationReductionSalairePeriodeActiviteSurMois> liste = justifReductionSalaireMoisCivilCourant.getListPeriodeActiviteSurMois();
    for (JustificationReductionSalairePeriodeActiviteSurMois justifActivite : liste) {
      if (justifActivite.getSiren().equals(siren)) {
        coefficient = justifActivite.getCoefEcretementHeures();
      }
    }
    return coefficient;
  }
  
  protected void determinerSrip(QuantiteEuro sripForce, Demande demande, ConstitutionSalaireReference constitutionSalaireReference, Chronologie chronoActivitesSalariesParticipantSr)
    throws CoucheLogiqueException
  {
    if (sripForce != null)
    {
      constitutionSalaireReference.setSalaireReferenceInitialPlafonne(sripForce);
    }
    else
    {
      determinerSrip(constitutionSalaireReference, demande, chronoActivitesSalariesParticipantSr);
      ValidationProduit validationProduit = ((DossierExamen)demande.getDossierExamen()).getValidationProduit();
      JustificationAffiliation justificationAffiliation = validationProduit.getJustificationAffiliation();
      verifierForcageAffiliationSrip(justificationAffiliation);
      constitutionSalaireReference.setNombreJoursInactiviteDansPRC(new BigDecimal(justificationAffiliation.getNombreJourAssimilationSalaire()));
      BigDecimal sripMajore = majorerSrip(constitutionSalaireReference.getSalaireReferenceInitialPlafonne().getValeur(), constitutionSalaireReference.getPrc(), constitutionSalaireReference.getNombreJoursInactiviteDansPRC().intValue());
      
      constitutionSalaireReference.setSalaireReferenceInitial(new QuantiteEuro(sripMajore));
      constitutionSalaireReference.setSalaireReferenceInitialPlafonne(new QuantiteEuro(sripMajore));
    }
  }
  
  public static BigDecimal calculerPlafondSAR(int nombreJoursEmploi, int joursInactivite, Damj dateRevalorisation)
  {
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    BigDecimal plafondMensuelApplicable = parametresIndemnisation.getElementActif(dateRevalorisation).getPlafond();
    BigDecimal plafondJournalierApplicable = Mathematiques.proratiser(NBRE_MOIS_ANNEE, plafondMensuelApplicable, NBRE_JOURS_ANNEE);
    
    BigDecimal plafondSrr = plafondJournalierApplicable.multiply(BigDecimal.valueOf(nombreJoursEmploi + joursInactivite));
    
    return Mathematiques.tronque(plafondSrr, 2);
  }
  
  protected void verifierForcageAffiliationSrip(JustificationAffiliation justificationAffiliation)
    throws CoucheLogiqueException
  {
    if (justificationAffiliation == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_AFFI_FORCEE_FORCER_SRIP");
    }
  }
  
  protected BigDecimal majorerSrip(BigDecimal srip, Periode pra, int nombreJourAssimilationSalaire)
  {
    BigDecimal sripMajore = srip;
    BigDecimal nombreTotalJourInactivite = new BigDecimal(nombreJourAssimilationSalaire);
    BigDecimal nombreJourPra = new BigDecimal(pra.getDuree());
    if (nombreTotalJourInactivite.intValue() != 0) {
      sripMajore = srip.multiply(nombreJourPra).divide(nombreJourPra.subtract(nombreTotalJourInactivite), 2, 4);
    }
    return sripMajore;
  }
  
  protected void determinerPlafondPSrr(ConstitutionSalaireReference constitutionSalaireReference, Demande demande, Chronologie chronoActivitesSalariesParticipantSr, Damj dateRevalorisation)
  {
    int nbJoursEmploiPRC = determinerNbJoursEmploiDansPrcSpe02P05(demande.getDonneesTemporaires().getNbJourContratSurPraSpectacle(), constitutionSalaireReference.getPrc(), chronoActivitesSalariesParticipantSr);
    
    constitutionSalaireReference.setNombreJoursEmploiDansPRC(nbJoursEmploiPRC);
    
    int joursInactivite = 0;
    if (constitutionSalaireReference.getNombreJoursInactiviteDansPRC() != null) {
      joursInactivite = constitutionSalaireReference.getNombreJoursInactiviteDansPRC().intValue();
    }
    BigDecimal plafondSrr = calculerPlafondSARSpe02P05(nbJoursEmploiPRC, joursInactivite, dateRevalorisation);
    
    constitutionSalaireReference.setMontantPlafond(new QuantiteEuro(plafondSrr));
  }
  
  protected int determinerNbJoursEmploiDansPrcSpe02P05(Quantite nbJourContratSurPraSpectacleForce, Periode prc, Chronologie chronoActivitesSalariesParticipantSr)
  {
    return determinerNbJoursEmploiDansPrc(nbJourContratSurPraSpectacleForce, prc, chronoActivitesSalariesParticipantSr);
  }
  
  protected BigDecimal calculerPlafondSARSpe02P05(int nombreJoursEmploi, int joursInactivite, Damj dateRevalorisation)
  {
    return calculerPlafondSAR(nombreJoursEmploi, joursInactivite, dateRevalorisation);
  }
  
  public Damj getDateExamen()
  {
    return dateExamen;
  }
  
  public void setDateExamen(Damj dateExamen)
  {
    this.dateExamen = dateExamen;
  }
  
  public Damj getDateCalcul()
  {
    return dateCalcul;
  }
  
  public void setDateCalcul(Damj dateCalcul)
  {
    this.dateCalcul = dateCalcul;
  }
  
  public IndividuSpec getIndividu()
  {
    return individu;
  }
  
  public void setIndividu(IndividuSpec individu)
  {
    this.individu = individu;
  }
}

/* Location:
 * Qualified Name:     DeterminationSalaireReferenceSPE02P05
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */