package fr.unedic.cali.asu.spe02.p05.liquidation.parcours;

import fr.pe.cali.liquidation.outilsfonctionnels.dom.ResultatImputationSuiteArce;
import fr.pe.cali.reglementaire.dom.impl.CriteresFabriqueReglementaire;
import fr.pe.cali.reglementaire.regles.assurance.cep.delaisreports.fabrique.FabriqueCorpsRegleConstitutionDelaisReports;
import fr.pe.cali.reglementaire.regles.assurance.cep.delaisreports.outils.spec.IOutilConstitutionDelaisReportsSpectacle;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Differe;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.OutilDeterminationDelaisReportSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionDelaisReportPourReprise;
import fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels.OutilConstitutionDelaisReports;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class ParcoursConstitutionDelaisReportsPourReprise
  extends ConstitutionDelaisReportPourReprise
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    Resultat resultat = super.demarrer(contexte);
    
    determinerReliquatFranchiseSalaire(contexte);
    
    determinerReliquatFranchiseCP(contexte);
    
    determinerReliquatDiffere7Jours(contexte);
    return resultat;
  }
  
  protected OutilDeterminationDelaisReportSpec getOutilDeterminationDelaisReport()
  {
    return new OutilConstitutionDelaisReports();
  }
  
  protected void determinerReliquatFranchiseSalaire(Contexte contexte)
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    Attribution attribution = (Attribution)demande.getDossierExamen();
    ConstitutionDelaisReport cep = attribution.getConstitutionDelaisReport();
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    Quantite reliquat = dom.getResultatExecutionCalculDroitPrecedent().getReliquatFranchiseSalaire();
    if (reliquat != null) {
      cep.setNbJoursCarenceStandard(determinerReliquatFranchise(reliquat.getValeurEntiere(), dom.getResultatImputationArce()));
    }
    if (cep.getNbJoursCarenceStandard() > 0)
    {
      Attribution attributionPrecedente = (Attribution)dom.getResultatExecutionCalculDroitPrecedent().getAttributionEtudiee();
      cep.setQuantiteFranchiseSalaireMensuelle(attributionPrecedente.getConstitutionDelaisReport().getQuantiteFranchiseSalaireMensuelle());
    }
  }
  
  protected int determinerReliquatFranchise(int reliquat, ResultatImputationSuiteArce resultatImputationArce)
  {
    BigDecimal reliquatARetourner = BigDecimal.valueOf(reliquat);
    if ((resultatImputationArce != null) && (resultatImputationArce.isDateLimiteImputee())) {
      reliquatARetourner = BigDecimal.ZERO;
    }
    return reliquatARetourner.intValue();
  }
  
  protected void determinerReliquatFranchiseCP(Contexte contexte)
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    Attribution attribution = (Attribution)demande.getDossierExamen();
    ConstitutionDelaisReport cep = attribution.getConstitutionDelaisReport();
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    Quantite reliquat = dom.getResultatExecutionCalculDroitPrecedent().getReliquatFranchiseCP();
    if (reliquat != null) {
      cep.setFranchiseCongesPayes(determinerReliquatFranchise(reliquat.getValeurEntiere(), dom.getResultatImputationArce()));
    }
    if (cep.getFranchiseCongesPayes() > 0)
    {
      Attribution attributionPrecedente = (Attribution)dom.getResultatExecutionCalculDroitPrecedent().getAttributionEtudiee();
      cep.setQuantiteFranchiseCPMensuelle(attributionPrecedente.getConstitutionDelaisReport().getQuantiteFranchiseCPMensuelle());
    }
  }
  
  protected void determinerReliquatDiffere7Jours(Contexte contexte)
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    Attribution attribution = (Attribution)demande.getDossierExamen();
    IOutilConstitutionDelaisReportsSpectacle outil = recupererOutilReglementaire(attribution);
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    int reliquatDiffere = 0;
    Quantite reliquat = dom.getResultatExecutionCalculDroitPrecedent().getReliquatDelaiAttente();
    Periode periodeApplication = dom.getResultatExecutionCalculDroitPrecedent().getPeriodeApplicationDelaiAttente();
    Damj dateAttribution = attribution.getDateAttribution();
    if (reliquat != null) {
      reliquatDiffere = reliquat.getValeurEntiere();
    }
    int reliquatRestant = outil.calculerReliquatCarenceDiffere7Jours(reliquatDiffere, periodeApplication, dateAttribution);
    if (reliquatRestant > 0)
    {
      ConstitutionDelaisReport cep = attribution.getConstitutionDelaisReport();
      Differe differe = new Differe();
      differe.setQuantiteInitiale(new QuantiteJour(BigDecimal.valueOf(reliquatRestant)));
      cep.ajouterCarence(differe);
    }
  }
  
  protected IOutilConstitutionDelaisReportsSpectacle recupererOutilReglementaire(Attribution attribution)
  {
    CriteresFabriqueReglementaire criteres = new CriteresFabriqueReglementaire();
    criteres.setCodeProduit(attribution.getProduit().getNomUnique());
    criteres.setDate(attribution.getDateAttribution());
    return (IOutilConstitutionDelaisReportsSpectacle)FabriqueCorpsRegleConstitutionDelaisReports.getInstance().recupererOutilCorpsRegle(criteres);
  }
}

/* Location:
 * Qualified Name:     ParcoursConstitutionDelaisReportsPourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */