package fr.unedic.cali.asu.ssp07.p05.avant.outilsfonctionnels;

import fr.unedic.cali.asu.spe02.p03.avant.outilsfonctionnels.TraitementDureeConsommableAvant;
import fr.unedic.cali.calcul.dom.DureeConsommableAvant;
import fr.unedic.cali.calcul.dom.UniteTraitementAvant;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyseSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class TraitementPeriodesAnalyseAvant
{
  public static void traitementDesPeriodesAnalyses(UniteTraitementAvant utAvant, ChronologiePeriodes periodesAnalyse)
    throws CoucheLogiqueException
  {
    DureeConsommableAvant dureePmc = (DureeConsommableAvant)utAvant.getDureePmcEnDebutUT().copie();
    DureeConsommableAvant dureeDiffereStandard = (DureeConsommableAvant)utAvant.getDureeDiffereStandardEnDebutUT().copie();
    DureeConsommableAvant dureeDiffereSpecifique = (DureeConsommableAvant)utAvant.getDureeDiffereSpecifiqueEnDebutUT().copie();
    DureeConsommableAvant dureeDelaiAttente = (DureeConsommableAvant)utAvant.getDureeDelaiAttenteEnDebutUT().copie();
    
    periodesAnalyse.iterer();
    while (periodesAnalyse.encoreSuivant())
    {
      PeriodeAnalyseSpec pa = (PeriodeAnalyseSpec)periodesAnalyse.elementSuivant();
      pa.setQuantiteIndemnisable(new QuantiteJour(new BigDecimal(pa.getDuree())));
      Damj dateDebutConsommationSurPa = pa.getDateDebut();
      Quantite quantiteAImputerSurLaPA = pa.getQuantiteIndemnisable().soustraire(pa.getQuantiteNonIndemnisee());
      Quantite quantiteRestante = new Quantite(quantiteAImputerSurLaPA.getValeur(), quantiteAImputerSurLaPA.getUnite());
      
      gestionPmcNonEpuisee(utAvant, quantiteAImputerSurLaPA, dureePmc, dateDebutConsommationSurPa, quantiteRestante);
      
      postTraitementPa(utAvant, pa);
    }
    utAvant.setDureePmcEnFinUT(dureePmc);
    utAvant.setDureeDiffereStandardEnFinUT(dureeDiffereStandard);
    utAvant.setDureeDiffereSpecifiqueEnFinUT(dureeDiffereSpecifique);
    utAvant.setDureeDelaiAttenteEnFinUT(dureeDelaiAttente);
    
    utAvant.setPmcConsomme(pmcConsomme(utAvant));
    utAvant.setDiffereStandardConsomme(differeStandardConsomme(utAvant));
    utAvant.setDiffereSpecifiqueConsomme(differeSpecifiqueConsomme(utAvant));
    utAvant.setDelaiAttenteConsomme(delaiAttenteConsomme(utAvant));
  }
  
  private static Quantite gestionPmcNonEpuisee(UniteTraitementAvant utAvant, Quantite quantiteAImputerSurLaPA, DureeConsommableAvant dureePmc, Damj dateDebutConsommationSurPa, Quantite quantiteRestante)
    throws CoucheLogiqueException
  {
    Quantite quantiteRestanteTmp = quantiteRestante;
    if (dureePmc.getEtat() != 2) {
      quantiteRestanteTmp = TraitementDureeConsommableAvant.simulerImputationEtImputerLaQuantite(quantiteAImputerSurLaPA, dureePmc, utAvant, dateDebutConsommationSurPa);
    }
    return quantiteRestanteTmp;
  }
  
  private static void postTraitementPa(UniteTraitementAvant utAvant, PeriodeAnalyseSpec pa)
    throws CoucheLogiqueException
  {
    if (pa.isProduitATerminerApresPA()) {
      utAvant.setProduitATerminerApresUT(pa.isProduitATerminerApresPA());
    }
  }
  
  private static Quantite pmcConsomme(UniteTraitementAvant utAvant)
  {
    Quantite pmcConsomme;
    Quantite pmcConsomme;
    if (utAvant.getDureePmcEnFinUT().getEtat() == 0)
    {
      pmcConsomme = new QuantiteJour("0");
    }
    else
    {
      Quantite pmcConsomme;
      if (utAvant.getDureePmcEnDebutUT().getEtat() == 0) {
        pmcConsomme = utAvant.getDureePmcEnDebutUT().getQuantiteInitial().soustraire(utAvant.getDureePmcEnFinUT().getQuantiteCourante());
      } else {
        pmcConsomme = utAvant.getDureePmcEnDebutUT().getQuantiteCourante().soustraire(utAvant.getDureePmcEnFinUT().getQuantiteCourante());
      }
    }
    return pmcConsomme;
  }
  
  private static Quantite differeStandardConsomme(UniteTraitementAvant utAvant)
  {
    Quantite differeStandardConsomme;
    Quantite differeStandardConsomme;
    if (utAvant.getDureeDiffereStandardEnFinUT().getEtat() == 0)
    {
      differeStandardConsomme = new QuantiteJour("0");
    }
    else
    {
      Quantite differeStandardConsomme;
      if (utAvant.getDureeDiffereStandardEnDebutUT().getEtat() == 0) {
        differeStandardConsomme = utAvant.getDureeDiffereStandardEnDebutUT().getQuantiteInitial().soustraire(utAvant.getDureeDiffereStandardEnFinUT().getQuantiteCourante());
      } else {
        differeStandardConsomme = utAvant.getDureeDiffereStandardEnDebutUT().getQuantiteCourante().soustraire(utAvant.getDureeDiffereStandardEnFinUT().getQuantiteCourante());
      }
    }
    return differeStandardConsomme;
  }
  
  private static Quantite differeSpecifiqueConsomme(UniteTraitementAvant utAvant)
  {
    Quantite differeSpecifiqueConsomme;
    Quantite differeSpecifiqueConsomme;
    if (utAvant.getDureeDiffereSpecifiqueEnFinUT().getEtat() == 0)
    {
      differeSpecifiqueConsomme = new QuantiteJour("0");
    }
    else
    {
      Quantite differeSpecifiqueConsomme;
      if (utAvant.getDureeDiffereSpecifiqueEnDebutUT().getEtat() == 0) {
        differeSpecifiqueConsomme = utAvant.getDureeDiffereSpecifiqueEnDebutUT().getQuantiteInitial().soustraire(utAvant.getDureeDiffereSpecifiqueEnFinUT().getQuantiteCourante());
      } else {
        differeSpecifiqueConsomme = utAvant.getDureeDiffereSpecifiqueEnDebutUT().getQuantiteCourante().soustraire(utAvant.getDureeDiffereSpecifiqueEnFinUT().getQuantiteCourante());
      }
    }
    return differeSpecifiqueConsomme;
  }
  
  private static Quantite delaiAttenteConsomme(UniteTraitementAvant utAvant)
  {
    Quantite delaiAttenteConsomme;
    Quantite delaiAttenteConsomme;
    if (utAvant.getDureeDelaiAttenteEnFinUT().getEtat() == 0)
    {
      delaiAttenteConsomme = new QuantiteJour("0");
    }
    else
    {
      Quantite delaiAttenteConsomme;
      if (utAvant.getDureeDelaiAttenteEnDebutUT().getEtat() == 0) {
        delaiAttenteConsomme = utAvant.getDureeDelaiAttenteEnDebutUT().getQuantiteInitial().soustraire(utAvant.getDureeDelaiAttenteEnFinUT().getQuantiteCourante());
      } else {
        delaiAttenteConsomme = utAvant.getDureeDelaiAttenteEnDebutUT().getQuantiteCourante().soustraire(utAvant.getDureeDelaiAttenteEnFinUT().getQuantiteCourante());
      }
    }
    return delaiAttenteConsomme;
  }
}

/* Location:
 * Qualified Name:     TraitementPeriodesAnalyseAvant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */