package fr.unedic.cali.asu.ssp07.p05.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.asu.spe02.p03.calcul.dom.CalendrierExecutionCalcul;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p05.calcul.dom.FormuleMontantAREF;
import fr.unedic.cali.asu.spe02.p05.calcul.dom.ObjetChronoDateLimiteIndemnisation;
import fr.unedic.cali.asu.spe02.p05.calcul.outilsfonctionnels.PostTraitements;
import fr.unedic.cali.asu.spe02.p05.liquidation.outilsaffiliation.ConvertisseurUniteAffiliation;
import fr.unedic.cali.asu.ssp07.p05.calcul.outilsfonctionnels.Qualification;
import fr.unedic.cali.calcul.OutillageCalculADate;
import fr.unedic.cali.calcul.TraitementDureeNonIndemnisable;
import fr.unedic.cali.calcul.dom.ArretProduitAvecRaison;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.EtatAuDji;
import fr.unedic.cali.calcul.dom.EtatAuDjiSpec;
import fr.unedic.cali.calcul.dom.EvenementDateLimiteIndemnisation;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.QuantiteNonIndemnises;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.periode.PeriodeActiviteEmploiCalcul;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoNonIndemnise;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeInterProduits;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoRemplissage;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ContexteUT;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ContexteUT.ElementContexteUT;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodesPriseEnCompte;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculPAEC;
import fr.unedic.cali.calcul.outilsfonctionnels.proratisation.PeriodeProratisationFactory;
import fr.unedic.cali.calcul.pbjc.dom.DroitPbjcNcp;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DureeNonIndemnisable;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.OdAssuranceSpec;
import fr.unedic.cali.dom.QuantiteDroitSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.Retraite;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.cali.parcours.ResultatCalcul;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.List;

public class FacadeCalculProduitImpl
  extends fr.unedic.cali.asu.ssp07.p04.calcul.FacadeCalculProduitImpl
{
  private static final int ZERO = 0;
  
  public QualificationPeriodes qualificationPeriodes(ChronologiePeriodes chronologiePeriodes, AttributionSpec attribution, ContexteUT contexteUT)
    throws CoucheLogiqueException
  {
    return new Qualification().qualificationPeriodes(chronologiePeriodes, attribution);
  }
  
  public FormuleMontantSpec getFormuleMontant(String code)
  {
    FormuleMontantSpec fm = null;
    if (FormuleMontantAREF.getCode().equals(code)) {
      fm = new FormuleMontantAREF();
    } else if (fr.unedic.cali.asu.spe02.p05.calcul.dom.FormuleMontantRegimeGeneral.getCode().equals(code)) {
      fm = new fr.unedic.cali.asu.spe02.p05.calcul.dom.FormuleMontantRegimeGeneral();
    }
    return fm;
  }
  
  public ConstituantsIndemnisation creationConstituantsIndemnisation(AttributionSpec attributionSpec)
    throws CoucheLogiqueException
  {
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    Attribution attribution = (Attribution)attributionSpec;
    constituantsIndemnisation.setCodeFormuleMontant(fr.unedic.cali.asu.ssp07.p03.calcul.dom.FormuleMontantRegimeGeneral.getCode());
    boolean majReliquatFranchise = false;
    EtatAuDjiSpec etatAuDJI = null;
    if (((attribution instanceof RepriseSpec)) && (attribution.getAttributionPrecedente() != null) && (attribution.getAttributionPrecedente().getCalendrierExecutionCalcul() != null) && (attribution.getAttributionPrecedente().getCalendrierExecutionCalcul().getEtatAuDJI() != null))
    {
      etatAuDJI = attribution.getAttributionPrecedente().getCalendrierExecutionCalcul().getEtatAuDJI();
      Damj dji = attribution.getAttributionPrecedente().getCalendrierExecutionCalcul().getDernierJourIndemnisable();
      if ((attribution.getPji().getMois() == dji.getMois()) && (attribution.getPji().getAnnee() == dji.getAnnee())) {
        majReliquatFranchise = true;
      }
    }
    ElementBaseIndemnisation ebiAttributionSpectacle = attribution.getElementBaseIndemnisation();
    if (ebiAttributionSpectacle.getDureeFranchiseCp() > 0)
    {
      DureeNonIndemnisable dureeFCP = new DureeNonIndemnisable(ebiAttributionSpectacle.getDureeFranchiseCp());
      dureeFCP.setRythmeConsomation(new QuantiteJour(Integer.toString(ebiAttributionSpectacle.getQuantiteMensConsomFranchiseCp())));
      dureeFCP.setType("FCP");
      if ((majReliquatFranchise) && (((EtatAuDji)etatAuDJI).getReliquatMaxFCP() != null)) {
        dureeFCP.setReliquatMaxMois(new QuantiteJour(((EtatAuDji)etatAuDJI).getReliquatMaxFCP().toString()));
      }
      dureeFCP.activer();
      constituantsIndemnisation.ajouterListeDureeNonIndemnisables(dureeFCP);
    }
    if (ebiAttributionSpectacle.getDureeFranchiseSalaire() > 0)
    {
      DureeNonIndemnisable dureeSalaire = new DureeNonIndemnisable(ebiAttributionSpectacle.getDureeFranchiseSalaire());
      dureeSalaire.setRythmeConsomation(new QuantiteJour(Integer.toString(ebiAttributionSpectacle.getQuantiteMensConsomFranchiseSalaire())));
      dureeSalaire.setType("FS");
      if ((majReliquatFranchise) && (((EtatAuDji)etatAuDJI).getReliquatMaxFS() != null)) {
        dureeSalaire.setReliquatMaxMois(new QuantiteJour(((EtatAuDji)etatAuDJI).getReliquatMaxFS().toString()));
      }
      dureeSalaire.activer();
      constituantsIndemnisation.ajouterListeDureeNonIndemnisables(dureeSalaire);
    }
    return constituantsIndemnisation;
  }
  
  public EtatAuDji renseignerEtatAuDji(UniteTraitement derniereUT, CalendrierExecutionCalculPeriodique calendrier, AttributionSpec attribution, EtatAuDji etatAuDji)
    throws CoucheLogiqueException
  {
    EtatAuDji etatAuDjiReturn = super.renseignerEtatAuDji(derniereUT, calendrier, attribution, etatAuDji);
    
    List<DureeNonIndemnisable> listeDureeNiEnFinUT = derniereUT.getConstituantsIndemnisationEnFinUT().getListListeDureeNonIndemnisables();
    DureeNonIndemnisable franchiseCP = TraitementDureeNonIndemnisable.recupererDureeNonIndemnisable(listeDureeNiEnFinUT, "FCP");
    
    DureeNonIndemnisable franchiseS = TraitementDureeNonIndemnisable.recupererDureeNonIndemnisable(listeDureeNiEnFinUT, "FS");
    if (franchiseCP != null)
    {
      etatAuDjiReturn.setReliquatFCP(franchiseCP.getQuantiteCourante() != null ? Integer.valueOf(franchiseCP.getQuantiteCourante().getValeurEntiere()) : null);
      etatAuDjiReturn.setReliquatMaxFCP(franchiseCP.getQuantiteRestanteAConsommeSurMois() != null ? Integer.valueOf(franchiseCP.getQuantiteRestanteAConsommeSurMois().getValeurEntiere()) : null);
    }
    if (franchiseS != null)
    {
      etatAuDjiReturn.setReliquatFS(franchiseS.getQuantiteCourante() != null ? Integer.valueOf(franchiseS.getQuantiteCourante().getValeurEntiere()) : null);
      etatAuDjiReturn.setReliquatMaxFS(franchiseS.getQuantiteRestanteAConsommeSurMois() != null ? Integer.valueOf(franchiseS.getQuantiteRestanteAConsommeSurMois().getValeurEntiere()) : null);
    }
    etatAuDjiReturn.setCumulJoursIndemnise(derniereUT.getCumulJoursIndemnise());
    
    return etatAuDjiReturn;
  }
  
  public ResultatCalcul postTraitementResultatDeterminationEtatDroit(AttributionSpec attribution, CalendrierExecutionCalculSpec calendrierExecutionCalcul, Damj dateEtatDroit)
    throws CoucheLogiqueException
  {
    return PostTraitements.postTraitementResultatDeterminationEtatDroit(attribution, (CalendrierExecutionCalcul)calendrierExecutionCalcul, dateEtatDroit);
  }
  
  public void traitementPeriodesNonIndemnises(UniteTraitement ut, QualificationPeriodes qualificationPeriodes, QuantiteNonIndemnises quantiteNonIndemnises, ConstituantsIndemnisation constituantsIndemnisation)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoPeriodesNI = PeriodeProratisationFactory.decoupeEtProratiseParDefaut(qualificationPeriodes.getPeriodesSuspensives(), ut.getPeriode());
    
    int plafond = ut.getQuantitePlafonnee().getValeurEntiere();
    int decalage = ut.getCreditDecalage() != null ? ut.getCreditDecalage().getValeurEntiere() - (ut.getCreditDecalageDureeEnFinUT() != null ? ut.getCreditDecalageDureeEnFinUT().getValeurEntiere() : 0) : 0;
    
    ajouterPeriodeNI(ut, decalage, chronoPeriodesNI, quantiteNonIndemnises, "DECALAGE", false);
    ajouterPeriodeNI(ut, plafond, chronoPeriodesNI, quantiteNonIndemnises, "PLAFOND", false);
    ajouterPeriodeNI(ut, quantiteNonIndemnises.getQuantiteFranchiseCP(), chronoPeriodesNI, quantiteNonIndemnises, "FCP", false);
    
    ajouterPeriodeNI(ut, quantiteNonIndemnises.getQuantiteFranchiseSalaire(), chronoPeriodesNI, quantiteNonIndemnises, "FS", false);
    
    ajouterPeriodeNI(ut, quantiteNonIndemnises.getQuantiteReportCP(), chronoPeriodesNI, quantiteNonIndemnises, "FCPR", false);
    
    ajouterPeriodeNI(ut, quantiteNonIndemnises.getQuantiteReportSalaire(), chronoPeriodesNI, quantiteNonIndemnises, "FSR", false);
  }
  
  public static void ajouterPeriodeNI(UniteTraitement ut, int quantite, ChronologiePeriodes chronoPeriodesNonIndemniseEtSuspensive, QuantiteNonIndemnises qni, String type, boolean estReliquatDA)
    throws CoucheLogiqueException
  {
    if (quantite == 0) {
      return;
    }
    int quantiteARemplir = quantite;
    
    ChronologiePeriodes chronologiePeriodesRemplie = OutillageCalculADate.boucheLesTrous(estReliquatDA ? new ChronologiePeriodes() : chronoPeriodesNonIndemniseEtSuspensive, ObjetChronoRemplissage.class, qni.getDateDebut(), ut.getDateFin());
    
    chronologiePeriodesRemplie.iterer();
    while ((chronologiePeriodesRemplie.encoreSuivant()) && (quantiteARemplir > 0))
    {
      ObjetChronoPeriode objetChronoPeriode = (ObjetChronoPeriode)chronologiePeriodesRemplie.elementSuivant();
      if ((objetChronoPeriode instanceof ObjetChronoRemplissage))
      {
        int quantiteTmp = Math.min(objetChronoPeriode.getDuree(), quantiteARemplir);
        ObjetChronoNonIndemnise o = new ObjetChronoNonIndemnise(objetChronoPeriode.getDateDebut(), objetChronoPeriode.getDateDebut().deplacerVersAvant(new DureeCalendaire(0, 0, quantiteTmp - 1)), type);
        
        ut.ajouterChronoNonIndemnisee(o);
        chronoPeriodesNonIndemniseEtSuspensive.ajouter(o);
        quantiteARemplir -= quantiteTmp;
      }
    }
  }
  
  public ChronologiePeriodes recupererPeriodesProduit(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesIndividuelles = super.recupererPeriodesProduit(attribution);
    
    ElementBaseIndemnisation ebiSpectacle = ((Attribution)attribution).getElementBaseIndemnisation();
    if (ebiSpectacle.getDateLimiteIndemnisation() != null) {
      periodesIndividuelles.ajouter(new ObjetChronoDateLimiteIndemnisation(ebiSpectacle.getDateLimiteIndemnisation().lendemain(), ebiSpectacle.getDateLimiteIndemnisation().lendemain(), attribution.getRsod()));
    }
    return periodesIndividuelles;
  }
  
  public Damj getDateFinQuantiteDroit(Periode periode, AttributionSpec attribution, QuantiteDroitSpec quantiteDroit, ChronologiePeriodes chronologieRemplissage, Quantite quantiteAImputer, Damj dateDebutQuantiteDroit)
  {
    return ((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation().getDateLimiteIndemnisation().lendemain();
  }
  
  public void initialisationQuantitesIndemnisation(ConstituantsIndemnisation constituantsIndemnisation, AttributionSpec attribution, Periode periodeUT)
    throws ApplicativeException
  {
    initialiseElementBaseIndemnisationCourante(constituantsIndemnisation, attribution, periodeUT);
  }
  
  public Damj recupererDateFinDroitTheorique(CalendrierExecutionCalculSpec calendrierExecutionCalcul, AttributionSpec attributionParam)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)attributionParam;
    Damj dateFinDeDroit = null;
    if (calendrierExecutionCalcul != null)
    {
      Chronologie chronoUT = ((CalendrierExecutionCalculPeriodique)calendrierExecutionCalcul).getChronologieUnitesTraitements();
      if ((chronoUT != null) && (!chronoUT.estVide()) && (chronoUT.dernierElement() != null))
      {
        UniteTraitement derniereUT = (UniteTraitement)chronoUT.dernierElement();
        ArretProduitAvecRaison arretProduit = derniereUT.getArretProduitAvecRaison();
        if ((arretProduit != null) && (estinterruptionAutreDroit(arretProduit))) {
          dateFinDeDroit = arretProduit.recupereLendemainDateArret().veille();
        }
      }
    }
    if (dateFinDeDroit != null) {
      return Damj.min(attribution.getElementBaseIndemnisation().getDateLimiteIndemnisation(), dateFinDeDroit);
    }
    if (attribution.estMaintenue()) {
      return OutilRetraite.getInstance().determinerRetraite(attribution.getDemandeur()).getDate().veille();
    }
    return attribution.getElementBaseIndemnisation().getDateLimiteIndemnisation();
  }
  
  private static boolean estinterruptionAutreDroit(ArretProduitAvecRaison arretProduitAvecRaison)
  {
    for (Object o : arretProduitAvecRaison.getPeriodesInterruptivesDefinitives()) {
      if (((o instanceof ObjetChronoPeriodeInterProduits)) && (((ObjetChronoPeriodeInterProduits)o).getTypePeriode() == 1)) {
        return true;
      }
    }
    return false;
  }
  
  public void initialiseElementBaseIndemnisationCourante(ConstituantsIndemnisation constituantsIndemnisation, AttributionSpec attributionSpec, Periode periodeUT)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)attributionSpec;
    super.initialiseElementBaseIndemnisationCourante(constituantsIndemnisation, attributionSpec, periodeUT);
    valorisationRythmeConsommation(constituantsIndemnisation, attribution);
  }
  
  private void valorisationRythmeConsommation(ConstituantsIndemnisation constituantsIndemnisation, Attribution attribution)
  {
    if ((constituantsIndemnisation.getElementBaseIndemnisationCourant() != null) && (constituantsIndemnisation.getListListeDureeNonIndemnisables() != null) && (!constituantsIndemnisation.getListListeDureeNonIndemnisables().isEmpty()))
    {
      List<DureeNonIndemnisable> listeDureeNiEnFinUT = constituantsIndemnisation.getListListeDureeNonIndemnisables();
      DureeNonIndemnisable franchiseCP = TraitementDureeNonIndemnisable.recupererDureeNonIndemnisable(listeDureeNiEnFinUT, "FCP");
      if (franchiseCP != null) {
        franchiseCP.setRythmeConsomation(new QuantiteJour(Integer.toString(attribution.getElementBaseIndemnisation().getQuantiteMensConsomFranchiseCp())));
      }
      DureeNonIndemnisable franchiseSalaire = TraitementDureeNonIndemnisable.recupererDureeNonIndemnisable(listeDureeNiEnFinUT, "FS");
      if (franchiseSalaire != null) {
        franchiseSalaire.setRythmeConsomation(new QuantiteJour(Integer.toString(attribution.getElementBaseIndemnisation().getQuantiteMensConsomFranchiseSalaire())));
      }
    }
  }
  
  public void traiterPeriodeInterruptiveDefinitive(AttributionSpec attribution, UniteTraitement ut, ObjetChronoPeriode objetChronoPeriode, ArretProduitAvecRaison arretProduitAvecRaison, CalendrierExecutionCalculPeriodique calendrier)
    throws CoucheLogiqueException
  {
    if ((objetChronoPeriode instanceof ObjetChronoDateLimiteIndemnisation)) {
      ut.ajouterEvenement(new EvenementDateLimiteIndemnisation(objetChronoPeriode.getDateDebut().veille()));
    } else {
      super.traiterPeriodeInterruptiveDefinitive(attribution, ut, objetChronoPeriode, arretProduitAvecRaison, calendrier);
    }
  }
  
  public int calculerCompteurNombreJoursIndemnisesSurUT(UniteTraitement ut, int cumulNombreJoursServi)
  {
    return cumulNombreJoursServi + ut.getQuantiteIndemnisee().getValeur().intValue();
  }
  
  public void alimenterDonneesSpectacle(AttributionSpec attribution, CalendrierExecutionCalculSpec calendrierExecutionCalcul, DroitPbjcNcp droitPbjcNcp)
  {
    Attribution attrib = (Attribution)attribution;
    
    EtatAuDji etatAuDji = calendrierExecutionCalcul.getEtatAuDJI();
    ElementBaseIndemnisation ebiAttributionSpectacle = attrib.getElementBaseIndemnisation();
    Damj dateAttribution;
    Damj dateAttribution;
    if ((attribution instanceof RepriseSpec)) {
      dateAttribution = attrib.getOuvertureDroit().getDateAttribution();
    } else {
      dateAttribution = attrib.getDateAttribution();
    }
    droitPbjcNcp.setDateDebutDroit(dateAttribution);
    if (ebiAttributionSpectacle != null)
    {
      droitPbjcNcp.setMontantBrutOd(ebiAttributionSpectacle.getMontantBrut());
      if ((ebiAttributionSpectacle.getMontantBrut() != null) && (ebiAttributionSpectacle.getMontantBrutPrecompte() != null)) {
        droitPbjcNcp.setMontantPrecompteOd(ebiAttributionSpectacle.getMontantBrut().subtract(ebiAttributionSpectacle.getMontantBrutPrecompte()));
      }
      droitPbjcNcp.setFranchiseSalaireInit(Integer.valueOf(ebiAttributionSpectacle.getDureeFranchiseSalaire()));
      droitPbjcNcp.setFranchiseCPinit(Integer.valueOf(ebiAttributionSpectacle.getDureeFranchiseCp()));
    }
    if (etatAuDji != null)
    {
      droitPbjcNcp.setReliquatFranchiseCP(etatAuDji.getReliquatFCP());
      droitPbjcNcp.setReliquatFranchiseSalaire(etatAuDji.getReliquatFS());
      int sommeReliquat = 0;
      sommeReliquat += (etatAuDji.getReliquatFCP() != null ? etatAuDji.getReliquatFCP().intValue() : 0);
      sommeReliquat += (etatAuDji.getReliquatFS() != null ? etatAuDji.getReliquatFS().intValue() : 0);
      int nbjourIndemnise = etatAuDji.getCumulJoursIndemnise();
      droitPbjcNcp.setSommeReliquatPlafonee(Integer.valueOf(Math.min(sommeReliquat, nbjourIndemnise)));
    }
  }
  
  public void convertionCachets(ChronologiePeriodes periodes)
  {
    if ((periodes != null) && (!periodes.estVide()))
    {
      Chronologie chronoPeriodesPAEC = periodes.copier(new FiltrePeriodeTravailCalculPAEC());
      if ((chronoPeriodesPAEC != null) && (!chronoPeriodesPAEC.estVide()))
      {
        chronoPeriodesPAEC.iterer();
        while (chronoPeriodesPAEC.encoreSuivant())
        {
          PeriodeActiviteEmploiCalcul periodeActivite = (PeriodeActiviteEmploiCalcul)chronoPeriodesPAEC.elementSuivant();
          if ((periodeActivite.getCachets() != null) && (periodeActivite.getCachets().intValue() > 0)) {
            periodeActivite.setNombreHeures(periodeActivite.getNombreHeuresDeCompletude().add(new Quantite(periodeActivite.getCachets(), UniteAffiliation.CACHET_GROUPE).convertir(UniteAffiliation.HEURE_TRAVAIL, ConvertisseurUniteAffiliation.getInstance()).getValeur()));
          }
        }
      }
    }
  }
  
  public void appliquerFiltreSurFDDSuiteEpuismentOuDateAnniverssaire(PeriodesPriseEnCompte periodesPriseEnCompte, Periode periodeUT, ContexteUT contexteUT, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    if ((OutilDemande.estUneDemandeFinDeDroitSurEpuissement((AttributionAssuranceSpec)attribution, periodeUT)) && (!((AttributionAssuranceSpec)attribution).getOuvertureDroit().getDateAttribution().coincideAvec(periodeUT.getDebut())))
    {
      Damj dateFinTraitementARattributionPrecedente = null;
      
      List<?> listeAttributions = contexteUT.getListeOrdonneeCandidats();
      Iterator<?> it = listeAttributions.iterator();
      while (it.hasNext())
      {
        AttributionSpec attributionCandidate = (AttributionSpec)it.next();
        if (attributionCandidate != attribution)
        {
          ContexteUT.ElementContexteUT elementContexteUT = contexteUT.getElementContexteUT(attributionCandidate);
          dateFinTraitementARattributionPrecedente = (dateFinTraitementARattributionPrecedente == null) || ((elementContexteUT.recupererDateTraitementARSurMoisDJI() != null) && (dateFinTraitementARattributionPrecedente.estAvant(elementContexteUT.recupererDateTraitementARSurMoisDJI()))) ? elementContexteUT.recupererDateTraitementARSurMoisDJI() : dateFinTraitementARattributionPrecedente;
        }
      }
      if (dateFinTraitementARattributionPrecedente != null)
      {
        periodesPriseEnCompte.tronquePeriodeParTypologieEnDebut(dateFinTraitementARattributionPrecedente.lendemain(), 5);
        periodesPriseEnCompte.tronquePeriodeParTypologieEnDebut(dateFinTraitementARattributionPrecedente.lendemain(), 4);
      }
    }
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */