package fr.unedic.cali.asu.ssp07.p05.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.fps.liquidation.outilsaffiliation.convention2017.ComportementAffiliationConvention2017;
import fr.unedic.cali.asu.fps.liquidation.outilsaffiliation.convention2017.ParametresAffiliationConvention2017;
import fr.unedic.cali.asu.fps.liquidation.outilsaffiliation.spec.IComportementAffiliationFPS;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ParametresAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationPeriodeReference;
import fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels.DeterminationPeriodeReferenceSPE02P05;
import fr.unedic.cali.asu.ssp07.p03.liquidation.outilsfonctionnels.OutilConditionAffiliation;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.affectation.LigneAsuFds12;
import fr.unedic.cali.dom.affectation.LigneAsuSsp07;
import fr.unedic.cali.dom.affectation.ProduitAsuSsp07P05;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourLigne;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreOuvertureDroitSurDecision;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class OutilConditionAffiliationConvention2017
  extends OutilConditionAffiliation
{
  public OutilConditionAffiliationConvention2017()
  {
    parametresAffiliation = new ParametresAffiliationConvention2017();
  }
  
  protected IComportementAffiliationFPS instancierComportementAffiliationFPS()
  {
    return new ComportementAffiliationConvention2017();
  }
  
  protected boolean etudierToutesActivitesReference(DemandeAssuranceSpec demande)
  {
    return false;
  }
  
  protected Damj determinerTermePRA(Damj dateFct, Damj dateExamen, boolean estContexteDroitSuiteCRA)
  {
    Damj dateTermePra = dateFct;
    if (estContexteDroitSuiteCRA) {
      dateTermePra = dateExamen.veille();
    }
    return dateTermePra;
  }
  
  protected Damj determinerBornePRA(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Damj dateBornePRA = Damj.NUIT_DES_TEMPS;
    
    FiltreOU filtreProduit = new FiltreOU();
    filtreProduit.ajouterFiltre(new FiltreDecisionPourLigne(LigneAsuSsp07.getInstance().getNomUnique()));
    filtreProduit.ajouterFiltre(new FiltreDecisionPourLigne(LigneAsuFds12.getInstance().getNomUnique()));
    filtreProduit.ajouterFiltre(new FiltreDecisionARESurDecision());
    
    FiltreET filtreOd = new FiltreET();
    filtreOd.ajouterFiltre(filtreProduit);
    filtreOd.ajouterFiltre(new FiltreOuvertureDroitSurDecision());
    filtreOd.ajouterFiltre(new FiltreNegation(new FiltreDemandePourTypeContexteDemande(8)));
    
    AttributionSpec odPrecedente = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande.getDateExamen(), filtreOd);
    if (odPrecedente != null) {
      dateBornePRA = ((Demande)odPrecedente.getDemande()).getDateFaitGenerateurOuDernierSinistre().lendemain();
    }
    return dateBornePRA;
  }
  
  protected DeterminationPeriodeReference getOutilDeterminationPRA()
  {
    return DeterminationPeriodeReferenceSPE02P05.getInstance();
  }
  
  protected ParametresAffiliationSpec getParametresAffiliation()
  {
    return parametresAffiliation;
  }
  
  protected ProduitSpec getProduit()
  {
    return ProduitAsuSsp07P05.getInstance();
  }
}

/* Location:
 * Qualified Name:     OutilConditionAffiliationConvention2017
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */