package fr.unedic.cali.asu.asr.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.StrategieConditionFaitGenerateurDemandeClassique;
import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.CertifieSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.DeclareSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.autresdoms.ga.outilsfonctionnels.OutilPasseProfessionel;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteNonSalariee;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeHorsChamp;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesCertifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesDeclarees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;

public abstract class RechercheConditionFaitGenerateur
  implements OutilFonctionnel
{
  protected abstract void verifierMotifRuptureDernierAu(TravailSpec paramTravailSpec, boolean paramBoolean)
    throws CoucheLogiqueException;
  
  protected void verifierPresenceAe(TravailSpec dernierSinistre)
    throws CoucheLogiqueException
  {
    boolean estActiviteSalarieeNonAtteste = ((dernierSinistre instanceof ActiviteSalarie)) && (!((ActiviteSalarie)dernierSinistre).estAtteste());
    boolean estCertifieNonAtteste = ((dernierSinistre instanceof CertifieSpec)) && (!((CertifieSpec)dernierSinistre).estAtteste());
    boolean estDeclareNonJustifie = ((dernierSinistre instanceof DeclareSpec)) && (!((DeclareSpec)dernierSinistre).estJustifie());
    if ((estActiviteSalarieeNonAtteste) || (estCertifieNonAtteste) || (estDeclareNonJustifie)) {
      StrategieConditionFaitGenerateurDemandeClassique.lancerAlerteA11MB1(dernierSinistre);
    }
  }
  
  protected abstract void verifierDateExamenLendemainDernierAu(DossierAffectation paramDossierAffectation, TravailSpec paramTravailSpec)
    throws CoucheLogiqueException;
  
  public ConditionFaitGenerateur rechercheConditionFaitGenerateur(Demande demande)
    throws CoucheLogiqueException
  {
    controleReintegrationDemandee(demande);
    ConditionFaitGenerateur faitGenerateur = ((DossierExamen)demande.getDossierExamen()).createConditionFaitGenerateur();
    DossierAffecte dossierAffecte = (DossierAffecte)demande.getDossierAffectationAdmission();
    TravailSpec dernierSinistre = dossierAffecte.getSinistre();
    verifierPresenceAe(dernierSinistre);
    faitGenerateur.setPeriodeFaitGenerateur((ActiviteSalarie)dossierAffecte.getSinistre());
    
    faitGenerateur.setEtatSatisfait(true);
    if (seulementChronoActivitesHorsChampDansDelai(demande))
    {
      faitGenerateur.setEtatSatisfait(false);
      faitGenerateur.setCodeMotifEchec(42);
    }
    else
    {
      boolean estDernierSinistre = dernierSinistre != null;
      verifierExistanceDernierAu(estDernierSinistre, demande);
      verifierDateExamenLendemainDernierAu(dossierAffecte, dernierSinistre);
      
      boolean estContextePap = OutilGestionContexteDemande.estContextePresentDansRegroupement(demande.getListContexteDemande(), 10);
      
      verifierMotifRuptureDernierAu(dernierSinistre, estContextePap);
      
      faitGenerateur.setAgeIndividuDateFG(demande.getDemandeur().getAgeALaDate(dernierSinistre.getDateFin()));
    }
    return faitGenerateur;
  }
  
  private void verifierExistanceDernierAu(boolean estDernierSinistre, Demande demande)
    throws CoucheLogiqueException
  {
    if (!estDernierSinistre) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A6MB5", new String[] { demande.getDateExamen().toString() });
    }
  }
  
  public static boolean seulementChronoActivitesHorsChampDansDelai(Demande demande)
  {
    FiltrePeriodesSurFiltresExclusifs filtresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    
    FiltresTemporel filtresTravailSalarieNonSalarie = new FiltresTemporel();
    filtresTravailSalarieNonSalarie.ajouterFiltre(new FiltrePeriodesCertifiees());
    filtresExclusifs.ajouterFiltre(filtresTravailSalarieNonSalarie);
    
    FiltresTemporel filtresDeclareTravail = new FiltresTemporel();
    filtresDeclareTravail.ajouterFiltre(new FiltrePeriodesDeclarees());
    filtresDeclareTravail.ajouterFiltre(new FiltreTravailSpec());
    filtresExclusifs.ajouterFiltre(filtresDeclareTravail);
    
    Chronologie chronoActivitesParticipantes = OutilPasseProfessionel.trouverChronoPasseProfessionelAvecFiltrageDNJ(demande.getDemandeur()).copier(filtresExclusifs);
    
    chronoActivitesParticipantes = chronoActivitesParticipantes.copier(new FiltreFinAvantOuCoincideAvecDate(demande.getDateExamen()));
    
    Chronologie chronoActivitesParticipantesDansDelai = null;
    
    DelaiRechercheProduit periodeDelaiForclusion = ((DossierAffectation)demande.getDossierAffectation()).getDelaiRecherche();
    if (periodeDelaiForclusion != null) {
      chronoActivitesParticipantesDansDelai = chronoActivitesParticipantes.copier(new FiltreFinDansBornes(periodeDelaiForclusion));
    }
    Chronologie chronoActivitesHorsChampDansDelai = null;
    
    filtresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    FiltreTemporel filtreActiviteSalarieHorsChamp = new FiltrePeriodeActiviteSalarieeHorsChamp();
    filtresExclusifs.ajouterFiltre(filtreActiviteSalarieHorsChamp);
    FiltreTemporel filtreActiviteNonSalarie = new FiltrePeriodeActiviteNonSalariee();
    filtresExclusifs.ajouterFiltre(filtreActiviteNonSalarie);
    if (chronoActivitesParticipantesDansDelai != null) {
      chronoActivitesHorsChampDansDelai = chronoActivitesParticipantesDansDelai.copier(filtresExclusifs);
    }
    return (chronoActivitesParticipantesDansDelai != null) && (chronoActivitesHorsChampDansDelai != null) && (chronoActivitesParticipantesDansDelai.getTaille() > 0) && (chronoActivitesParticipantesDansDelai.getTaille() == chronoActivitesHorsChampDansDelai.getTaille());
  }
  
  private static void controleReintegrationDemandee(Demande demande)
    throws CoucheLogiqueException
  {
    if ((!demande.getDonneesTemporaires().isEstDemarcheReintegrationEffectuee()) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "CRSPMVS"))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB15");
    }
  }
}

/* Location:
 * Qualified Name:     RechercheConditionFaitGenerateur
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */