package fr.unedic.cali.asu.caa14.p02.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDroitResultant;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.services.Resultat;

public class ConstitutionProduitResultant
  extends ConstitutionProduitResultantClassique
  implements ParcoursAssurance
{
  public Resultat demarrerParcours(Contexte p_contexte)
    throws CoucheLogiqueException, ApplicativeException
  {
    Resultat resultat = new Resultat(0);
    
    DomLiquidationAssurance dom = (DomLiquidationAssurance)p_contexte.getDonnees();
    Demande demandeCourante = dom.getDemande();
    int contexteExamen = dom.getContexteExamen();
    DossierExamen dossierExamen = (DossierExamen)demandeCourante.getDossierExamen();
    dossierExamen.createConstitutionProduitResultant();
    
    alimentationCapitalDroitCourant(demandeCourante);
    
    Parcours parcoursProduitResultant = getParcoursProduitResultant(contexteExamen);
    if (parcoursProduitResultant == null) {
      return resultat;
    }
    JustificationDroitResultant justif = new JustificationDroitResultant();
    dossierExamen.getConstitutionProduitResultant().setJustificationDroitResultant(justif);
    resultat = parcoursProduitResultant.effectuerParcours(p_contexte);
    
    return resultat;
  }
  
  public Parcours getParcoursProduitResultant(int p_contexteExamen)
  {
    if (p_contexteExamen == 3) {
      return new ConstitutionProduitResultantClassique();
    }
    if (p_contexteExamen == 4) {
      return new ConstitutionProduitResultantSP();
    }
    return null;
  }
  
  protected void alimentationCapitalDroitCourant(Demande p_demande)
    throws ApplicativeException
  {
    Attribution attribution = (Attribution)p_demande.getDossierExamen();
    ConstitutionMontantsBruts cepMontant = attribution.getConstitutionMontantsBruts();
    
    Quantite nbJourIndemnisesTheorique = attribution.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    Quantite capitalProduitCourant = AppelCalculParLiquidationAsu.calculerCapital(attribution, cepMontant.getMontantAAttribution(), attribution.getDateAttribution(), nbJourIndemnisesTheorique);
    
    cepMontant.setCapitalInitialBrut(capitalProduitCourant);
  }
}

/* Location:
 * Qualified Name:     ConstitutionProduitResultant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */