package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleICCPSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.BaseDelaiReport;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.BaseDelaiReportAbstrait;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.QuantiteJoursOuvrables;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class FormuleDiffereICCPConservatoireBatiment
  implements FormuleICCPSpec
{
  private static final BigDecimal RATIO_JOUR_MOIS = BigDecimal.valueOf(30.55D);
  private static final int MOIS_LIMITE = 4;
  private static final int JOUR_LIMITE = 1;
  private static final BigDecimal FORFAIT_ICCP_MOIS = BigDecimal.valueOf(2.5D);
  private static final int PLAFOND_ICCP = 35;
  private static final BigDecimal NBRE_JOURS_SEMAINE = BigDecimal.valueOf(7L);
  
  public Object appliquerFormule(BaseDelaiReportAbstrait baseFormule)
    throws CoucheLogiqueException
  {
    BaseDelaiReport donneesEntree = (BaseDelaiReport)baseFormule;
    Periode periodeCarence = bornerPeriodeReferenceICCP(donneesEntree.getPeriodeActiviteSalarie());
    int nombreJourICCPConservatoire = calculerICCPConservatoire(periodeCarence);
    return new QuantiteJour(BigDecimal.valueOf(nombreJourICCPConservatoire));
  }
  
  public int recupererPlafondISLR(BaseDelaiReportAbstrait baseFormule)
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée");
  }
  
  public boolean estFormuleConservatoire()
  {
    return true;
  }
  
  protected Periode bornerPeriodeReferenceICCP(Periode periodeActiviteSalarie)
  {
    int anneeMoinsUn = periodeActiviteSalarie.getFin().getAnnee() - 1;
    Damj dateBorne = new Damj(anneeMoinsUn, 4, 1);
    return new Periode(Damj.max(dateBorne, periodeActiviteSalarie.getDebut()), periodeActiviteSalarie.getFin());
  }
  
  protected int calculerICCPConservatoire(Periode periodeCarence)
  {
    BigDecimal nombreMois = BigDecimal.valueOf(periodeCarence.getDuree()).divide(RATIO_JOUR_MOIS, 6, 1);
    int nombreICCPCalcule = nombreMois.multiply(FORFAIT_ICCP_MOIS).intValue();
    int nombreICCPCalculeCalendaire = convertirJourOuvrableEnJourCalendaire(new QuantiteJoursOuvrables(nombreICCPCalcule));
    return appliquerPlafond(nombreICCPCalculeCalendaire);
  }
  
  protected int appliquerPlafond(int nombreICCPCalcule)
  {
    return Math.min(nombreICCPCalcule, 35);
  }
  
  protected int convertirJourOuvrableEnJourCalendaire(QuantiteJoursOuvrables nbJourOuvrable)
  {
    int nombreJoursSemaine = nbJourOuvrable.getNombreJoursSemaine();
    
    BigDecimal nominateur1 = new BigDecimal(String.valueOf(nbJourOuvrable.getValeur()));
    BigDecimal nominateur2 = NBRE_JOURS_SEMAINE;
    BigDecimal denominateur = new BigDecimal(String.valueOf(nombreJoursSemaine));
    BigDecimal resultatFormule = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
    
    return resultatFormule.intValue();
  }
}

/* Location:
 * Qualified Name:     FormuleDiffereICCPConservatoireBatiment
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */