package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleICCPSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.BaseDelaiReportAbstrait;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.QuantiteJourTravailDansSemaineSpec;
import fr.unedic.util.services.PasAssezInformationException;
import java.math.BigDecimal;

public class FormuleDiffereICCPTemps
  implements FormuleICCPSpec
{
  private static final BigDecimal NBRE_JOURS_SEMAINE = new BigDecimal(7);
  
  public Object appliquerFormule(BaseDelaiReportAbstrait baseFormule)
    throws PasAssezInformationException
  {
    if (baseFormule == null) {
      throw new IllegalArgumentException("Impossible d'appliquer la formule du différé ICCP sans BaseDelaiReport.");
    }
    QuantiteJourTravailDansSemaineSpec quantiteJourIccp = baseFormule.getQuantiteJourIccp();
    if (quantiteJourIccp == null) {
      throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR08_ABSENCE_JOURS_FORMULE_ICCP", "Impossible d'appliquer la formule du différé ICCP sans nombre de jours ICCP.");
    }
    BigDecimal nombreJoursIccp = ((QuantiteJour)quantiteJourIccp).getValeur();
    
    int nombreJoursSemaine = quantiteJourIccp.getNombreJoursSemaine();
    
    BigDecimal nominateur1 = new BigDecimal(String.valueOf(nombreJoursIccp));
    BigDecimal nominateur2 = NBRE_JOURS_SEMAINE;
    BigDecimal denominateur = new BigDecimal(String.valueOf(nombreJoursSemaine));
    BigDecimal resultatFormule = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
    
    QuantiteJour quantiteJourCalculee = new QuantiteJour(Mathematiques.tronque(resultatFormule, 0).toString());
    
    return quantiteJourCalculee;
  }
  
  public int recupererPlafondISLR(BaseDelaiReportAbstrait baseFormule)
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée");
  }
  
  public boolean estFormuleConservatoire()
  {
    return false;
  }
}

/* Location:
 * Qualified Name:     FormuleDiffereICCPTemps
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */