package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleDelaiReportSpec;
import fr.unedic.cali.asu.cge01.parametres.ParametrageISLR;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.BaseDelaiReportAbstrait;
import fr.unedic.cali.outilsfonctionnels.DetectionTypeChomage;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.PasAssezInformationException;
import java.math.BigDecimal;

public class FormuleDiffereISLR17
  implements FormuleDelaiReportSpec
{
  public static final int DUREE_MAX_DIFFERE_ISLR_MOTIF_ECO = 75;
  public static final int DUREE_MAX_DIFFERE_ISLR_MOTIF_NON_ECO = 150;
  
  public Object appliquerFormule(BaseDelaiReportAbstrait baseFormule)
    throws CoucheLogiqueException
  {
    if (baseFormule == null) {
      throw new IllegalArgumentException("La BaseFormule passée en paramètre est égale à null : impossible d'appliquer la formule CarenceISLR.");
    }
    QuantiteJour carenceEnJourCalculee;
    try
    {
      QuantiteEuro quantiteEuroIslr = baseFormule.getQuantiteEuroIslr();
      if (quantiteEuroIslr == null) {
        throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR08_ABSENCE_MONTANT_FORMULE_ISLR", "QuantiteEuro ISLR null dans BaseFormule passé en paramètre: impossible d'appliquer la formule CarenceISLR.");
      }
      BigDecimal montantIslr = quantiteEuroIslr.getValeur();
      ParametrageISLR paramISLR = ParametrageISLR.getInstance();
      BigDecimal diviseurRevalorise = paramISLR.recuperDiviseur(baseFormule.getDateFg());
      
      BigDecimal carenceCalculee = Mathematiques.tronque(Mathematiques.diviseParDefaut(montantIslr, diviseurRevalorise), 0).min(BigDecimal.valueOf(recupererPlafondISLR(baseFormule)));
      
      carenceEnJourCalculee = new QuantiteJour(carenceCalculee);
    }
    catch (ClassCastException ex)
    {
      throw new IllegalArgumentException("La BaseFormule n'est pas une BaseCarenceMontant : impossible d'appliquer la formule CarenceISLR.", ex);
    }
    return carenceEnJourCalculee;
  }
  
  public int recupererPlafondISLR(BaseDelaiReportAbstrait baseFormule)
  {
    if (DetectionTypeChomage.estChomageEconomique(baseFormule.getMotifRupture())) {
      return 75;
    }
    return 150;
  }
}

/* Location:
 * Qualified Name:     FormuleDiffereISLR17
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */