package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatDeterminationDuree;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationDureeReglementaire;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;

public class ConstitutionDureeReglementaire
  extends ParcoursCali
  implements ParcoursAssurance
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCEPA02 = new Resultat(0);
    
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    
    boolean plafonnementActif = true;
    if (demande.getDonneesTemporaires().getQuantiteAffiliation() != null) {
      plafonnementActif = false;
    }
    ConstitutionDurees constitutionDurees = dossierExamenCourant.getConstitutionDurees();
    if (constitutionDurees == null) {
      constitutionDurees = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionDurees();
    }
    DureeIndemnisation dureeIndemnisation = constitutionDurees.createDureeIndemnisation();
    DeterminationDureeReglementaire of = DeterminationDureeReglementaire.getInstance();
    ResultatDeterminationDuree resultat = of.determinerDureeReglementaire(demande, plafonnementActif, true);
    
    ResultatDeterminationDuree resultatAvecImputation = of.imputerReliquatImputation(demande, resultat);
    of.mapperResultatSurDom(resultatAvecImputation, dureeIndemnisation);
    
    OutilTrace.tracerFinParcours();
    
    return resultatCEPA02;
  }
  
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution des durees impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "Le dossier examen courante est null: constitution des durees impossible.");
    }
  }
}

/* Location:
 * Qualified Name:     ConstitutionDureeReglementaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */