package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.parcours.conteneurs.ConteneurParcoursRevisionAutomatique;
import fr.unedic.cali.asu.cge01.revision.outilsfonctionnels.fabriques.FabriqueStrategieRevisionAutomatique;
import fr.unedic.cali.asu.cge01.revision.outilsfonctionnels.fabriques.FabriqueStrategieRevisionAutomatiquePourExamenIPR;
import fr.unedic.cali.asu.cge01.revision.outilsfonctionnels.strategies.spec.StrategieRevisionAutomatiqueSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.GestionDemandeDv122eJour;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsActiviteConserve;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.Rejet;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;

public class ConstitutionRevisionAutomatiqueExamenIPR
  extends ConstitutionRevisionAutomatiqueFinDroit
{
  private Damj m_dateFaitGenerateurOdPrecedenteRejetDv = null;
  
  protected Chronologie trouverChronoActiviteAReviser(Demande p_demandeCourante)
    throws ApplicativeException
  {
    Demande demandeDv = GestionDemandeDv122eJour.retrouverDemandePortantDv(p_demandeCourante);
    Rejet rejetDv = (Rejet)demandeDv.getDossierExamen();
    if (demandeDv.getDateFaitGenerateurOdPrecedente() != null) {
      m_dateFaitGenerateurOdPrecedenteRejetDv = demandeDv.getDateFaitGenerateurOdPrecedente();
    } else {
      m_dateFaitGenerateurOdPrecedenteRejetDv = Damj.NUIT_DES_TEMPS;
    }
    Chronologie activitesConservesRejetDv = OutilsActiviteConserve.filtreListeActiviteConserve(rejetDv.getListeActiviteConserveePerdues());
    return activitesConservesRejetDv.copier(new FiltreFinAvantOuCoincideAvecDate(p_demandeCourante.getDossierExamen().getDateAttribution().veille()));
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    Attribution attributionIPR = (Attribution)demandeCourante.getDossierExamen();
    ConteneurParcoursRevisionAutomatique conteneur = initialiserDonneesEnEntree(demandeCourante, attributionIPR, demandeCourante);
    return demarrerParcours(conteneur);
  }
  
  protected ConteneurParcoursRevisionAutomatique initialiserDonneesEnEntree(Demande p_demandeCourante, Attribution p_attributionAReviser, Demande p_demandeOrigine)
  {
    ConteneurParcoursRevisionAutomatique conteneur = new ConteneurParcoursRevisionAutomatique();
    conteneur.setDemandeCourante(p_demandeCourante);
    conteneur.setAttributionAReviser(p_attributionAReviser);
    conteneur.setDemandeOrigine(p_demandeOrigine);
    conteneur.setNouvelleRevisionDroit(false);
    return conteneur;
  }
  
  protected Demande creerDemandeAReviser(ConteneurParcoursRevisionAutomatique conteneur)
    throws ApplicativeException
  {
    StrategieRevisionAutomatiqueSpec strategieRevision = recupererStrategiePourRevisionAutomatique();
    Demande demandeRevision = strategieRevision.creerDemandeAReviser(conteneur);
    conteneur.setDemandeRevision(demandeRevision);
    conteneur.setDateFaitGenerateurOdPrecedenteForcee(m_dateFaitGenerateurOdPrecedenteRejetDv);
    strategieRevision.mettreAJourDemandeRevision(conteneur);
    return demandeRevision;
  }
  
  protected FabriqueStrategieRevisionAutomatique recupererFabriquePourRevisionAutomatique()
  {
    return new FabriqueStrategieRevisionAutomatiquePourExamenIPR();
  }
}

/* Location:
 * Qualified Name:     ConstitutionRevisionAutomatiqueExamenIPR
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */