package fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDuree;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Damj;

public class DeterminationDureeEffective
  implements OutilFonctionnel
{
  public static DureeIndemnisation determinerDureeEffective(Demande p_demande)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la détermination des durées réglementaires." });
    
    DureeIndemnisation dureeIndemnisation = null;
    
    DossierExamen dossierExamenCourant = (DossierExamen)p_demande.getDossierExamen();
    
    Quantite qteDureeTheorique = dossierExamenCourant.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    
    Damj pji = dossierExamenCourant.getConstitutionPointDepartIndemnisation().getPji();
    
    dureeIndemnisation = dossierExamenCourant.getConstitutionDurees().getDureeIndemnisation();
    if (((p_demande.estUneDemandeFinDroit()) || (p_demande.estUneDemandeFinancement())) && (qteDureeTheorique.getValeurEntiere() == 0)) {
      dureeIndemnisation.setDureeEffective(new Quantite(0, DureeReglementaire.UNITE_DEFAUT));
    } else {
      dureeIndemnisation.setDureeEffective(ConstitutionDuree.calculerDureeEffectivePourAdmission(p_demande.getDemandeur(), pji, qteDureeTheorique, DureeReglementaire.UNITE_DEFAUT, ConstitutionDuree.bornageALaRetraiteApplicablePourAdmission(p_demande)));
    }
    return dureeIndemnisation;
  }
  
  public static DureeIndemnisation determinerDureeEffectivePourReprise(Demande p_demande)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la détermination des durées réglementaires." });
    
    DureeIndemnisation dureeIndemnisation = null;
    
    DossierExamen dossierExamenCourant = (DossierExamen)p_demande.getDossierExamen();
    
    Quantite qteDureeTheorique = dossierExamenCourant.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    
    Damj pji = dossierExamenCourant.getConstitutionPointDepartIndemnisation().getPji();
    
    dureeIndemnisation = dossierExamenCourant.getConstitutionDurees().getDureeIndemnisation();
    if (((p_demande.estUneDemandeFinDroit()) || (p_demande.estUneDemandeFinancement())) && (qteDureeTheorique.getValeurEntiere() == 0)) {
      dureeIndemnisation.setDureeEffective(new Quantite(0, DureeReglementaire.UNITE_DEFAUT));
    } else {
      dureeIndemnisation.setDureeEffective(ConstitutionDuree.calculerDureeEffectivePourReprise(p_demande.getDemandeur(), pji, qteDureeTheorique, DureeReglementaire.UNITE_DEFAUT, ConstitutionDuree.bornageALaRetraiteApplicablePourReprise(p_demande)));
    }
    return dureeIndemnisation;
  }
}

/* Location:
 * Qualified Name:     DeterminationDureeEffective
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */