package fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleDelaiReportSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.BaseDelaiReportAbstrait;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class FormuleCarenceIslr
  implements FormuleDelaiReportSpec
{
  private static final Damj DATE01072002 = new Damj(2002, 7, 1);
  public static final int DUREE_MAX_ISLR = 75;
  public static final int DUREE_CARENCE_TRANSACT_FINANCE_ISLR = 75;
  
  public Object appliquerFormule(BaseDelaiReportAbstrait baseFormule)
    throws CoucheLogiqueException
  {
    QuantiteJour quantiteJourCalculee = null;
    if (baseFormule == null) {
      throw new IllegalArgumentException("La BaseFormule passée en paramètre est égale à null: impossible d'appliquer la formule CarenceISLR.");
    }
    try
    {
      QuantiteEuro quantiteEuroIslr = baseFormule.getQuantiteEuroIslr();
      if (quantiteEuroIslr == null) {
        throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR08_ABSENCE_MONTANT_FORMULE_ISLR", "QuantiteEuro ISLR null dans BaseFormule passé en paramètre: impossible d'appliquer la formule CarenceISLR.");
      }
      BigDecimal valeurMontant = quantiteEuroIslr.getValeurMontant();
      
      Sjr salaireJournalierReference = baseFormule.getSjrrp();
      if (salaireJournalierReference == null) {
        throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR08_ABSENCE_SJRRP_FORMULE_ISLR", "SJRRP null dans BaseFormule passé en paramètre: impossible d'appliquer la formule CarenceISLR.");
      }
      BigDecimal valeurSjrrp = salaireJournalierReference.getSalaire();
      if (valeurSjrrp.compareTo(BigDecimal.ZERO) == 0) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_SC_L_ES_ED_CDR08_INCOHERENCE_SJRRP_ISLR", 2);
      }
      BigDecimal resultatFormule = null;
      
      Damj dateFG = baseFormule.getDateFg();
      if (dateFG == null) {
        throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR08_ABSENCE_DATE_FG_FORMULE_ISLR", "dateFG null dans BaseFormule passé en paramètre: impossible d'appliquer la formule CarenceISLR.");
      }
      if (dateFG.estAvant(DATE01072002)) {
        resultatFormule = Mathematiques.diviseParDefaut(valeurMontant, new BigDecimal("2").multiply(valeurSjrrp));
      } else {
        resultatFormule = Mathematiques.diviseParDefaut(valeurMontant, valeurSjrrp);
      }
      quantiteJourCalculee = new QuantiteJour(new BigDecimal(75).min(Mathematiques.tronque(resultatFormule, 0)).toString());
    }
    catch (ClassCastException ex)
    {
      throw new IllegalArgumentException("La BaseFormule n'est pas une BaseCarenceMontant: impossible d'appliquer la formule CarenceISLR.");
    }
    return quantiteJourCalculee;
  }
  
  public int recupererPlafondISLR(BaseDelaiReportAbstrait baseFormule)
  {
    return 75;
  }
}

/* Location:
 * Qualified Name:     FormuleCarenceIslr
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */