package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConditionAge;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConditionRechercheEmploi;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.RechercheConditionAge;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.ElementConditionAge;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;

public class DeterminationConditionAge
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_context)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_context) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: determination condition age impossible.");
    }
    if (DomLiquidationAssurance.getDemande(p_context).getDemandeur() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Le demandeur est null: determination condition age impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCAPA06 = new Resultat(1);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    ConditionAge conditionAge = new ConditionAge();
    ElementConditionAge elementConditionAge = null;
    if (verifierPreconditions(p_contexte))
    {
      elementConditionAge = RechercheConditionAge.getInstance().rechercherConditionAge(demandeCourante);
      conditionAge.setCodeMotifEchec(elementConditionAge.getCodeMotifEchec());
      conditionAge.setDateEffetPension(elementConditionAge.getDateAtteinteRetraite());
      conditionAge.setEtat(elementConditionAge.getEtat());
    }
    else
    {
      conditionAge.setCodeMotifEchec(1);
      conditionAge.setEtatSatisfait(false);
    }
    dossierExamenCourant.setConditionAge(conditionAge);
    if (conditionAge.estSatisfait())
    {
      resultatCAPA06.setEtat(0);
    }
    else
    {
      resultatCAPA06.setEtat(1);
      resultatCAPA06.setMessageErreur(Integer.toString(conditionAge.getCodeMotifEchec()));
    }
    OutilTrace.tracerFinParcours();
    
    return resultatCAPA06;
  }
  
  protected boolean verifierPreconditions(Contexte p_contexte)
  {
    boolean preconditionsValides = true;
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    if ((dossierExamenCourant.getConditionRechercheEmploi() != null) && (dossierExamenCourant.getConditionRechercheEmploi().estSatisfait())) {
      preconditionsValides = true;
    } else {
      preconditionsValides = false;
    }
    return preconditionsValides;
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionAge
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */