package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDuree;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.outilsfonctionnels.AppelAvant;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.List;

public class ConstitutionDureeEffectivePourReprise
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Sjc impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution courante est null: constitution du Sjc impossible.");
    }
    if ((!DomLiquidationAssurance.getDemande(contexte).getReliquat().estReliquatValide()) || (((DomLiquidationAssurance)contexte.getDonnees()).getContexteExamen() != 3)) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Pas de reliquat pour cette demande d'assurance.");
    }
  }
  
  public Resultat demarrer(Contexte contexte)
    throws CoucheLogiqueException, ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    DureeIndemnisation dureeIndemnisation = dossierExamen.getConstitutionDurees().getDureeIndemnisation();
    
    Quantite dureeTheorique = dureeIndemnisation.getDureeTheorique();
    dureeIndemnisation.setDureeEffective(trouverDureeEffective(demande, dureeTheorique));
    
    OutilTrace.tracerFinParcours();
    
    return new Resultat();
  }
  
  public Quantite trouverDureeEffective(Demande demande, Quantite qteDureeTheorique)
    throws ApplicativeException
  {
    List listeAttribution = new ArrayList();
    listeAttribution.add(demande.getAttribution());
    AppelAvant.executerAvant(listeAttribution, null);
    Damj pji = null;
    if (demande.getAttribution().getPjiEffectif() == null) {
      pji = demande.getAttribution().getDateAttribution();
    } else {
      pji = demande.getAttribution().getPjiEffectif();
    }
    Quantite dureeEffective;
    Quantite dureeEffective;
    if (((demande.estUneDemandeFinDroit()) || (demande.estUneDemandeFinancement())) && (qteDureeTheorique.getValeurEntiere() == 0)) {
      dureeEffective = new Quantite(0, DureeReglementaire.UNITE_DEFAUT);
    } else {
      dureeEffective = ConstitutionDuree.calculerDureeEffectivePourReprise(demande.getDemandeur(), pji, qteDureeTheorique, DureeReglementaire.UNITE_DEFAUT, ConstitutionDuree.bornageALaRetraiteApplicablePourReprise(demande));
    }
    return dureeEffective;
  }
}

/* Location:
 * Qualified Name:     ConstitutionDureeEffectivePourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */