package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;

public class ConstitutionPointDeDepartPourRevision
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null pour la constitution du point de départ");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "Le dossier examen courant est null: constitution du point de départ");
    }
    if (((DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen()).getAttributionPrecedente() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution est null pour la constitution du point de départ");
    }
    if (((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionPointDepartIndemnisation().getPji() == null) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_SJRIP", "Le pji de l'attribution precedente est null : constitution du point de départ");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCepa = new Resultat(0);
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    
    ConstitutionPointDepartIndemnisation cepa = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionPointDepartIndemnisation();
    
    ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit((Attribution)dossierExamenCourant, null, false);
    
    cepa.setPji(resultatCalcul.getPji());
    if (Log.isTraceActive(ConstitutionPointDeDepartPourRevision.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionPointDeDepartPourRevision.class, "demarrer", "\t\t******** Fin Parcours ConstitutionPointDeDepartPourRevision ********\n");
    }
    OutilTrace.tracerFinParcours();
    return resultatCepa;
  }
}

/* Location:
 * Qualified Name:     ConstitutionPointDeDepartPourRevision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */