package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.RechercheConditionFaitGenerateur;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ComparateurTemporelsSurDateDebut;
import java.math.BigDecimal;

public class DeterminationConditionFaitGenerateur
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La DemandeAssurance est null pour la détermination du fait générateur.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (Log.isTraceActive(DeterminationConditionFaitGenerateur.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionFaitGenerateur.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionFaitGenerateur.class, "demarrer", "\t\t******** Début Parcours DeterminationFaitGenerateur ********\n");
    }
    Resultat resultatCAPA04 = new Resultat();
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    
    ConditionFaitGenerateur faitGenerateur = RechercheConditionFaitGenerateur.rechercherConditionFaitGenerateur(demande);
    if (faitGenerateur.estSatisfait())
    {
      resultatCAPA04.setEtat(0);
    }
    else
    {
      resultatCAPA04.setEtat(1);
      resultatCAPA04.setMessageErreur(Integer.toString(faitGenerateur.getCodeMotifEchec()));
    }
    alimenterDonneesComplementairesConditionFaitGenerateur(faitGenerateur);
    
    DomLiquidationAssurance.getDemande(p_contexte).getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().setComparateur(new ComparateurTemporelsSurDateDebut());
    if (Log.isTraceActive(DeterminationConditionFaitGenerateur.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionFaitGenerateur.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionFaitGenerateur.class, "demarrer", "\t\t******** Résultat Parcours DeterminationFaitGenerateur ********\n" + resultatCAPA04);
      
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionFaitGenerateur.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionFaitGenerateur.class, "demarrer", "\t\t******** Fin Parcours DeterminationFaitGenerateur ********\n");
    }
    return resultatCAPA04;
  }
  
  private void alimenterDonneesComplementairesConditionFaitGenerateur(ConditionFaitGenerateur p_faitGenerateur)
  {
    if ((p_faitGenerateur != null) && (p_faitGenerateur.getRefusFne() != null)) {
      p_faitGenerateur.setRefusAdhesionFne(String.valueOf(p_faitGenerateur.getRefusFne().intValue()));
    }
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionFaitGenerateur
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */