package fr.unedic.cali.asu.cve13.p01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsr;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;

public class DeterminationDateLimiteIndemnisation
  implements OutilFonctionnel
{
  private static final DureeCalendaire DUREE_INDEMNISATION = new DureeCalendaire(0, 12);
  
  public static DeterminationDateLimiteIndemnisation getInstance()
  {
    return new DeterminationDateLimiteIndemnisation();
  }
  
  public ConstitutionDateLimiteIndemnisation determinerDateLimiteIndemnisation(Demande p_demande)
  {
    DossierExamen dossierExamenCourant = (DossierExamen)p_demande.getDossierExamen();
    ConstitutionDateLimiteIndemnisation constitutionDateLimiteIndemnisation = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionDateLimiteIndemnisation();
    
    Damj dateFGD = dossierExamenCourant.getConditionsAttributionAdmission().getConditionFaitGenerateur().getDateFaitGenerateur();
    
    Damj dateLimiteIndemnisation = dateFGD.lendemain().deplacerVersAvant(DUREE_INDEMNISATION).veille();
    
    constitutionDateLimiteIndemnisation.setDateDebutIndem(dateFGD.lendemain());
    constitutionDateLimiteIndemnisation.setDateLimiteIndem(dateLimiteIndemnisation);
    
    return constitutionDateLimiteIndemnisation;
  }
  
  public ConstitutionDateLimiteIndemnisation determinerDateLimiteIndemnisationBasculeCrpCtp(Demande p_demande)
  {
    DossierExamen dossierExamenCourant = (DossierExamen)p_demande.getDossierExamen();
    ConstitutionDateLimiteIndemnisation constitutionDateLimiteIndemnisation = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionDateLimiteIndemnisation();
    
    Damj dateFGD = dossierExamenCourant.getConditionsAttributionAdmission().getConditionFaitGenerateur().getDateFaitGenerateur();
    
    AttributionSpec attributionCRP = OutilAsr.rechercherAttributionAsrPrecedent(p_demande, p_demande.getDateDepot());
    
    Damj dateLimiteIndemnisation = ((Attribution)attributionCRP).getDateLimiteIndemnisation();
    
    constitutionDateLimiteIndemnisation.setDateDebutIndem(dateFGD.lendemain());
    constitutionDateLimiteIndemnisation.setDateLimiteIndem(dateLimiteIndemnisation);
    
    return constitutionDateLimiteIndemnisation;
  }
}

/* Location:
 * Qualified Name:     DeterminationDateLimiteIndemnisation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */