package fr.unedic.cali.asu.dom;

import fr.unedic.cali.autresdoms.ga.dom.spec.AppartenanceSpec;
import fr.unedic.cali.dom.PeriodeElementaire;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Enumeration;
import java.util.Hashtable;

public class ActiviteProratisee
{
  private AppartenanceSpec m_periodeOrigine;
  private Hashtable m_tableQuantitesProratisees;
  private String m_naturePeriode;
  private String m_raisonSociale;
  
  public ActiviteProratisee()
  {
    m_tableQuantitesProratisees = new Hashtable();
  }
  
  public AppartenanceSpec getPeriodeOrigine()
  {
    if ((m_periodeOrigine instanceof PeriodeElementaire)) {
      return ((PeriodeElementaire)m_periodeOrigine).getPeriodeActiviteOrigine();
    }
    return m_periodeOrigine;
  }
  
  public void setPeriodeOrigine(AppartenanceSpec p_periodeActivite)
  {
    m_periodeOrigine = p_periodeActivite;
  }
  
  public void proratiser(int p_nbJoursInclus)
  {
    int nbJoursTotal = m_periodeOrigine.getPeriode().getDuree();
    
    m_tableQuantitesProratisees.clear();
    Hashtable tableQuantitesTotale = m_periodeOrigine.getListeQuantitesAppartenance();
    for (Enumeration e = tableQuantitesTotale.elements(); e.hasMoreElements();)
    {
      Quantite qteTotale = (Quantite)e.nextElement();
      Unite unite = qteTotale.getUnite();
      Quantite qteIncluse;
      Quantite qteIncluse;
      if (p_nbJoursInclus == nbJoursTotal)
      {
        qteIncluse = new Quantite(qteTotale.getValeur(), qteTotale.getUnite());
      }
      else
      {
        BigDecimal valTotale = qteTotale.getValeur();
        BigDecimal valIncluse = Mathematiques.proratiser(valTotale, new BigDecimal(p_nbJoursInclus), new BigDecimal(nbJoursTotal));
        qteIncluse = new Quantite(valIncluse, unite);
      }
      m_tableQuantitesProratisees.put(unite, qteIncluse);
    }
  }
  
  public Hashtable getListeQuantitesProratisees()
  {
    return m_tableQuantitesProratisees;
  }
  
  public Quantite getQuantiteProratisee(Unite p_unite)
  {
    return (Quantite)m_tableQuantitesProratisees.get(p_unite);
  }
  
  public void putQuantiteProratisee(Quantite p_quantite)
  {
    m_tableQuantitesProratisees.put(p_quantite.getUnite(), p_quantite);
  }
  
  public Quantite getQuantiteProratisee()
  {
    return (Quantite)m_tableQuantitesProratisees.elements().nextElement();
  }
  
  public boolean isDerogationPlafondMensuel()
  {
    return m_periodeOrigine.isDerogationPlafondMensuel();
  }
  
  public String toString()
  {
    return "Activité [" + m_periodeOrigine.getPeriode().getDebut() + " - " + m_periodeOrigine.getPeriode().getFin() + "]" + getQuantiteProratisee();
  }
  
  public String getNaturePeriode()
  {
    return m_naturePeriode;
  }
  
  public void setNaturePeriode(String p_naturePeriode)
  {
    m_naturePeriode = p_naturePeriode;
  }
  
  public String getRaisonSociale()
  {
    return m_raisonSociale;
  }
  
  public void setRaisonSociale(String p_raisonSociale)
  {
    m_raisonSociale = p_raisonSociale;
  }
  
  public int getNatureAppartenance()
  {
    return m_periodeOrigine.getNatureAppartenance();
  }
}

/* Location:
 * Qualified Name:     ActiviteProratisee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */