package fr.unedic.cali.asu.dom;

import fr.unedic.cali.asu.dom.gen.ContexteDemandeGen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class ContexteDemande
  extends ContexteDemandeGen
  implements ContexteDemandeSpec, ObjetPersistantSpec
{
  private static final long serialVersionUID = 1L;
  private transient String m_idPremiereDemandeCsrDansSuspension;
  private transient ActiviteSalarie m_derniereAeCspVolontaire;
  private transient AttributionAssuranceSpec m_attributionAreAdhesionVolontaire;
  private transient AttributionAssuranceSpec m_attributionLieeAFinDeDroit;
  
  public ContexteDemande(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public ContexteDemande() {}
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ContexteDemande copie = (ContexteDemande)p_copie;
    copie.setTypeContexteDemande(getTypeContexteDemande());
    copie.setSousTypeContexteDemande(getSousTypeContexteDemande());
    copie.setIdPremiereDemandeCsrDansSuspension(getIdPremiereDemandeCsrDansSuspension());
    copie.setDerniereAeCspVolontaire(getDerniereAeCspVolontaire());
  }
  
  public String getIdPremiereDemandeCsrDansSuspension()
  {
    return m_idPremiereDemandeCsrDansSuspension;
  }
  
  public void setIdPremiereDemandeCsrDansSuspension(String p_idPremiereDemandeCsrDansSuspension)
  {
    m_idPremiereDemandeCsrDansSuspension = p_idPremiereDemandeCsrDansSuspension;
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public Periode getPeriodeJustifContexte()
  {
    Periode periode = null;
    Damj dateDebutPeriode = getDateDebutJustifContexte();
    Damj dateFinPeriode = getDateFinJustifContexte();
    if ((dateDebutPeriode != null) && (dateFinPeriode != null)) {
      periode = new Periode(dateDebutPeriode, dateFinPeriode);
    }
    return periode;
  }
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void marquerGraphePersistant() {}
  
  public ActiviteSalarie getDerniereAeCspVolontaire()
  {
    return m_derniereAeCspVolontaire;
  }
  
  public void setDerniereAeCspVolontaire(ActiviteSalarie p_derniereAeCspVolontaire)
  {
    m_derniereAeCspVolontaire = p_derniereAeCspVolontaire;
  }
  
  public boolean estContexteDerniereAeCspAdhesionVolontaireForceeAspAdhesionVolontaire()
  {
    return ("ADHVOLARE".equals(getTypeContexteDemande())) || ("ASPVOLSARE".equals(getTypeContexteDemande())) || ("FINASPVOLC".equals(getTypeContexteDemande()));
  }
  
  public boolean estContexteFinAsp()
  {
    return ("FINASP".equals(getTypeContexteDemande())) || ("FINASPVOL".equals(getTypeContexteDemande())) || ("FINASPVOLC".equals(getTypeContexteDemande()));
  }
  
  public AttributionAssuranceSpec getAttributionAreAdhesionVolontaire()
  {
    return m_attributionAreAdhesionVolontaire;
  }
  
  public void setAttributionAreAdhesionVolontaire(AttributionAssuranceSpec p_attributionAreAdhesionVolontaire)
  {
    m_attributionAreAdhesionVolontaire = p_attributionAreAdhesionVolontaire;
  }
  
  public AttributionAssuranceSpec getAttributionLieeAFinDeDroit()
  {
    return m_attributionLieeAFinDeDroit;
  }
  
  public void setAttributionLieeAFinDeDroit(AttributionAssuranceSpec p_attributionLieeAFinDeDroit)
  {
    m_attributionLieeAFinDeDroit = p_attributionLieeAFinDeDroit;
  }
}

/* Location:
 * Qualified Name:     ContexteDemande
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */