package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDeterminationDateExamenPourFps;
import fr.unedic.cali.asu.outilsfonctionnels.OutilVerificationContexteEre;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsuExamenFilEau;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourLigne;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.temps.Damj;

public class EreAtAfdSuiteRejetAsu
  extends EreGammeAsu
{
  private static final long serialVersionUID = 1L;
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (demande.getFormulaire().getDateDepot() != null) {
      setDateDeclenchementExamen(demande.getFormulaire().getDateDepot());
    } else {
      setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    if (getDateEvenement() == null)
    {
      Damj dateExamen = OutilDeterminationDateExamenPourFps.getInstance().getDateIde(demande.getDemandeur(), demande.getFormulaire().getDateDepot());
      
      setDateEvenement(dateExamen);
    }
    return getDateEvenement();
  }
  
  public String getLibelle()
  {
    return "IDE";
  }
  
  public String getLibelleLong()
  {
    return "Demande AT/AFD IDE";
  }
  
  public String getTypeExamen()
  {
    return "ASU_10";
  }
  
  public int getPriorite()
  {
    return 5;
  }
  
  public ObjetMetierSpec copie()
  {
    EreAtAfdSuiteRejetAsu copie = new EreAtAfdSuiteRejetAsu();
    copieElements(copie);
    return copie;
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    OutilVerificationContexteEre.verifierDroitAreEnCours(demande, demande.getDateDeclenchementExamen());
    OutilVerificationContexteEre.verifierDroitApsEnCours(demande, demande.getDateDeclenchementExamen());
    OutilVerificationContexteEre.verifierDroitAtOuAfdEnCours(demande, demande.getDateDeclenchementExamen());
    OutilVerificationContexteEre.verifierPresenceReliquatAre(demande, demande.getDateDeclenchementExamen());
    OutilVerificationContexteEre.verifierPresenceReliquatAps(demande, demande.getDateDeclenchementExamen());
  }
  
  public void verifierContexteExamen(DemandeSpec demande)
    throws ApplicativeException
  {
    OutilVerificationContexteEre.verifierDroitAreEnCours(demande, demande.getDateExamen());
    OutilVerificationContexteEre.verifierDroitApsEnCours(demande, demande.getDateExamen());
    OutilVerificationContexteEre.verifierDroitAtOuAfdEnCours(demande, demande.getDateExamen());
    OutilVerificationContexteEre.verifierPresenceReliquatAre(demande, demande.getDateExamen());
    OutilVerificationContexteEre.verifierPresenceReliquatAps(demande, demande.getDateExamen());
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionPourLigne("ASU_FDS12");
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    return new AffectationDemandeAsuExamenFilEau();
  }
  
  public void determinerContexteDemande(DemandeSpec demande) {}
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {}
}

/* Location:
 * Qualified Name:     EreAtAfdSuiteRejetAsu
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */