package fr.unedic.cali.asu.eur05.p01.calcul.dom;

import fr.unedic.cali.asu.eur05.p01.liquidation.dom.MontantSegmentation;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteMonaitaire;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.List;

public class FormuleMontant
  implements FormuleMontantSpec
{
  private static final BigDecimal NB_JOURS_SEMAINE = new BigDecimal(7);
  private static final BigDecimal NB_JOURS_ANNEE = new BigDecimal(365);
  private static final BigDecimal NB_MOIS_ANNEE = new BigDecimal(12);
  private static final int CODE_ERREUR_POUR_NOMBRE = -1;
  
  public static String getCode()
  {
    return "1";
  }
  
  public MontantBaseSpec calculer(ConstituantsIndemnisation p_constituantsIndemnisation, Damj p_dateCalcul)
    throws CoucheLogiqueException
  {
    ElementBaseIndemnisation eltBaseIndemnisation = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
    
    List listeCoupleMontant = eltBaseIndemnisation.getListeMontant();
    
    Iterator iter = listeCoupleMontant.iterator();
    
    Quantite quantite = new Quantite(0, UniteMonaitaire.EUROS);
    while (iter.hasNext())
    {
      MontantSegmentation montantSegmentation = (MontantSegmentation)iter.next();
      if (p_dateCalcul.estApresOuCoincideAvec(montantSegmentation.getDateEffetSegmentation())) {
        quantite = montantSegmentation.getMontantSegmentation();
      }
    }
    BigDecimal nbJoursSemaine = new BigDecimal(eltBaseIndemnisation.getNombreJourParSemaine());
    BigDecimal nbJoursMois = new BigDecimal(eltBaseIndemnisation.getNombreJourParMois());
    
    BigDecimal frequenceIndemnisation = new BigDecimal(1);
    if ((nbJoursSemaine.intValue() != -1) && (nbJoursSemaine.intValue() != 0)) {
      frequenceIndemnisation = Mathematiques.diviseParDefaut(nbJoursSemaine, NB_JOURS_SEMAINE);
    }
    if ((nbJoursMois.intValue() != -1) && (nbJoursMois.intValue() != 0)) {
      frequenceIndemnisation = Mathematiques.diviseParDefaut(nbJoursMois.multiply(NB_MOIS_ANNEE), NB_JOURS_ANNEE);
    }
    BigDecimal quantiteEuros = quantite.getValeur().multiply(frequenceIndemnisation).setScale(2, 4);
    quantite = new Quantite(quantiteEuros, UniteMonaitaire.EUROS);
    
    Montant montant = new Montant(quantite);
    return montant;
  }
  
  public void setFormuleMontantDroitAssocie(FormuleMontantSpec p_formuleMontantDroitAssocie) {}
  
  public void setFormuleMontantApplicable(int p_formuleMontantApplicable) {}
}

/* Location:
 * Qualified Name:     FormuleMontant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */