package fr.unedic.cali.asu.fabriques;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionListeEre;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionListeEreConvention2017;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourLigne;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreAttributionEnCoursIndemnisationPourDate;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Temporel;

public class FabriqueConstitutionListeEre
{
  public static ConstitutionListeEre getOutilConstitutionListeEre(Damj datePivot, Demande demande)
    throws CoucheLogiqueException
  {
    ConstitutionListeEre outil;
    ConstitutionListeEre outil;
    if ((datePivot.estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("Date de debut du 2eme changement convention 2017"))) && (!estEnContexteChevauchementSpectacle(demande))) {
      outil = ConstitutionListeEreConvention2017.getInstance();
    } else {
      outil = ConstitutionListeEre.getInstance();
    }
    return outil;
  }
  
  public static boolean estEnContexteChevauchementSpectacle(Demande demande)
    throws CoucheLogiqueException
  {
    boolean retour = false;
    if (demande != null)
    {
      IndividuSpec individu = demande.getDemandeur();
      
      Chronologie chronoParticipantes = ConstitutionListeEre.getInstance().determinerChronologiePourDeterminationContexte(demande);
      if ((chronoParticipantes != null) && (!chronoParticipantes.estVide()))
      {
        Damj dateRecherche = chronoParticipantes.premierElement().getDateFin().lendemain();
        
        FiltreCaliSpec filtreAttributionSpectacle = getFiltreAttributionSpectacle(dateRecherche);
        
        Chronologie listeAttributionsSpectacle = OutilRecherche.rechercherDecisionsPrecedentes(individu.getChronoDemandeAssurance(), Damj.FIN_DES_TEMPS, filtreAttributionSpectacle);
        
        retour = !listeAttributionsSpectacle.estVide();
      }
    }
    return retour;
  }
  
  protected static FiltreCaliSpec getFiltreAttributionSpectacle(Damj dateRecherche)
  {
    FiltreOU filtreSpectacle = new FiltreOU();
    filtreSpectacle.ajouterFiltre(new FiltreDecisionPourLigne("ASU_SSP07"));
    filtreSpectacle.ajouterFiltre(new FiltreDecisionPourLigne("ASU_FDS12"));
    filtreSpectacle.ajouterFiltre(new FiltreDecisionPourLigne("ASU_SPE02"));
    
    FiltreET filtreAttributionSpectacle = new FiltreET();
    filtreAttributionSpectacle.ajouterFiltre(new FiltreAttributionStandardAssurance(false, true, false, false, null));
    filtreAttributionSpectacle.ajouterFiltre(filtreSpectacle);
    filtreAttributionSpectacle.ajouterFiltre(new FiltreAttributionEnCoursIndemnisationPourDate(dateRecherche));
    return filtreAttributionSpectacle;
  }
}

/* Location:
 * Qualified Name:     FabriqueConstitutionListeEre
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */