package fr.unedic.cali.asu.fds12.p03.liquidation.parcours;

import fr.pe.cali.reglementaire.regles.assurance.cep.delaisreports.outils.spec.IOutilConstitutionDelaisReportsSpectacle;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.fps.liquidation.outilsfonctionnels.convention17.OutilDelaisReport;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.OutilDeterminationDelaisReportSpec;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.ParcoursConstitutionDelaisReportsPourReprise;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class ParcoursConstitutionDelaisReportsPourRepriseAfd17
  extends ParcoursConstitutionDelaisReportsPourReprise
{
  protected OutilDeterminationDelaisReportSpec getOutilDeterminationDelaisReport()
  {
    return OutilDelaisReport.getInstance();
  }
  
  protected void determinerReliquatFranchiseSalaire(Contexte contexte)
  {
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    ResultatExecutionCalculSpec resultatCalcul = dom.getResultatExecutionCalculDroitPrecedent();
    Quantite reliquat = resultatCalcul.getReliquatFranchiseSalaire();
    Periode periodeApplication = resultatCalcul.getPeriodeApplicationFranchisesSalaire();
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    Attribution attribution = (Attribution)demande.getAttribution();
    int reliquatRestant = calculerReliquatFranchise(attribution, reliquat, periodeApplication);
    ConstitutionDelaisReport cep = attribution.getConstitutionDelaisReport();
    cep.setNbJoursCarenceStandard(reliquatRestant);
  }
  
  protected void determinerReliquatFranchiseCP(Contexte contexte)
  {
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    ResultatExecutionCalculSpec resultatCalcul = dom.getResultatExecutionCalculDroitPrecedent();
    Quantite reliquat = resultatCalcul.getReliquatFranchiseCP();
    Periode periodeApplication = resultatCalcul.getPeriodeApplicationFranchisesCP();
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    Attribution attribution = (Attribution)demande.getAttribution();
    int reliquatRestant = calculerReliquatFranchise(attribution, reliquat, periodeApplication);
    ConstitutionDelaisReport cep = attribution.getConstitutionDelaisReport();
    cep.setFranchiseCongesPayes(reliquatRestant);
  }
  
  protected int calculerReliquatFranchise(Attribution attribution, Quantite reliquat, Periode periodeApplication)
  {
    IOutilConstitutionDelaisReportsSpectacle outil = recupererOutilReglementaire(attribution);
    int reliquatFranchise = 0;
    Damj dateAttribution = attribution.getDateAttribution();
    if (reliquat != null) {
      reliquatFranchise = reliquat.getValeurEntiere();
    }
    return outil.calculerReliquatFranchise(reliquatFranchise, periodeApplication, dateAttribution);
  }
}

/* Location:
 * Qualified Name:     ParcoursConstitutionDelaisReportsPourRepriseAfd17
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */