package fr.unedic.cali.asu.migration.graphes;

import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.autresdoms.cohab.dom.CodesErreursMigration;
import fr.unedic.cali.dom.ClassementAdministratif;
import fr.unedic.cali.dom.ClassementAdministratifSpec;
import fr.unedic.cali.dom.ClassementCompetenceSecteurPublic;
import fr.unedic.cali.dom.ClassementSansObjet;
import fr.unedic.cali.dom.ClassementSansSuite;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.Prescription;
import fr.unedic.cohabitation.sigma.migration.dom.DecisionMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeV1;
import java.util.Collection;

public class GrapheClassementAdministratif
  extends GrapheAssurance
{
  protected DemandeSpec construireGraphe(DemandeMigreeV1 p_demandeV1)
  {
    DemandeSpec demande = null;
    
    DemandeMigreeAsuV1 demandeTemporaireSigma = (DemandeMigreeAsuV1)p_demandeV1;
    
    demande = super.construireGraphe(p_demandeV1);
    
    demande.setClassementAdministratif(creerClassementAdministratif(demande, demandeTemporaireSigma));
    
    return demande;
  }
  
  public DemandeMigreeV1 lireDonnees(DemandeSpec p_demande)
  {
    DemandeMigreeV1 demandeLue = super.lireDonnees(p_demande);
    
    lireClassementAdministratif(p_demande, demandeLue);
    
    return demandeLue;
  }
  
  protected ClassementAdministratif creerClassementAdministratif(DemandeSpec p_demande, DemandeMigreeAsuV1 p_demandeTemporaireSource)
  {
    ClassementAdministratif classementAdministratif = null;
    if (p_demandeTemporaireSource.getClassementAdministratif() != null) {
      if (p_demandeTemporaireSource.getClassementAdministratif().equalsIgnoreCase("SO"))
      {
        classementAdministratif = new ClassementSansObjet();
      }
      else if (p_demandeTemporaireSource.getClassementAdministratif().equalsIgnoreCase("CS"))
      {
        classementAdministratif = new ClassementSansSuite();
      }
      else if (p_demandeTemporaireSource.getClassementAdministratif().equalsIgnoreCase("PS"))
      {
        classementAdministratif = new Prescription();
      }
      else if (p_demandeTemporaireSource.getClassementAdministratif().equalsIgnoreCase("SP"))
      {
        classementAdministratif = new ClassementCompetenceSecteurPublic();
        
        DecisionMigreeAsuV1 decisionMigreeAsuV1 = p_demandeTemporaireSource.getDecision();
        ((ClassementCompetenceSecteurPublic)classementAdministratif).setMotifNotification(decisionMigreeAsuV1.getCodeRejet());
      }
      else
      {
        getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_HG_CLASS_ADM"));
      }
    }
    return classementAdministratif;
  }
  
  protected void lireClassementAdministratif(DemandeSpec p_demande, DemandeMigreeV1 p_demandeLue)
  {
    ClassementAdministratifSpec classement = p_demande.getClassementAdministratif();
    if ((classement instanceof ClassementSansObjet)) {
      p_demandeLue.setClassementAdministratif("SO");
    } else if ((classement instanceof ClassementSansSuite)) {
      p_demandeLue.setClassementAdministratif("CS");
    } else if ((classement instanceof Prescription)) {
      p_demandeLue.setClassementAdministratif("PS");
    }
  }
  
  protected ObjectifExamen creerObjectifDecision(DemandeMigreeAsuV1 p_demandeTemporaireSource)
  {
    return null;
  }
}

/* Location:
 * Qualified Name:     GrapheClassementAdministratif
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */