package fr.unedic.cali.asu.occasionnel.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.occasionnel.outilsfonctionnels.CriteresTraitementPopulation;
import fr.unedic.cali.occasionnel.outilsfonctionnels.ResultatTraitementPopulation;
import fr.unedic.cali.occasionnel.outilsfonctionnels.TraitementPopulationSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Chronologie;

public class TraitementPopulationRepriseStockNCSpectacle17SI1
  implements TraitementPopulationSpec
{
  private static final Quantite quantiteAffiSuffisante = new Quantite(338, UniteAffiliation.HEURE_TRAVAIL);
  private static final Quantite quantiteAffiNonSuffisante = new Quantite(337, UniteAffiliation.HEURE_TRAVAIL);
  
  public ResultatTraitementPopulation effectuerTraitement(CriteresTraitementPopulation criteres)
    throws ApplicativeException
  {
    IndividuSpec individu = criteres.getIndividu();
    Chronologie demandesAssurances = individu.getChronoDemandeAssurance();
    demandesAssurances.iterer();
    while (demandesAssurances.encoreSuivant())
    {
      Demande demandeCourante = (Demande)demandesAssurances.elementSuivant();
      if ((estDemandeEnEntreeCra(demandeCourante)) && (demandeCourante.getDonneesTemporaires().getQuantiteAffiliation() == null)) {
        demandeCourante.getDonneesTemporaires().setQuantiteAffiliation(determinerQuantite(demandeCourante.getDonneesTemporaires()));
      }
    }
    return new ResultatTraitementPopulation();
  }
  
  private boolean estDemandeEnEntreeCra(Demande demande)
  {
    return OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ENTREECRA");
  }
  
  private Quantite determinerQuantite(DonneesTemporaires donneesForcees)
  {
    Quantite quantiteARetourner;
    Quantite quantiteARetourner;
    if ((donneesForcees.isConditionAffiliationSatisfaiteForcee() != null) && (donneesForcees.isConditionAffiliationSatisfaiteForcee().booleanValue())) {
      quantiteARetourner = quantiteAffiSuffisante;
    } else {
      quantiteARetourner = quantiteAffiNonSuffisante;
    }
    return quantiteARetourner;
  }
}

/* Location:
 * Qualified Name:     TraitementPopulationRepriseStockNCSpectacle17SI1
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */