package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.ConditionChomageInvolontaireSpec;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.ClassementAdministratif;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourNatureDecision;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreReexamenSurDemande;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreValideeSurDecision;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;

public final class DetectionChomageLegitime
  implements OutilFonctionnel
{
  private static final DetectionChomageLegitime SINGLETON = new DetectionChomageLegitime();
  
  public static DetectionChomageLegitime getInstance()
  {
    return SINGLETON;
  }
  
  public boolean estAeDvRejetOuNonDecisionne(IndividuSpec individu, ActiviteSalarie activiteSalarieDemission)
  {
    boolean estNonValide = true;
    FiltreET filtresPoursuites = new FiltreET();
    filtresPoursuites.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
    filtresPoursuites.ajouterFiltre(new FiltreValideeSurDecision());
    filtresPoursuites.ajouterFiltre(new FiltreDecisionPourNatureDecision(49));
    
    Chronologie listePoursuites = OutilRecherche.rechercherDecisionsSuivantes(individu.getChronoDemandeAssurance(), activiteSalarieDemission.getDateFin(), filtresPoursuites);
    
    listePoursuites.iterer();
    while ((listePoursuites.encoreSuivant()) && (estNonValide))
    {
      DossierExamenAssuranceSpec decision = (DossierExamenAssuranceSpec)listePoursuites.elementSuivant();
      if (estPoursuiteLieeAvecActiviteSalariee(decision, activiteSalarieDemission)) {
        estNonValide = false;
      }
    }
    if (estNonValide)
    {
      DemandeSpec demandeDvFilEau = OutilRecherche.rechercherDemandeSuivante(individu.getChronoDemandeAssurance(), activiteSalarieDemission.getDateFin(), new FiltreDemandePourERE("ASU_30"));
      if ((demandeDvFilEau != null) && (demandeDvFilEau.getClassementAdministratif() != null) && ("SO".equals(demandeDvFilEau.getClassementAdministratif().getTypeClassement()))) {
        estNonValide = false;
      }
    }
    return estNonValide;
  }
  
  private boolean estPoursuiteLieeAvecActiviteSalariee(DossierExamenAssuranceSpec decision, ActiviteSalarie activiteSalarieDemission)
  {
    boolean estActiviteLegitimeParPoursuite = false;
    if (decision.getConditionChomageInvolontaire() != null)
    {
      Damj dateAEDV = decision.getConditionChomageInvolontaire().getDateFctAeDV();
      if (dateAEDV != null) {
        estActiviteLegitimeParPoursuite = dateAEDV.coincideAvec(activiteSalarieDemission.getDateFin());
      }
    }
    return estActiviteLegitimeParPoursuite;
  }
}

/* Location:
 * Qualified Name:     DetectionChomageLegitime
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */