package fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee;

import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.asu.dom.SituationDemandeur;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.fabrique.FabriqueStrategieAffiliationLiquidationSimplifiee;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.strategie.StrategieAffiliationLiquidationSimplifieeSpec;
import fr.unedic.cali.asu.parcours.DomLiquidationSimplifiee;
import fr.unedic.cali.asu.produits.liquidation.dom.ParametreLiquidationSimplifiee;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesPRA;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public final class Parametres
{
  public static final int AGE_50_ANS = 50;
  public static final int AGE_57_ANS = 57;
  public static final int INF_50ANS = 1;
  public static final int SUP_EGAL_50ANS = 2;
  public static final int SUP_EGAL_57ANS = 3;
  
  public static void chargerParametres(Contexte contexte)
  {
    DomLiquidationSimplifiee dom = (DomLiquidationSimplifiee)contexte.getDonnees();
    dom.setListeParametreLiquidationSimplifiee(chargerParametres());
  }
  
  public static List<ParametreLiquidationSimplifiee> chargerParametres()
  {
    List<DecorReglementaire> listeDecors = AccesDecorReglementaire.getInstance().getListeDecors();
    Iterator<DecorReglementaire> iter = listeDecors.iterator();
    ProduitAsuSpec produitParDefaut = null;
    ArrayList<ParametreLiquidationSimplifiee> listeParametres = new ArrayList();
    while (iter.hasNext())
    {
      DecorReglementaire decor = (DecorReglementaire)iter.next();
      if ((produitParDefaut == null) || (!produitParDefaut.estIdentiqueAuProduit(decor.getProduitParDefaut()))) {
        produitParDefaut = (ProduitAsuSpec)decor.getProduitParDefaut();
      }
      List listeParametresParProduit = produitParDefaut.recupererParametresPourLiquidationSimplifiee(produitParDefaut.getPeriodeValidite());
      if (listeParametresParProduit != null) {
        listeParametres.addAll(listeParametresParProduit);
      }
    }
    return listeParametres;
  }
  
  public static ParametreLiquidationSimplifiee determinerPraEligible(SituationDemandeur situation, Damj dateFCT, IndividuSpec individu)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(situation.getDateInscription());
    StrategieAffiliationLiquidationSimplifieeSpec strategie = (StrategieAffiliationLiquidationSimplifieeSpec)FabriqueStrategieAffiliationLiquidationSimplifiee.getInstance().getStrategie(critere);
    
    ParametreLiquidationSimplifiee param = strategie.determinerPra(situation, dateFCT, individu);
    
    return param;
  }
  
  public static CleAccesPRA construireCleAccesPRA(DureeCalendaire age, Damj dateFCT)
  {
    String nomReglement = "RG";
    int codeAge = getCodeAge(age);
    int[] listeCodeAge = { codeAge };
    return new CleAccesPRA(nomReglement, listeCodeAge, dateFCT);
  }
  
  private static int getCodeAge(DureeCalendaire age)
  {
    if (age.getAnnees() < 50) {
      return 1;
    }
    if (age.getAnnees() >= 57) {
      return 3;
    }
    return 2;
  }
}

/* Location:
 * Qualified Name:     Parametres
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */