package fr.unedic.cali.asu.parcours;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.DomLiquidationDemandeDude;
import fr.unedic.cali.parcours.LireDemandePrestation;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;

public class LireDemandePrestationDude
  extends LireDemandePrestation
{
  public void controleDonneesEnEntreeDeService(Contexte p_context)
    throws CoucheLogiqueException
  {
    if (p_context != null)
    {
      String idDemandeV1 = getIdentifiantDemandeV1(p_context);
      if ((idDemandeV1 == null) || (idDemandeV1.equals(""))) {
        throw new PasAssezInformationException("HG_PR_CALI_L_ERR_CONTEXTE", "la demande v1 n'a pas de correspondance v2.");
      }
    }
    else
    {
      throw new PasAssezInformationException("HG_PR_CALI_L_ERR_CONTEXTE_ABSENT", "Le contexte ne doit pas être null");
    }
    super.controleDonneesEnEntreeDeService(p_context);
  }
  
  private String getIdentifiantDemandeV1(Contexte p_contexte)
  {
    return ((DomLiquidationDemandeDude)p_contexte.getDonnees()).getIdDemandeV1();
  }
  
  public Resultat demarrerParcours(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    DomLiquidationDemandeDude dom = (DomLiquidationDemandeDude)p_contexte.getDonnees();
    dom.setIdDemande(rechercherDemandeAssurance(dom.getIdDemandeV1(), dom.getIndividu()));
    return super.demarrerParcours(p_contexte);
  }
  
  private String rechercherDemandeAssurance(String p_referenceExterne, IndividuSpec p_individu)
  {
    Demande demandeRecherche = null;
    boolean demandeTrouve = false;
    Chronologie listeDemandeAssurance = p_individu.getChronoDemandeAssurance();
    if (!listeDemandeAssurance.estVide())
    {
      listeDemandeAssurance.iterer();
      do
      {
        Demande demandeAssuranceIndividu = (Demande)listeDemandeAssurance.elementSuivant();
        if (demandeAssuranceIndividu.getFormulaire().getReferenceExterne().equalsIgnoreCase(p_referenceExterne))
        {
          demandeRecherche = demandeAssuranceIndividu;
          demandeTrouve = true;
        }
      } while ((!demandeTrouve) && (listeDemandeAssurance.encoreSuivant()));
    }
    return demandeRecherche != null ? demandeRecherche.getIdentifiant() : "";
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu p_individu)
  {
    return 2;
  }
  
  protected void alimenterAgregatGaec(Individu p_individu, String p_idDemande)
  {
    if (p_individu != null) {
      p_individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(0);
    }
  }
  
  protected void controlerPostTraitement(Individu p_individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(p_individu.getDonneesChargementGaec().getAppelGaecReduit(), 0);
  }
}

/* Location:
 * Qualified Name:     LireDemandePrestationDude
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */