package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursServiceAbstrait;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourProduit;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import java.util.ListIterator;

public class ParcoursDeterminationContexteParticulier
  extends ParcoursServiceAbstrait
{
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    IndividuSpec individu = getIndividu(contexte);
    DomLiquidationDemande dom = (DomLiquidationDemande)contexte.getDonnees();
    if (dom.getDemandeSpec() == null)
    {
      DemandeAssuranceSpec demandeAssuranceCourante = (DemandeAssuranceSpec)individu.rechercherDemande(getIdDemande(contexte));
      dom.setDemande(demandeAssuranceCourante);
      if (demandeAssuranceCourante == null) {
        throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "Une demande est obligatoire pour ce produit.", null);
      }
    }
  }
  
  public Resultat demarrerParcours(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    DemandeAssuranceSpec demandeAssuranceCourante = (DemandeAssuranceSpec)((DomLiquidationDemande)contexte.getDonnees()).getDemandeSpec();
    
    DetectionContexteParticulierLiquidation.getInstance().determinerContexteParticulierLiquidationAssurance(demandeAssuranceCourante);
    
    Resultat resultatContexte = creationResultatParcours();
    FiltreOU filtreProduitChomageSansRupture = new FiltreOU();
    filtreProduitChomageSansRupture.ajouterFiltre(new FiltreDecisionPourProduit(19));
    filtreProduitChomageSansRupture.ajouterFiltre(new FiltreDecisionPourProduit(33));
    Chronologie chrono = OutilRecherche.rechercherDemandesPrecedentes(demandeAssuranceCourante.getChronologieDemandesAssuranceSansCourante(), demandeAssuranceCourante, filtreProduitChomageSansRupture);
    
    ListIterator it = chrono.iterer();
    while (it.hasNext())
    {
      DemandeAssuranceSpec demandeCourante = (DemandeAssuranceSpec)it.next();
      DetectionContexteParticulierLiquidation.getInstance().determinerContexteParticulierLiquidationAssurance(demandeCourante);
    }
    OutilTrace.tracerFinParcours();
    return resultatContexte;
  }
  
  private Resultat creationResultatParcours()
  {
    Resultat resultat = new Resultat();
    resultat.setEtat(0);
    return resultat;
  }
  
  private String getIdDemande(Contexte contexte)
  {
    return ((DomLiquidationDemande)contexte.getDonnees()).getIdDemande();
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu individu)
  {
    return 0;
  }
  
  protected void alimenterAgregatGaec(Individu individu, String idDemande)
  {
    individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(0);
  }
  
  protected void controlerPostTraitement(Individu individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(individu.getDonneesChargementGaec().getAppelGaecReduit(), 0);
  }
}

/* Location:
 * Qualified Name:     ParcoursDeterminationContexteParticulier
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */