package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionReglementApplicable;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.PasAssezInformationException;

public class DeterminationReglementApplicable
{
  public static DeterminationReglementApplicable getInstance()
  {
    return new DeterminationReglementApplicable();
  }
  
  public ConstitutionReglementApplicable determinerReglementApplicable(Demande demande)
    throws PasAssezInformationException, CoucheLogiqueException
  {
    ConstitutionReglementApplicable reglementApplicable = ((DossierExamen)demande.getDossierExamen()).getConstitutionElementsActifs().createConstitutionReglementApplicable();
    
    Reglement reglement = ((DossierAffectation)demande.getDossierAffectation()).getReglementPeriodeValidationProduit();
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ASPSJACENT")) {
      reglement = ((ActiviteSalarie)demande.getDossierAffectationAdmission().getSinistre()).getReglement();
    }
    reglementApplicable.setReglement(reglement);
    
    return reglementApplicable;
  }
  
  public ConstitutionReglementApplicable determinerReglementApplicablePourReprise(Demande p_demande)
    throws PasAssezInformationException, CoucheLogiqueException
  {
    ConstitutionReglementApplicable reglementApplicable = ((DossierExamen)p_demande.getDossierExamen()).getConstitutionElementsActifs().createConstitutionReglementApplicable();
    
    ReglementApplicableSpec reglementApplicableAttributionPrecedente = ((DossierExamen)p_demande.getDossierExamen()).getAttributionPrecedente().getReglementApplicable();
    if (reglementApplicableAttributionPrecedente != null) {
      reglementApplicableAttributionPrecedente.copieElements(reglementApplicable);
    }
    return reglementApplicable;
  }
  
  public ConstitutionReglementApplicable determinerReglementApplicablePourFinAsr(Demande p_demande)
    throws PasAssezInformationException, CoucheLogiqueException
  {
    ConstitutionReglementApplicable reglementApplicable = ((DossierExamen)p_demande.getDossierExamen()).getConstitutionElementsActifs().createConstitutionReglementApplicable();
    
    DossierExamen dossierExamenCourant = (DossierExamen)p_demande.getDossierAffectation().getDossierExamen();
    ConditionFaitGenerateur conditionFaitGenerateur = (ConditionFaitGenerateur)dossierExamenCourant.getConditionFaitGenerateur();
    ActiviteSalarie activiteSalarie = conditionFaitGenerateur.getPeriodeFaitGenerateur();
    Reglement reglement = activiteSalarie.getReglement();
    
    reglementApplicable.setReglement(reglement);
    
    return reglementApplicable;
  }
}

/* Location:
 * Qualified Name:     DeterminationReglementApplicable
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */