package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import java.math.BigDecimal;

public class RechercheConditionMontantNonNul
  implements OutilFonctionnel
{
  private static final BigDecimal MONTANT_ZERO = new BigDecimal("0.00");
  
  public static RechercheConditionMontantNonNul getInstance()
  {
    return new RechercheConditionMontantNonNul();
  }
  
  public ResultatElementDroit rechercherConditionMontantNonNul(Demande p_demande)
    throws CoucheLogiqueException
  {
    ResultatElementDroit resultatElementDroit = new ResultatElementDroit();
    resultatElementDroit.setEtatSatisfait(false);
    
    AttributionAssuranceSpec attributionAssurance = p_demande.getAttribution();
    
    Quantite montantJournalier = attributionAssurance.getMontantJournalierBrut();
    
    BigDecimal valeurMontantJournalier = null;
    if (montantJournalier != null) {
      valeurMontantJournalier = Mathematiques.arrondiASup(montantJournalier.getValeur(), 2);
    }
    if ((valeurMontantJournalier != null) && (valeurMontantJournalier.compareTo(MONTANT_ZERO) > 0))
    {
      resultatElementDroit.setEtatSatisfait(true);
    }
    else
    {
      resultatElementDroit.setEtatSatisfait(false);
      resultatElementDroit.setCodeMotifEchec(181);
    }
    return resultatElementDroit;
  }
}

/* Location:
 * Qualified Name:     RechercheConditionMontantNonNul
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */