package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDuree;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.UniteDuree;
import java.math.BigDecimal;

public class DeterminationDureeEffective
  implements OutilFonctionnel
{
  public static final Unite UNITE_DEFAUT = UniteDuree.JOUR;
  public static final BigDecimal ZERO = new BigDecimal(0);
  
  public static ConstitutionDurees determinerDureeEffective(Demande p_demande)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    return determinerDureeEffective(p_demande, false);
  }
  
  public static ConstitutionDurees determinerDureeEffectivePourReprise(Demande p_demande)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    return determinerDureeEffective(p_demande, true);
  }
  
  private static ConstitutionDurees determinerDureeEffective(Demande p_demande, boolean p_pourReprise)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    DossierExamen dossierExamenCourant = (DossierExamen)p_demande.getDossierExamen();
    ConstitutionDurees constitutionDurees = dossierExamenCourant.getConstitutionDurees();
    
    Quantite qteDureeImputation = new Quantite(ZERO, UNITE_DEFAUT);
    
    Quantite qteDureeTheorique = constitutionDurees.getDureeTheorique();
    
    Damj pji = dossierExamenCourant.getConstitutionPointDepartIndemnisation().getPointDepartIndemnisation();
    
    constitutionDurees.setDureeEffective(ConstitutionDuree.calculerDureeEffective(p_demande.getDemandeur(), pji, qteDureeTheorique, qteDureeImputation, UNITE_DEFAUT, true));
    
    return constitutionDurees;
  }
}

/* Location:
 * Qualified Name:     DeterminationDureeEffective
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */