package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules;

import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.spec.ParametresCarenceIndemnisationStandardSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.PasAssezInformationException;
import java.math.BigDecimal;

public class FormuleCarenceIndemnisationStandardConvention2014
  implements FormuleTexteSpec
{
  private static final String PARAM_FORFAIT = "%FORFAIT%";
  private static final String FORMULE = "[(SALAIRES PRC / Smic mensuel) x (SJM / (3 x Smic journalier))] - %FORFAIT% jours";
  
  private void verifierParametresPourCalcul(ParametresFormuleSpec parametresFormule)
    throws PasAssezInformationException
  {
    if ((parametresFormule instanceof ParametresCarenceIndemnisationStandardConvention2014))
    {
      ParametresCarenceIndemnisationStandardConvention2014 parametresCarence = (ParametresCarenceIndemnisationStandardConvention2014)parametresFormule;
      if (parametresCarence.getMontantSalaires() == null) {
        throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "La somme des salaires n'est pas spécifiée.");
      }
      if (parametresCarence.getMontantSMICHoraire() == null) {
        throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "Le montant du SMIC Horaire n'est pas spécifié.");
      }
      if (parametresCarence.getMontantSalaireJournalierMoyen() == null) {
        throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "Le Salaire Journalier Moyen n'est pas spécifié.");
      }
      if (parametresCarence.getNombreHeuresTravaillees() == null) {
        throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "Le nombre d'heures travaillées n'est pas spécifié.");
      }
    }
    else
    {
      throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "Les paramètres passés en paramètre sont incompatibles avec le calcul de la formule souhaitée.");
    }
  }
  
  public Object appliquerFormule(ParametresFormuleSpec parametresFormule)
    throws PasAssezInformationException
  {
    verifierParametresPourCalcul(parametresFormule);
    
    ParametresCarenceIndemnisationStandardConvention2014 parametresCarence = (ParametresCarenceIndemnisationStandardConvention2014)parametresFormule;
    
    BigDecimal montantRelatifSmicHoraire = parametresCarence.getFacteurMultiplicationSMICHoraire().multiply(parametresCarence.getMontantSMICHoraire());
    
    BigDecimal montantRelatifNombreHeuresTravaillees = parametresCarence.getNombreHeuresTravaillees().multiply(montantRelatifSmicHoraire);
    BigDecimal montantNumerateur = parametresCarence.getMontantSalaires().subtract(montantRelatifNombreHeuresTravaillees);
    
    BigDecimal montantDenominateur = parametresCarence.getMontantSalaireJournalierMoyen().min(parametresCarence.getMontantPlafondSJM());
    
    BigDecimal nombreJoursDiffereStandard = Mathematiques.diviseParDefaut(montantNumerateur, montantDenominateur);
    
    BigDecimal nombreJoursArrondi = Mathematiques.tronque(nombreJoursDiffereStandard, 0);
    BigDecimal nombreJoursDiffereStandardResultat = nombreJoursArrondi.max(parametresCarence.getQuantiteJourMin());
    
    return new QuantiteJour(nombreJoursDiffereStandardResultat);
  }
  
  public String getFormule(ParametresFormuleSpec parametresFormule)
  {
    ParametresCarenceIndemnisationStandardSpec parametresCarence = (ParametresCarenceIndemnisationStandardSpec)parametresFormule;
    return "[(SALAIRES PRC / Smic mensuel) x (SJM / (3 x Smic journalier))] - %FORFAIT% jours".replaceAll("%FORFAIT%", String.valueOf(parametresCarence.getForfait().intValue()));
  }
}

/* Location:
 * Qualified Name:     FormuleCarenceIndemnisationStandardConvention2014
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */